--- old/usr/src/lib/libm/amd64/src/libm_inlines.h	2019-06-06 20:37:28.267902504 +0000
+++ new/usr/src/lib/libm/amd64/src/libm_inlines.h	2019-06-06 20:37:28.284778294 +0000
@@ -37,7 +37,6 @@
 #define	_LIBM_INLINES_H
 
 #ifdef __GNUC__
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -215,7 +214,5 @@
 #ifdef __cplusplus
 }
 #endif
-
 #endif  /* __GNUC__ */
-
 #endif /* _LIBM_INLINES_H */
--- old/usr/src/lib/libm/common/C/_SVID_error.c	2019-06-06 20:37:28.730885228 +0000
+++ new/usr/src/lib/libm/common/C/_SVID_error.c	2019-06-06 20:37:28.747121709 +0000
@@ -18,22 +18,24 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"			/* __xpg6 */
 #include <stdio.h>
-#include <float.h>		/* DBL_MAX, DBL_MIN */
-#include <unistd.h>		/* write */
+#include <float.h>			/* DBL_MAX, DBL_MIN */
+#include <unistd.h>			/* write */
 #if defined(__x86)
 #include <ieeefp.h>
-#undef	fp_class
+#undef  fp_class
 #define	fp_class	fpclass
 #define	fp_quiet	FP_QNAN
 #endif
@@ -41,7 +43,7 @@
 #undef fflush
 #include <sys/isa_defs.h>
 
-/* INDENT OFF */
+
 /*
  * Report libm exception error according to System V Interface Definition
  * (SVID).
@@ -94,13 +96,12 @@
  *	46-- nextafter overflow
  *	47-- scalb(x,inf)
  */
-/* INDENT ON */
 
 static double setexception(int, double);
 
 static const union {
-	unsigned	x[2];
-	double		d;
+	unsigned x[2];
+	double d;
 } C[] = {
 #ifdef _LITTLE_ENDIAN
 	{ 0xffffffff, 0x7fffffff },
@@ -111,29 +112,32 @@
 #endif
 };
 
-#define	NaN	C[0].d
-#define	PI_RZ	C[1].d
+#define	NaN		C[0].d
+#define	PI_RZ		C[1].d
 
-#define	__HI(x)	((unsigned *)&x)[HIWORD]
-#define	__LO(x)	((unsigned *)&x)[LOWORD]
-#undef	Inf
-#define	Inf	HUGE_VAL
+#define	__HI(x)		((unsigned *)&x)[HIWORD]
+#define	__LO(x)		((unsigned *)&x)[LOWORD]
+#undef  Inf
+#define	Inf		HUGE_VAL
 
 double
-_SVID_libm_err(double x, double y, int type) {
-	struct exception	exc;
-	double			t, w, ieee_retval = 0;
-	enum version		lib_version = _lib_version;
-	int			iy;
+_SVID_libm_err(double x, double y, int type)
+{
+	struct exception exc;
+	double t, w, ieee_retval = 0;
+	enum version lib_version = _lib_version;
+	int iy;
 
 	/* force libm_ieee behavior in SUSv3 mode */
 	if ((__xpg6 & _C99SUSv3_math_errexcept) != 0)
 		lib_version = libm_ieee;
-	if (lib_version == c_issue_4) {
+
+	if (lib_version == c_issue_4)
 		(void) fflush(stdout);
-	}
+
 	exc.arg1 = x;
 	exc.arg2 = y;
+
 	switch (type) {
 	case 1:
 		/* acos(|x|>1) */
@@ -141,14 +145,16 @@
 		exc.name = "acos";
 		ieee_retval = setexception(3, 1.0);
 		exc.retval = 0.0;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "acos: DOMAIN error\n", 19);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 2:
 		/* asin(|x|>1) */
@@ -156,14 +162,16 @@
 		exc.name = "asin";
 		exc.retval = 0.0;
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "asin: DOMAIN error\n", 19);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 3:
 		/* atan2(+-0,+-0) */
@@ -171,59 +179,70 @@
 		exc.arg2 = x;
 		exc.type = DOMAIN;
 		exc.name = "atan2";
-		ieee_retval = copysign(1.0, x) == 1.0 ? y :
-			copysign(PI_RZ + DBL_MIN, y);
+		ieee_retval = copysign(1.0, x) == 1.0 ? y : copysign(PI_RZ +
+		    DBL_MIN, y);
 		exc.retval = 0.0;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "atan2: DOMAIN error\n", 20);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 4:
 		/* hypot(finite,finite) overflow */
 		exc.type = OVERFLOW;
 		exc.name = "hypot";
 		ieee_retval = Inf;
+
 		if (lib_version == c_issue_4)
 			exc.retval = HUGE;
 		else
 			exc.retval = HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 5:
 		/* cosh(finite) overflow */
 		exc.type = OVERFLOW;
 		exc.name = "cosh";
 		ieee_retval = setexception(2, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = HUGE;
 		else
 			exc.retval = HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 6:
 		/* exp(finite) overflow */
 		exc.type = OVERFLOW;
 		exc.name = "exp";
 		ieee_retval = setexception(2, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = HUGE;
 		else
 			exc.retval = HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 7:
 		/* exp(finite) underflow */
@@ -231,160 +250,188 @@
 		exc.name = "exp";
 		ieee_retval = setexception(1, 1.0);
 		exc.retval = 0.0;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 8:
 		/* y0(0) = -inf */
 		exc.type = DOMAIN;	/* should be SING for IEEE */
 		exc.name = "y0";
 		ieee_retval = setexception(0, -1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "y0: DOMAIN error\n", 17);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 9:
 		/* y0(x<0) = NaN */
 		exc.type = DOMAIN;
 		exc.name = "y0";
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "y0: DOMAIN error\n", 17);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 10:
 		/* y1(0) = -inf */
 		exc.type = DOMAIN;	/* should be SING for IEEE */
 		exc.name = "y1";
 		ieee_retval = setexception(0, -1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "y1: DOMAIN error\n", 17);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 11:
 		/* y1(x<0) = NaN */
 		exc.type = DOMAIN;
 		exc.name = "y1";
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "y1: DOMAIN error\n", 17);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 12:
 		/* yn(n,0) = -inf */
 		exc.type = DOMAIN;	/* should be SING for IEEE */
 		exc.name = "yn";
 		ieee_retval = setexception(0, -1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "yn: DOMAIN error\n", 17);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 13:
 		/* yn(x<0) = NaN */
 		exc.type = DOMAIN;
 		exc.name = "yn";
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "yn: DOMAIN error\n", 17);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 14:
 		/* lgamma(finite) overflow */
 		exc.type = OVERFLOW;
 		exc.name = "lgamma";
 		ieee_retval = setexception(2, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = HUGE;
 		else
 			exc.retval = HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 15:
 		/* lgamma(-integer) or lgamma(0) */
 		exc.type = SING;
 		exc.name = "lgamma";
 		ieee_retval = setexception(0, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = HUGE;
 		else
 			exc.retval = HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "lgamma: SING error\n", 19);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 16:
 		/* log(0) */
 		exc.type = SING;
 		exc.name = "log";
 		ieee_retval = setexception(0, -1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -395,34 +442,40 @@
 				errno = ERANGE;
 			}
 		}
+
 		break;
 	case 17:
 		/* log(x<0) */
 		exc.type = DOMAIN;
 		exc.name = "log";
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "log: DOMAIN error\n", 18);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 18:
 		/* log10(0) */
 		exc.type = SING;
 		exc.name = "log10";
 		ieee_retval = setexception(0, -1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -433,77 +486,97 @@
 				errno = ERANGE;
 			}
 		}
+
 		break;
 	case 19:
 		/* log10(x<0) */
 		exc.type = DOMAIN;
 		exc.name = "log10";
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "log10: DOMAIN error\n", 20);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 20:
-		/* pow(0.0,0.0) */
-		/* error only if lib_version == c_issue_4 */
+
+		/*
+		 * pow(0.0,0.0)
+		 * error only if lib_version == c_issue_4
+		 */
 		exc.type = DOMAIN;
 		exc.name = "pow";
 		exc.retval = 0.0;
 		ieee_retval = 1.0;
+
 		if (lib_version != c_issue_4) {
 			exc.retval = 1.0;
 		} else if (!matherr(&exc)) {
 			(void) write(2, "pow(0,0): DOMAIN error\n", 23);
 			errno = EDOM;
 		}
+
 		break;
 	case 21:
 		/* pow(x,y) overflow */
 		exc.type = OVERFLOW;
 		exc.name = "pow";
-		exc.retval = (lib_version == c_issue_4)? HUGE : HUGE_VAL;
+		exc.retval = (lib_version == c_issue_4) ? HUGE : HUGE_VAL;
+
 		if (signbit(x)) {
 			t = rint(y);
+
 			if (t == y) {
 				w = rint(0.5 * y);
-				if (t != w + w)	{	/* y is odd */
+
+				if (t != w + w)	/* y is odd */
 					exc.retval = -exc.retval;
-				}
 			}
 		}
+
 		ieee_retval = setexception(2, exc.retval);
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 22:
 		/* pow(x,y) underflow */
 		exc.type = UNDERFLOW;
 		exc.name = "pow";
 		exc.retval = 0.0;
+
 		if (signbit(x)) {
 			t = rint(y);
+
 			if (t == y) {
 				w = rint(0.5 * y);
+
 				if (t != w + w)	/* y is odd */
 					exc.retval = -exc.retval;
 			}
 		}
+
 		ieee_retval = setexception(1, exc.retval);
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 23:
 		/* (+-0)**neg */
@@ -512,40 +585,48 @@
 		ieee_retval = setexception(0, 1.0);
 		{
 			int ahy, k, j, yisint, ly, hx;
-			/* INDENT OFF */
+
+			/* BEGIN CSTYLED */
 			/*
 			 * determine if y is an odd int when x = -0
 			 * yisint = 0       ... y is not an integer
 			 * yisint = 1       ... y is an odd int
 			 * yisint = 2       ... y is an even int
 			 */
-			/* INDENT ON */
-			hx  = __HI(x);
-			ahy = __HI(y)&0x7fffffff;
-			ly  = __LO(y);
+			/* END CSTYLED */
+			hx = __HI(x);
+			ahy = __HI(y) & 0x7fffffff;
+			ly = __LO(y);
 
 			yisint = 0;
+
 			if (ahy >= 0x43400000) {
-				yisint = 2;	/* even integer y */
+				yisint = 2; /* even integer y */
 			} else if (ahy >= 0x3ff00000) {
 				k = (ahy >> 20) - 0x3ff;	/* exponent */
+
 				if (k > 20) {
 					j = ly >> (52 - k);
+
 					if ((j << (52 - k)) == ly)
 						yisint = 2 - (j & 1);
 				} else if (ly == 0) {
 					j = ahy >> (20 - k);
+
 					if ((j << (20 - k)) == ahy)
 						yisint = 2 - (j & 1);
 				}
 			}
+
 			if (hx < 0 && yisint == 1)
 				ieee_retval = -ieee_retval;
 		}
+
 		if (lib_version == c_issue_4)
 			exc.retval = 0.0;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
@@ -553,18 +634,22 @@
 				(void) write(2, "pow(0,neg): DOMAIN error\n",
 				    25);
 			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 24:
 		/* neg**non-integral */
 		exc.type = DOMAIN;
 		exc.name = "pow";
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = 0.0;
 		else
 			exc.retval = ieee_retval;	/* X/Open allow NaN */
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
@@ -572,80 +657,96 @@
 				(void) write(2,
 				    "neg**non-integral: DOMAIN error\n", 32);
 			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 25:
 		/* sinh(finite) overflow */
 		exc.type = OVERFLOW;
 		exc.name = "sinh";
 		ieee_retval = copysign(Inf, x);
+
 		if (lib_version == c_issue_4)
 			exc.retval = x > 0.0 ? HUGE : -HUGE;
 		else
 			exc.retval = x > 0.0 ? HUGE_VAL : -HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 26:
 		/* sqrt(x<0) */
 		exc.type = DOMAIN;
 		exc.name = "sqrt";
 		ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = 0.0;
 		else
 			exc.retval = ieee_retval;	/* quiet NaN */
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "sqrt: DOMAIN error\n", 19);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 27:
 		/* fmod(x,0) */
 		exc.type = DOMAIN;
 		exc.name = "fmod";
+
 		if (fp_class(x) == fp_quiet)
 			ieee_retval = NaN;
 		else
 			ieee_retval = setexception(3, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = x;
 		else
 			exc.retval = ieee_retval;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "fmod:  DOMAIN error\n", 20);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 28:
 		/* remainder(x,0) */
 		exc.type = DOMAIN;
 		exc.name = "remainder";
+
 		if (fp_class(x) == fp_quiet)
 			ieee_retval = NaN;
 		else
 			ieee_retval = setexception(3, 1.0);
+
 		exc.retval = NaN;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "remainder: DOMAIN error\n",
 				    24);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 29:
 		/* acosh(x<1) */
@@ -653,14 +754,16 @@
 		exc.name = "acosh";
 		ieee_retval = setexception(3, 1.0);
 		exc.retval = NaN;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "acosh: DOMAIN error\n", 20);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 30:
 		/* atanh(|x|>1) */
@@ -668,14 +771,16 @@
 		exc.name = "atanh";
 		ieee_retval = setexception(3, 1.0);
 		exc.retval = NaN;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "atanh: DOMAIN error\n", 20);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 31:
 		/* atanh(|x|=1) */
@@ -683,6 +788,7 @@
 		exc.name = "atanh";
 		ieee_retval = setexception(0, x);
 		exc.retval = ieee_retval;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -693,6 +799,7 @@
 				errno = ERANGE;
 			}
 		}
+
 		break;
 	case 32:
 		/* scalb overflow; SVID also returns +-HUGE_VAL */
@@ -700,10 +807,12 @@
 		exc.name = "scalb";
 		ieee_retval = setexception(2, x);
 		exc.retval = x > 0.0 ? HUGE_VAL : -HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 33:
 		/* scalb underflow */
@@ -711,10 +820,12 @@
 		exc.name = "scalb";
 		ieee_retval = setexception(1, x);
 		exc.retval = ieee_retval;	/* +-0.0 */
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 34:
 		/* j0(|x|>X_TLOSS) */
@@ -722,6 +833,7 @@
 		exc.name = "j0";
 		exc.retval = 0.0;
 		ieee_retval = y;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -729,8 +841,10 @@
 				(void) write(2, exc.name, 2);
 				(void) write(2, ": TLOSS error\n", 14);
 			}
+
 			errno = ERANGE;
 		}
+
 		break;
 	case 35:
 		/* y0(x>X_TLOSS) */
@@ -738,6 +852,7 @@
 		exc.name = "y0";
 		exc.retval = 0.0;
 		ieee_retval = y;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -745,8 +860,10 @@
 				(void) write(2, exc.name, 2);
 				(void) write(2, ": TLOSS error\n", 14);
 			}
+
 			errno = ERANGE;
 		}
+
 		break;
 	case 36:
 		/* j1(|x|>X_TLOSS) */
@@ -754,6 +871,7 @@
 		exc.name = "j1";
 		exc.retval = 0.0;
 		ieee_retval = y;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -761,8 +879,10 @@
 				(void) write(2, exc.name, 2);
 				(void) write(2, ": TLOSS error\n", 14);
 			}
+
 			errno = ERANGE;
 		}
+
 		break;
 	case 37:
 		/* y1(x>X_TLOSS) */
@@ -770,6 +890,7 @@
 		exc.name = "y1";
 		exc.retval = 0.0;
 		ieee_retval = y;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -777,16 +898,22 @@
 				(void) write(2, exc.name, 2);
 				(void) write(2, ": TLOSS error\n", 14);
 			}
+
 			errno = ERANGE;
 		}
+
 		break;
 	case 38:
-		/* jn(|x|>X_TLOSS) */
-		/* incorrect ieee value: ieee should never be here */
+
+		/*
+		 * jn(|x|>X_TLOSS)
+		 * incorrect ieee value: ieee should never be here
+		 */
 		exc.type = TLOSS;
 		exc.name = "jn";
 		exc.retval = 0.0;
 		ieee_retval = 0.0;	/* shall not be used */
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -794,16 +921,22 @@
 				(void) write(2, exc.name, 2);
 				(void) write(2, ": TLOSS error\n", 14);
 			}
+
 			errno = ERANGE;
 		}
+
 		break;
 	case 39:
-		/* yn(x>X_TLOSS) */
-		/* incorrect ieee value: ieee should never be here */
+
+		/*
+		 * yn(x>X_TLOSS)
+		 * incorrect ieee value: ieee should never be here
+		 */
 		exc.type = TLOSS;
 		exc.name = "yn";
 		exc.retval = 0.0;
 		ieee_retval = 0.0;	/* shall not be used */
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -811,64 +944,80 @@
 				(void) write(2, exc.name, 2);
 				(void) write(2, ": TLOSS error\n", 14);
 			}
+
 			errno = ERANGE;
 		}
+
 		break;
 	case 40:
 		/* gamma(finite) overflow */
 		exc.type = OVERFLOW;
 		exc.name = "gamma";
 		ieee_retval = setexception(2, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = HUGE;
 		else
 			exc.retval = HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 41:
 		/* gamma(-integer) or gamma(0) */
 		exc.type = SING;
 		exc.name = "gamma";
 		ieee_retval = setexception(0, 1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = HUGE;
 		else
 			exc.retval = HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "gamma: SING error\n", 18);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 42:
-		/* pow(NaN,0.0) */
-		/* error if lib_version == c_issue_4 or ansi_1 */
+
+		/*
+		 * pow(NaN,0.0)
+		 * error if lib_version == c_issue_4 or ansi_1
+		 */
 		exc.type = DOMAIN;
 		exc.name = "pow";
 		exc.retval = x;
 		ieee_retval = 1.0;
+
 		if (lib_version == strict_ansi) {
 			exc.retval = 1.0;
 		} else if (!matherr(&exc)) {
-			if ((lib_version == c_issue_4) || (lib_version == ansi_1))
+			if ((lib_version == c_issue_4) || (lib_version ==
+			    ansi_1))
 				errno = EDOM;
 		}
+
 		break;
 	case 43:
 		/* log1p(-1) */
 		exc.type = SING;
 		exc.name = "log1p";
 		ieee_retval = setexception(0, -1.0);
+
 		if (lib_version == c_issue_4)
 			exc.retval = -HUGE;
 		else
 			exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi) {
 			errno = ERANGE;
 		} else if (!matherr(&exc)) {
@@ -879,6 +1028,7 @@
 				errno = ERANGE;
 			}
 		}
+
 		break;
 	case 44:
 		/* log1p(x<-1) */
@@ -886,14 +1036,16 @@
 		exc.name = "log1p";
 		ieee_retval = setexception(3, 1.0);
 		exc.retval = ieee_retval;
+
 		if (lib_version == strict_ansi) {
 			errno = EDOM;
 		} else if (!matherr(&exc)) {
-			if (lib_version == c_issue_4) {
+			if (lib_version == c_issue_4)
 				(void) write(2, "log1p: DOMAIN error\n", 20);
-			}
+
 			errno = EDOM;
 		}
+
 		break;
 	case 45:
 		/* logb(0) */
@@ -901,15 +1053,18 @@
 		exc.name = "logb";
 		ieee_retval = setexception(0, -1.0);
 		exc.retval = -HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = EDOM;
 		else if (!matherr(&exc))
 			errno = EDOM;
+
 		break;
 	case 46:
 		/* nextafter overflow */
 		exc.type = OVERFLOW;
 		exc.name = "nextafter";
+
 		/*
 		 * The value as returned by setexception is +/-DBL_MAX in
 		 * round-to-{zero,-/+Inf} mode respectively, which is not
@@ -918,37 +1073,44 @@
 		(void) setexception(2, x);
 		ieee_retval = x > 0 ? Inf : -Inf;
 		exc.retval = x > 0 ? HUGE_VAL : -HUGE_VAL;
+
 		if (lib_version == strict_ansi)
 			errno = ERANGE;
 		else if (!matherr(&exc))
 			errno = ERANGE;
+
 		break;
 	case 47:
 		/* scalb(x,inf) */
 		iy = ((int *)&y)[HIWORD];
+
 		if (lib_version == c_issue_4)
 			/* SVID3: ERANGE in all cases */
 			errno = ERANGE;
 		else if ((x == 0.0 && iy > 0) || (!finite(x) && iy < 0))
 			/* EDOM for scalb(0,+inf) or scalb(inf,-inf) */
 			errno = EDOM;
-		exc.retval = ieee_retval = ((iy < 0)? x / -y : x * y);
+
+		exc.retval = ieee_retval = ((iy < 0) ? x / -y : x * y);
 		break;
 	}
+
 	switch (lib_version) {
 	case c_issue_4:
 	case ansi_1:
 	case strict_ansi:
 		return (exc.retval);
-		/* NOTREACHED */
+	/* NOTREACHED */
 	default:
 		return (ieee_retval);
 	}
+
 	/* NOTREACHED */
 }
 
 static double
-setexception(int n, double x) {
+setexception(int n, double x)
+{
 	/*
 	 * n =
 	 * 0	division by zero
@@ -959,18 +1121,19 @@
 	volatile double one = 1.0, zero = 0.0, retv;
 
 	switch (n) {
-	case 0:		/* division by zero */
+	case 0:				/* division by zero */
 		retv = copysign(one / zero, x);
 		break;
-	case 1:		/* underflow */
+	case 1:				/* underflow */
 		retv = DBL_MIN * copysign(DBL_MIN, x);
 		break;
-	case 2:		/* overflow */
+	case 2:				/* overflow */
 		retv = DBL_MAX * copysign(DBL_MAX, x);
 		break;
-	case 3:		/* invalid */
+	case 3:				/* invalid */
 		retv = zero * Inf;	/* for Cheetah */
 		break;
 	}
+
 	return (retv);
 }
--- old/usr/src/lib/libm/common/C/_TBL_atan.c	2019-06-06 20:37:29.296903094 +0000
+++ new/usr/src/lib/libm/common/C/_TBL_atan.c	2019-06-06 20:37:29.312510996 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,100 +40,100 @@
  */
 
 const double _TBL_atan[] = {
-1.28906287871928065814e-01,  1.28199318484201185697e-01,
-1.36718905591866640714e-01,  1.35876480966603985223e-01,
-1.44531257606217988787e-01,  1.43537301152401930437e-01,
-1.52343679482641575218e-01,  1.51181262880709432750e-01,
-1.60156177403962790562e-01,  1.58807537535115006477e-01,
-1.67968772982362929413e-01,  1.66415323534856884891e-01,
-1.75781211596017922227e-01,  1.74003563682464612583e-01,
-1.83593807762862160082e-01,  1.81571767039387044207e-01,
-1.91406205589629646591e-01,  1.89118806085245338977e-01,
-1.99218440148815872925e-01,  1.96643947167121080355e-01,
-2.07031180070658488157e-01,  2.04147078126891479144e-01,
-2.14843557086546094181e-01,  2.11626624363759674452e-01,
-2.22656308649619494311e-01,  2.19082566659412503185e-01,
-2.30468759807905931858e-01,  2.26513550670145669130e-01,
-2.38281413377399470255e-01,  2.33919360814280885563e-01,
-2.46093763828156536499e-01,  2.41298839969374956382e-01,
-2.57812599322508773092e-01,  2.52318074018685223336e-01,
-2.73437443946477509726e-01,  2.66912935433335718471e-01,
-2.89062532292519769328e-01,  2.81392462451501401688e-01,
-3.04687577351389293767e-01,  2.95751756530947318424e-01,
-3.20312405527377053183e-01,  3.09986305565206343715e-01,
-3.35937715576634265968e-01,  3.24092664204967739749e-01,
-3.51562621385942464247e-01,  3.38066230870244233131e-01,
-3.67187719833070636000e-01,  3.51904019130060419229e-01,
-3.82812538440931826589e-01,  3.65602365234580339859e-01,
-3.98437724467857745658e-01,  3.79158862748537828224e-01,
-4.14062683287296784407e-01,  3.92570291474021892952e-01,
-4.29687654458357937148e-01,  4.05834423459965343284e-01,
-4.45312642848883721847e-01,  4.18949086342842669239e-01,
-4.60937644536906665493e-01,  4.31912354681638355203e-01,
-4.76563149131543906112e-01,  4.44722952952162131623e-01,
-4.92187842452541601812e-01,  4.57378374341803173309e-01,
-5.15624825518001039804e-01,  4.76069192487019954285e-01,
-5.46874516057966109095e-01,  5.00440440618262982753e-01,
-5.78125566624434150675e-01,  5.24180053466007933594e-01,
-6.09375102172641347487e-01,  5.47284455493244337276e-01,
-6.40624936950189516338e-01,  5.69756408779493739303e-01,
-6.71875248719545625775e-01,  5.91599881698465779323e-01,
-7.03124988865964306584e-01,  6.12820194714659649549e-01,
-7.34376295967088421612e-01,  6.33426724884753156175e-01,
-7.65624929092156736310e-01,  6.53426296477277901431e-01,
-7.96874196003358736817e-01,  6.72832055855442590087e-01,
-8.28125565205639735389e-01,  6.91656957129326954714e-01,
-8.59375453355927021448e-01,  7.09911879233846576653e-01,
-8.90625694745052709500e-01,  7.27611720056701827275e-01,
-9.21875110259870345075e-01,  7.44770185320721367361e-01,
-9.53125042657123722201e-01,  7.61402792157321428590e-01,
-9.84374765277631902372e-01,  7.77524191164056688308e-01,
-1.03126494373528343473e+00,  8.00788807142382097481e-01,
-1.09374968909110092952e+00,  8.30144253291031475328e-01,
-1.15625019152505204012e+00,  8.57735575892430546219e-01,
-1.21874985186151341132e+00,  8.83672057048812575886e-01,
-1.28124876006842702836e+00,  9.08066349515326720621e-01,
-1.34375006271148444981e+00,  9.31026566320014126177e-01,
-1.40627222899692072566e+00,  9.52659566341466756967e-01,
-1.46874957658300542285e+00,  9.73037801091363618866e-01,
-1.53124999999999555911e+00,  9.92272112377190040888e-01,
-1.59375089676214143353e+00,  1.01043670320979472876e+00,
-1.65624949800269094524e+00,  1.02760661639661776690e+00,
-1.71874946971376685312e+00,  1.04385296549501305208e+00,
-1.78125111924655166185e+00,  1.05924046784549474864e+00,
-1.84374921332370989013e+00,  1.07382754310190620117e+00,
-1.90625055239083862624e+00,  1.08767078118685489585e+00,
-1.96874992734227549640e+00,  1.10081967347672460278e+00,
-2.06250046973591683042e+00,  1.11934332464931074469e+00,
-2.18749905173933534286e+00,  1.14201813543610697366e+00,
-2.31249933788800232648e+00,  1.16264711873167669864e+00,
-2.43749855191054187742e+00,  1.18147939634549814514e+00,
-2.56251104936881235474e+00,  1.19873002825057639598e+00,
-2.68750036758144528193e+00,  1.21457671610223272296e+00,
-2.81249907059852954916e+00,  1.22918073183895870670e+00,
-2.93749583903062294610e+00,  1.24267599964591468620e+00,
-3.06250108260464948273e+00,  1.25518076906426045980e+00,
-3.18750016629930410517e+00,  1.26679540235591403530e+00,
-3.31250071362610132297e+00,  1.27760948984166233799e+00,
-3.43749999999999333866e+00,  1.28770054149540058575e+00,
-3.56249877589327157423e+00,  1.29713691630583838332e+00,
-3.68750696071718842006e+00,  1.30597947372626776996e+00,
-3.81250023149192607264e+00,  1.31427972905173717777e+00,
-3.93749827850909683846e+00,  1.32208623339324304879e+00,
-4.12500187917697846984e+00,  1.33296050364557672196e+00,
-4.37499759905160701123e+00,  1.34608503917096200553e+00,
-4.62500066729278191957e+00,  1.35785800701782477518e+00,
-4.87499852385410648026e+00,  1.36847463881194641999e+00,
-5.12499918742110072145e+00,  1.37809553833018583191e+00,
-5.37500000000004529710e+00,  1.38685287025772296943e+00,
-5.62499999999991828759e+00,  1.39485670134236627860e+00,
-5.87499417854096694924e+00,  1.40219922327269230777e+00,
-6.12500000000013233858e+00,  1.40895889555647713109e+00,
-6.37499999999991828759e+00,  1.41520149881786494461e+00,
-6.62499933107761584949e+00,  1.42098385532083781868e+00,
-6.87500431528593747288e+00,  1.42635483782722261026e+00,
-7.12499228632883863099e+00,  1.43135612069194451124e+00,
-7.37499257154547205317e+00,  1.43602490820671135907e+00,
-7.62499911873607416624e+00,  1.44039300400460135165e+00,
-7.87500000000018918200e+00,  1.44448820973165936721e+00,
+	1.28906287871928065814e-01, 1.28199318484201185697e-01,
+	1.36718905591866640714e-01, 1.35876480966603985223e-01,
+	1.44531257606217988787e-01, 1.43537301152401930437e-01,
+	1.52343679482641575218e-01, 1.51181262880709432750e-01,
+	1.60156177403962790562e-01, 1.58807537535115006477e-01,
+	1.67968772982362929413e-01, 1.66415323534856884891e-01,
+	1.75781211596017922227e-01, 1.74003563682464612583e-01,
+	1.83593807762862160082e-01, 1.81571767039387044207e-01,
+	1.91406205589629646591e-01, 1.89118806085245338977e-01,
+	1.99218440148815872925e-01, 1.96643947167121080355e-01,
+	2.07031180070658488157e-01, 2.04147078126891479144e-01,
+	2.14843557086546094181e-01, 2.11626624363759674452e-01,
+	2.22656308649619494311e-01, 2.19082566659412503185e-01,
+	2.30468759807905931858e-01, 2.26513550670145669130e-01,
+	2.38281413377399470255e-01, 2.33919360814280885563e-01,
+	2.46093763828156536499e-01, 2.41298839969374956382e-01,
+	2.57812599322508773092e-01, 2.52318074018685223336e-01,
+	2.73437443946477509726e-01, 2.66912935433335718471e-01,
+	2.89062532292519769328e-01, 2.81392462451501401688e-01,
+	3.04687577351389293767e-01, 2.95751756530947318424e-01,
+	3.20312405527377053183e-01, 3.09986305565206343715e-01,
+	3.35937715576634265968e-01, 3.24092664204967739749e-01,
+	3.51562621385942464247e-01, 3.38066230870244233131e-01,
+	3.67187719833070636000e-01, 3.51904019130060419229e-01,
+	3.82812538440931826589e-01, 3.65602365234580339859e-01,
+	3.98437724467857745658e-01, 3.79158862748537828224e-01,
+	4.14062683287296784407e-01, 3.92570291474021892952e-01,
+	4.29687654458357937148e-01, 4.05834423459965343284e-01,
+	4.45312642848883721847e-01, 4.18949086342842669239e-01,
+	4.60937644536906665493e-01, 4.31912354681638355203e-01,
+	4.76563149131543906112e-01, 4.44722952952162131623e-01,
+	4.92187842452541601812e-01, 4.57378374341803173309e-01,
+	5.15624825518001039804e-01, 4.76069192487019954285e-01,
+	5.46874516057966109095e-01, 5.00440440618262982753e-01,
+	5.78125566624434150675e-01, 5.24180053466007933594e-01,
+	6.09375102172641347487e-01, 5.47284455493244337276e-01,
+	6.40624936950189516338e-01, 5.69756408779493739303e-01,
+	6.71875248719545625775e-01, 5.91599881698465779323e-01,
+	7.03124988865964306584e-01, 6.12820194714659649549e-01,
+	7.34376295967088421612e-01, 6.33426724884753156175e-01,
+	7.65624929092156736310e-01, 6.53426296477277901431e-01,
+	7.96874196003358736817e-01, 6.72832055855442590087e-01,
+	8.28125565205639735389e-01, 6.91656957129326954714e-01,
+	8.59375453355927021448e-01, 7.09911879233846576653e-01,
+	8.90625694745052709500e-01, 7.27611720056701827275e-01,
+	9.21875110259870345075e-01, 7.44770185320721367361e-01,
+	9.53125042657123722201e-01, 7.61402792157321428590e-01,
+	9.84374765277631902372e-01, 7.77524191164056688308e-01,
+	1.03126494373528343473e+00, 8.00788807142382097481e-01,
+	1.09374968909110092952e+00, 8.30144253291031475328e-01,
+	1.15625019152505204012e+00, 8.57735575892430546219e-01,
+	1.21874985186151341132e+00, 8.83672057048812575886e-01,
+	1.28124876006842702836e+00, 9.08066349515326720621e-01,
+	1.34375006271148444981e+00, 9.31026566320014126177e-01,
+	1.40627222899692072566e+00, 9.52659566341466756967e-01,
+	1.46874957658300542285e+00, 9.73037801091363618866e-01,
+	1.53124999999999555911e+00, 9.92272112377190040888e-01,
+	1.59375089676214143353e+00, 1.01043670320979472876e+00,
+	1.65624949800269094524e+00, 1.02760661639661776690e+00,
+	1.71874946971376685312e+00, 1.04385296549501305208e+00,
+	1.78125111924655166185e+00, 1.05924046784549474864e+00,
+	1.84374921332370989013e+00, 1.07382754310190620117e+00,
+	1.90625055239083862624e+00, 1.08767078118685489585e+00,
+	1.96874992734227549640e+00, 1.10081967347672460278e+00,
+	2.06250046973591683042e+00, 1.11934332464931074469e+00,
+	2.18749905173933534286e+00, 1.14201813543610697366e+00,
+	2.31249933788800232648e+00, 1.16264711873167669864e+00,
+	2.43749855191054187742e+00, 1.18147939634549814514e+00,
+	2.56251104936881235474e+00, 1.19873002825057639598e+00,
+	2.68750036758144528193e+00, 1.21457671610223272296e+00,
+	2.81249907059852954916e+00, 1.22918073183895870670e+00,
+	2.93749583903062294610e+00, 1.24267599964591468620e+00,
+	3.06250108260464948273e+00, 1.25518076906426045980e+00,
+	3.18750016629930410517e+00, 1.26679540235591403530e+00,
+	3.31250071362610132297e+00, 1.27760948984166233799e+00,
+	3.43749999999999333866e+00, 1.28770054149540058575e+00,
+	3.56249877589327157423e+00, 1.29713691630583838332e+00,
+	3.68750696071718842006e+00, 1.30597947372626776996e+00,
+	3.81250023149192607264e+00, 1.31427972905173717777e+00,
+	3.93749827850909683846e+00, 1.32208623339324304879e+00,
+	4.12500187917697846984e+00, 1.33296050364557672196e+00,
+	4.37499759905160701123e+00, 1.34608503917096200553e+00,
+	4.62500066729278191957e+00, 1.35785800701782477518e+00,
+	4.87499852385410648026e+00, 1.36847463881194641999e+00,
+	5.12499918742110072145e+00, 1.37809553833018583191e+00,
+	5.37500000000004529710e+00, 1.38685287025772296943e+00,
+	5.62499999999991828759e+00, 1.39485670134236627860e+00,
+	5.87499417854096694924e+00, 1.40219922327269230777e+00,
+	6.12500000000013233858e+00, 1.40895889555647713109e+00,
+	6.37499999999991828759e+00, 1.41520149881786494461e+00,
+	6.62499933107761584949e+00, 1.42098385532083781868e+00,
+	6.87500431528593747288e+00, 1.42635483782722261026e+00,
+	7.12499228632883863099e+00, 1.43135612069194451124e+00,
+	7.37499257154547205317e+00, 1.43602490820671135907e+00,
+	7.62499911873607416624e+00, 1.44039300400460135165e+00,
+	7.87500000000018918200e+00, 1.44448820973165936721e+00,
 };
--- old/usr/src/lib/libm/common/C/_TBL_exp2.c	2019-06-06 20:37:29.764548556 +0000
+++ new/usr/src/lib/libm/common/C/_TBL_exp2.c	2019-06-06 20:37:29.781041209 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,50 +31,71 @@
 #include "libm_protos.h"
 
 const double _TBL_exp2_hi[] = {
- 1.00000000000000000e+00, 1.01088928605170048e+00, 1.02189714865411663e+00,
- 1.03302487902122841e+00, 1.04427378242741375e+00, 1.05564517836055716e+00,
- 1.06714040067682370e+00, 1.07876079775711986e+00, 1.09050773266525769e+00,
- 1.10238258330784089e+00, 1.11438674259589243e+00, 1.12652161860824185e+00,
- 1.13878863475669156e+00, 1.15118922995298267e+00, 1.16372485877757748e+00,
- 1.17639699165028122e+00, 1.18920711500272103e+00, 1.20215673145270308e+00,
- 1.21524735998046896e+00, 1.22848053610687002e+00, 1.24185781207348400e+00,
- 1.25538075702469110e+00, 1.26905095719173322e+00, 1.28287001607877826e+00,
- 1.29683955465100964e+00, 1.31096121152476441e+00, 1.32523664315974132e+00,
- 1.33966752405330292e+00, 1.35425554693689265e+00, 1.36900242297459052e+00,
- 1.38390988196383202e+00, 1.39897967253831124e+00, 1.41421356237309515e+00,
- 1.42961333839197002e+00, 1.44518080697704665e+00, 1.46091779418064704e+00,
- 1.47682614593949935e+00, 1.49290772829126484e+00, 1.50916442759342284e+00,
- 1.52559815074453820e+00, 1.54221082540794074e+00, 1.55900440023783693e+00,
- 1.57598084510788650e+00, 1.59314215134226700e+00, 1.61049033194925428e+00,
- 1.62802742185734783e+00, 1.64575547815396495e+00, 1.66367658032673638e+00,
- 1.68179283050742900e+00, 1.70010635371852348e+00, 1.71861929812247793e+00,
- 1.73733383527370622e+00, 1.75625216037329945e+00, 1.77537649252652119e+00,
- 1.79470907500310717e+00, 1.81425217550039886e+00, 1.83400808640934243e+00,
- 1.85397912508338547e+00, 1.87416763411029996e+00, 1.89457598158696561e+00,
- 1.91520656139714740e+00, 1.93606179349229435e+00, 1.95714412417540018e+00,
- 1.97845602638795093e+00,
+	1.00000000000000000e+00, 1.01088928605170048e+00,
+	1.02189714865411663e+00, 1.03302487902122841e+00,
+	1.04427378242741375e+00, 1.05564517836055716e+00,
+	1.06714040067682370e+00, 1.07876079775711986e+00,
+	1.09050773266525769e+00, 1.10238258330784089e+00,
+	1.11438674259589243e+00, 1.12652161860824185e+00,
+	1.13878863475669156e+00, 1.15118922995298267e+00,
+	1.16372485877757748e+00, 1.17639699165028122e+00,
+	1.18920711500272103e+00, 1.20215673145270308e+00,
+	1.21524735998046896e+00, 1.22848053610687002e+00,
+	1.24185781207348400e+00, 1.25538075702469110e+00,
+	1.26905095719173322e+00, 1.28287001607877826e+00,
+	1.29683955465100964e+00, 1.31096121152476441e+00,
+	1.32523664315974132e+00, 1.33966752405330292e+00,
+	1.35425554693689265e+00, 1.36900242297459052e+00,
+	1.38390988196383202e+00, 1.39897967253831124e+00,
+	1.41421356237309515e+00, 1.42961333839197002e+00,
+	1.44518080697704665e+00, 1.46091779418064704e+00,
+	1.47682614593949935e+00, 1.49290772829126484e+00,
+	1.50916442759342284e+00, 1.52559815074453820e+00,
+	1.54221082540794074e+00, 1.55900440023783693e+00,
+	1.57598084510788650e+00, 1.59314215134226700e+00,
+	1.61049033194925428e+00, 1.62802742185734783e+00,
+	1.64575547815396495e+00, 1.66367658032673638e+00,
+	1.68179283050742900e+00, 1.70010635371852348e+00,
+	1.71861929812247793e+00, 1.73733383527370622e+00,
+	1.75625216037329945e+00, 1.77537649252652119e+00,
+	1.79470907500310717e+00, 1.81425217550039886e+00,
+	1.83400808640934243e+00, 1.85397912508338547e+00,
+	1.87416763411029996e+00, 1.89457598158696561e+00,
+	1.91520656139714740e+00, 1.93606179349229435e+00,
+	1.95714412417540018e+00, 1.97845602638795093e+00,
 };
+
 const double _TBL_exp2_lo[] = {
- 0.00000000000000000e+00,-1.52347786033685772e-17, 5.10922502897344389e-17,
- 7.60083887402708849e-18, 8.55188970553796366e-17, 1.75932573877209198e-18,
--7.89985396684158212e-17,-6.65666043605659260e-17,-3.04678207981247115e-17,
- 5.26603687157069439e-17, 1.04102784568455710e-16, 5.16585675879545612e-17,
- 8.91281267602540778e-17, 3.25071021886382721e-17, 3.82920483692409350e-17,
- 5.55420325421807896e-17, 3.98201523146564611e-17, 6.64498149925230124e-17,
--7.71263069268148813e-17,-1.89878163130252995e-17, 4.65802759183693679e-17,
--6.71138982129687842e-18, 2.66793213134218610e-18, 1.71359491824356097e-17,
- 2.53825027948883150e-17,-7.18153613551945386e-17,-2.85873121003886076e-17,
- 8.92728259483173198e-17, 7.70094837980298946e-17, 9.59379791911884877e-17,
--6.77051165879478629e-17,-9.61421320905132307e-17,-9.66729331345291345e-17,
--1.20316424890536552e-17,-3.02375813499398732e-17,-5.60037718607521580e-17,
--3.48399455689279580e-17, 1.41929201542840358e-17,-1.01645532775429504e-16,
- 1.11795187801605699e-16, 7.94983480969762086e-17, 3.78120705335752750e-17,
--1.01369164712783040e-17,-1.00944065423119625e-16, 2.47071925697978879e-17,
--6.71295508470708409e-17,-1.01256799136747726e-16, 5.89099269671309967e-17,
- 8.19901002058149652e-17,-8.02371937039770025e-18,-1.85138041826311099e-17,
- 3.16438929929295695e-17, 2.96014069544887331e-17, 6.42973179655657203e-17,
- 1.82274584279120868e-17,-9.96953153892034882e-17, 3.28310722424562659e-17,
- 9.76188749072759354e-17,-6.12276341300414256e-17, 3.40340353521652967e-17,
--1.06199460561959626e-16, 1.03323859606763257e-16, 8.96076779103666777e-17,
- 4.03887531092781666e-17,
+	0.00000000000000000e+00, -1.52347786033685772e-17,
+	5.10922502897344389e-17, 7.60083887402708849e-18,
+	8.55188970553796366e-17, 1.75932573877209198e-18,
+	-7.89985396684158212e-17, -6.65666043605659260e-17,
+	-3.04678207981247115e-17, 5.26603687157069439e-17,
+	1.04102784568455710e-16, 5.16585675879545612e-17,
+	8.91281267602540778e-17, 3.25071021886382721e-17,
+	3.82920483692409350e-17, 5.55420325421807896e-17,
+	3.98201523146564611e-17, 6.64498149925230124e-17,
+	-7.71263069268148813e-17, -1.89878163130252995e-17,
+	4.65802759183693679e-17, -6.71138982129687842e-18,
+	2.66793213134218610e-18, 1.71359491824356097e-17,
+	2.53825027948883150e-17, -7.18153613551945386e-17,
+	-2.85873121003886076e-17, 8.92728259483173198e-17,
+	7.70094837980298946e-17, 9.59379791911884877e-17,
+	-6.77051165879478629e-17, -9.61421320905132307e-17,
+	-9.66729331345291345e-17, -1.20316424890536552e-17,
+	-3.02375813499398732e-17, -5.60037718607521580e-17,
+	-3.48399455689279580e-17, 1.41929201542840358e-17,
+	-1.01645532775429504e-16, 1.11795187801605699e-16,
+	7.94983480969762086e-17, 3.78120705335752750e-17,
+	-1.01369164712783040e-17, -1.00944065423119625e-16,
+	2.47071925697978879e-17, -6.71295508470708409e-17,
+	-1.01256799136747726e-16, 5.89099269671309967e-17,
+	8.19901002058149652e-17, -8.02371937039770025e-18,
+	-1.85138041826311099e-17, 3.16438929929295695e-17,
+	2.96014069544887331e-17, 6.42973179655657203e-17,
+	1.82274584279120868e-17, -9.96953153892034882e-17,
+	3.28310722424562659e-17, 9.76188749072759354e-17,
+	-6.12276341300414256e-17, 3.40340353521652967e-17,
+	-1.06199460561959626e-16, 1.03323859606763257e-16,
+	8.96076779103666777e-17, 4.03887531092781666e-17,
 };
--- old/usr/src/lib/libm/common/C/_TBL_ipio2.c	2019-06-06 20:37:30.234523801 +0000
+++ new/usr/src/lib/libm/common/C/_TBL_ipio2.c	2019-06-06 20:37:30.253877770 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,51 +38,51 @@
  * 396 Hex digits (476 decimal) of 2/pi
  */
 const int _TBL_ipio2_inf[] = {
-0xA2F983, 0x6E4E44, 0x1529FC, 0x2757D1, 0xF534DD, 0xC0DB62,
-0x95993C, 0x439041, 0xFE5163, 0xABDEBB, 0xC561B7, 0x246E3A,
-0x424DD2, 0xE00649, 0x2EEA09, 0xD1921C, 0xFE1DEB, 0x1CB129,
-0xA73EE8, 0x8235F5, 0x2EBB44, 0x84E99C, 0x7026B4, 0x5F7E41,
-0x3991D6, 0x398353, 0x39F49C, 0x845F8B, 0xBDF928, 0x3B1FF8,
-0x97FFDE, 0x05980F, 0xEF2F11, 0x8B5A0A, 0x6D1F6D, 0x367ECF,
-0x27CB09, 0xB74F46, 0x3F669E, 0x5FEA2D, 0x7527BA, 0xC7EBE5,
-0xF17B3D, 0x0739F7, 0x8A5292, 0xEA6BFB, 0x5FB11F, 0x8D5D08,
-0x560330, 0x46FC7B, 0x6BABF0, 0xCFBC20, 0x9AF436, 0x1DA9E3,
-0x91615E, 0xE61B08, 0x659985, 0x5F14A0, 0x68408D, 0xFFD880,
-0x4D7327, 0x310606, 0x1556CA, 0x73A8C9, 0x60E27B, 0xC08C6B,
+	0xA2F983, 0x6E4E44, 0x1529FC, 0x2757D1, 0xF534DD, 0xC0DB62,
+	0x95993C, 0x439041, 0xFE5163, 0xABDEBB, 0xC561B7, 0x246E3A,
+	0x424DD2, 0xE00649, 0x2EEA09, 0xD1921C, 0xFE1DEB, 0x1CB129,
+	0xA73EE8, 0x8235F5, 0x2EBB44, 0x84E99C, 0x7026B4, 0x5F7E41,
+	0x3991D6, 0x398353, 0x39F49C, 0x845F8B, 0xBDF928, 0x3B1FF8,
+	0x97FFDE, 0x05980F, 0xEF2F11, 0x8B5A0A, 0x6D1F6D, 0x367ECF,
+	0x27CB09, 0xB74F46, 0x3F669E, 0x5FEA2D, 0x7527BA, 0xC7EBE5,
+	0xF17B3D, 0x0739F7, 0x8A5292, 0xEA6BFB, 0x5FB11F, 0x8D5D08,
+	0x560330, 0x46FC7B, 0x6BABF0, 0xCFBC20, 0x9AF436, 0x1DA9E3,
+	0x91615E, 0xE61B08, 0x659985, 0x5F14A0, 0x68408D, 0xFFD880,
+	0x4D7327, 0x310606, 0x1556CA, 0x73A8C9, 0x60E27B, 0xC08C6B,
 };
 
-#if 0	/* remove from SVR4 */
+#if 0					/* remove from SVR4 */
 /*
  * 396 Hex digits (476 decimal) of 2/PI, PI = 66 bits of pi
  */
 const int _TBL_ipio2_66[] = {
-0xA2F983, 0x6E4E44, 0x152A00, 0x062BC4, 0x0DA276, 0xBED4C1,
-0xFDF905, 0x5CD5BA, 0x767CEC, 0x1F80D6, 0xC26053, 0x3A0070,
-0x107C2A, 0xF68EE9, 0x687B7A, 0xB990AA, 0x38DE4B, 0x96CFF3,
-0x92735E, 0x8B34F6, 0x195BFC, 0x27F88E, 0xA93EC5, 0x3958A5,
-0x3E5D13, 0x1C55A8, 0x5B4A8B, 0xA42E04, 0x12D105, 0x35580D,
-0xF62347, 0x450900, 0xB98BCA, 0xF7E8A4, 0xA2E5D5, 0x69BC52,
-0xF0381D, 0x1A0A88, 0xFE8714, 0x7F6735, 0xBB7D4D, 0xC6F642,
-0xB27E80, 0x6191BF, 0xB6B750, 0x52776E, 0xD60FD0, 0x607DCC,
-0x68BFAF, 0xED69FC, 0x6EB305, 0xD2557D, 0x25BDFB, 0x3E4AA1,
-0x84472D, 0x8B0376, 0xF77740, 0xD290DF, 0x15EC8C, 0x45A5C3,
-0x6181EF, 0xC5E7E8, 0xD8909C, 0xF62144, 0x298428, 0x6E5D9D,
+	0xA2F983, 0x6E4E44, 0x152A00, 0x062BC4, 0x0DA276, 0xBED4C1,
+	0xFDF905, 0x5CD5BA, 0x767CEC, 0x1F80D6, 0xC26053, 0x3A0070,
+	0x107C2A, 0xF68EE9, 0x687B7A, 0xB990AA, 0x38DE4B, 0x96CFF3,
+	0x92735E, 0x8B34F6, 0x195BFC, 0x27F88E, 0xA93EC5, 0x3958A5,
+	0x3E5D13, 0x1C55A8, 0x5B4A8B, 0xA42E04, 0x12D105, 0x35580D,
+	0xF62347, 0x450900, 0xB98BCA, 0xF7E8A4, 0xA2E5D5, 0x69BC52,
+	0xF0381D, 0x1A0A88, 0xFE8714, 0x7F6735, 0xBB7D4D, 0xC6F642,
+	0xB27E80, 0x6191BF, 0xB6B750, 0x52776E, 0xD60FD0, 0x607DCC,
+	0x68BFAF, 0xED69FC, 0x6EB305, 0xD2557D, 0x25BDFB, 0x3E4AA1,
+	0x84472D, 0x8B0376, 0xF77740, 0xD290DF, 0x15EC8C, 0x45A5C3,
+	0x6181EF, 0xC5E7E8, 0xD8909C, 0xF62144, 0x298428, 0x6E5D9D,
 };
 
 /*
  * 396 Hex digits (476 decimal) of 2/PI, PI = 53 bits of pi
  */
 const int _TBL_ipio2_53[] = {
-0xA2F983, 0x6E4E44, 0x16F3C4, 0xEA69B5, 0xD3E131, 0x60E1D2,
-0xD7982A, 0xC031F5, 0xD67BCC, 0xFD1375, 0x60919B, 0x3FA0BB,
-0x612ABB, 0x714F9B, 0x03DA8A, 0xC05948, 0xD023F4, 0x5AFA37,
-0x51631D, 0xCD7A90, 0xC0474A, 0xF6A6F3, 0x1A52E1, 0x5C3927,
-0x3ADA45, 0x4E2DB5, 0x64E8C4, 0x274A5B, 0xB74ADC, 0x1E6591,
-0x2822BE, 0x4771F5, 0x12A63F, 0x83BD35, 0x2488CA, 0x1FE1BE,
-0x42C21A, 0x682569, 0x2AFB91, 0x68ADE1, 0x4A42E5, 0x9BE357,
-0xB79675, 0xCE998A, 0x83AF8B, 0xE645E6, 0xDF0789, 0x9E9747,
-0xAA15FF, 0x358C3F, 0xAF3141, 0x72A3F7, 0x2BF1D4, 0xF3AD96,
-0x7D759F, 0x257FCE, 0x29FB69, 0xB1B42C, 0xC32DE1, 0x8C0BBD,
-0x31EC2F, 0x942026, 0x85DCE7, 0x653FF3, 0x136FA7, 0x0D7A5F,
+	0xA2F983, 0x6E4E44, 0x16F3C4, 0xEA69B5, 0xD3E131, 0x60E1D2,
+	0xD7982A, 0xC031F5, 0xD67BCC, 0xFD1375, 0x60919B, 0x3FA0BB,
+	0x612ABB, 0x714F9B, 0x03DA8A, 0xC05948, 0xD023F4, 0x5AFA37,
+	0x51631D, 0xCD7A90, 0xC0474A, 0xF6A6F3, 0x1A52E1, 0x5C3927,
+	0x3ADA45, 0x4E2DB5, 0x64E8C4, 0x274A5B, 0xB74ADC, 0x1E6591,
+	0x2822BE, 0x4771F5, 0x12A63F, 0x83BD35, 0x2488CA, 0x1FE1BE,
+	0x42C21A, 0x682569, 0x2AFB91, 0x68ADE1, 0x4A42E5, 0x9BE357,
+	0xB79675, 0xCE998A, 0x83AF8B, 0xE645E6, 0xDF0789, 0x9E9747,
+	0xAA15FF, 0x358C3F, 0xAF3141, 0x72A3F7, 0x2BF1D4, 0xF3AD96,
+	0x7D759F, 0x257FCE, 0x29FB69, 0xB1B42C, 0xC32DE1, 0x8C0BBD,
+	0x31EC2F, 0x942026, 0x85DCE7, 0x653FF3, 0x136FA7, 0x0D7A5F,
 };
 #endif
--- old/usr/src/lib/libm/common/C/_TBL_log.c	2019-06-06 20:37:30.733752927 +0000
+++ new/usr/src/lib/libm/common/C/_TBL_log.c	2019-06-06 20:37:30.752840850 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -40,260 +41,388 @@
  * double. In addition, each log(Y[j]) has 3 trailing zeros.
  */
 const double _TBL_log[] = {
-9.47265623608246343e-02, 1.05567010464380857e+01, -2.35676082856530300e+00,
-9.66796869131412717e-02, 1.03434344062203838e+01, -2.33635196153499791e+00,
-9.86328118117651004e-02, 1.01386139321308306e+01, -2.31635129573594156e+00,
-1.00585936733578435e-01, 9.94174764856737347e+00, -2.29674282498938709e+00,
-1.02539062499949152e-01, 9.75238095238578850e+00, -2.27751145544242561e+00,
-1.04492186859904843e-01, 9.57009351656812157e+00, -2.25864297726331742e+00,
-1.06445312294918631e-01, 9.39449543094380957e+00, -2.24012392529694537e+00,
-1.08398437050250693e-01, 9.22522526350104144e+00, -2.22194160843615762e+00,
-1.10351562442130582e-01, 9.06194690740703912e+00, -2.20408398741152212e+00,
-1.12304686894746625e-01, 8.90434787407592943e+00, -2.18653968262558962e+00,
-1.14257811990227776e-01, 8.75213679118525256e+00, -2.16929787526329321e+00,
-1.16210936696872255e-01, 8.60504207627572093e+00, -2.15234831939887172e+00,
-1.18164061975360682e-01, 8.46280995492959498e+00, -2.13568126444263484e+00,
-1.20117187499996322e-01, 8.32520325203277523e+00, -2.11928745022706622e+00,
-1.22070312499895098e-01, 8.19200000000703987e+00, -2.10315806829801133e+00,
-1.24023436774175100e-01, 8.06299217317146599e+00, -2.08728472499318229e+00,
-1.26953123746900931e-01, 7.87692315467275872e+00, -2.06393736501443570e+00,
-1.30859374098123454e-01, 7.64179109744297769e+00, -2.03363201254049386e+00,
-1.34765623780674720e-01, 7.42028992220936967e+00, -2.00421812948999545e+00,
-1.38671874242985771e-01, 7.21126764500034501e+00, -1.97564475345722457e+00,
-1.42578124148616536e-01, 7.01369867201821506e+00, -1.94786518986246371e+00,
-1.46484374166731490e-01, 6.82666670549979404e+00, -1.92083651719164372e+00,
-1.50390624434435488e-01, 6.64935067435644189e+00, -1.89451920694646070e+00,
-1.54296874339723084e-01, 6.48101268596180624e+00, -1.86887677685174936e+00,
-1.58203124999987427e-01, 6.32098765432149001e+00, -1.84387547036714849e+00,
-1.62109374999815342e-01, 6.16867469880220742e+00, -1.81948401724404896e+00,
-1.66015624243955634e-01, 6.02352943919619310e+00, -1.79567337310324682e+00,
-1.69921874302298687e-01, 5.88505749542848644e+00, -1.77241651049093640e+00,
-1.73828124315277527e-01, 5.75280901142480605e+00, -1.74968825924644555e+00,
-1.77734374286237506e-01, 5.62637364896854919e+00, -1.72746512253855222e+00,
-1.81640624146994889e-01, 5.50537636993989743e+00, -1.70572513658236602e+00,
-1.85546874316304788e-01, 5.38947370406942916e+00, -1.68444773712372431e+00,
-1.89453124405085355e-01, 5.27835053203882509e+00, -1.66361364967629299e+00,
-1.93359374570531595e-01, 5.17171718320401652e+00, -1.64320477712600699e+00,
-1.97265624263334577e-01, 5.06930694962380368e+00, -1.62320411193263148e+00,
-2.01171874086291030e-01, 4.97087380898513764e+00, -1.60359564135180399e+00,
-2.05078123979995308e-01, 4.87619050044336610e+00, -1.58436427985572159e+00,
-2.08984373896073439e-01, 4.78504675424820736e+00, -1.56549579585994181e+00,
-2.12890623963011144e-01, 4.69724772930228163e+00, -1.54697674768135762e+00,
-2.16796874723889421e-01, 4.61261261848719517e+00, -1.52879442500076479e+00,
-2.20703124198150608e-01, 4.53097346778917753e+00, -1.51093680996032553e+00,
-2.24609374375627030e-01, 4.45217392541970725e+00, -1.49339249945607477e+00,
-2.28515625000094036e-01, 4.37606837606657528e+00, -1.47615069024134016e+00,
-2.32421873924349737e-01, 4.30252102831546246e+00, -1.45920113655598627e+00,
-2.36328123935216378e-01, 4.23140497774241098e+00, -1.44253408394829741e+00,
-2.40234375000066919e-01, 4.16260162601510064e+00, -1.42614026966681173e+00,
-2.44140623863132178e-01, 4.09600001907347711e+00, -1.41001089239381727e+00,
-2.48046874999894917e-01, 4.03149606299383390e+00, -1.39413753858134015e+00,
-2.53906248590769879e-01, 3.93846156032078243e+00, -1.37079018013412401e+00,
-2.61718748558906533e-01, 3.82089554342693294e+00, -1.34048483059486401e+00,
-2.69531249159214337e-01, 3.71014493910979404e+00, -1.31107094300173976e+00,
-2.77343749428383191e-01, 3.60563381024826013e+00, -1.28249756949928795e+00,
-2.85156249289339359e-01, 3.50684932380819214e+00, -1.25471800582335113e+00,
-2.92968749999700462e-01, 3.41333333333682321e+00, -1.22768933094427446e+00,
-3.00781248554318814e-01, 3.32467534065511261e+00, -1.20137202743229921e+00,
-3.08593748521894806e-01, 3.24050634463533127e+00, -1.17572959680235023e+00,
-3.16406249999639899e-01, 3.16049382716409077e+00, -1.15072828980826181e+00,
-3.24218749999785061e-01, 3.08433734939963511e+00, -1.12633683668362750e+00,
-3.32031248841858584e-01, 3.01176471638753718e+00, -1.10252619147729547e+00,
-3.39843749265406558e-01, 2.94252874199264314e+00, -1.07926932798654107e+00,
-3.47656249999834799e-01, 2.87640449438338930e+00, -1.05654107474789782e+00,
-3.55468749999899247e-01, 2.81318681318761055e+00, -1.03431793796299587e+00,
-3.63281249999864997e-01, 2.75268817204403371e+00, -1.01257795132667816e+00,
-3.71093749064121570e-01, 2.69473684890124421e+00, -9.91300555400967731e-01,
-3.78906249999751032e-01, 2.63917525773369288e+00, -9.70466465976836723e-01,
-3.86718748879039009e-01, 2.58585859335407608e+00, -9.50057597243619156e-01,
-3.94531249999987899e-01, 2.53465346534661240e+00, -9.30056927638333697e-01,
-4.02343749999485523e-01, 2.48543689320706163e+00, -9.10448456251205407e-01,
-4.10156249578856991e-01, 2.43809524059864202e+00, -8.91217095348825872e-01,
-4.17968749447214571e-01, 2.39252336765021800e+00, -8.72348611340208357e-01,
-4.25781248601723117e-01, 2.34862386092395203e+00, -8.53829565534445223e-01,
-4.33593749393073047e-01, 2.30630630953458038e+00, -8.35647244566987801e-01,
-4.41406248572254134e-01, 2.26548673299152270e+00, -8.17789629001761220e-01,
-4.49218749348472501e-01, 2.22608695975035964e+00, -8.00245317566669279e-01,
-4.57031249277175089e-01, 2.18803419149470768e+00, -7.83003511263371976e-01,
-4.64843748529596368e-01, 2.15126051100659366e+00, -7.66053954531254355e-01,
-4.72656248830947701e-01, 2.11570248457175136e+00, -7.49386901356188240e-01,
-4.80468748609962581e-01, 2.08130081902951236e+00, -7.32993092000230995e-01,
-4.88281249241778237e-01, 2.04800000318021258e+00, -7.16863708730099525e-01,
-4.96093748931098810e-01, 2.01574803583926521e+00, -7.00990360175606675e-01,
-5.07812497779701388e-01, 1.96923077784079825e+00, -6.77642998396260410e-01,
-5.23437498033319737e-01, 1.91044776837204044e+00, -6.47337648285891021e-01,
-5.39062498006593560e-01, 1.85507247062801328e+00, -6.17923763020271188e-01,
-5.54687498964024250e-01, 1.80281690477552603e+00, -5.89350388745976339e-01,
-5.70312499806522322e-01, 1.75342465812909332e+00, -5.61570823110474571e-01,
-5.85937497921867001e-01, 1.70666667271966777e+00, -5.34542153929987052e-01,
-6.01562498226483444e-01, 1.66233766723853860e+00, -5.08224845014116688e-01,
-6.17187498682654212e-01, 1.62025316801528496e+00, -4.82582413587029357e-01,
-6.32812500000264566e-01, 1.58024691357958624e+00, -4.57581109246760320e-01,
-6.48437499353274216e-01, 1.54216867623689291e+00, -4.33189657120379490e-01,
-6.64062498728508976e-01, 1.50588235582451335e+00, -4.09379009344016609e-01,
-6.79687498865382267e-01, 1.47126437027210688e+00, -3.86122146934356092e-01,
-6.95312498728747119e-01, 1.43820224982050338e+00, -3.63393896015796081e-01,
-7.10937499999943157e-01, 1.40659340659351906e+00, -3.41170757402847080e-01,
-7.26562499999845568e-01, 1.37634408602179792e+00, -3.19430770766573779e-01,
-7.42187500000120126e-01, 1.34736842105241350e+00, -2.98153372318914478e-01,
-7.57812499999581890e-01, 1.31958762886670744e+00, -2.77319285416786077e-01,
-7.73437498602746576e-01, 1.29292929526503420e+00, -2.56910415591577124e-01,
-7.89062500000142664e-01, 1.26732673267303819e+00, -2.36909747078176913e-01,
-8.04687500000259015e-01, 1.24271844660154174e+00, -2.17301275689659512e-01,
-8.20312499999677036e-01, 1.21904761904809900e+00, -1.98069913762487504e-01,
-8.35937499999997113e-01, 1.19626168224299478e+00, -1.79201429457714445e-01,
-8.51562499999758749e-01, 1.17431192660583728e+00, -1.60682381690756770e-01,
-8.67187500000204725e-01, 1.15315315315288092e+00, -1.42500062607046951e-01,
-8.82812500000407896e-01, 1.13274336283133503e+00, -1.24642445206814556e-01,
-8.98437499999816813e-01, 1.11304347826109651e+00, -1.07098135556570995e-01,
-9.14062499999708455e-01, 1.09401709401744296e+00, -8.98563291221800009e-02,
-9.29687500000063949e-01, 1.07563025210076635e+00, -7.29067708080189947e-02,
-9.45312499999844014e-01, 1.05785123966959604e+00, -5.62397183230410880e-02,
-9.60937500000120459e-01, 1.04065040650393459e+00, -3.98459085470743157e-02,
-9.76562499999976685e-01, 1.02400000000002445e+00, -2.37165266173399170e-02,
-9.92187500000169420e-01, 1.00787401574785940e+00, -7.84317746085513856e-03,
-1.01562500000004907e+00, 9.84615384615337041e-01,  1.55041865360135717e-02,
-1.04687500000009237e+00, 9.55223880596930641e-01,  4.58095360313824362e-02,
-1.07812500000002154e+00, 9.27536231884039442e-01,  7.52234212376075018e-02,
-1.10937499999982481e+00, 9.01408450704367703e-01,  1.03796793681485644e-01,
-1.14062500000007416e+00, 8.76712328767066285e-01,  1.31576357788784293e-01,
-1.17187500000009659e+00, 8.53333333333263000e-01,  1.58605030176721007e-01,
-1.20312499999950173e+00, 8.31168831169175393e-01,  1.84922338493597849e-01,
-1.23437500000022027e+00, 8.10126582278336449e-01,  2.10564769107528083e-01,
-1.26562500000064615e+00, 7.90123456789720069e-01,  2.35566071313277448e-01,
-1.29687500000144706e+00, 7.71084337348537208e-01,  2.59957524438041876e-01,
-1.32812499999945932e+00, 7.52941176470894757e-01,  2.83768173130237500e-01,
-1.35937500055846350e+00, 7.35632183605830825e-01,  3.07025035705735583e-01,
-1.39062499999999467e+00, 7.19101123595508374e-01,  3.29753286372464149e-01,
-1.42187500000017564e+00, 7.03296703296616421e-01,  3.51976423157301710e-01,
-1.45312500161088876e+00, 6.88172042247866766e-01,  3.73716410902152685e-01,
-1.48437500134602307e+00, 6.73684209915422660e-01,  3.94993809147663466e-01,
-1.51562499999932343e+00, 6.59793814433284220e-01,  4.15827895143264570e-01,
-1.54687500000028200e+00, 6.46464646464528614e-01,  4.36236766775100371e-01,
-1.57812500000061906e+00, 6.33663366336385092e-01,  4.56237433481979870e-01,
-1.60937500243255216e+00, 6.21359222361793417e-01,  4.75845906381452632e-01,
-1.64062500000026312e+00, 6.09523809523711768e-01,  4.95077266798011895e-01,
-1.67187500000027911e+00, 5.98130841121395473e-01,  5.13945751102401260e-01,
-1.70312500224662178e+00, 5.87155962528224662e-01,  5.32464800188589216e-01,
-1.73437500283893620e+00, 5.76576575632799071e-01,  5.50647119589526390e-01,
-1.76562500399259092e+00, 5.66371680135198341e-01,  5.68504737613959144e-01,
-1.79687500443862880e+00, 5.56521737755718449e-01,  5.86049047473771623e-01,
-1.82812500114411280e+00, 5.47008546666207462e-01,  6.03290852063923744e-01,
-1.85937500250667465e+00, 5.37815125325376786e-01,  6.20240411099985067e-01,
-1.89062500504214515e+00, 5.28925618424108568e-01,  6.36907464903988974e-01,
-1.92187500371610143e+00, 5.20325202245941476e-01,  6.53301273946326866e-01,
-1.95312500494870611e+00, 5.11999998702726389e-01,  6.69430656476366792e-01,
-1.98437500351688123e+00, 5.03937006980894941e-01,  6.85304004871206018e-01,
-2.03125000000003997e+00, 4.92307692307682621e-01,  7.08651367095930240e-01,
-2.09375000579615866e+00, 4.77611938976327366e-01,  7.38956719359554093e-01,
-2.15625000000061062e+00, 4.63768115941897652e-01,  7.68370601797816022e-01,
-2.21875000323311955e+00, 4.50704224695355204e-01,  7.96943975698769513e-01,
-2.28125000853738547e+00, 4.38356162743050726e-01,  8.24723542091080120e-01,
-2.34374999999916556e+00, 4.26666666666818573e-01,  8.51752210736227866e-01,
-2.40625000438447856e+00, 4.15584414827170512e-01,  8.78069520876078258e-01,
-2.46875000884389584e+00, 4.05063289688167072e-01,  9.03711953249632494e-01,
-2.53124999999940403e+00, 3.95061728395154743e-01,  9.28713251872476775e-01,
-2.59375000434366632e+00, 3.85542168029044230e-01,  9.53104706671537905e-01,
-2.65625000734081196e+00, 3.76470587194880080e-01,  9.76915356454189698e-01,
-2.71875000787161980e+00, 3.67816090889081959e-01,  1.00017221875016560e+00,
-2.78125001557333462e+00, 3.59550559784484969e-01,  1.02290047253181449e+00,
-2.84375001147093220e+00, 3.51648350229895601e-01,  1.04512360775085789e+00,
-2.90625000771072894e+00, 3.44086020592463127e-01,  1.06686359300668343e+00,
-2.96875001371853831e+00, 3.36842103706616824e-01,  1.08814099342179560e+00,
-3.03125000512624965e+00, 3.29896906658595002e-01,  1.10897507739479018e+00,
-3.09375001373132807e+00, 3.23232321797685962e-01,  1.12938395177327244e+00,
-3.15625001204422961e+00, 3.16831681959289180e-01,  1.14938461785752644e+00,
-3.21875000888250318e+00, 3.10679610793130057e-01,  1.16899308818952186e+00,
-3.28125000000102052e+00, 3.04761904761809976e-01,  1.18822444735810784e+00,
-3.34375001587649123e+00, 2.99065419140752298e-01,  1.20709293641028914e+00,
-3.40625000791328070e+00, 2.93577980969346064e-01,  1.22561198175258212e+00,
-3.46875000615970519e+00, 2.88288287776354346e-01,  1.24379430028837845e+00,
-3.53125000516822674e+00, 2.83185840293502689e-01,  1.26165191737618265e+00,
-3.59375001425228779e+00, 2.78260868461675415e-01,  1.27919622952937750e+00,
-3.65625001719730669e+00, 2.73504272217836075e-01,  1.29643803670156643e+00,
-3.71875000856489324e+00, 2.68907562405871714e-01,  1.31338759261496740e+00,
-3.78125001788371806e+00, 2.64462808666557803e-01,  1.33005464752659286e+00,
-3.84375001532508964e+00, 2.60162600588744020e-01,  1.34644845655970613e+00,
-3.90625000429340918e+00, 2.55999999718627136e-01,  1.36257783560168733e+00,
-3.96875001912740766e+00, 2.51968502722644594e-01,  1.37845118847836900e+00,
-4.06250002536431332e+00, 2.46153844616978895e-01,  1.40179855389937913e+00,
-4.18750001743208244e+00, 2.38805969155131859e-01,  1.43210390131407017e+00,
-4.31250002253733200e+00, 2.31884056759177282e-01,  1.46151778758352613e+00,
-4.43750000671406397e+00, 2.25352112335092170e-01,  1.49009115631456268e+00,
-4.56250002627485340e+00, 2.19178080929562313e-01,  1.51787072466748185e+00,
-4.68750001185115028e+00, 2.13333332793974317e-01,  1.54489939382477459e+00,
-4.81250001682742301e+00, 2.07792207065640028e-01,  1.57121670311050998e+00,
-4.93750000000042366e+00, 2.02531645569602875e-01,  1.59685913022732606e+00,
-5.06249999999927613e+00, 1.97530864197559108e-01,  1.62186043243251454e+00,
-5.18750002327641901e+00, 1.92771083472381588e-01,  1.64625189004383721e+00,
-5.31250002381002329e+00, 1.88235293273997795e-01,  1.67006253873242194e+00,
-5.43750000000577405e+00, 1.83908045976816203e-01,  1.69331939641586438e+00,
-5.56250002193114934e+00, 1.79775280190080267e-01,  1.71604765143503712e+00,
-5.68749999999938005e+00, 1.75824175824194989e-01,  1.73827078427695980e+00,
-5.81250002749782002e+00, 1.72043009938785768e-01,  1.76001077564428243e+00,
-5.93749999999874767e+00, 1.68421052631614471e-01,  1.78128816936054868e+00,
-6.06250001966917473e+00, 1.64948453073088669e-01,  1.80212225950800153e+00,
-6.18750003004243609e+00, 1.61616160831459688e-01,  1.82253113275015188e+00,
-6.31250002448351388e+00, 1.58415840969730465e-01,  1.84253179848005466e+00,
-6.43750001359968849e+00, 1.55339805497076044e-01,  1.86214026810242750e+00,
-6.56250003345742350e+00, 1.52380951604072529e-01,  1.88137163301601618e+00,
-6.68750002403557531e+00, 1.49532709742937614e-01,  1.90024011581622965e+00,
-6.81250003423489581e+00, 1.46788990088028509e-01,  1.91875916501466826e+00,
-6.93750003062940923e+00, 1.44144143507740546e-01,  1.93694148348760287e+00,
-7.06250002747386052e+00, 1.41592919803171097e-01,  1.95479910036266347e+00,
-7.18750003617887856e+00, 1.39130434082284093e-01,  1.97234341115705192e+00,
-7.31250000000050537e+00, 1.36752136752127301e-01,  1.98958521255804399e+00,
-7.43750002212249761e+00, 1.34453781112678528e-01,  2.00653477384620160e+00,
-7.56250003604752941e+00, 1.32231404328381430e-01,  2.02320182812357530e+00,
-7.68750005007207449e+00, 1.30081299965731312e-01,  2.03959563964607682e+00,
-7.81249996125652668e+00, 1.28000000634773070e-01,  2.05572501010335529e+00,
-7.93750005224239974e+00, 1.25984251139310915e-01,  2.07159837080052966e+00,
-8.12500004244456164e+00, 1.23076922433975874e-01,  2.09494573343974722e+00,
-8.37500006149772425e+00, 1.19402984197849338e-01,  2.12525108505414195e+00,
-8.62500006593247370e+00, 1.15942028099206410e-01,  2.15466497056176820e+00,
-8.87500007743793873e+00, 1.12676055354884341e-01,  2.18323834408688100e+00,
-9.12500001754142609e+00, 1.09589040885222130e-01,  2.21101790139090326e+00,
-9.37500007707016181e+00, 1.06666665789779500e-01,  2.23804658007729174e+00,
-9.62500004426353151e+00, 1.03896103418305616e-01,  2.26436388477265638e+00,
-9.87500006518495788e+00, 1.01265822116353585e-01,  2.29000631738819393e+00,
-1.01250000000026539e+01, 9.87654320987395445e-02,  2.31500761299286495e+00,
-1.03750000409819823e+01, 9.63855417879450060e-02,  2.33939907006683256e+00,
-1.06250000362555337e+01, 9.41176467376672460e-02,  2.36320971822276604e+00,
-1.08750000879032314e+01, 9.19540222452362582e-02,  2.38646658505780351e+00,
-1.11250000697274576e+01, 8.98876398860551373e-02,  2.40919483431994053e+00,
-1.13750000462194141e+01, 8.79120875548795450e-02,  2.43141796890025930e+00,
-1.16250000714972366e+01, 8.60215048472860316e-02,  2.45315795762371991e+00,
-1.18750000788855150e+01, 8.42105257563797310e-02,  2.47443535656369562e+00,
-1.21250000895724916e+01, 8.24742261948517991e-02,  2.49526944421096886e+00,
-1.23750000985058719e+01, 8.08080801648427965e-02,  2.51567831641482442e+00,
-1.26250000894226950e+01, 7.92079202310506381e-02,  2.53567898224440924e+00,
-1.28750000768594433e+01, 7.76699024489580225e-02,  2.55528745251946532e+00,
-1.31250000578007420e+01, 7.61904758549435401e-02,  2.57451881288155349e+00,
-1.33750000809310077e+01, 7.47663546877819496e-02,  2.59338729883298669e+00,
-1.36250000915049636e+01, 7.33944949199294983e-02,  2.61190634726526838e+00,
-1.38750000830616607e+01, 7.20720716406179490e-02,  2.63008866561892418e+00,
-1.41249999999960103e+01, 7.07964601770111474e-02,  2.64794627703222218e+00,
-1.43750000290097564e+01, 6.95652172509168693e-02,  2.66549058870148414e+00,
-1.46250000868097665e+01, 6.83760679702078294e-02,  2.68273239905363070e+00,
-1.48750000966053975e+01, 6.72268903196987927e-02,  2.69968195792617394e+00,
-1.51250001097012756e+01, 6.61157019998031836e-02,  2.71634901116988203e+00,
-1.53750000510427132e+01, 6.50406501905787804e-02,  2.73274281701243282e+00,
-1.56250001080665442e+01, 6.39999995573594382e-02,  2.74887220253872400e+00,
-1.58750000434989929e+01, 6.29921258116476201e-02,  2.76474554751884938e+00,
-1.62500000641781739e+01, 6.15384612954199342e-02,  2.78809291272517257e+00,
-1.67500001015987401e+01, 5.97014921751882754e-02,  2.81839826433667184e+00,
-1.72500001048300184e+01, 5.79710141404578272e-02,  2.84781214955447126e+00,
-1.77500001262529885e+01, 5.63380277682904579e-02,  2.87638552303426920e+00,
-1.82500001543340602e+01, 5.47945200845665337e-02,  2.90416508848516131e+00,
-1.87500001096404212e+01, 5.33333330214672482e-02,  2.93119375826390893e+00,
-1.92500001680268191e+01, 5.19480514946147609e-02,  2.95751106946245912e+00,
-1.97500000329124035e+01, 5.06329113080278073e-02,  2.98315349301358168e+00,
-2.02500001270002485e+01, 4.93827157396732261e-02,  3.00815479982416534e+00,
-2.07500001519906796e+01, 4.81927707313324349e-02,  3.03254625400155930e+00,
-2.12500001425219267e+01, 4.70588232137922752e-02,  3.05635690207734001e+00,
-2.17500000758314478e+01, 4.59770113339538697e-02,  3.07961376102119644e+00,
-2.22500001767207358e+01, 4.49438198677525880e-02,  3.10234201655475417e+00,
-2.27500001365873317e+01, 4.39560436921389575e-02,  3.12456515140079816e+00,
-2.32500001697599998e+01, 4.30107523741288036e-02,  3.14630513933487066e+00,
-2.37500001766865303e+01, 4.21052628446554611e-02,  3.16758253792008304e+00,
+	9.47265623608246343e-02, 1.05567010464380857e+01,
+	-2.35676082856530300e+00, 9.66796869131412717e-02,
+	1.03434344062203838e+01, -2.33635196153499791e+00,
+	9.86328118117651004e-02, 1.01386139321308306e+01,
+	-2.31635129573594156e+00, 1.00585936733578435e-01,
+	9.94174764856737347e+00, -2.29674282498938709e+00,
+	1.02539062499949152e-01, 9.75238095238578850e+00,
+	-2.27751145544242561e+00, 1.04492186859904843e-01,
+	9.57009351656812157e+00, -2.25864297726331742e+00,
+	1.06445312294918631e-01, 9.39449543094380957e+00,
+	-2.24012392529694537e+00, 1.08398437050250693e-01,
+	9.22522526350104144e+00, -2.22194160843615762e+00,
+	1.10351562442130582e-01, 9.06194690740703912e+00,
+	-2.20408398741152212e+00, 1.12304686894746625e-01,
+	8.90434787407592943e+00, -2.18653968262558962e+00,
+	1.14257811990227776e-01, 8.75213679118525256e+00,
+	-2.16929787526329321e+00, 1.16210936696872255e-01,
+	8.60504207627572093e+00, -2.15234831939887172e+00,
+	1.18164061975360682e-01, 8.46280995492959498e+00,
+	-2.13568126444263484e+00, 1.20117187499996322e-01,
+	8.32520325203277523e+00, -2.11928745022706622e+00,
+	1.22070312499895098e-01, 8.19200000000703987e+00,
+	-2.10315806829801133e+00, 1.24023436774175100e-01,
+	8.06299217317146599e+00, -2.08728472499318229e+00,
+	1.26953123746900931e-01, 7.87692315467275872e+00,
+	-2.06393736501443570e+00, 1.30859374098123454e-01,
+	7.64179109744297769e+00, -2.03363201254049386e+00,
+	1.34765623780674720e-01, 7.42028992220936967e+00,
+	-2.00421812948999545e+00, 1.38671874242985771e-01,
+	7.21126764500034501e+00, -1.97564475345722457e+00,
+	1.42578124148616536e-01, 7.01369867201821506e+00,
+	-1.94786518986246371e+00, 1.46484374166731490e-01,
+	6.82666670549979404e+00, -1.92083651719164372e+00,
+	1.50390624434435488e-01, 6.64935067435644189e+00,
+	-1.89451920694646070e+00, 1.54296874339723084e-01,
+	6.48101268596180624e+00, -1.86887677685174936e+00,
+	1.58203124999987427e-01, 6.32098765432149001e+00,
+	-1.84387547036714849e+00, 1.62109374999815342e-01,
+	6.16867469880220742e+00, -1.81948401724404896e+00,
+	1.66015624243955634e-01, 6.02352943919619310e+00,
+	-1.79567337310324682e+00, 1.69921874302298687e-01,
+	5.88505749542848644e+00, -1.77241651049093640e+00,
+	1.73828124315277527e-01, 5.75280901142480605e+00,
+	-1.74968825924644555e+00, 1.77734374286237506e-01,
+	5.62637364896854919e+00, -1.72746512253855222e+00,
+	1.81640624146994889e-01, 5.50537636993989743e+00,
+	-1.70572513658236602e+00, 1.85546874316304788e-01,
+	5.38947370406942916e+00, -1.68444773712372431e+00,
+	1.89453124405085355e-01, 5.27835053203882509e+00,
+	-1.66361364967629299e+00, 1.93359374570531595e-01,
+	5.17171718320401652e+00, -1.64320477712600699e+00,
+	1.97265624263334577e-01, 5.06930694962380368e+00,
+	-1.62320411193263148e+00, 2.01171874086291030e-01,
+	4.97087380898513764e+00, -1.60359564135180399e+00,
+	2.05078123979995308e-01, 4.87619050044336610e+00,
+	-1.58436427985572159e+00, 2.08984373896073439e-01,
+	4.78504675424820736e+00, -1.56549579585994181e+00,
+	2.12890623963011144e-01, 4.69724772930228163e+00,
+	-1.54697674768135762e+00, 2.16796874723889421e-01,
+	4.61261261848719517e+00, -1.52879442500076479e+00,
+	2.20703124198150608e-01, 4.53097346778917753e+00,
+	-1.51093680996032553e+00, 2.24609374375627030e-01,
+	4.45217392541970725e+00, -1.49339249945607477e+00,
+	2.28515625000094036e-01, 4.37606837606657528e+00,
+	-1.47615069024134016e+00, 2.32421873924349737e-01,
+	4.30252102831546246e+00, -1.45920113655598627e+00,
+	2.36328123935216378e-01, 4.23140497774241098e+00,
+	-1.44253408394829741e+00, 2.40234375000066919e-01,
+	4.16260162601510064e+00, -1.42614026966681173e+00,
+	2.44140623863132178e-01, 4.09600001907347711e+00,
+	-1.41001089239381727e+00, 2.48046874999894917e-01,
+	4.03149606299383390e+00, -1.39413753858134015e+00,
+	2.53906248590769879e-01, 3.93846156032078243e+00,
+	-1.37079018013412401e+00, 2.61718748558906533e-01,
+	3.82089554342693294e+00, -1.34048483059486401e+00,
+	2.69531249159214337e-01, 3.71014493910979404e+00,
+	-1.31107094300173976e+00, 2.77343749428383191e-01,
+	3.60563381024826013e+00, -1.28249756949928795e+00,
+	2.85156249289339359e-01, 3.50684932380819214e+00,
+	-1.25471800582335113e+00, 2.92968749999700462e-01,
+	3.41333333333682321e+00, -1.22768933094427446e+00,
+	3.00781248554318814e-01, 3.32467534065511261e+00,
+	-1.20137202743229921e+00, 3.08593748521894806e-01,
+	3.24050634463533127e+00, -1.17572959680235023e+00,
+	3.16406249999639899e-01, 3.16049382716409077e+00,
+	-1.15072828980826181e+00, 3.24218749999785061e-01,
+	3.08433734939963511e+00, -1.12633683668362750e+00,
+	3.32031248841858584e-01, 3.01176471638753718e+00,
+	-1.10252619147729547e+00, 3.39843749265406558e-01,
+	2.94252874199264314e+00, -1.07926932798654107e+00,
+	3.47656249999834799e-01, 2.87640449438338930e+00,
+	-1.05654107474789782e+00, 3.55468749999899247e-01,
+	2.81318681318761055e+00, -1.03431793796299587e+00,
+	3.63281249999864997e-01, 2.75268817204403371e+00,
+	-1.01257795132667816e+00, 3.71093749064121570e-01,
+	2.69473684890124421e+00, -9.91300555400967731e-01,
+	3.78906249999751032e-01, 2.63917525773369288e+00,
+	-9.70466465976836723e-01, 3.86718748879039009e-01,
+	2.58585859335407608e+00, -9.50057597243619156e-01,
+	3.94531249999987899e-01, 2.53465346534661240e+00,
+	-9.30056927638333697e-01, 4.02343749999485523e-01,
+	2.48543689320706163e+00, -9.10448456251205407e-01,
+	4.10156249578856991e-01, 2.43809524059864202e+00,
+	-8.91217095348825872e-01, 4.17968749447214571e-01,
+	2.39252336765021800e+00, -8.72348611340208357e-01,
+	4.25781248601723117e-01, 2.34862386092395203e+00,
+	-8.53829565534445223e-01, 4.33593749393073047e-01,
+	2.30630630953458038e+00, -8.35647244566987801e-01,
+	4.41406248572254134e-01, 2.26548673299152270e+00,
+	-8.17789629001761220e-01, 4.49218749348472501e-01,
+	2.22608695975035964e+00, -8.00245317566669279e-01,
+	4.57031249277175089e-01, 2.18803419149470768e+00,
+	-7.83003511263371976e-01, 4.64843748529596368e-01,
+	2.15126051100659366e+00, -7.66053954531254355e-01,
+	4.72656248830947701e-01, 2.11570248457175136e+00,
+	-7.49386901356188240e-01, 4.80468748609962581e-01,
+	2.08130081902951236e+00, -7.32993092000230995e-01,
+	4.88281249241778237e-01, 2.04800000318021258e+00,
+	-7.16863708730099525e-01, 4.96093748931098810e-01,
+	2.01574803583926521e+00, -7.00990360175606675e-01,
+	5.07812497779701388e-01, 1.96923077784079825e+00,
+	-6.77642998396260410e-01, 5.23437498033319737e-01,
+	1.91044776837204044e+00, -6.47337648285891021e-01,
+	5.39062498006593560e-01, 1.85507247062801328e+00,
+	-6.17923763020271188e-01, 5.54687498964024250e-01,
+	1.80281690477552603e+00, -5.89350388745976339e-01,
+	5.70312499806522322e-01, 1.75342465812909332e+00,
+	-5.61570823110474571e-01, 5.85937497921867001e-01,
+	1.70666667271966777e+00, -5.34542153929987052e-01,
+	6.01562498226483444e-01, 1.66233766723853860e+00,
+	-5.08224845014116688e-01, 6.17187498682654212e-01,
+	1.62025316801528496e+00, -4.82582413587029357e-01,
+	6.32812500000264566e-01, 1.58024691357958624e+00,
+	-4.57581109246760320e-01, 6.48437499353274216e-01,
+	1.54216867623689291e+00, -4.33189657120379490e-01,
+	6.64062498728508976e-01, 1.50588235582451335e+00,
+	-4.09379009344016609e-01, 6.79687498865382267e-01,
+	1.47126437027210688e+00, -3.86122146934356092e-01,
+	6.95312498728747119e-01, 1.43820224982050338e+00,
+	-3.63393896015796081e-01, 7.10937499999943157e-01,
+	1.40659340659351906e+00, -3.41170757402847080e-01,
+	7.26562499999845568e-01, 1.37634408602179792e+00,
+	-3.19430770766573779e-01, 7.42187500000120126e-01,
+	1.34736842105241350e+00, -2.98153372318914478e-01,
+	7.57812499999581890e-01, 1.31958762886670744e+00,
+	-2.77319285416786077e-01, 7.73437498602746576e-01,
+	1.29292929526503420e+00, -2.56910415591577124e-01,
+	7.89062500000142664e-01, 1.26732673267303819e+00,
+	-2.36909747078176913e-01, 8.04687500000259015e-01,
+	1.24271844660154174e+00, -2.17301275689659512e-01,
+	8.20312499999677036e-01, 1.21904761904809900e+00,
+	-1.98069913762487504e-01, 8.35937499999997113e-01,
+	1.19626168224299478e+00, -1.79201429457714445e-01,
+	8.51562499999758749e-01, 1.17431192660583728e+00,
+	-1.60682381690756770e-01, 8.67187500000204725e-01,
+	1.15315315315288092e+00, -1.42500062607046951e-01,
+	8.82812500000407896e-01, 1.13274336283133503e+00,
+	-1.24642445206814556e-01, 8.98437499999816813e-01,
+	1.11304347826109651e+00, -1.07098135556570995e-01,
+	9.14062499999708455e-01, 1.09401709401744296e+00,
+	-8.98563291221800009e-02, 9.29687500000063949e-01,
+	1.07563025210076635e+00, -7.29067708080189947e-02,
+	9.45312499999844014e-01, 1.05785123966959604e+00,
+	-5.62397183230410880e-02, 9.60937500000120459e-01,
+	1.04065040650393459e+00, -3.98459085470743157e-02,
+	9.76562499999976685e-01, 1.02400000000002445e+00,
+	-2.37165266173399170e-02, 9.92187500000169420e-01,
+	1.00787401574785940e+00, -7.84317746085513856e-03,
+	1.01562500000004907e+00, 9.84615384615337041e-01,
+	1.55041865360135717e-02, 1.04687500000009237e+00,
+	9.55223880596930641e-01, 4.58095360313824362e-02,
+	1.07812500000002154e+00, 9.27536231884039442e-01,
+	7.52234212376075018e-02, 1.10937499999982481e+00,
+	9.01408450704367703e-01, 1.03796793681485644e-01,
+	1.14062500000007416e+00, 8.76712328767066285e-01,
+	1.31576357788784293e-01, 1.17187500000009659e+00,
+	8.53333333333263000e-01, 1.58605030176721007e-01,
+	1.20312499999950173e+00, 8.31168831169175393e-01,
+	1.84922338493597849e-01, 1.23437500000022027e+00,
+	8.10126582278336449e-01, 2.10564769107528083e-01,
+	1.26562500000064615e+00, 7.90123456789720069e-01,
+	2.35566071313277448e-01, 1.29687500000144706e+00,
+	7.71084337348537208e-01, 2.59957524438041876e-01,
+	1.32812499999945932e+00, 7.52941176470894757e-01,
+	2.83768173130237500e-01, 1.35937500055846350e+00,
+	7.35632183605830825e-01, 3.07025035705735583e-01,
+	1.39062499999999467e+00, 7.19101123595508374e-01,
+	3.29753286372464149e-01, 1.42187500000017564e+00,
+	7.03296703296616421e-01, 3.51976423157301710e-01,
+	1.45312500161088876e+00, 6.88172042247866766e-01,
+	3.73716410902152685e-01, 1.48437500134602307e+00,
+	6.73684209915422660e-01, 3.94993809147663466e-01,
+	1.51562499999932343e+00, 6.59793814433284220e-01,
+	4.15827895143264570e-01, 1.54687500000028200e+00,
+	6.46464646464528614e-01, 4.36236766775100371e-01,
+	1.57812500000061906e+00, 6.33663366336385092e-01,
+	4.56237433481979870e-01, 1.60937500243255216e+00,
+	6.21359222361793417e-01, 4.75845906381452632e-01,
+	1.64062500000026312e+00, 6.09523809523711768e-01,
+	4.95077266798011895e-01, 1.67187500000027911e+00,
+	5.98130841121395473e-01, 5.13945751102401260e-01,
+	1.70312500224662178e+00, 5.87155962528224662e-01,
+	5.32464800188589216e-01, 1.73437500283893620e+00,
+	5.76576575632799071e-01, 5.50647119589526390e-01,
+	1.76562500399259092e+00, 5.66371680135198341e-01,
+	5.68504737613959144e-01, 1.79687500443862880e+00,
+	5.56521737755718449e-01, 5.86049047473771623e-01,
+	1.82812500114411280e+00, 5.47008546666207462e-01,
+	6.03290852063923744e-01, 1.85937500250667465e+00,
+	5.37815125325376786e-01, 6.20240411099985067e-01,
+	1.89062500504214515e+00, 5.28925618424108568e-01,
+	6.36907464903988974e-01, 1.92187500371610143e+00,
+	5.20325202245941476e-01, 6.53301273946326866e-01,
+	1.95312500494870611e+00, 5.11999998702726389e-01,
+	6.69430656476366792e-01, 1.98437500351688123e+00,
+	5.03937006980894941e-01, 6.85304004871206018e-01,
+	2.03125000000003997e+00, 4.92307692307682621e-01,
+	7.08651367095930240e-01, 2.09375000579615866e+00,
+	4.77611938976327366e-01, 7.38956719359554093e-01,
+	2.15625000000061062e+00, 4.63768115941897652e-01,
+	7.68370601797816022e-01, 2.21875000323311955e+00,
+	4.50704224695355204e-01, 7.96943975698769513e-01,
+	2.28125000853738547e+00, 4.38356162743050726e-01,
+	8.24723542091080120e-01, 2.34374999999916556e+00,
+	4.26666666666818573e-01, 8.51752210736227866e-01,
+	2.40625000438447856e+00, 4.15584414827170512e-01,
+	8.78069520876078258e-01, 2.46875000884389584e+00,
+	4.05063289688167072e-01, 9.03711953249632494e-01,
+	2.53124999999940403e+00, 3.95061728395154743e-01,
+	9.28713251872476775e-01, 2.59375000434366632e+00,
+	3.85542168029044230e-01, 9.53104706671537905e-01,
+	2.65625000734081196e+00, 3.76470587194880080e-01,
+	9.76915356454189698e-01, 2.71875000787161980e+00,
+	3.67816090889081959e-01, 1.00017221875016560e+00,
+	2.78125001557333462e+00, 3.59550559784484969e-01,
+	1.02290047253181449e+00, 2.84375001147093220e+00,
+	3.51648350229895601e-01, 1.04512360775085789e+00,
+	2.90625000771072894e+00, 3.44086020592463127e-01,
+	1.06686359300668343e+00, 2.96875001371853831e+00,
+	3.36842103706616824e-01, 1.08814099342179560e+00,
+	3.03125000512624965e+00, 3.29896906658595002e-01,
+	1.10897507739479018e+00, 3.09375001373132807e+00,
+	3.23232321797685962e-01, 1.12938395177327244e+00,
+	3.15625001204422961e+00, 3.16831681959289180e-01,
+	1.14938461785752644e+00, 3.21875000888250318e+00,
+	3.10679610793130057e-01, 1.16899308818952186e+00,
+	3.28125000000102052e+00, 3.04761904761809976e-01,
+	1.18822444735810784e+00, 3.34375001587649123e+00,
+	2.99065419140752298e-01, 1.20709293641028914e+00,
+	3.40625000791328070e+00, 2.93577980969346064e-01,
+	1.22561198175258212e+00, 3.46875000615970519e+00,
+	2.88288287776354346e-01, 1.24379430028837845e+00,
+	3.53125000516822674e+00, 2.83185840293502689e-01,
+	1.26165191737618265e+00, 3.59375001425228779e+00,
+	2.78260868461675415e-01, 1.27919622952937750e+00,
+	3.65625001719730669e+00, 2.73504272217836075e-01,
+	1.29643803670156643e+00, 3.71875000856489324e+00,
+	2.68907562405871714e-01, 1.31338759261496740e+00,
+	3.78125001788371806e+00, 2.64462808666557803e-01,
+	1.33005464752659286e+00, 3.84375001532508964e+00,
+	2.60162600588744020e-01, 1.34644845655970613e+00,
+	3.90625000429340918e+00, 2.55999999718627136e-01,
+	1.36257783560168733e+00, 3.96875001912740766e+00,
+	2.51968502722644594e-01, 1.37845118847836900e+00,
+	4.06250002536431332e+00, 2.46153844616978895e-01,
+	1.40179855389937913e+00, 4.18750001743208244e+00,
+	2.38805969155131859e-01, 1.43210390131407017e+00,
+	4.31250002253733200e+00, 2.31884056759177282e-01,
+	1.46151778758352613e+00, 4.43750000671406397e+00,
+	2.25352112335092170e-01, 1.49009115631456268e+00,
+	4.56250002627485340e+00, 2.19178080929562313e-01,
+	1.51787072466748185e+00, 4.68750001185115028e+00,
+	2.13333332793974317e-01, 1.54489939382477459e+00,
+	4.81250001682742301e+00, 2.07792207065640028e-01,
+	1.57121670311050998e+00, 4.93750000000042366e+00,
+	2.02531645569602875e-01, 1.59685913022732606e+00,
+	5.06249999999927613e+00, 1.97530864197559108e-01,
+	1.62186043243251454e+00, 5.18750002327641901e+00,
+	1.92771083472381588e-01, 1.64625189004383721e+00,
+	5.31250002381002329e+00, 1.88235293273997795e-01,
+	1.67006253873242194e+00, 5.43750000000577405e+00,
+	1.83908045976816203e-01, 1.69331939641586438e+00,
+	5.56250002193114934e+00, 1.79775280190080267e-01,
+	1.71604765143503712e+00, 5.68749999999938005e+00,
+	1.75824175824194989e-01, 1.73827078427695980e+00,
+	5.81250002749782002e+00, 1.72043009938785768e-01,
+	1.76001077564428243e+00, 5.93749999999874767e+00,
+	1.68421052631614471e-01, 1.78128816936054868e+00,
+	6.06250001966917473e+00, 1.64948453073088669e-01,
+	1.80212225950800153e+00, 6.18750003004243609e+00,
+	1.61616160831459688e-01, 1.82253113275015188e+00,
+	6.31250002448351388e+00, 1.58415840969730465e-01,
+	1.84253179848005466e+00, 6.43750001359968849e+00,
+	1.55339805497076044e-01, 1.86214026810242750e+00,
+	6.56250003345742350e+00, 1.52380951604072529e-01,
+	1.88137163301601618e+00, 6.68750002403557531e+00,
+	1.49532709742937614e-01, 1.90024011581622965e+00,
+	6.81250003423489581e+00, 1.46788990088028509e-01,
+	1.91875916501466826e+00, 6.93750003062940923e+00,
+	1.44144143507740546e-01, 1.93694148348760287e+00,
+	7.06250002747386052e+00, 1.41592919803171097e-01,
+	1.95479910036266347e+00, 7.18750003617887856e+00,
+	1.39130434082284093e-01, 1.97234341115705192e+00,
+	7.31250000000050537e+00, 1.36752136752127301e-01,
+	1.98958521255804399e+00, 7.43750002212249761e+00,
+	1.34453781112678528e-01, 2.00653477384620160e+00,
+	7.56250003604752941e+00, 1.32231404328381430e-01,
+	2.02320182812357530e+00, 7.68750005007207449e+00,
+	1.30081299965731312e-01, 2.03959563964607682e+00,
+	7.81249996125652668e+00, 1.28000000634773070e-01,
+	2.05572501010335529e+00, 7.93750005224239974e+00,
+	1.25984251139310915e-01, 2.07159837080052966e+00,
+	8.12500004244456164e+00, 1.23076922433975874e-01,
+	2.09494573343974722e+00, 8.37500006149772425e+00,
+	1.19402984197849338e-01, 2.12525108505414195e+00,
+	8.62500006593247370e+00, 1.15942028099206410e-01,
+	2.15466497056176820e+00, 8.87500007743793873e+00,
+	1.12676055354884341e-01, 2.18323834408688100e+00,
+	9.12500001754142609e+00, 1.09589040885222130e-01,
+	2.21101790139090326e+00, 9.37500007707016181e+00,
+	1.06666665789779500e-01, 2.23804658007729174e+00,
+	9.62500004426353151e+00, 1.03896103418305616e-01,
+	2.26436388477265638e+00, 9.87500006518495788e+00,
+	1.01265822116353585e-01, 2.29000631738819393e+00,
+	1.01250000000026539e+01, 9.87654320987395445e-02,
+	2.31500761299286495e+00, 1.03750000409819823e+01,
+	9.63855417879450060e-02, 2.33939907006683256e+00,
+	1.06250000362555337e+01, 9.41176467376672460e-02,
+	2.36320971822276604e+00, 1.08750000879032314e+01,
+	9.19540222452362582e-02, 2.38646658505780351e+00,
+	1.11250000697274576e+01, 8.98876398860551373e-02,
+	2.40919483431994053e+00, 1.13750000462194141e+01,
+	8.79120875548795450e-02, 2.43141796890025930e+00,
+	1.16250000714972366e+01, 8.60215048472860316e-02,
+	2.45315795762371991e+00, 1.18750000788855150e+01,
+	8.42105257563797310e-02, 2.47443535656369562e+00,
+	1.21250000895724916e+01, 8.24742261948517991e-02,
+	2.49526944421096886e+00, 1.23750000985058719e+01,
+	8.08080801648427965e-02, 2.51567831641482442e+00,
+	1.26250000894226950e+01, 7.92079202310506381e-02,
+	2.53567898224440924e+00, 1.28750000768594433e+01,
+	7.76699024489580225e-02, 2.55528745251946532e+00,
+	1.31250000578007420e+01, 7.61904758549435401e-02,
+	2.57451881288155349e+00, 1.33750000809310077e+01,
+	7.47663546877819496e-02, 2.59338729883298669e+00,
+	1.36250000915049636e+01, 7.33944949199294983e-02,
+	2.61190634726526838e+00, 1.38750000830616607e+01,
+	7.20720716406179490e-02, 2.63008866561892418e+00,
+	1.41249999999960103e+01, 7.07964601770111474e-02,
+	2.64794627703222218e+00, 1.43750000290097564e+01,
+	6.95652172509168693e-02, 2.66549058870148414e+00,
+	1.46250000868097665e+01, 6.83760679702078294e-02,
+	2.68273239905363070e+00, 1.48750000966053975e+01,
+	6.72268903196987927e-02, 2.69968195792617394e+00,
+	1.51250001097012756e+01, 6.61157019998031836e-02,
+	2.71634901116988203e+00, 1.53750000510427132e+01,
+	6.50406501905787804e-02, 2.73274281701243282e+00,
+	1.56250001080665442e+01, 6.39999995573594382e-02,
+	2.74887220253872400e+00, 1.58750000434989929e+01,
+	6.29921258116476201e-02, 2.76474554751884938e+00,
+	1.62500000641781739e+01, 6.15384612954199342e-02,
+	2.78809291272517257e+00, 1.67500001015987401e+01,
+	5.97014921751882754e-02, 2.81839826433667184e+00,
+	1.72500001048300184e+01, 5.79710141404578272e-02,
+	2.84781214955447126e+00, 1.77500001262529885e+01,
+	5.63380277682904579e-02, 2.87638552303426920e+00,
+	1.82500001543340602e+01, 5.47945200845665337e-02,
+	2.90416508848516131e+00, 1.87500001096404212e+01,
+	5.33333330214672482e-02, 2.93119375826390893e+00,
+	1.92500001680268191e+01, 5.19480514946147609e-02,
+	2.95751106946245912e+00, 1.97500000329124035e+01,
+	5.06329113080278073e-02, 2.98315349301358168e+00,
+	2.02500001270002485e+01, 4.93827157396732261e-02,
+	3.00815479982416534e+00, 2.07500001519906796e+01,
+	4.81927707313324349e-02, 3.03254625400155930e+00,
+	2.12500001425219267e+01, 4.70588232137922752e-02,
+	3.05635690207734001e+00, 2.17500000758314478e+01,
+	4.59770113339538697e-02, 3.07961376102119644e+00,
+	2.22500001767207358e+01, 4.49438198677525880e-02,
+	3.10234201655475417e+00, 2.27500001365873317e+01,
+	4.39560436921389575e-02, 3.12456515140079816e+00,
+	2.32500001697599998e+01, 4.30107523741288036e-02,
+	3.14630513933487066e+00, 2.37500001766865303e+01,
+	4.21052628446554611e-02, 3.16758253792008304e+00,
 };
--- old/usr/src/lib/libm/common/C/_TBL_log2.c	2019-06-06 20:37:31.268677219 +0000
+++ new/usr/src/lib/libm/common/C/_TBL_log2.c	2019-06-06 20:37:31.288988869 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,92 +31,135 @@
 #include "libm_protos.h"
 
 const double _TBL_log2_hi[] = {
- 0.00000000000000000e+00, 1.12272500991821289e-02, 2.23678052425384521e-02,
- 3.34229767322540283e-02, 4.43941056728363037e-02, 5.52824139595031738e-02,
- 6.60891532897949219e-02, 7.68155455589294434e-02, 8.74627828598022461e-02,
- 9.80320572853088379e-02, 1.08524441719055176e-01, 1.18941068649291992e-01,
- 1.29282951354980469e-01, 1.39551281929016113e-01, 1.49747014045715332e-01,
- 1.59871220588684082e-01, 1.69924974441528320e-01, 1.79908990859985352e-01,
- 1.89824461936950684e-01, 1.99672341346740723e-01, 2.09453344345092773e-01,
- 2.19168424606323242e-01, 2.28818655014038086e-01, 2.38404631614685059e-01,
- 2.47927427291870117e-01, 2.57387638092041016e-01, 2.66786336898803711e-01,
- 2.76124238967895508e-01, 2.85402059555053711e-01, 2.94620513916015625e-01,
- 3.03780555725097656e-01, 3.12882900238037109e-01, 3.21928024291992188e-01,
- 3.30916643142700195e-01, 3.39849948883056641e-01, 3.48727941513061523e-01,
- 3.57551813125610352e-01, 3.66322040557861328e-01, 3.75039339065551758e-01,
- 3.83704185485839844e-01, 3.92317295074462891e-01, 4.00879383087158203e-01,
- 4.09390926361083984e-01, 4.17852401733398438e-01, 4.26264524459838867e-01,
- 4.34628009796142578e-01, 4.42943334579467773e-01, 4.51210975646972656e-01,
- 4.59431409835815430e-01, 4.67605352401733398e-01, 4.75733280181884766e-01,
- 4.83815670013427734e-01, 4.91852998733520508e-01, 4.99845743179321289e-01,
- 5.07794380187988281e-01, 5.15699386596679688e-01, 5.23561954498291016e-01,
- 5.31381130218505859e-01, 5.39158344268798828e-01, 5.46894073486328125e-01,
- 5.54588794708251953e-01, 5.62242031097412109e-01, 5.69855213165283203e-01,
- 5.77428817749023438e-01, 5.84962368011474609e-01, 5.92456817626953125e-01,
- 5.99912643432617188e-01, 6.07329845428466797e-01, 6.14709377288818359e-01,
- 6.22051715850830078e-01, 6.29356384277343750e-01, 6.36624336242675781e-01,
- 6.43856048583984375e-01, 6.51051521301269531e-01, 6.58211231231689453e-01,
- 6.65335655212402344e-01, 6.72425270080566406e-01, 6.79480075836181641e-01,
- 6.86500072479248047e-01, 6.93486690521240234e-01, 7.00439453125000000e-01,
- 7.07358837127685547e-01, 7.14245319366455078e-01, 7.21098899841308594e-01,
- 7.27920055389404297e-01, 7.34709262847900391e-01, 7.41466522216796875e-01,
- 7.48192787170410156e-01, 7.54887104034423828e-01, 7.61550903320312500e-01,
- 7.68184185028076172e-01, 7.74786949157714844e-01, 7.81359672546386719e-01,
- 7.87902355194091797e-01, 7.94415473937988281e-01, 8.00899505615234375e-01,
- 8.07354450225830078e-01, 8.13780784606933594e-01, 8.20178508758544922e-01,
- 8.26548099517822266e-01, 8.32889556884765625e-01, 8.39203357696533203e-01,
- 8.45489978790283203e-01, 8.51748943328857422e-01, 8.57980728149414062e-01,
- 8.64185810089111328e-01, 8.70364665985107422e-01, 8.76516819000244141e-01,
- 8.82642745971679688e-01, 8.88742923736572266e-01, 8.94817352294921875e-01,
- 9.00866508483886719e-01, 9.06890392303466797e-01, 9.12889003753662109e-01,
- 9.18862819671630859e-01, 9.24812316894531250e-01, 9.30737018585205078e-01,
- 9.36637878417968750e-01, 9.42514419555664062e-01, 9.48367118835449219e-01,
- 9.54195976257324219e-01, 9.60001468658447266e-01, 9.65784072875976562e-01,
- 9.71543312072753906e-01, 9.77279663085937500e-01, 9.82993125915527344e-01,
- 9.88684654235839844e-01, 9.94353294372558594e-01,
+	0.00000000000000000e+00, 1.12272500991821289e-02,
+	2.23678052425384521e-02, 3.34229767322540283e-02,
+	4.43941056728363037e-02, 5.52824139595031738e-02,
+	6.60891532897949219e-02, 7.68155455589294434e-02,
+	8.74627828598022461e-02, 9.80320572853088379e-02,
+	1.08524441719055176e-01, 1.18941068649291992e-01,
+	1.29282951354980469e-01, 1.39551281929016113e-01,
+	1.49747014045715332e-01, 1.59871220588684082e-01,
+	1.69924974441528320e-01, 1.79908990859985352e-01,
+	1.89824461936950684e-01, 1.99672341346740723e-01,
+	2.09453344345092773e-01, 2.19168424606323242e-01,
+	2.28818655014038086e-01, 2.38404631614685059e-01,
+	2.47927427291870117e-01, 2.57387638092041016e-01,
+	2.66786336898803711e-01, 2.76124238967895508e-01,
+	2.85402059555053711e-01, 2.94620513916015625e-01,
+	3.03780555725097656e-01, 3.12882900238037109e-01,
+	3.21928024291992188e-01, 3.30916643142700195e-01,
+	3.39849948883056641e-01, 3.48727941513061523e-01,
+	3.57551813125610352e-01, 3.66322040557861328e-01,
+	3.75039339065551758e-01, 3.83704185485839844e-01,
+	3.92317295074462891e-01, 4.00879383087158203e-01,
+	4.09390926361083984e-01, 4.17852401733398438e-01,
+	4.26264524459838867e-01, 4.34628009796142578e-01,
+	4.42943334579467773e-01, 4.51210975646972656e-01,
+	4.59431409835815430e-01, 4.67605352401733398e-01,
+	4.75733280181884766e-01, 4.83815670013427734e-01,
+	4.91852998733520508e-01, 4.99845743179321289e-01,
+	5.07794380187988281e-01, 5.15699386596679688e-01,
+	5.23561954498291016e-01, 5.31381130218505859e-01,
+	5.39158344268798828e-01, 5.46894073486328125e-01,
+	5.54588794708251953e-01, 5.62242031097412109e-01,
+	5.69855213165283203e-01, 5.77428817749023438e-01,
+	5.84962368011474609e-01, 5.92456817626953125e-01,
+	5.99912643432617188e-01, 6.07329845428466797e-01,
+	6.14709377288818359e-01, 6.22051715850830078e-01,
+	6.29356384277343750e-01, 6.36624336242675781e-01,
+	6.43856048583984375e-01, 6.51051521301269531e-01,
+	6.58211231231689453e-01, 6.65335655212402344e-01,
+	6.72425270080566406e-01, 6.79480075836181641e-01,
+	6.86500072479248047e-01, 6.93486690521240234e-01,
+	7.00439453125000000e-01, 7.07358837127685547e-01,
+	7.14245319366455078e-01, 7.21098899841308594e-01,
+	7.27920055389404297e-01, 7.34709262847900391e-01,
+	7.41466522216796875e-01, 7.48192787170410156e-01,
+	7.54887104034423828e-01, 7.61550903320312500e-01,
+	7.68184185028076172e-01, 7.74786949157714844e-01,
+	7.81359672546386719e-01, 7.87902355194091797e-01,
+	7.94415473937988281e-01, 8.00899505615234375e-01,
+	8.07354450225830078e-01, 8.13780784606933594e-01,
+	8.20178508758544922e-01, 8.26548099517822266e-01,
+	8.32889556884765625e-01, 8.39203357696533203e-01,
+	8.45489978790283203e-01, 8.51748943328857422e-01,
+	8.57980728149414062e-01, 8.64185810089111328e-01,
+	8.70364665985107422e-01, 8.76516819000244141e-01,
+	8.82642745971679688e-01, 8.88742923736572266e-01,
+	8.94817352294921875e-01, 9.00866508483886719e-01,
+	9.06890392303466797e-01, 9.12889003753662109e-01,
+	9.18862819671630859e-01, 9.24812316894531250e-01,
+	9.30737018585205078e-01, 9.36637878417968750e-01,
+	9.42514419555664062e-01, 9.48367118835449219e-01,
+	9.54195976257324219e-01, 9.60001468658447266e-01,
+	9.65784072875976562e-01, 9.71543312072753906e-01,
+	9.77279663085937500e-01, 9.82993125915527344e-01,
+	9.88684654235839844e-01, 9.94353294372558594e-01,
 };
+
 const double _TBL_log2_lo[] = {
- 0.00000000000000000e+00, 5.32407199143163062e-09, 7.78591605611869461e-09,
- 2.48051962506972834e-08, 1.36856171339421649e-08, 2.15416864274073636e-08,
- 3.71679775110542797e-08, 5.14919014488721604e-08, 5.83905371621603131e-08,
- 2.56752178779050280e-08, 1.50591138779666358e-08, 4.07421543880223335e-09,
- 6.55899859865622946e-08, 7.04697774403433060e-08, 1.05458966729375492e-07,
- 1.16189705334564924e-07, 2.70007840425949794e-08, 9.91549491170275978e-08,
- 9.69430665462702729e-08, 3.48962367368142750e-09, 2.12838570084203029e-08,
- 9.58558383294243244e-08, 3.54818427912568755e-08, 1.07710393847949145e-07,
- 8.61517153766060168e-08, 2.04600610755536536e-07, 2.03796097652703831e-07,
- 1.66306342048863931e-07, 1.59307194630913047e-07, 2.34975611381410033e-07,
- 1.92452005268177275e-07, 5.50463182513595194e-08, 7.05953701603703195e-08,
- 2.34971916784423615e-07, 5.40015680851899589e-08, 2.12718016029126278e-07,
- 1.91492473341603465e-07, 1.73687954457398432e-07, 9.22813729985471341e-08,
- 1.06988212380721318e-07, 1.27704297398270718e-07, 5.31950261176686284e-08,
- 9.77661777174938596e-09, 1.13152499419201003e-07, 2.30242259071696645e-07,
- 2.17840582054596399e-07, 1.61269260528736021e-07, 1.36185356146932601e-07,
- 2.08801481826511869e-07, 1.97681264041823641e-07, 1.50784512989339287e-07,
- 1.07250828689716638e-07, 9.75961542029652924e-08, 1.43903884071471071e-07,
- 2.60010707986588806e-07, 4.51687362770425967e-07, 1.55872185666914818e-09,
- 3.30297806270353139e-07, 4.66839232562134881e-07, 3.86401308539453419e-07,
- 5.69693854190458130e-08, 3.93123660542428204e-07, 3.95165664638538863e-07,
- 1.02867252517587785e-08, 1.32709681572078730e-07, 2.19641127294637299e-07,
- 1.98754510492326232e-07, 4.68321143892845854e-07, 4.66826389855508924e-07,
- 1.03605546188658804e-07, 2.35802265869106829e-07, 2.84300973057307715e-07,
- 1.41190740320740639e-07, 1.69877659083133016e-07, 2.51520105284046651e-07,
- 2.61972773884411727e-07, 7.18909291834578061e-08, 2.36692644004112907e-08,
- 4.54703970334185855e-07, 2.66978085000826612e-07, 2.65016092160396791e-07,
- 2.94953197203117899e-07, 1.98299667558641024e-07, 2.88865876540408914e-07,
- 3.99173794882405776e-07, 3.57377937852235498e-07, 4.64184350072864601e-07,
- 6.24190501305044646e-08, 3.98129044716236242e-07, 3.29124166816248113e-07,
- 1.39748850186603795e-07, 1.10443458567567753e-07, 4.09782728853196823e-08,
- 2.04197339771775867e-07, 3.92412117682061536e-07, 3.94305070358032831e-07,
- 4.71831774029316962e-07, 4.06610103464898125e-07, 4.53656642786443564e-07,
- 3.87773092718157073e-07, 4.57279976050247260e-07, 4.30400410735578705e-07,
- 7.21540920170394723e-08, 9.80872001232200742e-08, 2.66978158058219765e-07,
- 3.34565168908893463e-07, 5.35982971014292903e-08, 1.27564755579416119e-07,
- 3.03390161571307385e-07, 3.25161686840256005e-07, 4.11013021640696012e-07,
- 2.99496861839592342e-07, 2.03305051732449063e-07, 3.32476299509608735e-07,
- 4.17602963653023739e-07, 1.86711249657268702e-07, 3.18977681198347184e-07,
- 6.05846018127542565e-08, 8.57835758121197076e-08, 1.12749228435440334e-07,
- 3.34129550990056099e-07, 4.63409633672188390e-07, 2.11786110481110945e-07,
- 2.41878018084726962e-07, 2.60413978970349421e-07, 4.48778782784743522e-07,
- 3.25363260095300064e-08, 1.42486299343828112e-07,
+	0.00000000000000000e+00, 5.32407199143163062e-09,
+	7.78591605611869461e-09, 2.48051962506972834e-08,
+	1.36856171339421649e-08, 2.15416864274073636e-08,
+	3.71679775110542797e-08, 5.14919014488721604e-08,
+	5.83905371621603131e-08, 2.56752178779050280e-08,
+	1.50591138779666358e-08, 4.07421543880223335e-09,
+	6.55899859865622946e-08, 7.04697774403433060e-08,
+	1.05458966729375492e-07, 1.16189705334564924e-07,
+	2.70007840425949794e-08, 9.91549491170275978e-08,
+	9.69430665462702729e-08, 3.48962367368142750e-09,
+	2.12838570084203029e-08, 9.58558383294243244e-08,
+	3.54818427912568755e-08, 1.07710393847949145e-07,
+	8.61517153766060168e-08, 2.04600610755536536e-07,
+	2.03796097652703831e-07, 1.66306342048863931e-07,
+	1.59307194630913047e-07, 2.34975611381410033e-07,
+	1.92452005268177275e-07, 5.50463182513595194e-08,
+	7.05953701603703195e-08, 2.34971916784423615e-07,
+	5.40015680851899589e-08, 2.12718016029126278e-07,
+	1.91492473341603465e-07, 1.73687954457398432e-07,
+	9.22813729985471341e-08, 1.06988212380721318e-07,
+	1.27704297398270718e-07, 5.31950261176686284e-08,
+	9.77661777174938596e-09, 1.13152499419201003e-07,
+	2.30242259071696645e-07, 2.17840582054596399e-07,
+	1.61269260528736021e-07, 1.36185356146932601e-07,
+	2.08801481826511869e-07, 1.97681264041823641e-07,
+	1.50784512989339287e-07, 1.07250828689716638e-07,
+	9.75961542029652924e-08, 1.43903884071471071e-07,
+	2.60010707986588806e-07, 4.51687362770425967e-07,
+	1.55872185666914818e-09, 3.30297806270353139e-07,
+	4.66839232562134881e-07, 3.86401308539453419e-07,
+	5.69693854190458130e-08, 3.93123660542428204e-07,
+	3.95165664638538863e-07, 1.02867252517587785e-08,
+	1.32709681572078730e-07, 2.19641127294637299e-07,
+	1.98754510492326232e-07, 4.68321143892845854e-07,
+	4.66826389855508924e-07, 1.03605546188658804e-07,
+	2.35802265869106829e-07, 2.84300973057307715e-07,
+	1.41190740320740639e-07, 1.69877659083133016e-07,
+	2.51520105284046651e-07, 2.61972773884411727e-07,
+	7.18909291834578061e-08, 2.36692644004112907e-08,
+	4.54703970334185855e-07, 2.66978085000826612e-07,
+	2.65016092160396791e-07, 2.94953197203117899e-07,
+	1.98299667558641024e-07, 2.88865876540408914e-07,
+	3.99173794882405776e-07, 3.57377937852235498e-07,
+	4.64184350072864601e-07, 6.24190501305044646e-08,
+	3.98129044716236242e-07, 3.29124166816248113e-07,
+	1.39748850186603795e-07, 1.10443458567567753e-07,
+	4.09782728853196823e-08, 2.04197339771775867e-07,
+	3.92412117682061536e-07, 3.94305070358032831e-07,
+	4.71831774029316962e-07, 4.06610103464898125e-07,
+	4.53656642786443564e-07, 3.87773092718157073e-07,
+	4.57279976050247260e-07, 4.30400410735578705e-07,
+	7.21540920170394723e-08, 9.80872001232200742e-08,
+	2.66978158058219765e-07, 3.34565168908893463e-07,
+	5.35982971014292903e-08, 1.27564755579416119e-07,
+	3.03390161571307385e-07, 3.25161686840256005e-07,
+	4.11013021640696012e-07, 2.99496861839592342e-07,
+	2.03305051732449063e-07, 3.32476299509608735e-07,
+	4.17602963653023739e-07, 1.86711249657268702e-07,
+	3.18977681198347184e-07, 6.05846018127542565e-08,
+	8.57835758121197076e-08, 1.12749228435440334e-07,
+	3.34129550990056099e-07, 4.63409633672188390e-07,
+	2.11786110481110945e-07, 2.41878018084726962e-07,
+	2.60413978970349421e-07, 4.48778782784743522e-07,
+	3.25363260095300064e-08, 1.42486299343828112e-07,
 };
--- old/usr/src/lib/libm/common/C/_TBL_sin.c	2019-06-06 20:37:31.777435094 +0000
+++ new/usr/src/lib/libm/common/C/_TBL_sin.c	2019-06-06 20:37:31.797637136 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/C/_TBL_tan.c	2019-06-06 20:37:32.296752182 +0000
+++ new/usr/src/lib/libm/common/C/_TBL_tan.c	2019-06-06 20:37:32.315640029 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,56 +31,83 @@
 #include "libm_protos.h"
 
 const double _TBL_tan_hi[] = {
- 1.57534107325271622e-01, 1.61539784049521462e-01, 1.65550519273933966e-01,
- 1.69566445219766521e-01, 1.73587694767981526e-01, 1.77614401477446726e-01,
- 1.81646699603321415e-01, 1.85684724115634414e-01, 1.89728610718059132e-01,
- 1.93778495866891859e-01, 1.97834516790238668e-01, 2.01896811507417145e-01,
- 2.05965518848578860e-01, 2.10040778474558987e-01, 2.14122730896958657e-01,
- 2.18211517498467428e-01, 2.22307280553431325e-01, 2.26410163248673829e-01,
- 2.30520309704576154e-01, 2.34637864996423667e-01, 2.38762975176025932e-01,
- 2.42895787293616550e-01, 2.47036449420041271e-01, 2.51185110669240763e-01,
- 2.55341921221036272e-01, 2.63680596419996804e-01, 2.72053698658770882e-01,
- 2.80462470145251386e-01, 2.88908172440514699e-01, 2.97392087269024608e-01,
- 3.05915517353059274e-01, 3.14479787272571532e-01, 3.23086244351745544e-01,
- 3.31736259573572778e-01, 3.40431228523830398e-01, 3.49172572365910372e-01,
- 3.57961738848017019e-01, 3.66800203344323394e-01, 3.75689469931754838e-01,
- 3.84631072504149241e-01, 3.93626575925632771e-01, 4.02677577225140193e-01,
- 4.11785706834108478e-01, 4.20952629869475847e-01, 4.30180047464230053e-01,
- 4.39469698147866239e-01, 4.48823359279239720e-01, 4.58242848534432368e-01,
- 4.67730025452391784e-01, 4.77286793041252266e-01, 4.86915099448406330e-01,
- 4.96616939697565651e-01, 5.06394357496229852e-01, 5.16249447117175131e-01,
- 5.26184355357779188e-01, 5.36201283581215993e-01, 5.46302489843790484e-01,
- 5.66767065580586427e-01, 5.87597367591443209e-01, 6.08813740324380737e-01,
- 6.30437673835884782e-01, 6.52491897928808018e-01, 6.75000485144242934e-01,
- 6.97988963623599301e-01, 7.21484440990904474e-01, 7.45515740559391960e-01,
- 7.70113551344208669e-01, 7.95310593568674173e-01, 8.21141801589894138e-01,
- 8.47644526446552637e-01, 8.74858760554482306e-01, 9.02827387452673547e-01,
- 9.31596459944072475e-01, 9.61215510494370373e-01, 9.91737898363268644e-01,
+	1.57534107325271622e-01, 1.61539784049521462e-01,
+	1.65550519273933966e-01, 1.69566445219766521e-01,
+	1.73587694767981526e-01, 1.77614401477446726e-01,
+	1.81646699603321415e-01, 1.85684724115634414e-01,
+	1.89728610718059132e-01, 1.93778495866891859e-01,
+	1.97834516790238668e-01, 2.01896811507417145e-01,
+	2.05965518848578860e-01, 2.10040778474558987e-01,
+	2.14122730896958657e-01, 2.18211517498467428e-01,
+	2.22307280553431325e-01, 2.26410163248673829e-01,
+	2.30520309704576154e-01, 2.34637864996423667e-01,
+	2.38762975176025932e-01, 2.42895787293616550e-01,
+	2.47036449420041271e-01, 2.51185110669240763e-01,
+	2.55341921221036272e-01, 2.63680596419996804e-01,
+	2.72053698658770882e-01, 2.80462470145251386e-01,
+	2.88908172440514699e-01, 2.97392087269024608e-01,
+	3.05915517353059274e-01, 3.14479787272571532e-01,
+	3.23086244351745544e-01, 3.31736259573572778e-01,
+	3.40431228523830398e-01, 3.49172572365910372e-01,
+	3.57961738848017019e-01, 3.66800203344323394e-01,
+	3.75689469931754838e-01, 3.84631072504149241e-01,
+	3.93626575925632771e-01, 4.02677577225140193e-01,
+	4.11785706834108478e-01, 4.20952629869475847e-01,
+	4.30180047464230053e-01, 4.39469698147866239e-01,
+	4.48823359279239720e-01, 4.58242848534432368e-01,
+	4.67730025452391784e-01, 4.77286793041252266e-01,
+	4.86915099448406330e-01, 4.96616939697565651e-01,
+	5.06394357496229852e-01, 5.16249447117175131e-01,
+	5.26184355357779188e-01, 5.36201283581215993e-01,
+	5.46302489843790484e-01, 5.66767065580586427e-01,
+	5.87597367591443209e-01, 6.08813740324380737e-01,
+	6.30437673835884782e-01, 6.52491897928808018e-01,
+	6.75000485144242934e-01, 6.97988963623599301e-01,
+	7.21484440990904474e-01, 7.45515740559391960e-01,
+	7.70113551344208669e-01, 7.95310593568674173e-01,
+	8.21141801589894138e-01, 8.47644526446552637e-01,
+	8.74858760554482306e-01, 9.02827387452673547e-01,
+	9.31596459944072475e-01, 9.61215510494370373e-01,
+	9.91737898363268644e-01,
 };
+
 const double _TBL_tan_lo[] = {
--1.10615392752930551e-17, 1.42255435911932711e-17, 1.02781342487141920e-17,
--1.04735896510580927e-17,-5.46679990560150911e-18, 1.50201543247778489e-18,
- 1.22522327805930836e-17,-2.52772423968968903e-18, 9.78955701743985001e-19,
- 4.61515122717816178e-18, 7.14813042382104539e-19,-1.25529909642919992e-17,
- 1.19416304006222131e-17,-5.91325462642753544e-18, 7.53213214053688138e-18,
- 4.77223821731568090e-18, 6.32882137760769522e-18, 8.33823681661647871e-18,
--1.25419320906151988e-17, 1.16585041935775587e-17,-1.19653634178542542e-17,
--7.22806346068389604e-18,-6.16674472236513534e-18, 4.26199277415660669e-18,
--5.58935834356478328e-18,-4.56998635843850688e-18, 1.78004627511465564e-18,
- 1.74249040881549088e-17, 2.70817328270223006e-17,-1.80870634839170844e-17,
--1.00676145758650168e-17,-1.53577462986005684e-17,-2.38939880909534397e-17,
--1.08193046058071237e-17,-1.06856311222117164e-17,-1.96951245902998606e-17,
--2.08660034657941102e-17, 2.82596474303348100e-17, 2.34797942068937341e-18,
--1.76131026613802985e-17,-1.29729310968305823e-17, 1.87495311063417555e-17,
--2.29163073231136327e-18,-2.51936954463539765e-17,-4.11327516430776285e-18,
- 1.50393242431203736e-18,-1.09029595007501330e-17,-6.87284752683418342e-19,
- 1.55195027932634982e-17,-4.62284921534513474e-18,-5.45294879014110259e-18,
--2.56576334605328725e-17,-4.00960685506800741e-17, 1.35860113023765056e-17,
--4.34857062258506890e-17, 3.85791583096984630e-17, 2.90965762168371759e-17,
- 1.90815918857458480e-17, 1.21159907937263400e-17,-1.52112721227855650e-17,
--1.51838757657007437e-17,-2.51352280752587451e-17,-2.66690480643161193e-17,
--4.59728584599455591e-17,-5.42439848134543255e-17, 3.56284233494755594e-17,
- 3.61475127591663133e-17, 1.22197541073075113e-17,-1.61356193051149559e-17,
- 1.66243632690603545e-17, 4.30578558405427098e-17,-4.43234026650131250e-17,
--1.35473813965930355e-17, 4.30118334112910435e-17, 3.62593428168003066e-17,
+	-1.10615392752930551e-17, 1.42255435911932711e-17,
+	1.02781342487141920e-17, -1.04735896510580927e-17,
+	-5.46679990560150911e-18, 1.50201543247778489e-18,
+	1.22522327805930836e-17, -2.52772423968968903e-18,
+	9.78955701743985001e-19, 4.61515122717816178e-18,
+	7.14813042382104539e-19, -1.25529909642919992e-17,
+	1.19416304006222131e-17, -5.91325462642753544e-18,
+	7.53213214053688138e-18, 4.77223821731568090e-18,
+	6.32882137760769522e-18, 8.33823681661647871e-18,
+	-1.25419320906151988e-17, 1.16585041935775587e-17,
+	-1.19653634178542542e-17, -7.22806346068389604e-18,
+	-6.16674472236513534e-18, 4.26199277415660669e-18,
+	-5.58935834356478328e-18, -4.56998635843850688e-18,
+	1.78004627511465564e-18, 1.74249040881549088e-17,
+	2.70817328270223006e-17, -1.80870634839170844e-17,
+	-1.00676145758650168e-17, -1.53577462986005684e-17,
+	-2.38939880909534397e-17, -1.08193046058071237e-17,
+	-1.06856311222117164e-17, -1.96951245902998606e-17,
+	-2.08660034657941102e-17, 2.82596474303348100e-17,
+	2.34797942068937341e-18, -1.76131026613802985e-17,
+	-1.29729310968305823e-17, 1.87495311063417555e-17,
+	-2.29163073231136327e-18, -2.51936954463539765e-17,
+	-4.11327516430776285e-18, 1.50393242431203736e-18,
+	-1.09029595007501330e-17, -6.87284752683418342e-19,
+	1.55195027932634982e-17, -4.62284921534513474e-18,
+	-5.45294879014110259e-18, -2.56576334605328725e-17,
+	-4.00960685506800741e-17, 1.35860113023765056e-17,
+	-4.34857062258506890e-17, 3.85791583096984630e-17,
+	2.90965762168371759e-17, 1.90815918857458480e-17,
+	1.21159907937263400e-17, -1.52112721227855650e-17,
+	-1.51838757657007437e-17, -2.51352280752587451e-17,
+	-2.66690480643161193e-17, -4.59728584599455591e-17,
+	-5.42439848134543255e-17, 3.56284233494755594e-17,
+	3.61475127591663133e-17, 1.22197541073075113e-17,
+	-1.61356193051149559e-17, 1.66243632690603545e-17,
+	4.30578558405427098e-17, -4.43234026650131250e-17,
+	-1.35473813965930355e-17, 4.30118334112910435e-17,
+	3.62593428168003066e-17,
 };
--- old/usr/src/lib/libm/common/C/__cos.c	2019-06-06 20:37:32.798028487 +0000
+++ new/usr/src/lib/libm/common/C/__cos.c	2019-06-06 20:37:32.815627099 +0000
@@ -18,15 +18,17 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * __k_cos(double x; double y)
  * kernel cos function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -41,84 +43,94 @@
 #include "libm.h"
 
 static const double sc[] = {
-/* ONE	= */  1.0,
+/* ONE	= */
+	1.0,
 /* NONE	= */ -1.0,
+
 /*
  * |sin(x) - (x+pp1*x^3+pp2*x^5)| <= 2^-58.79 for |x| < 0.008
  */
-/* PP1	= */ -0.166666666666316558867252052378889521480627858683055567,
-/* PP2	= */   .008333315652997472323564894248466758248475374977974017927,
+/* PP1	= */-0.166666666666316558867252052378889521480627858683055567,
+/* PP2	= */.008333315652997472323564894248466758248475374977974017927,
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p4*x^9)|
  * |------------------------------ | <= 2^-57.63 for |x| < 0.1953125
  * |                 x             |
  */
-/* P1  	= */ -1.666666666666629669805215138920301589656e-0001,
-/* P2  	= */  8.333333332390951295683993455280336376663e-0003,
-/* P3  	= */ -1.984126237997976692791551778230098403960e-0004,
-/* P4  	= */  2.753403624854277237649987622848330351110e-0006,
+/* P1   = */ -1.666666666666629669805215138920301589656e-0001,
+/* P2   = */ 8.333333332390951295683993455280336376663e-0003,
+/* P3   = */ -1.984126237997976692791551778230098403960e-0004,
+/* P4   = */ 2.753403624854277237649987622848330351110e-0006,
+
 /*
  * |cos(x) - (1+qq1*x^2+qq2*x^4)| <= 2^-55.99 for |x| <= 0.008 (0x3f80624d)
  */
-/* QQ1	= */ -0.4999999999975492381842911981948418542742729,
-/* QQ2	= */  0.041666542904352059294545209158357640398771740,
+/* QQ1	= */-0.4999999999975492381842911981948418542742729,
+/* QQ2	= */0.041666542904352059294545209158357640398771740,
+
 /*
  * |cos(x) - (1+q1*x^2+...+q4*x^8)| <= 2^-55.86 for |x| <= 0.1640625 (10.5/64)
  */
-/* Q1  	= */ -0.5,
-/* Q2  	= */  4.166666666500350703680945520860748617445e-0002,
-/* Q3  	= */ -1.388888596436972210694266290577848696006e-0003,
-/* Q4  	= */  2.478563078858589473679519517892953492192e-0005,
-};
-/* INDENT ON */
-
-#define	ONE	sc[0]
-#define	NONE	sc[1]
-#define	PP1	sc[2]
-#define	PP2	sc[3]
-#define	P1	sc[4]
-#define	P2	sc[5]
-#define	P3	sc[6]
-#define	P4	sc[7]
-#define	QQ1	sc[8]
-#define	QQ2	sc[9]
-#define	Q1	sc[10]
-#define	Q2	sc[11]
-#define	Q3	sc[12]
-#define	Q4	sc[13]
+/* Q1   = */ -0.5,
+/* Q2   = */ 4.166666666500350703680945520860748617445e-0002,
+/* Q3   = */ -1.388888596436972210694266290577848696006e-0003,
+/* Q4   = */ 2.478563078858589473679519517892953492192e-0005, };
+
+
+#define	ONE		sc[0]
+#define	NONE		sc[1]
+#define	PP1		sc[2]
+#define	PP2		sc[3]
+#define	P1		sc[4]
+#define	P2		sc[5]
+#define	P3		sc[6]
+#define	P4		sc[7]
+#define	QQ1		sc[8]
+#define	QQ2		sc[9]
+#define	Q1		sc[10]
+#define	Q2		sc[11]
+#define	Q3		sc[12]
+#define	Q4		sc[13]
 
 extern const double _TBL_sincos[], _TBL_sincosx[];
 
 double
-__k_cos(double x, double y) {
-	double	z, w, s, v, p, q;
-	int	i, j, n, hx, ix;
+__k_cos(double x, double y)
+{
+	double z, w, s, v, p, q;
+	int i, j, n, hx, ix;
 
 	hx = ((int *)&x)[HIWORD];
 	ix = hx & ~0x80000000;
 
-	if (ix <= 0x3fc50000) {	/* |x| < 10.5/64 = 0.164062500 */
+	if (ix <= 0x3fc50000) {		/* |x| < 10.5/64 = 0.164062500 */
 		if (ix < 0x3e400000)	/* |x| < 2**-27 */
 			if ((int)x == 0)
 				return (ONE);
+
 		z = x * x;
+
 		if (ix < 0x3f800000)	/* |x| < 0.008 */
 			q = z * (QQ1 + z * QQ2);
 		else
 			q = z * ((Q1 + z * Q2) + (z * z) * (Q3 + z * Q4));
+
 		return (ONE + q);
-	} else {		/* 0.164062500 < |x| < ~pi/4 */
+	} else {			/* 0.164062500 < |x| < ~pi/4 */
 		n = ix >> 20;
 		i = (((ix >> 12) & 0xff) | 0x100) >> (0x401 - n);
 		j = i - 10;
+
 		if (hx < 0)
 			v = -y - (_TBL_sincosx[j] + x);
 		else
 			v = y - (_TBL_sincosx[j] - x);
+
 		s = v * v;
 		j <<= 1;
 		w = _TBL_sincos[j];
-		z = _TBL_sincos[j+1];
+		z = _TBL_sincos[j + 1];
 		p = s * (PP1 + s * PP2);
 		q = s * (QQ1 + s * QQ2);
 		p = v + v * p;
--- old/usr/src/lib/libm/common/C/__lgamma.c	2019-06-06 20:37:33.277280495 +0000
+++ new/usr/src/lib/libm/common/C/__lgamma.c	2019-06-06 20:37:33.295228794 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,101 +38,109 @@
 
 #include "libm.h"
 
-static const double
-one	= 1.0,
-zero	= 0.0,
-hln2pi	= 0.9189385332046727417803297,	/* log(2*pi)/2 */
-pi	= 3.1415926535897932384626434,
-two52	= 4503599627370496.0,		/* 43300000,00000000 (used by sin_pi) */
+static const double one = 1.0,
+	zero = 0.0,
+	hln2pi = 0.9189385332046727417803297, /* log(2*pi)/2 */
+	pi = 3.1415926535897932384626434,
+	two52 = 4503599627370496.0, /* 43300000,00000000 (used by sin_pi) */
+
 /*
  * Numerator and denominator coefficients for rational minimax Approximation
  * P/Q over (0.5,1.5).
  */
-D1 = 	-5.772156649015328605195174e-1,
-p7 =	 4.945235359296727046734888e0,
-p6 =	 2.018112620856775083915565e2,
-p5 =	 2.290838373831346393026739e3,
-p4 =	 1.131967205903380828685045e4,
-p3 =	 2.855724635671635335736389e4,
-p2 =	 3.848496228443793359990269e4,
-p1 =	 2.637748787624195437963534e4,
-p0 =	 7.225813979700288197698961e3,
-q7 =	 6.748212550303777196073036e1,
-q6 =	 1.113332393857199323513008e3,
-q5 =	 7.738757056935398733233834e3,
-q4 =	 2.763987074403340708898585e4,
-q3 =	 5.499310206226157329794414e4,
-q2 =	 6.161122180066002127833352e4,
-q1 =	 3.635127591501940507276287e4,
-q0 =	 8.785536302431013170870835e3,
+	D1 = -5.772156649015328605195174e-1,
+	p7 = 4.945235359296727046734888e0,
+	p6 = 2.018112620856775083915565e2,
+	p5 = 2.290838373831346393026739e3,
+	p4 = 1.131967205903380828685045e4,
+	p3 = 2.855724635671635335736389e4,
+	p2 = 3.848496228443793359990269e4,
+	p1 = 2.637748787624195437963534e4,
+	p0 = 7.225813979700288197698961e3,
+	q7 = 6.748212550303777196073036e1,
+	q6 = 1.113332393857199323513008e3,
+	q5 = 7.738757056935398733233834e3,
+	q4 = 2.763987074403340708898585e4,
+	q3 = 5.499310206226157329794414e4,
+	q2 = 6.161122180066002127833352e4,
+	q1 = 3.635127591501940507276287e4,
+	q0 = 8.785536302431013170870835e3,
+
 /*
  * Numerator and denominator coefficients for rational minimax Approximation
  * G/H over (1.5,4.0).
  */
-D2 =	 4.227843350984671393993777e-1,
-g7 =	 4.974607845568932035012064e0,
-g6 =	 5.424138599891070494101986e2,
-g5 =	 1.550693864978364947665077e4,
-g4 =	 1.847932904445632425417223e5,
-g3 =	 1.088204769468828767498470e6,
-g2 =	 3.338152967987029735917223e6,
-g1 =	 5.106661678927352456275255e6,
-g0 =	 3.074109054850539556250927e6,
-h7 =	 1.830328399370592604055942e2,
-h6 =	 7.765049321445005871323047e3,
-h5 =	 1.331903827966074194402448e5,
-h4 =	 1.136705821321969608938755e6,
-h3 =	 5.267964117437946917577538e6,
-h2 =	 1.346701454311101692290052e7,
-h1 =	 1.782736530353274213975932e7,
-h0 =	 9.533095591844353613395747e6,
+	D2 = 4.227843350984671393993777e-1,
+	g7 = 4.974607845568932035012064e0,
+	g6 = 5.424138599891070494101986e2,
+	g5 = 1.550693864978364947665077e4,
+	g4 = 1.847932904445632425417223e5,
+	g3 = 1.088204769468828767498470e6,
+	g2 = 3.338152967987029735917223e6,
+	g1 = 5.106661678927352456275255e6,
+	g0 = 3.074109054850539556250927e6,
+	h7 = 1.830328399370592604055942e2,
+	h6 = 7.765049321445005871323047e3,
+	h5 = 1.331903827966074194402448e5,
+	h4 = 1.136705821321969608938755e6,
+	h3 = 5.267964117437946917577538e6,
+	h2 = 1.346701454311101692290052e7,
+	h1 = 1.782736530353274213975932e7,
+	h0 = 9.533095591844353613395747e6,
+
 /*
  * Numerator and denominator coefficients for rational minimax Approximation
  * U/V over (4.0,12.0).
  */
-D4 =	 1.791759469228055000094023e0,
-u7 =	 1.474502166059939948905062e4,
-u6 =	 2.426813369486704502836312e6,
-u5 =	 1.214755574045093227939592e8,
-u4 =	 2.663432449630976949898078e9,
-u3 =	 2.940378956634553899906876e10,
-u2 =	 1.702665737765398868392998e11,
-u1 =	 4.926125793377430887588120e11,
-u0 =	 5.606251856223951465078242e11,
-v7 =	 2.690530175870899333379843e3,
-v6 =	 6.393885654300092398984238e5,
-v5 =	 4.135599930241388052042842e7,
-v4 =	 1.120872109616147941376570e9,
-v3 =	 1.488613728678813811542398e10,
-v2 =	 1.016803586272438228077304e11,
-v1 =	 3.417476345507377132798597e11,
-v0 =	 4.463158187419713286462081e11,
+	D4 = 1.791759469228055000094023e0,
+	u7 = 1.474502166059939948905062e4,
+	u6 = 2.426813369486704502836312e6,
+	u5 = 1.214755574045093227939592e8,
+	u4 = 2.663432449630976949898078e9,
+	u3 = 2.940378956634553899906876e10,
+	u2 = 1.702665737765398868392998e11,
+	u1 = 4.926125793377430887588120e11,
+	u0 = 5.606251856223951465078242e11,
+	v7 = 2.690530175870899333379843e3,
+	v6 = 6.393885654300092398984238e5,
+	v5 = 4.135599930241388052042842e7,
+	v4 = 1.120872109616147941376570e9,
+	v3 = 1.488613728678813811542398e10,
+	v2 = 1.016803586272438228077304e11,
+	v1 = 3.417476345507377132798597e11,
+	v0 = 4.463158187419713286462081e11,
+
 /*
  * Coefficients for minimax approximation over (12, INF).
  */
-c5 =	-1.910444077728e-03,
-c4 =	 8.4171387781295e-04,
-c3 =	-5.952379913043012e-04,
-c2 =	 7.93650793500350248e-04,
-c1 =	-2.777777777777681622553e-03,
-c0 =	 8.333333333333333331554247e-02,
-c6 =	 5.7083835261e-03;
+	c5 = -1.910444077728e-03,
+	c4 = 8.4171387781295e-04,
+	c3 = -5.952379913043012e-04,
+	c2 = 7.93650793500350248e-04,
+	c1 = -2.777777777777681622553e-03,
+	c0 = 8.333333333333333331554247e-02,
+	c6 = 5.7083835261e-03;
 
 /*
  * Return sin(pi*x).  We assume x is finite and negative, and if it
  * is an integer, then the sign of the zero returned doesn't matter.
  */
 static double
-sin_pi(double x) {
-	double	y, z;
-	int	n;
+sin_pi(double x)
+{
+	double y, z;
+	int n;
 
 	y = -x;
+
 	if (y <= 0.25)
 		return (__k_sin(pi * x, 0.0));
+
 	if (y >= two52)
 		return (zero);
+
 	z = floor(y);
+
 	if (y == z)
 		return (zero);
 
@@ -140,6 +150,7 @@
 
 	/* now floor(y * 4) tells which octant y is in */
 	n = (int)(y * 4.0);
+
 	switch (n) {
 	case 0:
 		y = __k_sin(pi * y, 0.0);
@@ -160,21 +171,24 @@
 		y = __k_sin(pi * (y - 2.0), 0.0);
 		break;
 	}
+
 	return (-y);
 }
 
 static double
-neg(double z, int *signgamp) {
-	double	t, p;
+neg(double z, int *signgamp)
+{
+	double t, p;
 
+	/* BEGIN CSTYLED */
 	/*
 	 * written by K.C. Ng,  Feb 2, 1989.
 	 *
 	 * Since
 	 *		-z*G(-z)*G(z) = pi/sin(pi*z),
 	 * we have
-	 * 	G(-z) = -pi/(sin(pi*z)*G(z)*z)
-	 * 	      =  pi/(sin(pi*(-z))*G(z)*z)
+	 *      G(-z) = -pi/(sin(pi*z)*G(z)*z)
+	 *            =  pi/(sin(pi*(-z))*G(z)*z)
 	 * Algorithm
 	 *		z = |z|
 	 *		t = sin_pi(z); ...note that when z>2**52, z is an int
@@ -187,37 +201,48 @@
 	 *		else
 	 *		    return log(pi/(t*z))-__k_lgamma(z, signgamp);
 	 */
+	/* END CSTYLED */
 
 	t = sin_pi(z);			/* t := sin(pi*z) */
+
 	if (t == zero)			/* return 1.0/0.0 = +INF */
 		return (one / fabs(t));
+
 	z = -z;
 	p = z + one;
+
 	if (p == one)
 		p = -log(z);
 	else
 		p = log(pi / (fabs(t) * z)) - __k_lgamma(z, signgamp);
+
 	if (t < zero)
 		*signgamp = -1;
+
 	return (p);
 }
 
 double
-__k_lgamma(double x, int *signgamp) {
-	double	t, p, q, cr, y;
+__k_lgamma(double x, int *signgamp)
+{
+	double t, p, q, cr, y;
 
 	/* purge off +-inf, NaN and negative arguments */
 	if (!finite(x))
 		return (x * x);
+
 	*signgamp = 1;
+
 	if (signbit(x))
 		return (neg(x, signgamp));
 
 	/* lgamma(x) ~ log(1/x) for really tiny x */
 	t = one + x;
+
 	if (t == one) {
 		if (x == zero)
 			return (one / x);
+
 		return (-log(x));
 	}
 
@@ -234,35 +259,44 @@
 		if (x <= 0.5 || x >= 0.6796875) {
 			if (x == one)
 				return (zero);
-			p = p0+y*(p1+y*(p2+y*(p3+y*(p4+y*(p5+y*(p6+y*p7))))));
-			q = q0+y*(q1+y*(q2+y*(q3+y*(q4+y*(q5+y*(q6+y*
-			    (q7+y)))))));
-			return (cr+y*(D1+y*(p/q)));
+
+			p = p0 + y * (p1 + y * (p2 + y * (p3 + y * (p4 + y *
+			    (p5 + y * (p6 + y * p7))))));
+			q = q0 + y * (q1 + y * (q2 + y * (q3 + y * (q4 + y *
+			    (q5 + y * (q6 + y * (q7 + y)))))));
+			return (cr + y * (D1 + y * (p / q)));
 		} else {
 			y = x - one;
-			p = g0+y*(g1+y*(g2+y*(g3+y*(g4+y*(g5+y*(g6+y*g7))))));
-			q = h0+y*(h1+y*(h2+y*(h3+y*(h4+y*(h5+y*(h6+y*
-			    (h7+y)))))));
-			return (cr+y*(D2+y*(p/q)));
+			p = g0 + y * (g1 + y * (g2 + y * (g3 + y * (g4 + y *
+			    (g5 + y * (g6 + y * g7))))));
+			q = h0 + y * (h1 + y * (h2 + y * (h3 + y * (h4 + y *
+			    (h5 + y * (h6 + y * (h7 + y)))))));
+			return (cr + y * (D2 + y * (p / q)));
 		}
 	} else if (x <= 4.0) {
 		if (x == 2.0)
 			return (zero);
+
 		y = x - 2.0;
-		p = g0+y*(g1+y*(g2+y*(g3+y*(g4+y*(g5+y*(g6+y*g7))))));
-		q = h0+y*(h1+y*(h2+y*(h3+y*(h4+y*(h5+y*(h6+y*(h7+y)))))));
-		return (y*(D2+y*(p/q)));
+		p = g0 + y * (g1 + y * (g2 + y * (g3 + y * (g4 + y * (g5 + y *
+		    (g6 + y * g7))))));
+		q = h0 + y * (h1 + y * (h2 + y * (h3 + y * (h4 + y * (h5 + y *
+		    (h6 + y * (h7 + y)))))));
+		return (y * (D2 + y * (p / q)));
 	} else if (x <= 12.0) {
 		y = x - 4.0;
-		p = u0+y*(u1+y*(u2+y*(u3+y*(u4+y*(u5+y*(u6+y*u7))))));
-		q = v0+y*(v1+y*(v2+y*(v3+y*(v4+y*(v5+y*(v6+y*(v7-y)))))));
-		return (D4+y*(p/q));
-	} else if (x <= 1.0e17) {		/* x ~< 2**(prec+3) */
+		p = u0 + y * (u1 + y * (u2 + y * (u3 + y * (u4 + y * (u5 + y *
+		    (u6 + y * u7))))));
+		q = v0 + y * (v1 + y * (v2 + y * (v3 + y * (v4 + y * (v5 + y *
+		    (v6 + y * (v7 - y)))))));
+		return (D4 + y * (p / q));
+	} else if (x <= 1.0e17) {	/* x ~< 2**(prec+3) */
 		t = one / x;
 		y = t * t;
-		p = hln2pi+t*(c0+y*(c1+y*(c2+y*(c3+y*(c4+y*(c5+y*c6))))));
+		p = hln2pi + t * (c0 + y * (c1 + y * (c2 + y * (c3 + y * (c4 +
+		    y * (c5 + y * c6))))));
 		q = log(x);
-		return (x*(q-one)-(0.5*q-p));
+		return (x * (q - one) - (0.5 * q - p));
 	} else {			/* may overflow */
 		return (x * (log(x) - 1.0));
 	}
--- old/usr/src/lib/libm/common/C/__libx_errno.c	2019-06-06 20:37:33.755218535 +0000
+++ new/usr/src/lib/libm/common/C/__libx_errno.c	2019-06-06 20:37:33.769361946 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,6 +31,7 @@
 extern int *___errno(void);
 
 int *
-__libm_errno(void) {
+__libm_errno(void)
+{
 	return (___errno());
 }
--- old/usr/src/lib/libm/common/C/__rem_pio2.c	2019-06-06 20:37:34.228271547 +0000
+++ new/usr/src/lib/libm/common/C/__rem_pio2.c	2019-06-06 20:37:34.246342115 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,7 +41,7 @@
 
 extern const int _TBL_ipio2_inf[];
 
-/* INDENT OFF */
+
 /*
  * invpio2:  53 bits of 2/pi
  * pio2_1:   first  33 bit of pi/2
@@ -49,22 +51,22 @@
  * pio2_3:   third  33 bit of pi/2
  * pio2_3t:  pi/2 - pio2_3
  */
-static const double
-	half	= 0.5,
-	invpio2	= 0.636619772367581343075535,	/* 2^ -1  * 1.45F306DC9C883 */
-	pio2_1	= 1.570796326734125614166,	/* 2^  0  * 1.921FB54400000 */
-	pio2_1t	= 6.077100506506192601475e-11,	/* 2^-34  * 1.0B4611A626331 */
-	pio2_2	= 6.077100506303965976596e-11,	/* 2^-34  * 1.0B4611A600000 */
-	pio2_2t	= 2.022266248795950732400e-21,	/* 2^-69  * 1.3198A2E037073 */
-	pio2_3	= 2.022266248711166455796e-21,	/* 2^-69  * 1.3198A2E000000 */
-	pio2_3t	= 8.478427660368899643959e-32;	/* 2^-104 * 1.B839A252049C1 */
-/* INDENT ON */
+static const double half = 0.5,
+	invpio2 = 0.636619772367581343075535,	/* 2^ -1  * 1.45F306DC9C883 */
+	pio2_1 = 1.570796326734125614166,	/* 2^  0  * 1.921FB54400000 */
+	pio2_1t = 6.077100506506192601475e-11,	/* 2^-34  * 1.0B4611A626331 */
+	pio2_2 = 6.077100506303965976596e-11,	/* 2^-34  * 1.0B4611A600000 */
+	pio2_2t = 2.022266248795950732400e-21,	/* 2^-69  * 1.3198A2E037073 */
+	pio2_3 = 2.022266248711166455796e-21,	/* 2^-69  * 1.3198A2E000000 */
+	pio2_3t = 8.478427660368899643959e-32;	/* 2^-104 * 1.B839A252049C1 */
+
 
 int
-__rem_pio2(double x, double *y) {
-	double	w, t, r, fn;
-	double	tx[3];
-	int	e0, i, j, nx, n, ix, hx, lx;
+__rem_pio2(double x, double *y)
+{
+	double w, t, r, fn;
+	double tx[3];
+	int e0, i, j, nx, n, ix, hx, lx;
 
 	hx = ((int *)&x)[HIWORD];
 	ix = hx & 0x7fffffff;
@@ -72,6 +74,7 @@
 	if (ix < 0x4002d97c) {
 		/* |x| < 3pi/4, special case with n=1 */
 		t = fabs(x) - pio2_1;
+
 		if (ix != 0x3ff921fb) {	/* 33+53 bit pi is good enough */
 			y[0] = t - pio2_1t;
 			y[1] = (t - y[0]) - pio2_1t;
@@ -80,11 +83,13 @@
 			y[0] = t - pio2_2t;
 			y[1] = (t - y[0]) - pio2_2t;
 		}
+
 		if (hx < 0) {
 			y[0] = -y[0];
 			y[1] = -y[1];
 			return (-1);
 		}
+
 		return (1);
 	}
 
@@ -98,7 +103,8 @@
 		w = fn * pio2_1t;	/* 1st round good to 85 bit */
 		y[0] = r - w;
 		i = j - ((((int *)y)[HIWORD] >> 20) & 0x7ff);
-		if (i > 16) {	/* 2nd iteration (rare) */
+
+		if (i > 16) {		/* 2nd iteration (rare) */
 			/* 2nd round good to 118 bit */
 			if (i < 35) {
 				t = r;	/* r-fn*pio2_2 may not be exact */
@@ -111,14 +117,15 @@
 				w = fn * pio2_2t;
 				y[0] = r - w;
 				i = j - ((((int *)y)[HIWORD] >> 20) & 0x7ff);
+
 				if (i > 49) {
 					/* 3rd iteration (extremely rare) */
 					if (i < 68) {
 						t = r;
 						w = fn * pio2_3;
 						r = t - w;
-						w = fn * pio2_3t -
-						    ((t - r) - w);
+						w = fn * pio2_3t - ((t - r) -
+						    w);
 						y[0] = r - w;
 					} else {
 						/*
@@ -132,16 +139,19 @@
 				}
 			}
 		}
+
 		y[1] = (r - y[0]) - w;
+
 		if (hx < 0) {
 			y[0] = -y[0];
 			y[1] = -y[1];
 			return (-n);
 		}
+
 		return (n);
 	}
 
-	e0 = (ix >> 20) - 1046;	/* e0 = ilogb(x)-23; */
+	e0 = (ix >> 20) - 1046;		/* e0 = ilogb(x)-23; */
 
 	/* break x into three 24 bit pieces */
 	lx = ((int *)&x)[LOWORD];
@@ -149,20 +159,25 @@
 	tx[2] = (double)i;
 	j = (lx >> 5) & 0xffffff;
 	tx[1] = (double)j;
-	tx[0] = (double)((((ix & 0xfffff) | 0x100000) << 3) |
-	    ((unsigned)lx >> 29));
+	tx[0] = (double)((((ix & 0xfffff) | 0x100000) << 3) | ((unsigned)lx >>
+	    29));
 	nx = 3;
+
 	if (i == 0) {
 		/* skip zero term */
 		nx--;
+
 		if (j == 0)
 			nx--;
 	}
+
 	n = __rem_pio2m(tx, y, e0, nx, 2, _TBL_ipio2_inf);
+
 	if (hx < 0) {
 		y[0] = -y[0];
 		y[1] = -y[1];
 		return (-n);
 	}
+
 	return (n);
 }
--- old/usr/src/lib/libm/common/C/__rem_pio2m.c	2019-06-06 20:37:34.738986806 +0000
+++ new/usr/src/lib/libm/common/C/__rem_pio2m.c	2019-06-06 20:37:34.757486907 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,7 +46,7 @@
  * Here PI could as well be a machine value pi.
  *
  * Input parameters:
- * 	x[]	The input value (must be positive) is broken into nx
+ *      x[]	The input value (must be positive) is broken into nx
  *		pieces of 24-bit integers in double precision format.
  *		x[i] will be the i-th 24 bit of x. The scaled exponent
  *		of x[0] is given in input parameter e0 (i.e., x[0]*2^e0
@@ -77,7 +79,7 @@
  *
  *	nx	dimension of x[]
  *
- *  	prec	an interger indicating the precision:
+ *      prec	an interger indicating the precision:
  *			0	24  bits (single)
  *			1	53  bits (double)
  *			2	64  bits (extended)
@@ -96,11 +98,11 @@
  *
  * Here is the description of some local variables:
  *
- * 	jk	jk+1 is the initial number of terms of ipio2[] needed
+ *      jk	jk+1 is the initial number of terms of ipio2[] needed
  *		in the computation. The recommended value is 3,4,4,
  *		6 for single, double, extended,and quad.
  *
- * 	jz	local integer variable indicating the number of
+ *      jz	local integer variable indicating the number of
  *		terms of ipio2[] used.
  *
  *	jx	nx - 1
@@ -114,7 +116,7 @@
  *
  *	jp	jp+1 is the number of terms in pio2[] needed, jp = jk.
  *
- * 	q[]	double array with integral value, representing the
+ *      q[]	double array with integral value, representing the
  *		24-bits chunk of the product of x and 2/pi.
  *
  *	q0	the corresponding exponent of q[0]. Note that the
@@ -140,36 +142,31 @@
 extern int __swapRP(int);
 #endif
 
-static const int init_jk[] = { 3, 4, 4, 6 }; /* initial value for jk */
-
+static const int init_jk[] = { 3, 4, 4, 6 };	/* initial value for jk */
 static const double pio2[] = {
-	1.57079625129699707031e+00,
-	7.54978941586159635335e-08,
-	5.39030252995776476554e-15,
-	3.28200341580791294123e-22,
-	1.27065575308067607349e-29,
-	1.22933308981111328932e-36,
-	2.73370053816464559624e-44,
-	2.16741683877804819444e-51,
+	1.57079625129699707031e+00, 7.54978941586159635335e-08,
+	5.39030252995776476554e-15, 3.28200341580791294123e-22,
+	1.27065575308067607349e-29, 1.22933308981111328932e-36,
+	2.73370053816464559624e-44, 2.16741683877804819444e-51,
 };
 
-static const double
-	zero	= 0.0,
-	one	= 1.0,
-	half	= 0.5,
-	eight	= 8.0,
-	eighth	= 0.125,
-	two24	= 16777216.0,
-	twon24	= 5.960464477539062500E-8;
+static const double zero = 0.0,
+	one = 1.0,
+	half = 0.5,
+	eight = 8.0,
+	eighth = 0.125,
+	two24 = 16777216.0,
+	twon24 = 5.960464477539062500E-8;
 
 int
 __rem_pio2m(double *x, double *y, int e0, int nx, int prec, const int *ipio2)
 {
-	int	jz, jx, jv, jp, jk, carry, n, iq[20];
-	int	i, j, k, m, q0, ih;
-	double	z, fw, f[20], fq[20], q[20];
+	int jz, jx, jv, jp, jk, carry, n, iq[20];
+	int i, j, k, m, q0, ih;
+	double z, fw, f[20], fq[20], q[20];
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 
 	rp = __swapRP(fp_extended);
 #endif
@@ -180,30 +177,35 @@
 	/* determine jx,jv,q0, note that 3>q0 */
 	jx = nx - 1;
 	jv = (e0 - 3) / 24;
+
 	if (jv < 0)
 		jv = 0;
+
 	q0 = e0 - 24 * (jv + 1);
 
 	/* set up f[0] to f[jx+jk] where f[jx+jk] = ipio2[jv+jk] */
 	j = jv - jx;
 	m = jx + jk;
+
 	for (i = 0; i <= m; i++, j++)
-		f[i] = (j < 0)? zero : (double)ipio2[j];
+		f[i] = (j < 0) ? zero : (double)ipio2[j];
 
 	/* compute q[0],q[1],...q[jk] */
 	for (i = 0; i <= jk; i++) {
 		for (j = 0, fw = zero; j <= jx; j++)
-			fw += x[j] * f[jx+i-j];
+			fw += x[j] * f[jx + i - j];
+
 		q[i] = fw;
 	}
 
 	jz = jk;
+
 recompute:
 	/* distill q[] into iq[] reversingly */
 	for (i = 0, j = jz, z = q[jz]; j > 0; i++, j--) {
 		fw = (double)((int)(twon24 * z));
 		iq[i] = (int)(z - two24 * fw);
-		z = q[j-1] + fw;
+		z = q[j - 1] + fw;
 	}
 
 	/* compute n */
@@ -212,22 +214,25 @@
 	n = (int)z;
 	z -= (double)n;
 	ih = 0;
+
 	if (q0 > 0) {			/* need iq[jz-1] to determine n */
-		i = (iq[jz-1] >> (24 - q0));
+		i = (iq[jz - 1] >> (24 - q0));
 		n += i;
-		iq[jz-1] -= i << (24 - q0);
-		ih = iq[jz-1] >> (23 - q0);
+		iq[jz - 1] -= i << (24 - q0);
+		ih = iq[jz - 1] >> (23 - q0);
 	} else if (q0 == 0) {
-		ih = iq[jz-1] >> 23;
+		ih = iq[jz - 1] >> 23;
 	} else if (z >= half) {
 		ih = 2;
 	}
 
-	if (ih > 0) {	/* q > 0.5 */
+	if (ih > 0) {			/* q > 0.5 */
 		n += 1;
 		carry = 0;
+
 		for (i = 0; i < jz; i++) {	/* compute 1-q */
 			j = iq[i];
+
 			if (carry == 0) {
 				if (j != 0) {
 					carry = 1;
@@ -237,18 +242,21 @@
 				iq[i] = 0xffffff - j;
 			}
 		}
+
 		if (q0 > 0) {		/* rare case: chance is 1 in 12 */
 			switch (q0) {
 			case 1:
-				iq[jz-1] &= 0x7fffff;
+				iq[jz - 1] &= 0x7fffff;
 				break;
 			case 2:
-				iq[jz-1] &= 0x3fffff;
+				iq[jz - 1] &= 0x3fffff;
 				break;
 			}
 		}
+
 		if (ih == 2) {
 			z = one - z;
+
 			if (carry != 0)
 				z -= scalbn(one, q0);
 		}
@@ -257,20 +265,25 @@
 	/* check if recomputation is needed */
 	if (z == zero) {
 		j = 0;
+
 		for (i = jz - 1; i >= jk; i--)
 			j |= iq[i];
-		if (j == 0) {	/* need recomputation */
+
+		if (j == 0) {		/* need recomputation */
 			/* set k to no. of terms needed */
-			for (k = 1; iq[jk-k] == 0; k++)
+			for (k = 1; iq[jk - k] == 0; k++)
 				;
 
 			/* add q[jz+1] to q[jz+k] */
 			for (i = jz + 1; i <= jz + k; i++) {
-				f[jx+i] = (double)ipio2[jv+i];
+				f[jx + i] = (double)ipio2[jv + i];
+
 				for (j = 0, fw = zero; j <= jx; j++)
-					fw += x[j] * f[jx+i-j];
+					fw += x[j] * f[jx + i - j];
+
 				q[i] = fw;
 			}
+
 			jz += k;
 			goto recompute;
 		}
@@ -280,12 +293,14 @@
 	if (z == zero) {
 		jz -= 1;
 		q0 -= 24;
+
 		while (iq[jz] == 0) {
 			jz--;
 			q0 -= 24;
 		}
-	} else {		/* break z into 24-bit if neccessary */
+	} else {			/* break z into 24-bit if neccessary */
 		z = scalbn(z, -q0);
+
 		if (z >= two24) {
 			fw = (double)((int)(twon24 * z));
 			iq[jz] = (int)(z - two24 * fw);
@@ -299,6 +314,7 @@
 
 	/* convert integer "bit" chunk to floating-point value */
 	fw = scalbn(one, q0);
+
 	for (i = jz; i >= 0; i--) {
 		q[i] = fw * (double)iq[i];
 		fw *= twon24;
@@ -307,44 +323,55 @@
 	/* compute pio2[0,...,jp]*q[jz,...,0] */
 	for (i = jz; i >= 0; i--) {
 		for (fw = zero, k = 0; k <= jp && k <= jz - i; k++)
-			fw += pio2[k] * q[i+k];
-		fq[jz-i] = fw;
+			fw += pio2[k] * q[i + k];
+
+		fq[jz - i] = fw;
 	}
 
 	/* compress fq[] into y[] */
 	switch (prec) {
 	case 0:
 		fw = zero;
+
 		for (i = jz; i >= 0; i--)
 			fw += fq[i];
-		y[0] = (ih == 0)? fw : -fw;
+
+		y[0] = (ih == 0) ? fw : -fw;
 		break;
 
 	case 1:
 	case 2:
 		fw = zero;
+
 		for (i = jz; i >= 0; i--)
 			fw += fq[i];
-		y[0] = (ih == 0)? fw : -fw;
+
+		y[0] = (ih == 0) ? fw : -fw;
 		fw = fq[0] - fw;
+
 		for (i = 1; i <= jz; i++)
 			fw += fq[i];
-		y[1] = (ih == 0)? fw : -fw;
+
+		y[1] = (ih == 0) ? fw : -fw;
 		break;
 
 	default:
+
 		for (i = jz; i > 0; i--) {
-			fw = fq[i-1] + fq[i];
-			fq[i] += fq[i-1] - fw;
-			fq[i-1] = fw;
+			fw = fq[i - 1] + fq[i];
+			fq[i] += fq[i - 1] - fw;
+			fq[i - 1] = fw;
 		}
+
 		for (i = jz; i > 1; i--) {
-			fw = fq[i-1] + fq[i];
-			fq[i] += fq[i-1] - fw;
-			fq[i-1] = fw;
+			fw = fq[i - 1] + fq[i];
+			fq[i] += fq[i - 1] - fw;
+			fq[i - 1] = fw;
 		}
+
 		for (fw = zero, i = jz; i >= 2; i--)
 			fw += fq[i];
+
 		if (ih == 0) {
 			y[0] = fq[0];
 			y[1] = fq[1];
--- old/usr/src/lib/libm/common/C/__sin.c	2019-06-06 20:37:35.235440351 +0000
+++ new/usr/src/lib/libm/common/C/__sin.c	2019-06-06 20:37:35.253934553 +0000
@@ -18,15 +18,17 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * __k_sin( double x;  double y )
  * kernel sin function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -41,89 +43,100 @@
 #include "libm.h"
 
 static const double sc[] = {
-/* ONE	= */  1.0,
+/* ONE	= */
+	1.0,
 /* NONE	= */ -1.0,
+
 /*
  * |sin(x) - (x+pp1*x^3+pp2*x^5)| <= 2^-58.79 for |x| < 0.008
  */
-/* PP1	= */ -0.166666666666316558867252052378889521480627858683055567,
-/* PP2	= */   .008333315652997472323564894248466758248475374977974017927,
+/* PP1	= */-0.166666666666316558867252052378889521480627858683055567,
+/* PP2	= */.008333315652997472323564894248466758248475374977974017927,
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p4*x^9)|
  * |------------------------------ | <= 2^-57.63 for |x| < 0.1953125
  * |                 x             |
  */
-/* P1  	= */ -1.666666666666629669805215138920301589656e-0001,
-/* P2  	= */  8.333333332390951295683993455280336376663e-0003,
-/* P3  	= */ -1.984126237997976692791551778230098403960e-0004,
-/* P4  	= */  2.753403624854277237649987622848330351110e-0006,
+/* P1   = */ -1.666666666666629669805215138920301589656e-0001,
+/* P2   = */ 8.333333332390951295683993455280336376663e-0003,
+/* P3   = */ -1.984126237997976692791551778230098403960e-0004,
+/* P4   = */ 2.753403624854277237649987622848330351110e-0006,
+
 /*
  * |cos(x) - (1+qq1*x^2+qq2*x^4)| <= 2^-55.99 for |x| <= 0.008 (0x3f80624d)
  */
-/* QQ1	= */ -0.4999999999975492381842911981948418542742729,
-/* QQ2	= */  0.041666542904352059294545209158357640398771740,
+/* QQ1	= */-0.4999999999975492381842911981948418542742729,
+/* QQ2	= */0.041666542904352059294545209158357640398771740,
+
 /*
  * |cos(x) - (1+q1*x^2+...+q4*x^8)| <= 2^-55.86 for |x| <= 0.1640625 (10.5/64)
  */
-/* Q1  	= */ -0.5,
-/* Q2  	= */  4.166666666500350703680945520860748617445e-0002,
-/* Q3  	= */ -1.388888596436972210694266290577848696006e-0003,
-/* Q4  	= */  2.478563078858589473679519517892953492192e-0005,
+/* Q1   = */ -0.5,
+/* Q2   = */ 4.166666666500350703680945520860748617445e-0002,
+/* Q3   = */ -1.388888596436972210694266290577848696006e-0003,
+/* Q4   = */ 2.478563078858589473679519517892953492192e-0005,
 };
-/* INDENT ON */
 
-#define	ONE	sc[0]
-#define	NONE	sc[1]
-#define	PP1	sc[2]
-#define	PP2	sc[3]
-#define	P1	sc[4]
-#define	P2	sc[5]
-#define	P3	sc[6]
-#define	P4	sc[7]
-#define	QQ1	sc[8]
-#define	QQ2	sc[9]
-#define	Q1	sc[10]
-#define	Q2	sc[11]
-#define	Q3	sc[12]
-#define	Q4	sc[13]
+
+#define	ONE		sc[0]
+#define	NONE		sc[1]
+#define	PP1		sc[2]
+#define	PP2		sc[3]
+#define	P1		sc[4]
+#define	P2		sc[5]
+#define	P3		sc[6]
+#define	P4		sc[7]
+#define	QQ1		sc[8]
+#define	QQ2		sc[9]
+#define	Q1		sc[10]
+#define	Q2		sc[11]
+#define	Q3		sc[12]
+#define	Q4		sc[13]
 
 extern const double _TBL_sincos[], _TBL_sincosx[];
 
 double
-__k_sin(double x, double y) {
-	double	z, w, s, v, p, q;
-	int	i, j, n, hx, ix;
+__k_sin(double x, double y)
+{
+	double z, w, s, v, p, q;
+	int i, j, n, hx, ix;
 
 	hx = ((int *)&x)[HIWORD];
 	ix = hx & ~0x80000000;
 
-	if (ix <= 0x3fc50000) {	/* |x| < 10.5/64 = 0.164062500 */
+	if (ix <= 0x3fc50000) {		/* |x| < 10.5/64 = 0.164062500 */
 		if (ix < 0x3e400000)	/* |x| < 2**-27 */
 			if ((int)x == 0)
 				return (x + y);
+
 		z = x * x;
+
 		if (ix < 0x3f800000)	/* |x| < 0.008  */
 			p = (x * z) * (PP1 + z * PP2) + y;
 		else
-			p = (x * z) * ((P1 + z * P2) + (z * z) * (P3 +
-			    z * P4)) + y;
+			p = (x * z) * ((P1 + z * P2) + (z * z) * (P3 + z *
+			    P4)) + y;
+
 		return (x + p);
-	} else {		/* 0.164062500 < |x| < ~pi/4 */
+	} else {			/* 0.164062500 < |x| < ~pi/4 */
 		n = ix >> 20;
 		i = (((ix >> 12) & 0xff) | 0x100) >> (0x401 - n);
 		j = i - 10;
+
 		if (hx < 0)
 			v = -y - (_TBL_sincosx[j] + x);
 		else
 			v = y - (_TBL_sincosx[j] - x);
+
 		s = v * v;
 		j <<= 1;
 		w = _TBL_sincos[j];
-		z = _TBL_sincos[j+1];
+		z = _TBL_sincos[j + 1];
 		p = s * (PP1 + s * PP2);
 		q = s * (QQ1 + s * QQ2);
 		p = v + v * p;
 		s = w * q + z * p;
-		return ((hx >= 0)? w + s : -(w + s));
+		return ((hx >= 0) ? w + s : -(w + s));
 	}
 }
--- old/usr/src/lib/libm/common/C/__sincos.c	2019-06-06 20:37:35.709850430 +0000
+++ new/usr/src/lib/libm/common/C/__sincos.c	2019-06-06 20:37:35.727034241 +0000
@@ -18,15 +18,17 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * double __k_sincos(double x, double y, double *c);
  * kernel sincos function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -67,98 +69,109 @@
 #include "libm.h"
 
 static const double sc[] = {
-/* ONE	= */  1.0,
+/* ONE	= */
+	1.0,
 /* NONE	= */ -1.0,
+
 /*
  * |sin(x) - (x+pp1*x^3+pp2*x^5)| <= 2^-58.79 for |x| < 0.008
  */
-/* PP1	= */ -0.166666666666316558867252052378889521480627858683055567,
-/* PP2	= */   .008333315652997472323564894248466758248475374977974017927,
+/* PP1	= */-0.166666666666316558867252052378889521480627858683055567,
+/* PP2	= */.008333315652997472323564894248466758248475374977974017927,
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p4*x^9)|
  * |------------------------------ | <= 2^-57.63 for |x| < 0.1953125
  * |                 x             |
  */
-/* P1  	= */ -1.666666666666629669805215138920301589656e-0001,
-/* P2  	= */  8.333333332390951295683993455280336376663e-0003,
-/* P3  	= */ -1.984126237997976692791551778230098403960e-0004,
-/* P4  	= */  2.753403624854277237649987622848330351110e-0006,
+/* P1   = */ -1.666666666666629669805215138920301589656e-0001,
+/* P2   = */ 8.333333332390951295683993455280336376663e-0003,
+/* P3   = */ -1.984126237997976692791551778230098403960e-0004,
+/* P4   = */ 2.753403624854277237649987622848330351110e-0006,
+
 /*
  * |cos(x) - (1+qq1*x^2+qq2*x^4)| <= 2^-55.99 for |x| <= 0.008 (0x3f80624d)
  */
-/* QQ1	= */ -0.4999999999975492381842911981948418542742729,
-/* QQ2	= */  0.041666542904352059294545209158357640398771740,
+/* QQ1	= */-0.4999999999975492381842911981948418542742729,
+/* QQ2	= */0.041666542904352059294545209158357640398771740,
+
 /*
  * |cos(x) - (1+q1*x^2+...+q4*x^8)| <= 2^-55.86 for |x| <= 0.1640625 (10.5/64)
  */
-/* Q1  	= */ -0.5,
-/* Q2  	= */  4.166666666500350703680945520860748617445e-0002,
-/* Q3  	= */ -1.388888596436972210694266290577848696006e-0003,
-/* Q4  	= */  2.478563078858589473679519517892953492192e-0005,
+/* Q1   = */ -0.5,
+/* Q2   = */ 4.166666666500350703680945520860748617445e-0002,
+/* Q3   = */ -1.388888596436972210694266290577848696006e-0003,
+/* Q4   = */ 2.478563078858589473679519517892953492192e-0005,
 };
-/* INDENT ON */
 
-#define	ONE	sc[0]
-#define	NONE	sc[1]
-#define	PP1	sc[2]
-#define	PP2	sc[3]
-#define	P1	sc[4]
-#define	P2	sc[5]
-#define	P3	sc[6]
-#define	P4	sc[7]
-#define	QQ1	sc[8]
-#define	QQ2	sc[9]
-#define	Q1	sc[10]
-#define	Q2	sc[11]
-#define	Q3	sc[12]
-#define	Q4	sc[13]
+
+#define	ONE		sc[0]
+#define	NONE		sc[1]
+#define	PP1		sc[2]
+#define	PP2		sc[3]
+#define	P1		sc[4]
+#define	P2		sc[5]
+#define	P3		sc[6]
+#define	P4		sc[7]
+#define	QQ1		sc[8]
+#define	QQ2		sc[9]
+#define	Q1		sc[10]
+#define	Q2		sc[11]
+#define	Q3		sc[12]
+#define	Q4		sc[13]
 
 extern const double _TBL_sincos[], _TBL_sincosx[];
 
 double
-__k_sincos(double x, double y, double *c) {
-	double	z, w, s, v, p, q;
-	int	i, j, n, hx, ix;
+__k_sincos(double x, double y, double *c)
+{
+	double z, w, s, v, p, q;
+	int i, j, n, hx, ix;
 
 	hx = ((int *)&x)[HIWORD];
 	ix = hx & ~0x80000000;
 
-	if (ix <= 0x3fc50000) {	/* |x| < 10.5/64 = 0.164062500 */
+	if (ix <= 0x3fc50000) {		/* |x| < 10.5/64 = 0.164062500 */
 		if (ix < 0x3e400000) {	/* |x| < 2**-27 */
 			if ((int)x == 0)
 				*c = ONE;
+
 			return (x + y);
 		} else {
 			z = x * x;
+
 			if (ix < 0x3f800000) {	/* |x| < 0.008 */
 				q = z * (QQ1 + z * QQ2);
 				p = (x * z) * (PP1 + z * PP2) + y;
 			} else {
-				q = z * ((Q1 + z * Q2) + (z * z) * (Q3 +
-				    z * Q4));
+				q = z * ((Q1 + z * Q2) + (z * z) * (Q3 + z *
+				    Q4));
 				p = (x * z) * ((P1 + z * P2) + (z * z) * (P3 +
 				    z * P4)) + y;
 			}
+
 			*c = ONE + q;
 			return (x + p);
 		}
-	} else {		/* 0.164062500 < |x| < ~pi/4 */
+	} else {			/* 0.164062500 < |x| < ~pi/4 */
 		n = ix >> 20;
 		i = (((ix >> 12) & 0xff) | 0x100) >> (0x401 - n);
 		j = i - 10;
+
 		if (hx < 0)
 			v = -y - (_TBL_sincosx[j] + x);
 		else
 			v = y - (_TBL_sincosx[j] - x);
+
 		s = v * v;
 		j <<= 1;
 		w = _TBL_sincos[j];
-		z = _TBL_sincos[j+1];
+		z = _TBL_sincos[j + 1];
 		p = s * (PP1 + s * PP2);
 		q = s * (QQ1 + s * QQ2);
 		p = v + v * p;
 		*c = z - (w * p - z * q);
 		s = w * q + z * p;
-		return ((hx >= 0)? w + s : -(w + s));
+		return ((hx >= 0) ? w + s : -(w + s));
 	}
 }
--- old/usr/src/lib/libm/common/C/__tan.c	2019-06-06 20:37:36.187267810 +0000
+++ new/usr/src/lib/libm/common/C/__tan.c	2019-06-06 20:37:36.203499680 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * __k_tan( double x;  double y; int k )
  * kernel tan/cotan function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -47,7 +48,7 @@
  *		ht = (hx + 0x4000)&0x7fff8000	(round x to a break point t)
  *		lt = 0
  *		i  = (hy-0x3fc40000)>>15;	(i<=64)
- *		x' = (x - t)+y 			(|x'| ~<= 2^-7)
+ *		x' = (x - t)+y                  (|x'| ~<= 2^-7)
  *	   By
  *		tan(t+x')
  *		  = (tan(t)+tan(x'))/(1-tan(x')tan(t))
@@ -61,7 +62,7 @@
  *		       tan(t) + tan(t)*(cos(x')-1) + sin(x')
  *
  *
- *	   where 	tan(t) is from the table,
+ *	   where        tan(t) is from the table,
  *			sin(x') = x + pp1*x^3 + pp2*x^5
  *			cos(x') = 1 + qq1*x^2 + qq2*x^4
  */
@@ -69,21 +70,24 @@
 #include "libm.h"
 
 extern const double _TBL_tan_hi[], _TBL_tan_lo[];
+
 static const double q[] = {
-/* one  = */  1.0,
+/* one  = */
+	1.0,
+
 /*
  *                       2       2       -59.56
  * |sin(x) - pp1*x*(pp2+x *(pp3+x )| <= 2        for |x|<1/64
  */
-/* pp1  = */  8.33326120969096230395312119298978359438478946686e-0003,
-/* pp2  = */  1.20001038589438965215025680596868692381425944526e+0002,
+/* pp1  = */ 8.33326120969096230395312119298978359438478946686e-0003,
+/* pp2  = */ 1.20001038589438965215025680596868692381425944526e+0002,
 /* pp3  = */ -2.00001730975089451192161504877731204032897949219e+0001,
 
 /*
  *                   2      2        -56.19
  * |cos(x) - (1+qq1*x (qq2+x ))| <= 2        for |x|<=1/128
  */
-/* qq1  = */  4.16665486385721928197511942926212213933467864990e-0002,
+/* qq1  = */ 4.16665486385721928197511942926212213933467864990e-0002,
 /* qq2  = */ -1.20000339921340035687080671777948737144470214844e+0001,
 
 /*
@@ -94,52 +98,54 @@
  * where (let z = x*x)
  *	PF(x) = x + (t1*x*z)(t2 + z(t3 + z))(t4 + z)(t5 + z(t6 + z))
  */
-/* t1 = */  3.71923358986516816929168705030406272271648049355e-0003,
-/* t2 = */  6.02645120354857866118436504621058702468872070312e+0000,
-/* t3 = */  2.42627327587398156083509093150496482849121093750e+0000,
-/* t4 = */  2.44968983934252770851003333518747240304946899414e+0000,
-/* t5 = */  6.07089252571767978849948121933266520500183105469e+0000,
+/* t1 = */ 3.71923358986516816929168705030406272271648049355e-0003,
+/* t2 = */ 6.02645120354857866118436504621058702468872070312e+0000,
+/* t3 = */ 2.42627327587398156083509093150496482849121093750e+0000,
+/* t4 = */ 2.44968983934252770851003333518747240304946899414e+0000,
+/* t5 = */ 6.07089252571767978849948121933266520500183105469e+0000,
 /* t6 = */ -2.49403756995593761658369658107403665781021118164e+0000,
 };
 
-
-#define	one q[0]
-#define	pp1 q[1]
-#define	pp2 q[2]
-#define	pp3 q[3]
-#define	qq1 q[4]
-#define	qq2 q[5]
-#define	t1  q[6]
-#define	t2  q[7]
-#define	t3  q[8]
-#define	t4  q[9]
-#define	t5  q[10]
-#define	t6  q[11]
-
-/* INDENT ON */
+#define	one		q[0]
+#define	pp1		q[1]
+#define	pp2		q[2]
+#define	pp3		q[3]
+#define	qq1		q[4]
+#define	qq2		q[5]
+#define	t1		q[6]
+#define	t2		q[7]
+#define	t3		q[8]
+#define	t4		q[9]
+#define	t5		q[10]
+#define	t6		q[11]
 
 
 double
-__k_tan(double x, double y, int k) {
+__k_tan(double x, double y, int k)
+{
 	double a, t, z, w = 0.0L, s, c, r, rh, xh, xl;
 	int i, j, hx, ix;
 
 	t = one;
-	hx = ((int *) &x)[HIWORD];
+	hx = ((int *)&x)[HIWORD];
 	ix = hx & 0x7fffffff;
-	if (ix < 0x3fc40000) {		/* 0.15625 */
-		if (ix < 0x3e400000) {	/* 2^-27 */
-			if ((i = (int) x) == 0)		/* generate inexact */
+
+	if (ix < 0x3fc40000) {			/* 0.15625 */
+		if (ix < 0x3e400000) {		/* 2^-27 */
+			if ((i = (int)x) == 0)	/* generate inexact */
 				w = x;
+
 			t = y;
 		} else {
 			z = x * x;
-			t = y + (((t1 * x) * z) * (t2 + z * (t3 + z))) *
-				((t4 + z) * (t5 + z * (t6 + z)));
+			t = y + (((t1 * x) * z) * (t2 + z * (t3 + z))) * ((t4 +
+			    z) * (t5 + z * (t6 + z)));
 			w = x + t;
 		}
+
 		if (k == 0)
 			return (w);
+
 		/*
 		 * Compute -1/(x+T) with great care
 		 * Let r = -1/(x+T), rh = r chopped to 20 bits.
@@ -148,23 +154,27 @@
 		 *		= rh + r*((1+rh*xh)+rh*xl).
 		 */
 		rh = r = -one / w;
-		((int *) &rh)[LOWORD] = 0;
+		((int *)&rh)[LOWORD] = 0;
 		xh = w;
-		((int *) &xh)[LOWORD] = 0;
+		((int *)&xh)[LOWORD] = 0;
 		xl = (x - xh) + t;
 		return (rh + r * ((one + rh * xh) + rh * xl));
 	}
+
 	j = (ix + 0x4000) & 0x7fff8000;
 	i = (j - 0x3fc40000) >> 15;
-	((int *) &t)[HIWORD] = j;
+	((int *)&t)[HIWORD] = j;
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = -y - (t + x);
+
 	a = _TBL_tan_hi[i];
 	z = x * x;
 	s = (pp1 * x) * (pp2 + z * (pp3 + z));	/* sin(x) */
 	t = (qq1 * z) * (qq2 + z);		/* cos(x) - 1 */
+
 	if (k == 0) {
 		w = a * s;
 		t = _TBL_tan_lo[i] + (s + a * w) / (one - (w - t));
@@ -173,6 +183,7 @@
 		w = s + a * t;
 		c = w + _TBL_tan_lo[i];
 		t = a * s - t;
+
 		/*
 		 * Now try to compute [(1-T)/(a+c)] accurately
 		 *
@@ -185,9 +196,9 @@
 		 */
 		r = one / (a + c);
 		rh = (one - t) * r;
-		((int *) &rh)[LOWORD] = 0;
+		((int *)&rh)[LOWORD] = 0;
 		xh = a + c;
-		((int *) &xh)[LOWORD] = 0;
+		((int *)&xh)[LOWORD] = 0;
 		xl = (a - xh) + c;
 		z = rh + r * (((one - rh * xh) - t) - rh * xl);
 		return (hx >= 0 ? -z : z);
--- old/usr/src/lib/libm/common/C/__xpg6.c	2019-06-06 20:37:36.661069270 +0000
+++ new/usr/src/lib/libm/common/C/__xpg6.c	2019-06-06 20:37:36.678685647 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/C/_lib_version.c	2019-06-06 20:37:37.161753060 +0000
+++ new/usr/src/lib/libm/common/C/_lib_version.c	2019-06-06 20:37:37.179853589 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/C/acos.c	2019-06-06 20:37:37.642120933 +0000
+++ new/usr/src/lib/libm/common/C/acos.c	2019-06-06 20:37:37.659132711 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __acos = acos
 
-/* INDENT OFF */
+
 /*
  * acos(x)
  * Method :
@@ -38,9 +39,9 @@
  * For |x|<=0.5
  *	acos(x) = pi/2 - (x + x*x^2*R(x^2))	(see asin.c)
  * For x>0.5
- * 	acos(x) = pi/2 - (pi/2 - 2asin(sqrt((1-x)/2)))
+ *      acos(x) = pi/2 - (pi/2 - 2asin(sqrt((1-x)/2)))
  *		= 2asin(sqrt((1-x)/2))
- *		= 2s + 2s*z*R(z) 	...z=(1-x)/2, s=sqrt(z)
+ *		= 2s + 2s*z*R(z)        ...z=(1-x)/2, s=sqrt(z)
  *		= 2f + (2c + 2s*z*R(z))
  *     where f=hi part of s, and c = (z-f*f)/(s+f) is the correction term
  *     for f so that f+c ~ sqrt(z).
@@ -54,83 +55,87 @@
  *
  * Function needed: sqrt
  */
-/* INDENT ON */
 
-#include "libm_protos.h"	/* _SVID_libm_error */
+#include "libm_protos.h"		/* _SVID_libm_error */
 #include "libm_macros.h"
 #include <math.h>
 
-/* INDENT OFF */
 static const double xxx[] = {
-/* one */	 1.00000000000000000000e+00,	/* 3FF00000, 00000000 */
-/* pi */	 3.14159265358979311600e+00,	/* 400921FB, 54442D18 */
-/* pio2_hi */	 1.57079632679489655800e+00,	/* 3FF921FB, 54442D18 */
-/* pio2_lo */	 6.12323399573676603587e-17,	/* 3C91A626, 33145C07 */
-/* pS0 */	 1.66666666666666657415e-01,	/* 3FC55555, 55555555 */
-/* pS1 */	-3.25565818622400915405e-01,	/* BFD4D612, 03EB6F7D */
-/* pS2 */	 2.01212532134862925881e-01,	/* 3FC9C155, 0E884455 */
-/* pS3 */	-4.00555345006794114027e-02,	/* BFA48228, B5688F3B */
-/* pS4 */	 7.91534994289814532176e-04,	/* 3F49EFE0, 7501B288 */
-/* pS5 */	 3.47933107596021167570e-05,	/* 3F023DE1, 0DFDF709 */
-/* qS1 */	-2.40339491173441421878e+00,	/* C0033A27, 1C8A2D4B */
-/* qS2 */	 2.02094576023350569471e+00,	/* 40002AE5, 9C598AC8 */
-/* qS3 */	-6.88283971605453293030e-01,	/* BFE6066C, 1B8D0159 */
-/* qS4 */	 7.70381505559019352791e-02	/* 3FB3B8C5, B12E9282 */
+/* one */
+	1.00000000000000000000e+00,		/* 3FF00000, 00000000 */
+/* pi */ 3.14159265358979311600e+00,		/* 400921FB, 54442D18 */
+/* pio2_hi */ 1.57079632679489655800e+00,	/* 3FF921FB, 54442D18 */
+/* pio2_lo */ 6.12323399573676603587e-17,	/* 3C91A626, 33145C07 */
+/* pS0 */ 1.66666666666666657415e-01,		/* 3FC55555, 55555555 */
+/* pS1 */ -3.25565818622400915405e-01,		/* BFD4D612, 03EB6F7D */
+/* pS2 */ 2.01212532134862925881e-01,		/* 3FC9C155, 0E884455 */
+/* pS3 */ -4.00555345006794114027e-02,		/* BFA48228, B5688F3B */
+/* pS4 */ 7.91534994289814532176e-04,		/* 3F49EFE0, 7501B288 */
+/* pS5 */ 3.47933107596021167570e-05,		/* 3F023DE1, 0DFDF709 */
+/* qS1 */ -2.40339491173441421878e+00,		/* C0033A27, 1C8A2D4B */
+/* qS2 */ 2.02094576023350569471e+00,		/* 40002AE5, 9C598AC8 */
+/* qS3 */ -6.88283971605453293030e-01,		/* BFE6066C, 1B8D0159 */
+/* qS4 */ 7.70381505559019352791e-02		/* 3FB3B8C5, B12E9282 */
 };
-#define	one	xxx[0]
-#define	pi	xxx[1]
-#define	pio2_hi	xxx[2]
-#define	pio2_lo	xxx[3]
-#define	pS0	xxx[4]
-#define	pS1	xxx[5]
-#define	pS2	xxx[6]
-#define	pS3	xxx[7]
-#define	pS4	xxx[8]
-#define	pS5	xxx[9]
-#define	qS1	xxx[10]
-#define	qS2	xxx[11]
-#define	qS3	xxx[12]
-#define	qS4	xxx[13]
-/* INDENT ON */
+
+#define	one		xxx[0]
+#define	pi		xxx[1]
+#define	pio2_hi		xxx[2]
+#define	pio2_lo		xxx[3]
+#define	pS0		xxx[4]
+#define	pS1		xxx[5]
+#define	pS2		xxx[6]
+#define	pS3		xxx[7]
+#define	pS4		xxx[8]
+#define	pS5		xxx[9]
+#define	qS1		xxx[10]
+#define	qS2		xxx[11]
+#define	qS3		xxx[12]
+#define	qS4		xxx[13]
 
 double
-acos(double x) {
+acos(double x)
+{
 	double z, p, q, r, w, s, c, df;
 	int hx, ix;
 
-	hx = ((int *) &x)[HIWORD];
+	hx = ((int *)&x)[HIWORD];
 	ix = hx & 0x7fffffff;
-	if (ix >= 0x3ff00000) {	/* |x| >= 1 */
-		if (((ix - 0x3ff00000) | ((int *) &x)[LOWORD]) == 0) {
+
+	if (ix >= 0x3ff00000) {		/* |x| >= 1 */
+		if (((ix - 0x3ff00000) | ((int *)&x)[LOWORD]) == 0) {
 			/* |x| == 1 */
 			if (hx > 0)	/* acos(1) = 0 */
 				return (0.0);
 			else		/* acos(-1) = pi */
 				return (pi + 2.0 * pio2_lo);
-		} else if (isnan(x))
+		} else if (isnan(x)) {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 			return (ix >= 0x7ff80000 ? x : (x - x) / (x - x));
-			/* assumes sparc-like QNaN */
+		/* assumes sparc-like QNaN */
 #else
-			return (x - x) / (x - x);	/* acos(|x|>1) is NaN */
+			return ((x - x) / (x - x));	/* acos(|x|>1) is NaN */
 #endif
-		else
+		} else {
 			return (_SVID_libm_err(x, x, 1));
+		}
 	}
-	if (ix < 0x3fe00000) {	/* |x| < 0.5 */
+
+	if (ix < 0x3fe00000) {				/* |x| < 0.5 */
 		if (ix <= 0x3c600000)
 			return (pio2_hi + pio2_lo);	/* if |x| < 2**-57 */
+
 		z = x * x;
-		p = z * (pS0 + z * (pS1 + z * (pS2 + z * (pS3 +
-			z * (pS4 + z * pS5)))));
+		p = z * (pS0 + z * (pS1 + z * (pS2 + z * (pS3 + z * (pS4 + z *
+		    pS5)))));
 		q = one + z * (qS1 + z * (qS2 + z * (qS3 + z * qS4)));
 		r = p / q;
 		return (pio2_hi - (x - (pio2_lo - x * r)));
 	} else if (hx < 0) {
 		/* x < -0.5 */
 		z = (one + x) * 0.5;
-		p = z * (pS0 + z * (pS1 + z * (pS2 + z * (pS3 +
-			z * (pS4 + z * pS5)))));
+		p = z * (pS0 + z * (pS1 + z * (pS2 + z * (pS3 + z * (pS4 + z *
+		    pS5)))));
 		q = one + z * (qS1 + z * (qS2 + z * (qS3 + z * qS4)));
 		s = sqrt(z);
 		r = p / q;
@@ -141,10 +146,10 @@
 		z = (one - x) * 0.5;
 		s = sqrt(z);
 		df = s;
-		((int *) &df)[LOWORD] = 0;
+		((int *)&df)[LOWORD] = 0;
 		c = (z - df * df) / (s + df);
-		p = z * (pS0 + z * (pS1 + z * (pS2 + z * (pS3 +
-			z * (pS4 + z * pS5)))));
+		p = z * (pS0 + z * (pS1 + z * (pS2 + z * (pS3 + z * (pS4 + z *
+		    pS5)))));
 		q = one + z * (qS1 + z * (qS2 + z * (qS3 + z * qS4)));
 		r = p / q;
 		w = r * s + c;
--- old/usr/src/lib/libm/common/C/acosh.c	2019-06-06 20:37:38.144162772 +0000
+++ new/usr/src/lib/libm/common/C/acosh.c	2019-06-06 20:37:38.162054389 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __acosh = acosh
 
-/* INDENT OFF */
+
 /*
  * acosh(x)
  * Method :
@@ -44,29 +45,30 @@
  *	acosh(x) is NaN with signal if x < 1.
  *	acosh(NaN) is NaN without signal.
  */
-/* INDENT ON */
 
-#include "libm_protos.h"	/* _SVID_libm_error */
+#include "libm_protos.h"		/* _SVID_libm_error */
 #include "libm_macros.h"
 #include <math.h>
 
-static const double
-	one = 1.0,
+static const double one = 1.0,
 	ln2 = 6.93147180559945286227e-01;	/* 3FE62E42, FEFA39EF */
 
 double
-acosh(double x) {
+acosh(double x)
+{
 	double t;
 	int hx;
 
-	hx = ((int *) &x)[HIWORD];
-	if (hx < 0x3ff00000) {	/* x < 1 */
+	hx = ((int *)&x)[HIWORD];
+
+	if (hx < 0x3ff00000) {		/* x < 1 */
 		if (isnan(x))
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 			return (hx >= 0xfff80000 ? x : (x - x) / (x - x));
-			/* assumes sparc-like QNaN */
+
+		/* assumes sparc-like QNaN */
 #else
-			return (x - x) / (x - x);
+			return ((x - x) / (x - x));
 #endif
 		else
 			return (_SVID_libm_err(x, x, 29));
@@ -79,10 +81,11 @@
 #else
 			return (x + x);
 #endif
-		} else	/* acosh(huge)=log(2x) */
+		} else { /* acosh(huge)=log(2x) */
 			return (log(x) + ln2);
-	} else if (((hx - 0x3ff00000) | ((int *) &x)[LOWORD]) == 0) {
-		return (0.0);	/* acosh(1) = 0 */
+		}
+	} else if (((hx - 0x3ff00000) | ((int *)&x)[LOWORD]) == 0) {
+		return (0.0);		/* acosh(1) = 0 */
 	} else if (hx > 0x40000000) {
 		/* 2**28 > x > 2 */
 		t = x * x;
--- old/usr/src/lib/libm/common/C/asin.c	2019-06-06 20:37:38.633937635 +0000
+++ new/usr/src/lib/libm/common/C/asin.c	2019-06-06 20:37:38.652071505 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __asin = asin
 
-/* INDENT OFF */
+
 /*
  * asin(x)
  * Method :
@@ -49,7 +50,7 @@
  *			= pio2_hi - (2*(s+s*z*R(z)) - pio2_lo)
  *	For x<=0.98, let pio4_hi = pio2_hi/2, then
  *		f = hi part of s;
- *		c = sqrt(z) - f = (z-f*f)/(s+f) 	...f+c=sqrt(z)
+ *		c = sqrt(z) - f = (z-f*f)/(s+f)         ...f+c=sqrt(z)
  *	and
  *		asin(x) = pi/2 - 2*(s+s*z*R(z))
  *			= pio4_hi+(pio4-2s)-(2s*z*R(z)-pio2_lo)
@@ -60,98 +61,108 @@
  *	if |x|>1, return NaN with invalid signal.
  *
  */
-/* INDENT ON */
 
-#include "libm_protos.h"	/* _SVID_libm_error */
+#include "libm_protos.h"		/* _SVID_libm_error */
 #include "libm_macros.h"
 #include <math.h>
 
-/* INDENT OFF */
 static const double xxx[] = {
-/* one */	 1.00000000000000000000e+00,	/* 3FF00000, 00000000 */
-/* huge */	 1.000e+300,
-/* pio2_hi */	 1.57079632679489655800e+00,	/* 3FF921FB, 54442D18 */
-/* pio2_lo */	 6.12323399573676603587e-17,	/* 3C91A626, 33145C07 */
-/* pio4_hi */	 7.85398163397448278999e-01,	/* 3FE921FB, 54442D18 */
-/* coefficient for R(x^2) */
-/* pS0 */	 1.66666666666666657415e-01,	/* 3FC55555, 55555555 */
-/* pS1 */	-3.25565818622400915405e-01,	/* BFD4D612, 03EB6F7D */
-/* pS2 */	 2.01212532134862925881e-01,	/* 3FC9C155, 0E884455 */
-/* pS3 */	-4.00555345006794114027e-02,	/* BFA48228, B5688F3B */
-/* pS4 */	 7.91534994289814532176e-04,	/* 3F49EFE0, 7501B288 */
-/* pS5 */	 3.47933107596021167570e-05,	/* 3F023DE1, 0DFDF709 */
-/* qS1 */	-2.40339491173441421878e+00,	/* C0033A27, 1C8A2D4B */
-/* qS2 */	 2.02094576023350569471e+00,	/* 40002AE5, 9C598AC8 */
-/* qS3 */	-6.88283971605453293030e-01,	/* BFE6066C, 1B8D0159 */
-/* qS4 */	 7.70381505559019352791e-02	/* 3FB3B8C5, B12E9282 */
+/* one */
+	1.00000000000000000000e+00,		/* 3FF00000, 00000000 */
+/* huge */ 1.000e+300,
+/* pio2_hi */ 1.57079632679489655800e+00,	/* 3FF921FB, 54442D18 */
+/* pio2_lo */ 6.12323399573676603587e-17,	/* 3C91A626, 33145C07 */
+/* pio4_hi */ 7.85398163397448278999e-01,	/* 3FE921FB, 54442D18 */
+
+/*
+ * coefficient for R(x^2)
+ * pS0
+ */
+	1.66666666666666657415e-01,		/* 3FC55555, 55555555 */
+/* pS1 */ -3.25565818622400915405e-01,		/* BFD4D612, 03EB6F7D */
+/* pS2 */ 2.01212532134862925881e-01,		/* 3FC9C155, 0E884455 */
+/* pS3 */ -4.00555345006794114027e-02,		/* BFA48228, B5688F3B */
+/* pS4 */ 7.91534994289814532176e-04,		/* 3F49EFE0, 7501B288 */
+/* pS5 */ 3.47933107596021167570e-05,		/* 3F023DE1, 0DFDF709 */
+/* qS1 */ -2.40339491173441421878e+00,		/* C0033A27, 1C8A2D4B */
+/* qS2 */ 2.02094576023350569471e+00,		/* 40002AE5, 9C598AC8 */
+/* qS3 */ -6.88283971605453293030e-01,		/* BFE6066C, 1B8D0159 */
+/* qS4 */ 7.70381505559019352791e-02		/* 3FB3B8C5, B12E9282 */
 };
-#define	one	xxx[0]
-#define	huge	xxx[1]
-#define	pio2_hi	xxx[2]
-#define	pio2_lo	xxx[3]
-#define	pio4_hi	xxx[4]
-#define	pS0	xxx[5]
-#define	pS1	xxx[6]
-#define	pS2	xxx[7]
-#define	pS3	xxx[8]
-#define	pS4	xxx[9]
-#define	pS5	xxx[10]
-#define	qS1	xxx[11]
-#define	qS2	xxx[12]
-#define	qS3	xxx[13]
-#define	qS4	xxx[14]
-/* INDENT ON */
+
+#define	one		xxx[0]
+#define	huge		xxx[1]
+#define	pio2_hi		xxx[2]
+#define	pio2_lo		xxx[3]
+#define	pio4_hi		xxx[4]
+#define	pS0		xxx[5]
+#define	pS1		xxx[6]
+#define	pS2		xxx[7]
+#define	pS3		xxx[8]
+#define	pS4		xxx[9]
+#define	pS5		xxx[10]
+#define	qS1		xxx[11]
+#define	qS2		xxx[12]
+#define	qS3		xxx[13]
+#define	qS4		xxx[14]
 
 double
-asin(double x) {
+asin(double x)
+{
 	double t, w, p, q, c, r, s;
 	int hx, ix, i;
 
-	hx = ((int *) &x)[HIWORD];
+	hx = ((int *)&x)[HIWORD];
 	ix = hx & 0x7fffffff;
-	if (ix >= 0x3ff00000) {	/* |x| >= 1 */
-		if (((ix - 0x3ff00000) | ((int *) &x)[LOWORD]) == 0)
+
+	if (ix >= 0x3ff00000) {		/* |x| >= 1 */
+		if (((ix - 0x3ff00000) | ((int *)&x)[LOWORD]) == 0)
 			/* asin(1)=+-pi/2 with inexact */
 			return (x * pio2_hi + x * pio2_lo);
 		else if (isnan(x))
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 			return (ix >= 0x7ff80000 ? x : (x - x) / (x - x));
-			/* assumes sparc-like QNaN */
+
+		/* assumes sparc-like QNaN */
 #else
-			return (x - x) / (x - x);	/* asin(|x|>1) is NaN */
+			return ((x - x) / (x - x));	/* asin(|x|>1) is NaN */
 #endif
 		else
 			return (_SVID_libm_err(x, x, 2));
 	} else if (ix < 0x3fe00000) {	/* |x| < 0.5 */
 		if (ix < 0x3e400000) {	/* if |x| < 2**-27 */
-			if ((i = (int) x) == 0)
+			if ((i = (int)x) == 0)
 				/* return x with inexact if x != 0 */
 				return (x);
 		}
+
 		t = x * x;
-		p = t * (pS0 + t * (pS1 + t * (pS2 + t * (pS3 +
-			t * (pS4 + t * pS5)))));
+		p = t * (pS0 + t * (pS1 + t * (pS2 + t * (pS3 + t * (pS4 + t *
+		    pS5)))));
 		q = one + t * (qS1 + t * (qS2 + t * (qS3 + t * qS4)));
 		w = p / q;
 		return (x + x * w);
 	}
+
 	/* 1 > |x| >= 0.5 */
 	w = one - fabs(x);
 	t = w * 0.5;
 	p = t * (pS0 + t * (pS1 + t * (pS2 + t * (pS3 + t * (pS4 + t * pS5)))));
 	q = one + t * (qS1 + t * (qS2 + t * (qS3 + t * qS4)));
 	s = sqrt(t);
-	if (ix >= 0x3FEF3333) {	/* if |x| > 0.975 */
+
+	if (ix >= 0x3FEF3333) {		/* if |x| > 0.975 */
 		w = p / q;
 		t = pio2_hi - (2.0 * (s + s * w) - pio2_lo);
 	} else {
 		w = s;
-		((int *) &w)[LOWORD] = 0;
+		((int *)&w)[LOWORD] = 0;
 		c = (t - w * w) / (s + w);
 		r = p / q;
 		p = 2.0 * s * r - (pio2_lo - 2.0 * c);
 		q = pio4_hi - 2.0 * w;
 		t = pio4_hi - (p - q);
 	}
+
 	return (hx > 0 ? t : -t);
 }
--- old/usr/src/lib/libm/common/C/asinh.c	2019-06-06 20:37:39.124144430 +0000
+++ new/usr/src/lib/libm/common/C/asinh.c	2019-06-06 20:37:39.142390318 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __asinh = asinh
 
-/* INDENT OFF */
+
 /*
  * asinh(x)
  * Method :
@@ -41,39 +42,45 @@
  *		 := sign(x)*log(2|x|+1/(|x|+sqrt(x*x+1))) if|x| > 2, else
  *		 := sign(x)*log1p(|x|+x^2/(1+sqrt(1+x^2)))
  */
-/* INDENT ON */
 
 #include "libm_macros.h"
 #include <math.h>
 
 static const double xxx[] = {
-/* one */	1.00000000000000000000e+00,	/* 3FF00000, 00000000 */
-/* ln2 */	6.93147180559945286227e-01,	/* 3FE62E42, FEFA39EF */
-/* huge */	1.00000000000000000000e+300
+/* one */
+	1.00000000000000000000e+00,	/* 3FF00000, 00000000 */
+/* ln2 */ 6.93147180559945286227e-01,	/* 3FE62E42, FEFA39EF */
+/* huge */ 1.00000000000000000000e+300
 };
-#define	one	xxx[0]
-#define	ln2	xxx[1]
-#define	huge	xxx[2]
+
+#define	one		xxx[0]
+#define	ln2		xxx[1]
+#define	huge		xxx[2]
 
 double
-asinh(double x) {
+asinh(double x)
+{
 	double t, w;
 	int hx, ix;
 
-	hx = ((int *) &x)[HIWORD];
+	hx = ((int *)&x)[HIWORD];
 	ix = hx & 0x7fffffff;
+
 	if (ix >= 0x7ff00000)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (ix >= 0x7ff80000 ? x : x + x);
-		/* assumes sparc-like QNaN */
+
+	/* assumes sparc-like QNaN */
 #else
-		return (x + x);	/* x is inf or NaN */
+		return (x + x);		/* x is inf or NaN */
 #endif
-	if (ix < 0x3e300000) {	/* |x|<2**-28 */
+
+	if (ix < 0x3e300000) {		/* |x|<2**-28 */
 		if (huge + x > one)
 			return (x);	/* return x inexact except 0 */
 	}
-	if (ix > 0x41b00000) {	/* |x| > 2**28 */
+
+	if (ix > 0x41b00000) {		/* |x| > 2**28 */
 		w = log(fabs(x)) + ln2;
 	} else if (ix > 0x40000000) {
 		/* 2**28 > |x| > 2.0 */
@@ -84,5 +91,6 @@
 		t = x * x;
 		w = log1p(fabs(x) + t / (one + sqrt(one + t)));
 	}
+
 	return (hx > 0 ? w : -w);
 }
--- old/usr/src/lib/libm/common/C/atan.c	2019-06-06 20:37:39.670966142 +0000
+++ new/usr/src/lib/libm/common/C/atan.c	2019-06-06 20:37:39.690344022 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __atan = atan
 
-/* INDENT OFF */
+
 /*
  * atan(x)
  * Accurate Table look-up algorithm with polynomial approximation in
@@ -52,7 +53,7 @@
  *		B = (p4+z)+z*z) * (p5+z(p6+z))
  *	Note: (i) domain of poly1 is [0, 1/8], (ii) remez relative
  *	approximation error of poly1 is bounded by
- * 		|(atan(x)-poly1(x))/x| <= 2^-57.61
+ *              |(atan(x)-poly1(x))/x| <= 2^-57.61
  * (4). For x >= 8 then
  *	(3.1) if x >= 2^prec,     atan(x) = atan(inf) - pio2lo
  *	(3.2) if x >= 2^(prec/3), atan(x) = atan(inf) - 1/x
@@ -79,118 +80,127 @@
  * Accuracy: Maximum error observed is bounded by 0.6 ulp after testing
  * more than 10 million random arguments
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "libm_protos.h"
 
 extern const double _TBL_atan[];
+
 static const double g[] = {
-/* one	= */  1.0,
-/* p1	= */  8.02176624254765935351230154992663301527500152588e-0002,
-/* p2	= */  1.27223421700559402580665846471674740314483642578e+0000,
-/* p3	= */ -1.20606901800503640842521235754247754812240600586e+0000,
-/* p4	= */ -2.36088967922325565496066701598465442657470703125e+0000,
-/* p5	= */  1.38345799501389166152875986881554126739501953125e+0000,
-/* p6	= */  1.06742368078953453469637224770849570631980895996e+0000,
+/* one	= */
+	1.0,
+/* p1	= */8.02176624254765935351230154992663301527500152588e-0002,
+/* p2	= */1.27223421700559402580665846471674740314483642578e+0000,
+/* p3	= */-1.20606901800503640842521235754247754812240600586e+0000,
+/* p4	= */-2.36088967922325565496066701598465442657470703125e+0000,
+/* p5	= */1.38345799501389166152875986881554126739501953125e+0000,
+/* p6	= */1.06742368078953453469637224770849570631980895996e+0000,
 /* q1   = */ -1.42796626333911796935538518482644576579332351685e-0001,
-/* q2   = */  3.51427110447873227059810477159863497078605962912e+0000,
-/* q3   = */  5.92129112708164262457444237952586263418197631836e-0001,
+/* q2   = */ 3.51427110447873227059810477159863497078605962912e+0000,
+/* q3   = */ 5.92129112708164262457444237952586263418197631836e-0001,
 /* q4   = */ -1.99272234785683144409063061175402253866195678711e+0000,
-/* pio2hi */  1.570796326794896558e+00,
-/* pio2lo */  6.123233995736765886e-17,
+/* pio2hi */ 1.570796326794896558e+00,
+/* pio2lo */ 6.123233995736765886e-17,
 /* t1   = */ -0.333333333333333333333333333333333,
-/* t2   = */  0.2,
+/* t2   = */ 0.2,
 /* t3   = */ -1.666666666666666666666666666666666,
 };
 
-#define	one g[0]
-#define	p1 g[1]
-#define	p2 g[2]
-#define	p3 g[3]
-#define	p4 g[4]
-#define	p5 g[5]
-#define	p6 g[6]
-#define	q1 g[7]
-#define	q2 g[8]
-#define	q3 g[9]
-#define	q4 g[10]
-#define	pio2hi g[11]
-#define	pio2lo g[12]
-#define	t1 g[13]
-#define	t2 g[14]
-#define	t3 g[15]
-
+#define	one		g[0]
+#define	p1		g[1]
+#define	p2		g[2]
+#define	p3		g[3]
+#define	p4		g[4]
+#define	p5		g[5]
+#define	p6		g[6]
+#define	q1		g[7]
+#define	q2		g[8]
+#define	q3		g[9]
+#define	q4		g[10]
+#define	pio2hi		g[11]
+#define	pio2lo		g[12]
+#define	t1		g[13]
+#define	t2		g[14]
+#define	t3		g[15]
 
 double
-atan(double x) {
+atan(double x)
+{
 	double y, z, r, p, s;
 	int ix, lx, hx, j;
 
-	hx = ((int *) &x)[HIWORD];
-	lx = ((int *) &x)[LOWORD];
+	hx = ((int *)&x)[HIWORD];
+	lx = ((int *)&x)[LOWORD];
 	ix = hx & ~0x80000000;
 	j = ix >> 20;
 
 	/* for |x| < 1/8 */
 	if (j < 0x3fc) {
-		if (j < 0x3f5) {	/* when |x| < 2**(-prec/6-2) */
-			if (j < 0x3e3) {	/* if |x| < 2**(-prec/2-2) */
-				return ((int) x == 0 ? x : one);
-			}
+		if (j < 0x3f5) {		/* when |x| < 2**(-prec/6-2) */
+			if (j < 0x3e3)		/* if |x| < 2**(-prec/2-2) */
+				return ((int)x == 0 ? x : one);
+
 			if (j < 0x3f1) {	/* if |x| < 2**(-prec/4-1) */
 				return (x + (x * t1) * (x * x));
-			} else {	/* if |x| < 2**(-prec/6-2) */
+			} else {		/* if |x| < 2**(-prec/6-2) */
 				z = x * x;
 				s = t2 * x;
 				return (x + (t3 + z) * (s * z));
 			}
 		}
-		z = x * x; s = p1 * x;
+
+		z = x * x;
+		s = p1 * x;
 		return (x + ((s * z) * (p2 + z * (p3 + z))) *
-				(((p4 + z) + z * z) * (p5 + z * (p6 + z))));
+		    (((p4 + z) + z * z) * (p5 + z * (p6 + z))));
 	}
 
 	/* for |x| >= 8.0 */
 	if (j >= 0x402) {
 		if (j < 0x436) {
 			r = one / x;
+
 			if (hx >= 0) {
-				y =  pio2hi; p =  pio2lo;
+				y = pio2hi;
+				p = pio2lo;
 			} else {
-				y = -pio2hi; p = -pio2lo;
+				y = -pio2hi;
+				p = -pio2lo;
 			}
+
 			if (ix < 0x40504000) {	/* x <  65 */
 				z = r * r;
 				s = p1 * r;
-				return (y + ((p - r) - ((s * z) *
-					(p2 + z * (p3 + z))) *
-					(((p4 + z) + z * z) *
-					(p5 + z * (p6 + z)))));
+				return (y + ((p - r) - ((s * z) * (p2 + z *
+				    (p3 + z))) * (((p4 + z) + z * z) *
+				    (p5 + z * (p6 + z)))));
 			} else if (j < 0x412) {
 				z = r * r;
-				return (y + (p - ((q1 * r) * (q4 + z)) *
-					(q2 + z * (q3 + z))));
-			} else
+				return (y + (p - ((q1 * r) * (q4 + z)) * (q2 +
+				    z * (q3 + z))));
+			} else {
 				return (y + (p - r));
+			}
 		} else {
-			if (j >= 0x7ff) /* x is inf or NaN */
+			if (j >= 0x7ff)	/* x is inf or NaN */
 				if (((ix - 0x7ff00000) | lx) != 0)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 					return (ix >= 0x7ff80000 ? x : x - x);
-					/* assumes sparc-like QNaN */
+
+			/* assumes sparc-like QNaN */
 #else
 					return (x - x);
 #endif
 			y = -pio2lo;
 			return (hx >= 0 ? pio2hi - y : y - pio2hi);
 		}
-	} else {	/* now x is between 1/8 and 8 */
+	} else {			/* now x is between 1/8 and 8 */
 		double *w, w0, w1, s, z;
-		w = (double *) _TBL_atan + (((ix - 0x3fc00000) >> 16) << 1);
-		w0 = (hx >= 0)? w[0] : -w[0];
+
+		w = (double *)_TBL_atan + (((ix - 0x3fc00000) >> 16) << 1);
+		w0 = (hx >= 0) ? w[0] : -w[0];
 		s = (x - w0) / (one + x * w0);
-		w1 = (hx >= 0)? w[1] : -w[1];
+		w1 = (hx >= 0) ? w[1] : -w[1];
 		z = s * s;
 		return (((q1 * s) * (q4 + z)) * (q2 + z * (q3 + z)) + w1);
 	}
--- old/usr/src/lib/libm/common/C/atan2.c	2019-06-06 20:37:40.176025094 +0000
+++ new/usr/src/lib/libm/common/C/atan2.c	2019-06-06 20:37:40.193530212 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -392,25 +394,27 @@
 	+1.10894981496317081405107718475040168084164825641e-0001,
 };
 
-#define	zero	C[0]
-#define	twom3	C[1]
-#define	two110	C[2]
-#define	pio4	C[3]
-#define	pio2	C[4]
-#define	pio2_lo	C[5]
-#define	mpi	C[6]
-#define	mpi_lo	C[7]
-#define	p1	C[8]
-#define	p2	C[9]
-#define	p3	C[10]
-#define	p4	C[11]
+#define	zero		C[0]
+#define	twom3		C[1]
+#define	two110		C[2]
+#define	pio4		C[3]
+#define	pio2		C[4]
+#define	pio2_lo		C[5]
+#define	mpi		C[6]
+#define	mpi_lo		C[7]
+#define	p1		C[8]
+#define	p2		C[9]
+#define	p3		C[10]
+#define	p4		C[11]
 
 double
-atan2(double oy, double ox) {
-	double	ah, al, t, xh, x, y, z;
-	int	i, k, hx, hy, sx, sy;
+atan2(double oy, double ox)
+{
+	double ah, al, t, xh, x, y, z;
+	int i, k, hx, hy, sx, sy;
+
 #ifndef lint
-	volatile int	inexact __unused;
+	volatile int inexact __unused;
 #endif
 
 	hy = ((int *)&oy)[HIWORD];
@@ -428,6 +432,7 @@
 		hy = i;
 		x = fabs(oy);
 		y = fabs(ox);
+
 		if (sx) {
 			ah = pio2;
 			al = pio2_lo;
@@ -439,6 +444,7 @@
 	} else {
 		x = fabs(ox);
 		y = fabs(oy);
+
 		if (sx) {
 			ah = mpi;
 			al = mpi_lo;
@@ -452,18 +458,23 @@
 		if (hx >= 0x7ff00000) {
 			if (((hx ^ 0x7ff00000) | ((int *)&x)[LOWORD]) != 0)
 				return (ox * oy);
+
 			if (hy >= 0x7ff00000)
 				ah += pio4;
+
 #ifndef lint
 			inexact = (int)ah;	/* inexact if ah != 0 */
 #endif
-			return ((sy)? -ah : ah);
+			return ((sy) ? -ah : ah);
 		}
+
 		if (hx - hy >= 0x03600000) {
 			if ((int)ah == 0)
 				ah = y / x;
-			return ((sy)? -ah : ah);
+
+			return ((sy) ? -ah : ah);
 		}
+
 		y *= twom3;
 		x *= twom3;
 		hy -= 0x00300000;
@@ -472,11 +483,13 @@
 		if ((hy | ((int *)&y)[LOWORD]) == 0) {
 			if ((hx | ((int *)&x)[LOWORD]) == 0)
 				return (_SVID_libm_err(ox, oy, 3));
+
 #ifndef lint
 			inexact = (int)ah;	/* inexact if ah != 0 */
 #endif
-			return ((sy)? -ah : ah);
+			return ((sy) ? -ah : ah);
 		}
+
 		y *= two110;
 		x *= two110;
 		hy = ((int *)&y)[HIWORD];
@@ -484,16 +497,18 @@
 	}
 
 	k = (((hx - hy) + 0x00004000) >> 13) & ~0x3;
+
 	if (k > 644)
 		k = 644;
+
 	ah += TBL[k];
-	al += TBL[k+1];
-	t = TBL[k+2];
+	al += TBL[k + 1];
+	t = TBL[k + 2];
 
 	xh = x;
 	((int *)&xh)[LOWORD] = 0;
 	z = ((y - t * xh) - t * (x - xh)) / (x + y * t);
 	x = z * z;
 	t = ah + (z + (al + (z * x) * (p1 + x * (p2 + x * (p3 + x * p4)))));
-	return ((sy)? -t : t);
+	return ((sy) ? -t : t);
 }
--- old/usr/src/lib/libm/common/C/atan2pi.c	2019-06-06 20:37:40.673051643 +0000
+++ new/usr/src/lib/libm/common/C/atan2pi.c	2019-06-06 20:37:40.690939388 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,15 +37,19 @@
 static const double invpi = 0.3183098861837906715377675;
 
 double
-atan2pi(double y, double x) {
-	int	ix, iy;
+atan2pi(double y, double x)
+{
+	int ix, iy;
 
 	if (x == 0.0 && y == 0.0) {
 		ix = ((int *)&x)[HIWORD];
 		iy = ((int *)&y)[HIWORD];
+
 		if (ix >= 0)
 			return (y);
-		return ((iy >= 0)? 1.0 : -1.0);
+
+		return ((iy >= 0) ? 1.0 : -1.0);
 	}
+
 	return (atan2(y, x) * invpi);
 }
--- old/usr/src/lib/libm/common/C/atanh.c	2019-06-06 20:37:41.134991444 +0000
+++ new/usr/src/lib/libm/common/C/atanh.c	2019-06-06 20:37:41.151592112 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __atanh = atanh
 
-/* INDENT OFF */
+
 /*
  * atanh(x)
  * Code originated from 4.3bsd.
@@ -48,23 +49,27 @@
  *	atanh(NaN) is that NaN with no signal;
  *	atanh(+-1) is +-INF with signal.
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "libm_protos.h"
 #include <math.h>
 
 double
-atanh(double x) {
+atanh(double x)
+{
 	double t;
 
 	if (isnan(x))
 		return (x * x);		/* switched from x + x for Cheetah */
+
 	t = fabs(x);
+
 	if (t > 1.0)
 		return (_SVID_libm_err(x, x, 30));	/* sNaN */
+
 	if (t == 1.0)
 		return (_SVID_libm_err(x, x, 31));	/* x/0; */
+
 	t = t / (1.0 - t);
 	return (copysign(0.5, x) * log1p(t + t));
 }
--- old/usr/src/lib/libm/common/C/cbrt.c	2019-06-06 20:37:41.581830351 +0000
+++ new/usr/src/lib/libm/common/C/cbrt.c	2019-06-06 20:37:41.598468509 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,6 @@
 
 #include "libm_macros.h"
 
-/* INDENT OFF */
 
 /*
  *  cbrt: double precision cube root
@@ -60,135 +60,199 @@
  *   then TBL[i] = cbrt(x(i)) rounded to 17 significant bits
  */
 static const double __libm_TBL_cbrt[] = {
- 1.00000000000000000e+00, 1.00259399414062500e+00, 1.00518798828125000e+00,
- 1.00775146484375000e+00, 1.01031494140625000e+00, 1.01284790039062500e+00,
- 1.01538085937500000e+00, 1.01791381835937500e+00, 1.02041625976562500e+00,
- 1.02290344238281250e+00, 1.02539062500000000e+00, 1.02786254882812500e+00,
- 1.03031921386718750e+00, 1.03277587890625000e+00, 1.03520202636718750e+00,
- 1.03762817382812500e+00, 1.04003906250000000e+00, 1.04244995117187500e+00,
- 1.04483032226562500e+00, 1.04721069335937500e+00, 1.04959106445312500e+00,
- 1.05194091796875000e+00, 1.05429077148437500e+00, 1.05662536621093750e+00,
- 1.05895996093750000e+00, 1.06127929687500000e+00, 1.06358337402343750e+00,
- 1.06587219238281250e+00, 1.06816101074218750e+00, 1.07044982910156250e+00,
- 1.07270812988281250e+00, 1.07496643066406250e+00, 1.07722473144531250e+00,
- 1.07945251464843750e+00, 1.08168029785156250e+00, 1.08390808105468750e+00,
- 1.08612060546875000e+00, 1.08831787109375000e+00, 1.09051513671875000e+00,
- 1.09269714355468750e+00, 1.09487915039062500e+00, 1.09704589843750000e+00,
- 1.09921264648437500e+00, 1.10136413574218750e+00, 1.10350036621093750e+00,
- 1.10563659667968750e+00, 1.10775756835937500e+00, 1.10987854003906250e+00,
- 1.11198425292968750e+00, 1.11408996582031250e+00, 1.11618041992187500e+00,
- 1.11827087402343750e+00, 1.12034606933593750e+00, 1.12242126464843750e+00,
- 1.12448120117187500e+00, 1.12654113769531250e+00, 1.12858581542968750e+00,
- 1.13063049316406250e+00, 1.13265991210937500e+00, 1.13468933105468750e+00,
- 1.13670349121093750e+00, 1.13871765136718750e+00, 1.14073181152343750e+00,
- 1.14273071289062500e+00, 1.14471435546875000e+00, 1.14669799804687500e+00,
- 1.14868164062500000e+00, 1.15065002441406250e+00, 1.15260314941406250e+00,
- 1.15457153320312500e+00, 1.15650939941406250e+00, 1.15846252441406250e+00,
- 1.16040039062500000e+00, 1.16232299804687500e+00, 1.16424560546875000e+00,
- 1.16616821289062500e+00, 1.16807556152343750e+00, 1.16998291015625000e+00,
- 1.17189025878906250e+00, 1.17378234863281250e+00, 1.17567443847656250e+00,
- 1.17755126953125000e+00, 1.17942810058593750e+00, 1.18128967285156250e+00,
- 1.18315124511718750e+00, 1.18501281738281250e+00, 1.18685913085937500e+00,
- 1.18870544433593750e+00, 1.19055175781250000e+00, 1.19238281250000000e+00,
- 1.19421386718750000e+00, 1.19602966308593750e+00, 1.19786071777343750e+00,
- 1.19966125488281250e+00, 1.20147705078125000e+00, 1.20327758789062500e+00,
- 1.20507812500000000e+00, 1.20686340332031250e+00, 1.20864868164062500e+00,
- 1.21043395996093750e+00, 1.21220397949218750e+00, 1.21397399902343750e+00,
- 1.21572875976562500e+00, 1.21749877929687500e+00, 1.21925354003906250e+00,
- 1.22099304199218750e+00, 1.22274780273437500e+00, 1.22448730468750000e+00,
- 1.22621154785156250e+00, 1.22795104980468750e+00, 1.22967529296875000e+00,
- 1.23138427734375000e+00, 1.23310852050781250e+00, 1.23481750488281250e+00,
- 1.23652648925781250e+00, 1.23822021484375000e+00, 1.23991394042968750e+00,
- 1.24160766601562500e+00, 1.24330139160156250e+00, 1.24497985839843750e+00,
- 1.24665832519531250e+00, 1.24833679199218750e+00, 1.25000000000000000e+00,
- 1.25166320800781250e+00, 1.25332641601562500e+00, 1.25497436523437500e+00,
- 1.25663757324218750e+00, 1.25828552246093750e+00, 1.25991821289062500e+00,
- 1.26319885253906250e+00, 1.26644897460937500e+00, 1.26968383789062500e+00,
- 1.27290344238281250e+00, 1.27612304687500000e+00, 1.27931213378906250e+00,
- 1.28248596191406250e+00, 1.28564453125000000e+00, 1.28878784179687500e+00,
- 1.29191589355468750e+00, 1.29502868652343750e+00, 1.29812622070312500e+00,
- 1.30120849609375000e+00, 1.30427551269531250e+00, 1.30732727050781250e+00,
- 1.31036376953125000e+00, 1.31340026855468750e+00, 1.31640625000000000e+00,
- 1.31941223144531250e+00, 1.32238769531250000e+00, 1.32536315917968750e+00,
- 1.32832336425781250e+00, 1.33126831054687500e+00, 1.33419799804687500e+00,
- 1.33712768554687500e+00, 1.34002685546875000e+00, 1.34292602539062500e+00,
- 1.34580993652343750e+00, 1.34867858886718750e+00, 1.35153198242187500e+00,
- 1.35437011718750000e+00, 1.35720825195312500e+00, 1.36003112792968750e+00,
- 1.36283874511718750e+00, 1.36564636230468750e+00, 1.36842346191406250e+00,
- 1.37120056152343750e+00, 1.37396240234375000e+00, 1.37672424316406250e+00,
- 1.37945556640625000e+00, 1.38218688964843750e+00, 1.38491821289062500e+00,
- 1.38761901855468750e+00, 1.39031982421875000e+00, 1.39302062988281250e+00,
- 1.39569091796875000e+00, 1.39836120605468750e+00, 1.40101623535156250e+00,
- 1.40367126464843750e+00, 1.40631103515625000e+00, 1.40893554687500000e+00,
- 1.41156005859375000e+00, 1.41416931152343750e+00, 1.41676330566406250e+00,
- 1.41935729980468750e+00, 1.42193603515625000e+00, 1.42449951171875000e+00,
- 1.42706298828125000e+00, 1.42962646484375000e+00, 1.43215942382812500e+00,
- 1.43469238281250000e+00, 1.43722534179687500e+00, 1.43974304199218750e+00,
- 1.44224548339843750e+00, 1.44474792480468750e+00, 1.44723510742187500e+00,
- 1.44972229003906250e+00, 1.45219421386718750e+00, 1.45466613769531250e+00,
- 1.45712280273437500e+00, 1.45956420898437500e+00, 1.46200561523437500e+00,
- 1.46444702148437500e+00, 1.46687316894531250e+00, 1.46928405761718750e+00,
- 1.47169494628906250e+00, 1.47409057617187500e+00, 1.47648620605468750e+00,
- 1.47886657714843750e+00, 1.48124694824218750e+00, 1.48361206054687500e+00,
- 1.48597717285156250e+00, 1.48834228515625000e+00, 1.49067687988281250e+00,
- 1.49302673339843750e+00, 1.49536132812500000e+00, 1.49768066406250000e+00,
- 1.50000000000000000e+00, 1.50230407714843750e+00, 1.50460815429687500e+00,
- 1.50691223144531250e+00, 1.50920104980468750e+00, 1.51148986816406250e+00,
- 1.51376342773437500e+00, 1.51603698730468750e+00, 1.51829528808593750e+00,
- 1.52055358886718750e+00, 1.52279663085937500e+00, 1.52503967285156250e+00,
- 1.52728271484375000e+00, 1.52951049804687500e+00, 1.53173828125000000e+00,
- 1.53395080566406250e+00, 1.53616333007812500e+00, 1.53836059570312500e+00,
- 1.54055786132812500e+00, 1.54275512695312500e+00, 1.54493713378906250e+00,
- 1.54711914062500000e+00, 1.54928588867187500e+00, 1.55145263671875000e+00,
- 1.55361938476562500e+00, 1.55577087402343750e+00, 1.55792236328125000e+00,
- 1.56005859375000000e+00, 1.56219482421875000e+00, 1.56433105468750000e+00,
- 1.56645202636718750e+00, 1.56857299804687500e+00, 1.57069396972656250e+00,
- 1.57279968261718750e+00, 1.57490539550781250e+00, 1.57699584960937500e+00,
- 1.57908630371093750e+00, 1.58117675781250000e+00, 1.58325195312500000e+00,
- 1.58532714843750000e+00, 1.58740234375000000e+00, 1.59152221679687500e+00,
- 1.59562683105468750e+00, 1.59970092773437500e+00, 1.60375976562500000e+00,
- 1.60780334472656250e+00, 1.61183166503906250e+00, 1.61582946777343750e+00,
- 1.61981201171875000e+00, 1.62376403808593750e+00, 1.62770080566406250e+00,
- 1.63162231445312500e+00, 1.63552856445312500e+00, 1.63941955566406250e+00,
- 1.64328002929687500e+00, 1.64714050292968750e+00, 1.65097045898437500e+00,
- 1.65476989746093750e+00, 1.65856933593750000e+00, 1.66235351562500000e+00,
- 1.66610717773437500e+00, 1.66986083984375000e+00, 1.67358398437500000e+00,
- 1.67729187011718750e+00, 1.68098449707031250e+00, 1.68466186523437500e+00,
- 1.68832397460937500e+00, 1.69197082519531250e+00, 1.69560241699218750e+00,
- 1.69921875000000000e+00, 1.70281982421875000e+00, 1.70640563964843750e+00,
- 1.70997619628906250e+00, 1.71353149414062500e+00, 1.71707153320312500e+00,
- 1.72059631347656250e+00, 1.72410583496093750e+00, 1.72760009765625000e+00,
- 1.73109436035156250e+00, 1.73455810546875000e+00, 1.73800659179687500e+00,
- 1.74145507812500000e+00, 1.74488830566406250e+00, 1.74829101562500000e+00,
- 1.75169372558593750e+00, 1.75508117675781250e+00, 1.75846862792968750e+00,
- 1.76182556152343750e+00, 1.76516723632812500e+00, 1.76850891113281250e+00,
- 1.77183532714843750e+00, 1.77514648437500000e+00, 1.77844238281250000e+00,
- 1.78173828125000000e+00, 1.78500366210937500e+00, 1.78826904296875000e+00,
- 1.79151916503906250e+00, 1.79476928710937500e+00, 1.79798889160156250e+00,
- 1.80120849609375000e+00, 1.80441284179687500e+00, 1.80760192871093750e+00,
- 1.81079101562500000e+00, 1.81396484375000000e+00, 1.81712341308593750e+00,
- 1.82026672363281250e+00, 1.82341003417968750e+00, 1.82653808593750000e+00,
- 1.82965087890625000e+00, 1.83276367187500000e+00, 1.83586120605468750e+00,
- 1.83894348144531250e+00, 1.84201049804687500e+00, 1.84507751464843750e+00,
- 1.84812927246093750e+00, 1.85118103027343750e+00, 1.85421752929687500e+00,
- 1.85723876953125000e+00, 1.86026000976562500e+00, 1.86326599121093750e+00,
- 1.86625671386718750e+00, 1.86924743652343750e+00, 1.87222290039062500e+00,
- 1.87518310546875000e+00, 1.87814331054687500e+00, 1.88108825683593750e+00,
- 1.88403320312500000e+00, 1.88696289062500000e+00, 1.88987731933593750e+00,
- 1.89279174804687500e+00, 1.89569091796875000e+00, 1.89859008789062500e+00,
- 1.90147399902343750e+00, 1.90435791015625000e+00, 1.90722656250000000e+00,
- 1.91007995605468750e+00, 1.91293334960937500e+00, 1.91577148437500000e+00,
- 1.91860961914062500e+00, 1.92143249511718750e+00, 1.92425537109375000e+00,
- 1.92706298828125000e+00, 1.92985534667968750e+00, 1.93264770507812500e+00,
- 1.93544006347656250e+00, 1.93821716308593750e+00, 1.94097900390625000e+00,
- 1.94374084472656250e+00, 1.94650268554687500e+00, 1.94924926757812500e+00,
- 1.95198059082031250e+00, 1.95471191406250000e+00, 1.95742797851562500e+00,
- 1.96014404296875000e+00, 1.96286010742187500e+00, 1.96556091308593750e+00,
- 1.96824645996093750e+00, 1.97093200683593750e+00, 1.97361755371093750e+00,
- 1.97628784179687500e+00, 1.97894287109375000e+00, 1.98159790039062500e+00,
- 1.98425292968750000e+00, 1.98689270019531250e+00, 1.98953247070312500e+00,
- 1.99215698242187500e+00, 1.99478149414062500e+00, 1.99739074707031250e+00,
- 2.00000000000000000e+00,
+	1.00000000000000000e+00, 1.00259399414062500e+00,
+	1.00518798828125000e+00, 1.00775146484375000e+00,
+	1.01031494140625000e+00, 1.01284790039062500e+00,
+	1.01538085937500000e+00, 1.01791381835937500e+00,
+	1.02041625976562500e+00, 1.02290344238281250e+00,
+	1.02539062500000000e+00, 1.02786254882812500e+00,
+	1.03031921386718750e+00, 1.03277587890625000e+00,
+	1.03520202636718750e+00, 1.03762817382812500e+00,
+	1.04003906250000000e+00, 1.04244995117187500e+00,
+	1.04483032226562500e+00, 1.04721069335937500e+00,
+	1.04959106445312500e+00, 1.05194091796875000e+00,
+	1.05429077148437500e+00, 1.05662536621093750e+00,
+	1.05895996093750000e+00, 1.06127929687500000e+00,
+	1.06358337402343750e+00, 1.06587219238281250e+00,
+	1.06816101074218750e+00, 1.07044982910156250e+00,
+	1.07270812988281250e+00, 1.07496643066406250e+00,
+	1.07722473144531250e+00, 1.07945251464843750e+00,
+	1.08168029785156250e+00, 1.08390808105468750e+00,
+	1.08612060546875000e+00, 1.08831787109375000e+00,
+	1.09051513671875000e+00, 1.09269714355468750e+00,
+	1.09487915039062500e+00, 1.09704589843750000e+00,
+	1.09921264648437500e+00, 1.10136413574218750e+00,
+	1.10350036621093750e+00, 1.10563659667968750e+00,
+	1.10775756835937500e+00, 1.10987854003906250e+00,
+	1.11198425292968750e+00, 1.11408996582031250e+00,
+	1.11618041992187500e+00, 1.11827087402343750e+00,
+	1.12034606933593750e+00, 1.12242126464843750e+00,
+	1.12448120117187500e+00, 1.12654113769531250e+00,
+	1.12858581542968750e+00, 1.13063049316406250e+00,
+	1.13265991210937500e+00, 1.13468933105468750e+00,
+	1.13670349121093750e+00, 1.13871765136718750e+00,
+	1.14073181152343750e+00, 1.14273071289062500e+00,
+	1.14471435546875000e+00, 1.14669799804687500e+00,
+	1.14868164062500000e+00, 1.15065002441406250e+00,
+	1.15260314941406250e+00, 1.15457153320312500e+00,
+	1.15650939941406250e+00, 1.15846252441406250e+00,
+	1.16040039062500000e+00, 1.16232299804687500e+00,
+	1.16424560546875000e+00, 1.16616821289062500e+00,
+	1.16807556152343750e+00, 1.16998291015625000e+00,
+	1.17189025878906250e+00, 1.17378234863281250e+00,
+	1.17567443847656250e+00, 1.17755126953125000e+00,
+	1.17942810058593750e+00, 1.18128967285156250e+00,
+	1.18315124511718750e+00, 1.18501281738281250e+00,
+	1.18685913085937500e+00, 1.18870544433593750e+00,
+	1.19055175781250000e+00, 1.19238281250000000e+00,
+	1.19421386718750000e+00, 1.19602966308593750e+00,
+	1.19786071777343750e+00, 1.19966125488281250e+00,
+	1.20147705078125000e+00, 1.20327758789062500e+00,
+	1.20507812500000000e+00, 1.20686340332031250e+00,
+	1.20864868164062500e+00, 1.21043395996093750e+00,
+	1.21220397949218750e+00, 1.21397399902343750e+00,
+	1.21572875976562500e+00, 1.21749877929687500e+00,
+	1.21925354003906250e+00, 1.22099304199218750e+00,
+	1.22274780273437500e+00, 1.22448730468750000e+00,
+	1.22621154785156250e+00, 1.22795104980468750e+00,
+	1.22967529296875000e+00, 1.23138427734375000e+00,
+	1.23310852050781250e+00, 1.23481750488281250e+00,
+	1.23652648925781250e+00, 1.23822021484375000e+00,
+	1.23991394042968750e+00, 1.24160766601562500e+00,
+	1.24330139160156250e+00, 1.24497985839843750e+00,
+	1.24665832519531250e+00, 1.24833679199218750e+00,
+	1.25000000000000000e+00, 1.25166320800781250e+00,
+	1.25332641601562500e+00, 1.25497436523437500e+00,
+	1.25663757324218750e+00, 1.25828552246093750e+00,
+	1.25991821289062500e+00, 1.26319885253906250e+00,
+	1.26644897460937500e+00, 1.26968383789062500e+00,
+	1.27290344238281250e+00, 1.27612304687500000e+00,
+	1.27931213378906250e+00, 1.28248596191406250e+00,
+	1.28564453125000000e+00, 1.28878784179687500e+00,
+	1.29191589355468750e+00, 1.29502868652343750e+00,
+	1.29812622070312500e+00, 1.30120849609375000e+00,
+	1.30427551269531250e+00, 1.30732727050781250e+00,
+	1.31036376953125000e+00, 1.31340026855468750e+00,
+	1.31640625000000000e+00, 1.31941223144531250e+00,
+	1.32238769531250000e+00, 1.32536315917968750e+00,
+	1.32832336425781250e+00, 1.33126831054687500e+00,
+	1.33419799804687500e+00, 1.33712768554687500e+00,
+	1.34002685546875000e+00, 1.34292602539062500e+00,
+	1.34580993652343750e+00, 1.34867858886718750e+00,
+	1.35153198242187500e+00, 1.35437011718750000e+00,
+	1.35720825195312500e+00, 1.36003112792968750e+00,
+	1.36283874511718750e+00, 1.36564636230468750e+00,
+	1.36842346191406250e+00, 1.37120056152343750e+00,
+	1.37396240234375000e+00, 1.37672424316406250e+00,
+	1.37945556640625000e+00, 1.38218688964843750e+00,
+	1.38491821289062500e+00, 1.38761901855468750e+00,
+	1.39031982421875000e+00, 1.39302062988281250e+00,
+	1.39569091796875000e+00, 1.39836120605468750e+00,
+	1.40101623535156250e+00, 1.40367126464843750e+00,
+	1.40631103515625000e+00, 1.40893554687500000e+00,
+	1.41156005859375000e+00, 1.41416931152343750e+00,
+	1.41676330566406250e+00, 1.41935729980468750e+00,
+	1.42193603515625000e+00, 1.42449951171875000e+00,
+	1.42706298828125000e+00, 1.42962646484375000e+00,
+	1.43215942382812500e+00, 1.43469238281250000e+00,
+	1.43722534179687500e+00, 1.43974304199218750e+00,
+	1.44224548339843750e+00, 1.44474792480468750e+00,
+	1.44723510742187500e+00, 1.44972229003906250e+00,
+	1.45219421386718750e+00, 1.45466613769531250e+00,
+	1.45712280273437500e+00, 1.45956420898437500e+00,
+	1.46200561523437500e+00, 1.46444702148437500e+00,
+	1.46687316894531250e+00, 1.46928405761718750e+00,
+	1.47169494628906250e+00, 1.47409057617187500e+00,
+	1.47648620605468750e+00, 1.47886657714843750e+00,
+	1.48124694824218750e+00, 1.48361206054687500e+00,
+	1.48597717285156250e+00, 1.48834228515625000e+00,
+	1.49067687988281250e+00, 1.49302673339843750e+00,
+	1.49536132812500000e+00, 1.49768066406250000e+00,
+	1.50000000000000000e+00, 1.50230407714843750e+00,
+	1.50460815429687500e+00, 1.50691223144531250e+00,
+	1.50920104980468750e+00, 1.51148986816406250e+00,
+	1.51376342773437500e+00, 1.51603698730468750e+00,
+	1.51829528808593750e+00, 1.52055358886718750e+00,
+	1.52279663085937500e+00, 1.52503967285156250e+00,
+	1.52728271484375000e+00, 1.52951049804687500e+00,
+	1.53173828125000000e+00, 1.53395080566406250e+00,
+	1.53616333007812500e+00, 1.53836059570312500e+00,
+	1.54055786132812500e+00, 1.54275512695312500e+00,
+	1.54493713378906250e+00, 1.54711914062500000e+00,
+	1.54928588867187500e+00, 1.55145263671875000e+00,
+	1.55361938476562500e+00, 1.55577087402343750e+00,
+	1.55792236328125000e+00, 1.56005859375000000e+00,
+	1.56219482421875000e+00, 1.56433105468750000e+00,
+	1.56645202636718750e+00, 1.56857299804687500e+00,
+	1.57069396972656250e+00, 1.57279968261718750e+00,
+	1.57490539550781250e+00, 1.57699584960937500e+00,
+	1.57908630371093750e+00, 1.58117675781250000e+00,
+	1.58325195312500000e+00, 1.58532714843750000e+00,
+	1.58740234375000000e+00, 1.59152221679687500e+00,
+	1.59562683105468750e+00, 1.59970092773437500e+00,
+	1.60375976562500000e+00, 1.60780334472656250e+00,
+	1.61183166503906250e+00, 1.61582946777343750e+00,
+	1.61981201171875000e+00, 1.62376403808593750e+00,
+	1.62770080566406250e+00, 1.63162231445312500e+00,
+	1.63552856445312500e+00, 1.63941955566406250e+00,
+	1.64328002929687500e+00, 1.64714050292968750e+00,
+	1.65097045898437500e+00, 1.65476989746093750e+00,
+	1.65856933593750000e+00, 1.66235351562500000e+00,
+	1.66610717773437500e+00, 1.66986083984375000e+00,
+	1.67358398437500000e+00, 1.67729187011718750e+00,
+	1.68098449707031250e+00, 1.68466186523437500e+00,
+	1.68832397460937500e+00, 1.69197082519531250e+00,
+	1.69560241699218750e+00, 1.69921875000000000e+00,
+	1.70281982421875000e+00, 1.70640563964843750e+00,
+	1.70997619628906250e+00, 1.71353149414062500e+00,
+	1.71707153320312500e+00, 1.72059631347656250e+00,
+	1.72410583496093750e+00, 1.72760009765625000e+00,
+	1.73109436035156250e+00, 1.73455810546875000e+00,
+	1.73800659179687500e+00, 1.74145507812500000e+00,
+	1.74488830566406250e+00, 1.74829101562500000e+00,
+	1.75169372558593750e+00, 1.75508117675781250e+00,
+	1.75846862792968750e+00, 1.76182556152343750e+00,
+	1.76516723632812500e+00, 1.76850891113281250e+00,
+	1.77183532714843750e+00, 1.77514648437500000e+00,
+	1.77844238281250000e+00, 1.78173828125000000e+00,
+	1.78500366210937500e+00, 1.78826904296875000e+00,
+	1.79151916503906250e+00, 1.79476928710937500e+00,
+	1.79798889160156250e+00, 1.80120849609375000e+00,
+	1.80441284179687500e+00, 1.80760192871093750e+00,
+	1.81079101562500000e+00, 1.81396484375000000e+00,
+	1.81712341308593750e+00, 1.82026672363281250e+00,
+	1.82341003417968750e+00, 1.82653808593750000e+00,
+	1.82965087890625000e+00, 1.83276367187500000e+00,
+	1.83586120605468750e+00, 1.83894348144531250e+00,
+	1.84201049804687500e+00, 1.84507751464843750e+00,
+	1.84812927246093750e+00, 1.85118103027343750e+00,
+	1.85421752929687500e+00, 1.85723876953125000e+00,
+	1.86026000976562500e+00, 1.86326599121093750e+00,
+	1.86625671386718750e+00, 1.86924743652343750e+00,
+	1.87222290039062500e+00, 1.87518310546875000e+00,
+	1.87814331054687500e+00, 1.88108825683593750e+00,
+	1.88403320312500000e+00, 1.88696289062500000e+00,
+	1.88987731933593750e+00, 1.89279174804687500e+00,
+	1.89569091796875000e+00, 1.89859008789062500e+00,
+	1.90147399902343750e+00, 1.90435791015625000e+00,
+	1.90722656250000000e+00, 1.91007995605468750e+00,
+	1.91293334960937500e+00, 1.91577148437500000e+00,
+	1.91860961914062500e+00, 1.92143249511718750e+00,
+	1.92425537109375000e+00, 1.92706298828125000e+00,
+	1.92985534667968750e+00, 1.93264770507812500e+00,
+	1.93544006347656250e+00, 1.93821716308593750e+00,
+	1.94097900390625000e+00, 1.94374084472656250e+00,
+	1.94650268554687500e+00, 1.94924926757812500e+00,
+	1.95198059082031250e+00, 1.95471191406250000e+00,
+	1.95742797851562500e+00, 1.96014404296875000e+00,
+	1.96286010742187500e+00, 1.96556091308593750e+00,
+	1.96824645996093750e+00, 1.97093200683593750e+00,
+	1.97361755371093750e+00, 1.97628784179687500e+00,
+	1.97894287109375000e+00, 1.98159790039062500e+00,
+	1.98425292968750000e+00, 1.98689270019531250e+00,
+	1.98953247070312500e+00, 1.99215698242187500e+00,
+	1.99478149414062500e+00, 1.99739074707031250e+00,
+	2.00000000000000000e+00,
 };
 
 /*
@@ -197,65 +261,67 @@
  * |(1+x)^(1/3) - 1 - p(x)| < 2^-63  for |x| < 0.003914
  */
 static const double C[] = {
-	 3.33333333333333340735623180707664400321413178600e-0001,
+	3.33333333333333340735623180707664400321413178600e-0001,
 	-1.11111111111111111992797989129069515334791432304e-0001,
-	 6.17283950578506695710302115234720605072083379082e-0002,
+	6.17283950578506695710302115234720605072083379082e-0002,
 	-4.11522633731005164138964638666647311514892319010e-0002,
-	 3.01788343105268728151735586597807324859173704847e-0002,
+	3.01788343105268728151735586597807324859173704847e-0002,
 	-2.34723340038386971009665073968507263074215090751e-0002,
 	18014398509481984.0
 };
 
-#define p1			C[0]
-#define p2			C[1]
-#define p3			C[2]
-#define p4			C[3]
-#define p5			C[4]
-#define p6			C[5]
-#define two54		C[6]
+#define	p1		C[0]
+#define	p2		C[1]
+#define	p3		C[2]
+#define	p4		C[3]
+#define	p5		C[4]
+#define	p6		C[5]
+#define	two54		C[6]
 
-/* INDENT ON */
 
 #pragma weak cbrt = __cbrt
 
-double __cbrt(double x)
+double
+__cbrt(double x)
 {
 	union {
-		unsigned int	i[2];
-		double			d;
+		unsigned int i[2];
+		double d;
 	} xx, yy;
-	double			t, u, w;
-	unsigned int	hx, sx, ex, j, offset;
+
+	double t, u, w;
+	unsigned int hx, sx, ex, j, offset;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 	sx = xx.i[HIWORD] & 0x80000000;
 
 	/* handle special cases */
-	if (hx >= 0x7ff00000) /* x is inf or nan */
+	if (hx >= 0x7ff00000)		/* x is inf or nan */
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
-		return hx >= 0x7ff80000 ? x : x + x;
-		/* assumes sparc-like QNaN */
+		return (hx >= 0x7ff80000 ? x : x + x);
+
+	/* assumes sparc-like QNaN */
 #else
-		return x + x;
+		return (x + x);
 #endif
 
-	if (hx < 0x00100000) { /* x is subnormal or zero */
+	if (hx < 0x00100000) {		/* x is subnormal or zero */
 		if ((hx | xx.i[LOWORD]) == 0)
-			return x;
+			return (x);
 
 		/* scale x to normal range */
 		xx.d = x * two54;
 		hx = xx.i[HIWORD] & ~0x80000000;
 		offset = 0x29800000;
-	}
-	else
+	} else {
 		offset = 0x2aa00000;
+	}
 
 	ex = hx & 0x7ff00000;
 	j = (ex >> 2) + (ex >> 4) + (ex >> 6);
 	j = j + (j >> 6);
-	j = 0x7ff00000 & (j + 0x2aa00); /* j is ex/3 */
+	j = 0x7ff00000 & (j + 0x2aa00);	/* j is ex/3 */
 	hx -= (j + j + j);
 	xx.i[HIWORD] = 0x3ff00000 + hx;
 
@@ -267,6 +333,6 @@
 	yy.i[LOWORD] = 0;
 
 	w = t * t;
-	return yy.d * (u + u * (t * (p1 + t * p2 + w * p3) +
-		(w * w) * (p4 + t * p5 + w * p6)));
+	return (yy.d * (u + u * (t * (p1 + t * p2 + w * p3) + (w * w) *
+	    (p4 + t * p5 + w * p6))));
 }
--- old/usr/src/lib/libm/common/C/ceil.c	2019-06-06 20:37:42.077844445 +0000
+++ new/usr/src/lib/libm/common/C/ceil.c	2019-06-06 20:37:42.098746762 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,29 +39,31 @@
 
 #include "libm.h"
 
-static const double
-	zero = 0.0,
-	one = 1.0,
-	two52 = 4503599627370496.0;
+static const double zero = 0.0, one = 1.0, two52 = 4503599627370496.0;
 
 double
-ceil(double x) {
-	double	t, w;
-	int	hx, lx, ix;
+ceil(double x)
+{
+	double t, w;
+	int hx, lx, ix;
 
 	hx = ((int *)&x)[HIWORD];
 	lx = ((int *)&x)[LOWORD];
 	ix = hx & ~0x80000000;
+
 	if (ix >= 0x43300000)	/* return x if |x| >= 2^52, or x is NaN */
 		return (x * one);
-	t = (hx >= 0)? two52 : -two52;
+
+	t = (hx >= 0) ? two52 : -two52;
 	w = x + t;
 	t = w - t;
+
 	if (ix < 0x3ff00000) {
 		if ((ix | lx) == 0)
 			return (x);
 		else
-			return ((hx < 0)? -zero : one);
+			return ((hx < 0) ? -zero : one);
 	}
-	return ((t >= x)? t : t + one);
+
+	return ((t >= x) ? t : t + one);
 }
--- old/usr/src/lib/libm/common/C/copysign.c	2019-06-06 20:37:42.593945718 +0000
+++ new/usr/src/lib/libm/common/C/copysign.c	2019-06-06 20:37:42.611383521 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,10 +33,11 @@
 #include "libm.h"
 
 double
-copysign(double x, double y) {
+copysign(double x, double y)
+{
 	int hx, hy;
 
-	hx = ((int *) &x)[HIWORD];
-	hy = ((int *) &y)[HIWORD];
-	return (hx ^ hy) >= 0 ?  (x) : (-x);
+	hx = ((int *)&x)[HIWORD];
+	hy = ((int *)&y)[HIWORD];
+	return ((hx ^ hy) >= 0 ? (x) : (-x));
 }
--- old/usr/src/lib/libm/common/C/cos.c	2019-06-06 20:37:43.091023879 +0000
+++ new/usr/src/lib/libm/common/C/cos.c	2019-06-06 20:37:43.110733745 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __cos = cos
 
-/* INDENT OFF */
+
 /*
  * cos(x)
  * Accurate Table look-up algorithm by K.C. Ng, May, 1995.
@@ -39,45 +41,49 @@
 #include "libm.h"
 
 static const double sc[] = {
-/* ONE	= */  1.0,
+/* ONE	= */
+	1.0,
 /* NONE	= */ -1.0,
+
 /*
  * |sin(x) - (x+pp1*x^3+pp2*x^5)| <= 2^-58.79 for |x| < 0.008
  */
-/* PP1	= */ -0.166666666666316558867252052378889521480627858683055567,
-/* PP2	= */   .008333315652997472323564894248466758248475374977974017927,
+/* PP1	= */-0.166666666666316558867252052378889521480627858683055567,
+/* PP2	= */.008333315652997472323564894248466758248475374977974017927,
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p4*x^9)|
  * |------------------------------ | <= 2^-57.63 for |x| < 0.1953125
  * |                 x             |
  */
-/* P1  	= */ -1.666666666666629669805215138920301589656e-0001,
-/* P2  	= */  8.333333332390951295683993455280336376663e-0003,
-/* P3  	= */ -1.984126237997976692791551778230098403960e-0004,
-/* P4  	= */  2.753403624854277237649987622848330351110e-0006,
+/* P1   = */ -1.666666666666629669805215138920301589656e-0001,
+/* P2   = */ 8.333333332390951295683993455280336376663e-0003,
+/* P3   = */ -1.984126237997976692791551778230098403960e-0004,
+/* P4   = */ 2.753403624854277237649987622848330351110e-0006,
+
 /*
  * |cos(x) - (1+qq1*x^2+qq2*x^4)| <= 2^-55.99 for |x| <= 0.008 (0x3f80624d)
  */
-/* QQ1	= */ -0.4999999999975492381842911981948418542742729,
-/* QQ2	= */  0.041666542904352059294545209158357640398771740,
-/* Q1  	= */ -0.5,
-/* Q2  	= */  4.166666666500350703680945520860748617445e-0002,
-/* Q3  	= */ -1.388888596436972210694266290577848696006e-0003,
-/* Q4  	= */  2.478563078858589473679519517892953492192e-0005,
-/* PIO2_H    = */  1.570796326794896557999,
-/* PIO2_L    = */  6.123233995736765886130e-17,
-/* PIO2_L0   = */  6.123233995727922165564e-17,
-/* PIO2_L1   = */  8.843720566135701120255e-29,
-/* PI3O2_H   = */  4.712388980384689673997,
-/* PI3O2_L   = */  1.836970198721029765839e-16,
-/* PI3O2_L0  = */  1.836970198720396133587e-16,
-/* PI3O2_L1  = */  6.336322524749201142226e-29,
-/* PI5O2_H   = */  7.853981633974482789995,
-/* PI5O2_L   = */  3.061616997868382943065e-16,
-/* PI5O2_L0  = */  3.061616997861941598865e-16,
-/* PI5O2_L1  = */  6.441344200433640781982e-28,
+/* QQ1	= */-0.4999999999975492381842911981948418542742729,
+/* QQ2	= */0.041666542904352059294545209158357640398771740,
+/* Q1   = */ -0.5,
+/* Q2   = */ 4.166666666500350703680945520860748617445e-0002,
+/* Q3   = */ -1.388888596436972210694266290577848696006e-0003,
+/* Q4   = */ 2.478563078858589473679519517892953492192e-0005,
+/* PIO2_H    = */ 1.570796326794896557999,
+/* PIO2_L    = */ 6.123233995736765886130e-17,
+/* PIO2_L0   = */ 6.123233995727922165564e-17,
+/* PIO2_L1   = */ 8.843720566135701120255e-29,
+/* PI3O2_H   = */ 4.712388980384689673997,
+/* PI3O2_L   = */ 1.836970198721029765839e-16,
+/* PI3O2_L0  = */ 1.836970198720396133587e-16,
+/* PI3O2_L1  = */ 6.336322524749201142226e-29,
+/* PI5O2_H   = */ 7.853981633974482789995,
+/* PI5O2_L   = */ 3.061616997868382943065e-16,
+/* PI5O2_L0  = */ 3.061616997861941598865e-16,
+/* PI5O2_L1  = */ 6.441344200433640781982e-28,
 };
-/* INDENT ON */
+
 
 #define	ONE		sc[0]
 #define	PP1		sc[2]
@@ -108,108 +114,131 @@
 extern const double _TBL_sincos[], _TBL_sincosx[];
 
 double
-cos(double x) {
-	double	z, y[2], w, s, v, p, q;
-	int	i, j, n, hx, ix, lx;
+cos(double x)
+{
+	double z, y[2], w, s, v, p, q;
+	int i, j, n, hx, ix, lx;
 
 	hx = ((int *)&x)[HIWORD];
 	lx = ((int *)&x)[LOWORD];
 	ix = hx & ~0x80000000;
 
-	if (ix <= 0x3fc50000) {	/* |x| < 10.5/64 = 0.164062500 */
+	if (ix <= 0x3fc50000) {		/* |x| < 10.5/64 = 0.164062500 */
 		if (ix < 0x3e400000) {	/* |x| < 2**-27 */
 			if ((int)x == 0)
 				return (ONE);
 		}
+
 		z = x * x;
+
 		if (ix < 0x3f800000)	/* |x| < 0.008 */
 			w = z * (QQ1 + z * QQ2);
 		else
 			w = z * ((Q1 + z * Q2) + (z * z) * (Q3 + z * Q4));
+
 		return (ONE + w);
 	}
 
 	/* for 0.164062500 < x < M, */
 	n = ix >> 20;
-	if (n < 0x402) {	/* x < 8 */
+
+	if (n < 0x402) {		/* x < 8 */
 		i = (((ix >> 12) & 0xff) | 0x100) >> (0x401 - n);
 		j = i - 10;
 		x = fabs(x);
 		v = x - _TBL_sincosx[j];
+
 		if (((j - 81) ^ (j - 101)) < 0) {
 			/* near pi/2, cos(pi/2-x)=sin(x) */
 			p = PIO2_H - x;
 			i = ix - 0x3ff921fb;
 			x = p + PIO2_L;
+
 			if ((i | ((lx - 0x54442D00) & 0xffffff00)) == 0) {
 				/* very close to pi/2 */
 				x = p + PIO2_L0;
 				return (x + PIO2_L1);
 			}
+
 			z = x * x;
+
 			if (((ix - 0x3ff92000) >> 12) == 0) {
 				/* |pi/2-x|<2**-8 */
 				w = PIO2_L + (z * x) * (PP1 + z * PP2);
 			} else {
-				w = PIO2_L + (z * x) * ((P1 + z * P2) +
-				    (z * z) * (P3 + z * P4));
+				w = PIO2_L + (z * x) * ((P1 + z * P2) + (z *
+				    z) * (P3 + z * P4));
 			}
+
 			return (p + w);
 		}
+
 		s = v * v;
+
 		if (((j - 282) ^ (j - 302)) < 0) {
 			/* near 3/2pi, cos(x-3/2pi)=sin(x) */
 			p = x - PI3O2_H;
 			i = ix - 0x4012D97C;
 			x = p - PI3O2_L;
+
 			if ((i | ((lx - 0x7f332100) & 0xffffff00)) == 0) {
 				/* very close to 3/2pi */
 				x = p - PI3O2_L0;
 				return (x - PI3O2_L1);
 			}
+
 			z = x * x;
+
 			if (((ix - 0x4012D800) >> 9) == 0) {
 				/* |x-3/2pi|<2**-8 */
 				w = (z * x) * (PP1 + z * PP2) - PI3O2_L;
 			} else {
-				w = (z * x) * ((P1 + z * P2) + (z * z)
-				    * (P3 + z * P4)) - PI3O2_L;
+				w = (z * x) * ((P1 + z * P2) + (z * z) * (P3 +
+				    z * P4)) - PI3O2_L;
 			}
+
 			return (p + w);
 		}
+
 		if (((j - 483) ^ (j - 503)) < 0) {
 			/* near 5pi/2, cos(5pi/2-x)=sin(x) */
 			p = PI5O2_H - x;
 			i = ix - 0x401F6A7A;
 			x = p + PI5O2_L;
+
 			if ((i | ((lx - 0x29553800) & 0xffffff00)) == 0) {
 				/* very close to pi/2 */
 				x = p + PI5O2_L0;
 				return (x + PI5O2_L1);
 			}
+
 			z = x * x;
+
 			if (((ix - 0x401F6A7A) >> 7) == 0) {
 				/* |pi/2-x|<2**-8 */
 				w = PI5O2_L + (z * x) * (PP1 + z * PP2);
 			} else {
-				w = PI5O2_L + (z * x) * ((P1 + z * P2) +
-				    (z * z) * (P3 + z * P4));
+				w = PI5O2_L + (z * x) * ((P1 + z * P2) + (z *
+				    z) * (P3 + z * P4));
 			}
+
 			return (p + w);
 		}
+
 		j <<= 1;
 		w = _TBL_sincos[j];
-		z = _TBL_sincos[j+1];
+		z = _TBL_sincos[j + 1];
 		p = v + (v * s) * (PP1 + s * PP2);
 		q = s * (QQ1 + s * QQ2);
 		return (z - (w * p - z * q));
 	}
 
-	if (ix >= 0x7ff00000)	/* cos(Inf or NaN) is NaN */
+	if (ix >= 0x7ff00000)		/* cos(Inf or NaN) is NaN */
 		return (x / x);
 
 	/* argument reduction needed */
 	n = __rem_pio2(x, y);
+
 	switch (n & 3) {
 	case 0:
 		return (__k_cos(y[0], y[1]));
--- old/usr/src/lib/libm/common/C/cosh.c	2019-06-06 20:37:43.604894986 +0000
+++ new/usr/src/lib/libm/common/C/cosh.c	2019-06-06 20:37:43.624072096 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __cosh = cosh
 
-/* INDENT OFF */
+
 /*
  * cosh(x)
  * Code originated from 4.3bsd.
@@ -52,28 +54,31 @@
  *	cosh(x) is |x| if x is +INF, -INF, or NaN.
  *	only cosh(0)=1 is exact for finite x.
  */
-/* INDENT ON */
 
 #include "libm.h"
 
-static const double
-	ln2 = 6.93147180559945286227e-01,
+static const double ln2 = 6.93147180559945286227e-01,
 	ln2hi = 6.93147180369123816490e-01,
 	ln2lo = 1.90821492927058770002e-10,
 	lnovft = 7.09782712893383973096e+02;
 
 double
-cosh(double x) {
+cosh(double x)
+{
 	double t, w;
 
 	w = fabs(x);
+
 	if (!finite(w))
 		return (w * w);
+
 	if (w < 0.3465) {
 		t = expm1(w);
 		w = 1.0 + t;
+
 		if (w != 1.0)
 			w = 1.0 + (t * t) / (w + w);
+
 		return (w);
 	} else if (w < 22.0) {
 		t = exp(w);
@@ -82,6 +87,7 @@
 		return (0.5 * exp(w));
 	} else {
 		w = (w - 1024 * ln2hi) - 1024 * ln2lo;
+
 		if (w >= ln2)
 			return (_SVID_libm_err(x, x, 5));
 		else
--- old/usr/src/lib/libm/common/C/erf.c	2019-06-06 20:37:44.123619195 +0000
+++ new/usr/src/lib/libm/common/C/erf.c	2019-06-06 20:37:44.142130707 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,7 +31,7 @@
 #pragma weak __erf = erf
 #pragma weak __erfc = erfc
 
-/* INDENT OFF */
+
 /*
  * double erf(double x)
  * double erfc(double x)
@@ -67,10 +68,10 @@
  *
  *      2. For |x| in [0.84375,1.25], let s = |x| - 1, and
  *         c = 0.84506291151 rounded to single (24 bits)
- *         	erf(x)  = sign(x) * (c  + P1(s)/Q1(s))
- *         	erfc(x) = (1-c)  - P1(s)/Q1(s) if x > 0
+ *              erf(x)  = sign(x) * (c  + P1(s)/Q1(s))
+ *              erfc(x) = (1-c)  - P1(s)/Q1(s) if x > 0
  *			  1+(c+P1(s)/Q1(s))    if x < 0
- *         	|P1/Q1 - (erf(|x|)-c)| <= 2**-59.06
+ *              |P1/Q1 - (erf(|x|)-c)| <= 2**-59.06
  *	   Remark: here we use the taylor series expansion at x=1.
  *		erf(1+s) = erf(1) + s*Poly(s)
  *			 = 0.845.. + P1(s)/Q1(s)
@@ -82,18 +83,18 @@
  *		Q1(s) = degree 6 poly in s
  *
  *      3. For x in [1.25,1/0.35(~2.857143)],
- *         	erfc(x) = (1/x)*exp(-x*x-0.5625+R1/S1)
- *         	erf(x)  = 1 - erfc(x)
+ *              erfc(x) = (1/x)*exp(-x*x-0.5625+R1/S1)
+ *              erf(x)  = 1 - erfc(x)
  *	   where
  *		R1(z) = degree 7 poly in z, (z=1/x^2)
  *		S1(z) = degree 8 poly in z
  *
  *      4. For x in [1/0.35,28]
- *         	erfc(x) = (1/x)*exp(-x*x-0.5625+R2/S2) if x > 0
+ *              erfc(x) = (1/x)*exp(-x*x-0.5625+R2/S2) if x > 0
  *			= 2.0 - (1/x)*exp(-x*x-0.5625+R2/S2) if -6<x<0
  *			= 2.0 - tiny		(if x <= -6)
- *         	erf(x)  = sign(x)*(1.0 - erfc(x)) if x < 6, else
- *         	erf(x)  = sign(x)*(1.0 - tiny)
+ *              erf(x)  = sign(x)*(1.0 - erfc(x)) if x < 6, else
+ *              erf(x)  = sign(x)*(1.0 - tiny)
  *	   where
  *		R2(z) = degree 6 poly in z, (z=1/x^2)
  *		S2(z) = degree 7 poly in z
@@ -110,236 +111,255 @@
  *		erfc(x) ~ ---------- * ( 1 + Poly(1/x^2) )
  *			  x*sqrt(pi)
  *	   We use rational approximation to approximate
- *      	g(s)=f(1/x^2) = log(erfc(x)*x) - x*x + 0.5625
+ *              g(s)=f(1/x^2) = log(erfc(x)*x) - x*x + 0.5625
  *	   Here is the error bound for R1/S1 and R2/S2
- *      	|R1/S1 - f(x)|  < 2**(-62.57)
- *      	|R2/S2 - f(x)|  < 2**(-61.52)
+ *              |R1/S1 - f(x)|  < 2**(-62.57)
+ *              |R2/S2 - f(x)|  < 2**(-61.52)
  *
  *      5. For inf > x >= 28
- *         	erf(x)  = sign(x) *(1 - tiny)  (raise inexact)
- *         	erfc(x) = tiny*tiny (raise underflow) if x > 0
+ *              erf(x)  = sign(x) *(1 - tiny)  (raise inexact)
+ *              erfc(x) = tiny*tiny (raise underflow) if x > 0
  *			= 2 - tiny if x<0
  *
  *      7. Special case:
- *         	erf(0)  = 0, erf(inf)  = 1, erf(-inf) = -1,
- *         	erfc(0) = 1, erfc(inf) = 0, erfc(-inf) = 2,
- *   	erfc/erf(NaN) is NaN
+ *              erf(0)  = 0, erf(inf)  = 1, erf(-inf) = -1,
+ *              erfc(0) = 1, erfc(inf) = 0, erfc(-inf) = 2,
+ *      erfc/erf(NaN) is NaN
  */
-/* INDENT ON */
 
 #include "libm_macros.h"
 #include <math.h>
 
 static const double xxx[] = {
-/* tiny */	1e-300,
-/* half */	5.00000000000000000000e-01,	/* 3FE00000, 00000000 */
-/* one */	1.00000000000000000000e+00,	/* 3FF00000, 00000000 */
-/* two */	2.00000000000000000000e+00,	/* 40000000, 00000000 */
-/* erx */	8.45062911510467529297e-01,	/* 3FEB0AC1, 60000000 */
+/* tiny */
+	1e-300,
+/* half */ 5.00000000000000000000e-01,	/* 3FE00000, 00000000 */
+/* one */ 1.00000000000000000000e+00,	/* 3FF00000, 00000000 */
+/* two */ 2.00000000000000000000e+00,	/* 40000000, 00000000 */
+/* erx */ 8.45062911510467529297e-01,	/* 3FEB0AC1, 60000000 */
+
 /*
  * Coefficients for approximation to  erf on [0,0.84375]
  */
-/* efx */	 1.28379167095512586316e-01,	/* 3FC06EBA, 8214DB69 */
-/* efx8 */	 1.02703333676410069053e+00,	/* 3FF06EBA, 8214DB69 */
-/* pp0 */	 1.28379167095512558561e-01,	/* 3FC06EBA, 8214DB68 */
-/* pp1 */	-3.25042107247001499370e-01,	/* BFD4CD7D, 691CB913 */
-/* pp2 */	-2.84817495755985104766e-02,	/* BF9D2A51, DBD7194F */
-/* pp3 */	-5.77027029648944159157e-03,	/* BF77A291, 236668E4 */
-/* pp4 */	-2.37630166566501626084e-05,	/* BEF8EAD6, 120016AC */
-/* qq1 */	 3.97917223959155352819e-01,	/* 3FD97779, CDDADC09 */
-/* qq2 */	 6.50222499887672944485e-02,	/* 3FB0A54C, 5536CEBA */
-/* qq3 */	 5.08130628187576562776e-03,	/* 3F74D022, C4D36B0F */
-/* qq4 */	 1.32494738004321644526e-04,	/* 3F215DC9, 221C1A10 */
-/* qq5 */	-3.96022827877536812320e-06,	/* BED09C43, 42A26120 */
+/* efx */ 1.28379167095512586316e-01,	/* 3FC06EBA, 8214DB69 */
+/* efx8 */ 1.02703333676410069053e+00,	/* 3FF06EBA, 8214DB69 */
+/* pp0 */ 1.28379167095512558561e-01,	/* 3FC06EBA, 8214DB68 */
+/* pp1 */ -3.25042107247001499370e-01,	/* BFD4CD7D, 691CB913 */
+/* pp2 */ -2.84817495755985104766e-02,	/* BF9D2A51, DBD7194F */
+/* pp3 */ -5.77027029648944159157e-03,	/* BF77A291, 236668E4 */
+/* pp4 */ -2.37630166566501626084e-05,	/* BEF8EAD6, 120016AC */
+/* qq1 */ 3.97917223959155352819e-01,	/* 3FD97779, CDDADC09 */
+/* qq2 */ 6.50222499887672944485e-02,	/* 3FB0A54C, 5536CEBA */
+/* qq3 */ 5.08130628187576562776e-03,	/* 3F74D022, C4D36B0F */
+/* qq4 */ 1.32494738004321644526e-04,	/* 3F215DC9, 221C1A10 */
+/* qq5 */ -3.96022827877536812320e-06,	/* BED09C43, 42A26120 */
+
 /*
  * Coefficients for approximation to  erf  in [0.84375,1.25]
  */
-/* pa0 */	-2.36211856075265944077e-03,	/* BF6359B8, BEF77538 */
-/* pa1 */	 4.14856118683748331666e-01,	/* 3FDA8D00, AD92B34D */
-/* pa2 */	-3.72207876035701323847e-01,	/* BFD7D240, FBB8C3F1 */
-/* pa3 */	 3.18346619901161753674e-01,	/* 3FD45FCA, 805120E4 */
-/* pa4 */	-1.10894694282396677476e-01,	/* BFBC6398, 3D3E28EC */
-/* pa5 */	 3.54783043256182359371e-02,	/* 3FA22A36, 599795EB */
-/* pa6 */	-2.16637559486879084300e-03,	/* BF61BF38, 0A96073F */
-/* qa1 */	 1.06420880400844228286e-01,	/* 3FBB3E66, 18EEE323 */
-/* qa2 */	 5.40397917702171048937e-01,	/* 3FE14AF0, 92EB6F33 */
-/* qa3 */	 7.18286544141962662868e-02,	/* 3FB2635C, D99FE9A7 */
-/* qa4 */	 1.26171219808761642112e-01,	/* 3FC02660, E763351F */
-/* qa5 */	 1.36370839120290507362e-02,	/* 3F8BEDC2, 6B51DD1C */
-/* qa6 */	 1.19844998467991074170e-02,	/* 3F888B54, 5735151D */
+/* pa0 */ -2.36211856075265944077e-03,	/* BF6359B8, BEF77538 */
+/* pa1 */ 4.14856118683748331666e-01,	/* 3FDA8D00, AD92B34D */
+/* pa2 */ -3.72207876035701323847e-01,	/* BFD7D240, FBB8C3F1 */
+/* pa3 */ 3.18346619901161753674e-01,	/* 3FD45FCA, 805120E4 */
+/* pa4 */ -1.10894694282396677476e-01,	/* BFBC6398, 3D3E28EC */
+/* pa5 */ 3.54783043256182359371e-02,	/* 3FA22A36, 599795EB */
+/* pa6 */ -2.16637559486879084300e-03,	/* BF61BF38, 0A96073F */
+/* qa1 */ 1.06420880400844228286e-01,	/* 3FBB3E66, 18EEE323 */
+/* qa2 */ 5.40397917702171048937e-01,	/* 3FE14AF0, 92EB6F33 */
+/* qa3 */ 7.18286544141962662868e-02,	/* 3FB2635C, D99FE9A7 */
+/* qa4 */ 1.26171219808761642112e-01,	/* 3FC02660, E763351F */
+/* qa5 */ 1.36370839120290507362e-02,	/* 3F8BEDC2, 6B51DD1C */
+/* qa6 */ 1.19844998467991074170e-02,	/* 3F888B54, 5735151D */
+
 /*
  * Coefficients for approximation to  erfc in [1.25,1/0.35]
  */
-/* ra0 */	-9.86494403484714822705e-03,	/* BF843412, 600D6435 */
-/* ra1 */	-6.93858572707181764372e-01,	/* BFE63416, E4BA7360 */
-/* ra2 */	-1.05586262253232909814e+01,	/* C0251E04, 41B0E726 */
-/* ra3 */	-6.23753324503260060396e+01,	/* C04F300A, E4CBA38D */
-/* ra4 */	-1.62396669462573470355e+02,	/* C0644CB1, 84282266 */
-/* ra5 */	-1.84605092906711035994e+02,	/* C067135C, EBCCABB2 */
-/* ra6 */	-8.12874355063065934246e+01,	/* C0545265, 57E4D2F2 */
-/* ra7 */	-9.81432934416914548592e+00,	/* C023A0EF, C69AC25C */
-/* sa1 */	 1.96512716674392571292e+01,	/* 4033A6B9, BD707687 */
-/* sa2 */	 1.37657754143519042600e+02,	/* 4061350C, 526AE721 */
-/* sa3 */	 4.34565877475229228821e+02,	/* 407B290D, D58A1A71 */
-/* sa4 */	 6.45387271733267880336e+02,	/* 40842B19, 21EC2868 */
-/* sa5 */	 4.29008140027567833386e+02,	/* 407AD021, 57700314 */
-/* sa6 */	 1.08635005541779435134e+02,	/* 405B28A3, EE48AE2C */
-/* sa7 */	 6.57024977031928170135e+00,	/* 401A47EF, 8E484A93 */
-/* sa8 */	-6.04244152148580987438e-02,	/* BFAEEFF2, EE749A62 */
+/* ra0 */ -9.86494403484714822705e-03,	/* BF843412, 600D6435 */
+/* ra1 */ -6.93858572707181764372e-01,	/* BFE63416, E4BA7360 */
+/* ra2 */ -1.05586262253232909814e+01,	/* C0251E04, 41B0E726 */
+/* ra3 */ -6.23753324503260060396e+01,	/* C04F300A, E4CBA38D */
+/* ra4 */ -1.62396669462573470355e+02,	/* C0644CB1, 84282266 */
+/* ra5 */ -1.84605092906711035994e+02,	/* C067135C, EBCCABB2 */
+/* ra6 */ -8.12874355063065934246e+01,	/* C0545265, 57E4D2F2 */
+/* ra7 */ -9.81432934416914548592e+00,	/* C023A0EF, C69AC25C */
+/* sa1 */ 1.96512716674392571292e+01,	/* 4033A6B9, BD707687 */
+/* sa2 */ 1.37657754143519042600e+02,	/* 4061350C, 526AE721 */
+/* sa3 */ 4.34565877475229228821e+02,	/* 407B290D, D58A1A71 */
+/* sa4 */ 6.45387271733267880336e+02,	/* 40842B19, 21EC2868 */
+/* sa5 */ 4.29008140027567833386e+02,	/* 407AD021, 57700314 */
+/* sa6 */ 1.08635005541779435134e+02,	/* 405B28A3, EE48AE2C */
+/* sa7 */ 6.57024977031928170135e+00,	/* 401A47EF, 8E484A93 */
+/* sa8 */ -6.04244152148580987438e-02,	/* BFAEEFF2, EE749A62 */
+
 /*
  * Coefficients for approximation to  erfc in [1/.35,28]
  */
-/* rb0 */	-9.86494292470009928597e-03,	/* BF843412, 39E86F4A */
-/* rb1 */	-7.99283237680523006574e-01,	/* BFE993BA, 70C285DE */
-/* rb2 */	-1.77579549177547519889e+01,	/* C031C209, 555F995A */
-/* rb3 */	-1.60636384855821916062e+02,	/* C064145D, 43C5ED98 */
-/* rb4 */	-6.37566443368389627722e+02,	/* C083EC88, 1375F228 */
-/* rb5 */	-1.02509513161107724954e+03,	/* C0900461, 6A2E5992 */
-/* rb6 */	-4.83519191608651397019e+02,	/* C07E384E, 9BDC383F */
-/* sb1 */	 3.03380607434824582924e+01,	/* 403E568B, 261D5190 */
-/* sb2 */	 3.25792512996573918826e+02,	/* 40745CAE, 221B9F0A */
-/* sb3 */	 1.53672958608443695994e+03,	/* 409802EB, 189D5118 */
-/* sb4 */	 3.19985821950859553908e+03,	/* 40A8FFB7, 688C246A */
-/* sb5 */	 2.55305040643316442583e+03,	/* 40A3F219, CEDF3BE6 */
-/* sb6 */	 4.74528541206955367215e+02,	/* 407DA874, E79FE763 */
-/* sb7 */	-2.24409524465858183362e+01	/* C03670E2, 42712D62 */
+/* rb0 */ -9.86494292470009928597e-03,	/* BF843412, 39E86F4A */
+/* rb1 */ -7.99283237680523006574e-01,	/* BFE993BA, 70C285DE */
+/* rb2 */ -1.77579549177547519889e+01,	/* C031C209, 555F995A */
+/* rb3 */ -1.60636384855821916062e+02,	/* C064145D, 43C5ED98 */
+/* rb4 */ -6.37566443368389627722e+02,	/* C083EC88, 1375F228 */
+/* rb5 */ -1.02509513161107724954e+03,	/* C0900461, 6A2E5992 */
+/* rb6 */ -4.83519191608651397019e+02,	/* C07E384E, 9BDC383F */
+/* sb1 */ 3.03380607434824582924e+01,	/* 403E568B, 261D5190 */
+/* sb2 */ 3.25792512996573918826e+02,	/* 40745CAE, 221B9F0A */
+/* sb3 */ 1.53672958608443695994e+03,	/* 409802EB, 189D5118 */
+/* sb4 */ 3.19985821950859553908e+03,	/* 40A8FFB7, 688C246A */
+/* sb5 */ 2.55305040643316442583e+03,	/* 40A3F219, CEDF3BE6 */
+/* sb6 */ 4.74528541206955367215e+02,	/* 407DA874, E79FE763 */
+/* sb7 */ -2.24409524465858183362e+01	/* C03670E2, 42712D62 */
 };
 
-#define	tiny	xxx[0]
-#define	half	xxx[1]
-#define	one	xxx[2]
-#define	two	xxx[3]
-#define	erx	xxx[4]
+#define	tiny		xxx[0]
+#define	half		xxx[1]
+#define	one		xxx[2]
+#define	two		xxx[3]
+#define	erx		xxx[4]
+
 /*
  * Coefficients for approximation to  erf on [0,0.84375]
  */
-#define	efx	xxx[5]
-#define	efx8	xxx[6]
-#define	pp0	xxx[7]
-#define	pp1	xxx[8]
-#define	pp2	xxx[9]
-#define	pp3	xxx[10]
-#define	pp4	xxx[11]
-#define	qq1	xxx[12]
-#define	qq2	xxx[13]
-#define	qq3	xxx[14]
-#define	qq4	xxx[15]
-#define	qq5	xxx[16]
+#define	efx		xxx[5]
+#define	efx8		xxx[6]
+#define	pp0		xxx[7]
+#define	pp1		xxx[8]
+#define	pp2		xxx[9]
+#define	pp3		xxx[10]
+#define	pp4		xxx[11]
+#define	qq1		xxx[12]
+#define	qq2		xxx[13]
+#define	qq3		xxx[14]
+#define	qq4		xxx[15]
+#define	qq5		xxx[16]
+
 /*
  * Coefficients for approximation to  erf  in [0.84375,1.25]
  */
-#define	pa0	xxx[17]
-#define	pa1	xxx[18]
-#define	pa2	xxx[19]
-#define	pa3	xxx[20]
-#define	pa4	xxx[21]
-#define	pa5	xxx[22]
-#define	pa6	xxx[23]
-#define	qa1	xxx[24]
-#define	qa2	xxx[25]
-#define	qa3	xxx[26]
-#define	qa4	xxx[27]
-#define	qa5	xxx[28]
-#define	qa6	xxx[29]
+#define	pa0		xxx[17]
+#define	pa1		xxx[18]
+#define	pa2		xxx[19]
+#define	pa3		xxx[20]
+#define	pa4		xxx[21]
+#define	pa5		xxx[22]
+#define	pa6		xxx[23]
+#define	qa1		xxx[24]
+#define	qa2		xxx[25]
+#define	qa3		xxx[26]
+#define	qa4		xxx[27]
+#define	qa5		xxx[28]
+#define	qa6		xxx[29]
+
 /*
  * Coefficients for approximation to  erfc in [1.25,1/0.35]
  */
-#define	ra0	xxx[30]
-#define	ra1	xxx[31]
-#define	ra2	xxx[32]
-#define	ra3	xxx[33]
-#define	ra4	xxx[34]
-#define	ra5	xxx[35]
-#define	ra6	xxx[36]
-#define	ra7	xxx[37]
-#define	sa1	xxx[38]
-#define	sa2	xxx[39]
-#define	sa3	xxx[40]
-#define	sa4	xxx[41]
-#define	sa5	xxx[42]
-#define	sa6	xxx[43]
-#define	sa7	xxx[44]
-#define	sa8	xxx[45]
+#define	ra0		xxx[30]
+#define	ra1		xxx[31]
+#define	ra2		xxx[32]
+#define	ra3		xxx[33]
+#define	ra4		xxx[34]
+#define	ra5		xxx[35]
+#define	ra6		xxx[36]
+#define	ra7		xxx[37]
+#define	sa1		xxx[38]
+#define	sa2		xxx[39]
+#define	sa3		xxx[40]
+#define	sa4		xxx[41]
+#define	sa5		xxx[42]
+#define	sa6		xxx[43]
+#define	sa7		xxx[44]
+#define	sa8		xxx[45]
+
 /*
  * Coefficients for approximation to  erfc in [1/.35,28]
  */
-#define	rb0	xxx[46]
-#define	rb1	xxx[47]
-#define	rb2	xxx[48]
-#define	rb3	xxx[49]
-#define	rb4	xxx[50]
-#define	rb5	xxx[51]
-#define	rb6	xxx[52]
-#define	sb1	xxx[53]
-#define	sb2	xxx[54]
-#define	sb3	xxx[55]
-#define	sb4	xxx[56]
-#define	sb5	xxx[57]
-#define	sb6	xxx[58]
-#define	sb7	xxx[59]
+#define	rb0		xxx[46]
+#define	rb1		xxx[47]
+#define	rb2		xxx[48]
+#define	rb3		xxx[49]
+#define	rb4		xxx[50]
+#define	rb5		xxx[51]
+#define	rb6		xxx[52]
+#define	sb1		xxx[53]
+#define	sb2		xxx[54]
+#define	sb3		xxx[55]
+#define	sb4		xxx[56]
+#define	sb5		xxx[57]
+#define	sb6		xxx[58]
+#define	sb7		xxx[59]
 
 double
-erf(double x) {
+erf(double x)
+{
 	int hx, ix, i;
 	double R, S, P, Q, s, y, z, r;
 
-	hx = ((int *) &x)[HIWORD];
+	hx = ((int *)&x)[HIWORD];
 	ix = hx & 0x7fffffff;
-	if (ix >= 0x7ff00000) {	/* erf(nan)=nan */
+
+	if (ix >= 0x7ff00000) {		/* erf(nan)=nan */
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
-		if (ix >= 0x7ff80000)		/* assumes sparc-like QNaN */
+		if (ix >= 0x7ff80000)	/* assumes sparc-like QNaN */
 			return (x);
 #endif
-		i = ((unsigned) hx >> 31) << 1;
-		return ((double) (1 - i) + one / x);	/* erf(+-inf)=+-1 */
+		i = ((unsigned)hx >> 31) << 1;
+		return ((double)(1 - i) + one / x);	/* erf(+-inf)=+-1 */
 	}
 
-	if (ix < 0x3feb0000) {	/* |x|<0.84375 */
-		if (ix < 0x3e300000) {	/* |x|<2**-28 */
-			if (ix < 0x00800000)	/* avoid underflow */
+	if (ix < 0x3feb0000) {				/* |x|<0.84375 */
+		if (ix < 0x3e300000) {			/* |x|<2**-28 */
+			if (ix < 0x00800000)		/* avoid underflow */
 				return (0.125 * (8.0 * x + efx8 * x));
+
 			return (x + efx * x);
 		}
+
 		z = x * x;
 		r = pp0 + z * (pp1 + z * (pp2 + z * (pp3 + z * pp4)));
-		s = one +
-			z *(qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
+		s = one + z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z *
+		    qq5))));
 		y = r / s;
 		return (x + x * y);
 	}
-	if (ix < 0x3ff40000) {	/* 0.84375 <= |x| < 1.25 */
+
+	if (ix < 0x3ff40000) {		/* 0.84375 <= |x| < 1.25 */
 		s = fabs(x) - one;
-		P = pa0 + s * (pa1 + s * (pa2 + s * (pa3 + s * (pa4 +
-			s * (pa5 + s * pa6)))));
-		Q = one + s * (qa1 + s * (qa2 + s * (qa3 + s * (qa4 +
-			s * (qa5 + s * qa6)))));
+		P = pa0 + s * (pa1 + s * (pa2 + s * (pa3 + s * (pa4 + s * (pa5 +
+		    s * pa6)))));
+		Q = one + s * (qa1 + s * (qa2 + s * (qa3 + s * (qa4 + s * (qa5 +
+		    s * qa6)))));
+
 		if (hx >= 0)
 			return (erx + P / Q);
 		else
 			return (-erx - P / Q);
 	}
-	if (ix >= 0x40180000) {	/* inf > |x| >= 6 */
+
+	if (ix >= 0x40180000) {		/* inf > |x| >= 6 */
 		if (hx >= 0)
 			return (one - tiny);
 		else
 			return (tiny - one);
 	}
+
 	x = fabs(x);
 	s = one / (x * x);
-	if (ix < 0x4006DB6E) {	/* |x| < 1/0.35 */
-		R = ra0 + s * (ra1 + s * (ra2 + s * (ra3 + s * (ra4 +
-			s * (ra5 + s * (ra6 + s * ra7))))));
-		S = one + s * (sa1 + s * (sa2 + s * (sa3 + s * (sa4 +
-			s * (sa5 + s * (sa6 + s * (sa7 + s * sa8)))))));
+
+	if (ix < 0x4006DB6E) {		/* |x| < 1/0.35 */
+		R = ra0 + s * (ra1 + s * (ra2 + s * (ra3 + s * (ra4 + s * (ra5 +
+		    s * (ra6 + s * ra7))))));
+		S = one + s * (sa1 + s * (sa2 + s * (sa3 + s * (sa4 + s * (sa5 +
+		    s * (sa6 + s * (sa7 + s * sa8)))))));
 	} else {			/* |x| >= 1/0.35 */
-		R = rb0 + s * (rb1 + s * (rb2 + s * (rb3 + s * (rb4 +
-			s * (rb5 + s * rb6)))));
-		S = one + s * (sb1 + s * (sb2 + s * (sb3 + s * (sb4 +
-			s * (sb5 + s * (sb6 + s * sb7))))));
+		R = rb0 + s * (rb1 + s * (rb2 + s * (rb3 + s * (rb4 + s * (rb5 +
+		    s * rb6)))));
+		S = one + s * (sb1 + s * (sb2 + s * (sb3 + s * (sb4 + s * (sb5 +
+		    s * (sb6 + s * sb7))))));
 	}
+
 	z = x;
-	((int *) &z)[LOWORD] = 0;
+	((int *)&z)[LOWORD] = 0;
 	r = exp(-z * z - 0.5625) * exp((z - x) * (z + x) + R / S);
+
 	if (hx >= 0)
 		return (one - r / x);
 	else
@@ -347,29 +367,33 @@
 }
 
 double
-erfc(double x) {
+erfc(double x)
+{
 	int hx, ix;
 	double R, S, P, Q, s, y, z, r;
 
-	hx = ((int *) &x)[HIWORD];
+	hx = ((int *)&x)[HIWORD];
 	ix = hx & 0x7fffffff;
-	if (ix >= 0x7ff00000) {	/* erfc(nan)=nan */
+
+	if (ix >= 0x7ff00000) {		/* erfc(nan)=nan */
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
-		if (ix >= 0x7ff80000)		/* assumes sparc-like QNaN */
+		if (ix >= 0x7ff80000)	/* assumes sparc-like QNaN */
 			return (x);
 #endif
 		/* erfc(+-inf)=0,2 */
-		return ((double) (((unsigned) hx >> 31) << 1) + one / x);
+		return ((double)(((unsigned)hx >> 31) << 1) + one / x);
 	}
 
-	if (ix < 0x3feb0000) {	/* |x| < 0.84375 */
+	if (ix < 0x3feb0000) {		/* |x| < 0.84375 */
 		if (ix < 0x3c700000)	/* |x| < 2**-56 */
 			return (one - x);
+
 		z = x * x;
 		r = pp0 + z * (pp1 + z * (pp2 + z * (pp3 + z * pp4)));
-		s = one +
-			z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
+		s = one + z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z *
+		    qq5))));
 		y = r / s;
+
 		if (hx < 0x3fd00000) {	/* x < 1/4 */
 			return (one - (x + x * y));
 		} else {
@@ -378,12 +402,14 @@
 			return (half - r);
 		}
 	}
-	if (ix < 0x3ff40000) {	/* 0.84375 <= |x| < 1.25 */
+
+	if (ix < 0x3ff40000) {		/* 0.84375 <= |x| < 1.25 */
 		s = fabs(x) - one;
-		P = pa0 + s * (pa1 + s * (pa2 + s * (pa3 + s * (pa4 +
-			s * (pa5 + s * pa6)))));
-		Q = one + s * (qa1 + s * (qa2 + s * (qa3 + s * (qa4 +
-			s * (qa5 + s * qa6)))));
+		P = pa0 + s * (pa1 + s * (pa2 + s * (pa3 + s * (pa4 + s * (pa5 +
+		    s * pa6)))));
+		Q = one + s * (qa1 + s * (qa2 + s * (qa3 + s * (qa4 + s * (qa5 +
+		    s * qa6)))));
+
 		if (hx >= 0) {
 			z = one - erx;
 			return (z - P / Q);
@@ -392,27 +418,31 @@
 			return (one + z);
 		}
 	}
-	if (ix < 0x403c0000) {	/* |x|<28 */
+
+	if (ix < 0x403c0000) {		/* |x|<28 */
 		x = fabs(x);
 		s = one / (x * x);
+
 		if (ix < 0x4006DB6D) {	/* |x| < 1/.35 ~ 2.857143 */
 			R = ra0 + s * (ra1 + s * (ra2 + s * (ra3 + s * (ra4 +
-				s * (ra5 + s * (ra6 + s * ra7))))));
+			    s * (ra5 + s * (ra6 + s * ra7))))));
 			S = one + s * (sa1 + s * (sa2 + s * (sa3 + s * (sa4 +
-				s * (sa5 + s * (sa6 + s * (sa7 + s * sa8)))))));
+			    s * (sa5 + s * (sa6 + s * (sa7 + s * sa8)))))));
 		} else {
 			/* |x| >= 1/.35 ~ 2.857143 */
 			if (hx < 0 && ix >= 0x40180000)
 				return (two - tiny);	/* x < -6 */
 
 			R = rb0 + s * (rb1 + s * (rb2 + s * (rb3 + s * (rb4 +
-				s * (rb5 + s * rb6)))));
+			    s * (rb5 + s * rb6)))));
 			S = one + s * (sb1 + s * (sb2 + s * (sb3 + s * (sb4 +
-				s * (sb5 + s * (sb6 + s * sb7))))));
+			    s * (sb5 + s * (sb6 + s * sb7))))));
 		}
+
 		z = x;
-		((int *) &z)[LOWORD] = 0;
+		((int *)&z)[LOWORD] = 0;
 		r = exp(-z * z - 0.5625) * exp((z - x) * (z + x) + R / S);
+
 		if (hx > 0)
 			return (r / x);
 		else
--- old/usr/src/lib/libm/common/C/exp.c	2019-06-06 20:37:44.671324354 +0000
+++ new/usr/src/lib/libm/common/C/exp.c	2019-06-06 20:37:44.688823899 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -70,38 +72,38 @@
 #include "libm.h"
 
 static const double TBL[] = {
-	1.00000000000000000000e+00,  0.00000000000000000000e+00,
-	1.02189714865411662714e+00,  5.10922502897344389359e-17,
-	1.04427378242741375480e+00,  8.55188970553796365958e-17,
+	1.00000000000000000000e+00, 0.00000000000000000000e+00,
+	1.02189714865411662714e+00, 5.10922502897344389359e-17,
+	1.04427378242741375480e+00, 8.55188970553796365958e-17,
 	1.06714040067682369717e+00, -7.89985396684158212226e-17,
 	1.09050773266525768967e+00, -3.04678207981247114697e-17,
-	1.11438674259589243221e+00,  1.04102784568455709549e-16,
-	1.13878863475669156458e+00,  8.91281267602540777782e-17,
-	1.16372485877757747552e+00,  3.82920483692409349872e-17,
-	1.18920711500272102690e+00,  3.98201523146564611098e-17,
+	1.11438674259589243221e+00, 1.04102784568455709549e-16,
+	1.13878863475669156458e+00, 8.91281267602540777782e-17,
+	1.16372485877757747552e+00, 3.82920483692409349872e-17,
+	1.18920711500272102690e+00, 3.98201523146564611098e-17,
 	1.21524735998046895524e+00, -7.71263069268148813091e-17,
-	1.24185781207348400201e+00,  4.65802759183693679123e-17,
-	1.26905095719173321989e+00,  2.66793213134218609523e-18,
-	1.29683955465100964055e+00,  2.53825027948883149593e-17,
+	1.24185781207348400201e+00, 4.65802759183693679123e-17,
+	1.26905095719173321989e+00, 2.66793213134218609523e-18,
+	1.29683955465100964055e+00, 2.53825027948883149593e-17,
 	1.32523664315974132322e+00, -2.85873121003886075697e-17,
-	1.35425554693689265129e+00,  7.70094837980298946162e-17,
+	1.35425554693689265129e+00, 7.70094837980298946162e-17,
 	1.38390988196383202258e+00, -6.77051165879478628716e-17,
 	1.41421356237309514547e+00, -9.66729331345291345105e-17,
 	1.44518080697704665027e+00, -3.02375813499398731940e-17,
 	1.47682614593949934623e+00, -3.48399455689279579579e-17,
 	1.50916442759342284141e+00, -1.01645532775429503911e-16,
-	1.54221082540794074411e+00,  7.94983480969762085616e-17,
+	1.54221082540794074411e+00, 7.94983480969762085616e-17,
 	1.57598084510788649659e+00, -1.01369164712783039808e-17,
-	1.61049033194925428347e+00,  2.47071925697978878522e-17,
+	1.61049033194925428347e+00, 2.47071925697978878522e-17,
 	1.64575547815396494578e+00, -1.01256799136747726038e-16,
-	1.68179283050742900407e+00,  8.19901002058149652013e-17,
+	1.68179283050742900407e+00, 8.19901002058149652013e-17,
 	1.71861929812247793414e+00, -1.85138041826311098821e-17,
-	1.75625216037329945351e+00,  2.96014069544887330703e-17,
-	1.79470907500310716820e+00,  1.82274584279120867698e-17,
-	1.83400808640934243066e+00,  3.28310722424562658722e-17,
+	1.75625216037329945351e+00, 2.96014069544887330703e-17,
+	1.79470907500310716820e+00, 1.82274584279120867698e-17,
+	1.83400808640934243066e+00, 3.28310722424562658722e-17,
 	1.87416763411029996256e+00, -6.12276341300414256164e-17,
 	1.91520656139714740007e+00, -1.06199460561959626376e-16,
-	1.95714412417540017941e+00,  8.96076779103666776760e-17,
+	1.95714412417540017941e+00, 8.96076779103666776760e-17,
 };
 
 /*
@@ -263,35 +265,36 @@
 	1.3888949086377719040e-3,	/* 3f56c1728d739765 */
 	1.0,
 	0.0,
-	7.09782712893383973096e+02,	/* 0x40862E42, 0xFEFA39EF */
-	7.45133219101941108420e+02,	/* 0x40874910, 0xD52D3051 */
-	5.55111512312578270212e-17,	/* 0x3c900000, 0x00000000 */
+	7.09782712893383973096e+02, /* 0x40862E42, 0xFEFA39EF */
+	7.45133219101941108420e+02, /* 0x40874910, 0xD52D3051 */
+	5.55111512312578270212e-17, /* 0x3c900000, 0x00000000 */
 };
 
-#define	half		C[0]
-#define	invln2_32	C[1]
-#define	ln2_32hi	C[2]
-#define	ln2_32lo	C[3]
-#define	t2		C[4]
-#define	t3		C[5]
-#define	t4		C[6]
-#define	t5		C[7]
-#define	one		C[8]
-#define	zero		C[9]
-#define	threshold1	C[10]
-#define	threshold2	C[11]
-#define	twom54		C[12]
+#define	half			C[0]
+#define	invln2_32		C[1]
+#define	ln2_32hi		C[2]
+#define	ln2_32lo		C[3]
+#define	t2			C[4]
+#define	t3			C[5]
+#define	t4			C[6]
+#define	t5			C[7]
+#define	one			C[8]
+#define	zero			C[9]
+#define	threshold1		C[10]
+#define	threshold2		C[11]
+#define	twom54			C[12]
 
 double
-exp(double x) {
-	double	y, z, t;
-	int	hx, ix, k, j, m;
+exp(double x)
+{
+	double y, z, t;
+	int hx, ix, k, j, m;
 
 	ix = ((int *)&x)[HIWORD];
 	hx = ix & ~0x80000000;
 
-	if (hx < 0x3ff0a2b2) {	/* |x| < 3/2 ln 2 */
-		if (hx < 0x3f862e42) {	/* |x| < 1/64 ln 2 */
+	if (hx < 0x3ff0a2b2) {			/* |x| < 3/2 ln 2 */
+		if (hx < 0x3f862e42) {		/* |x| < 1/64 ln 2 */
 			if (hx < 0x3ed00000) {	/* |x| < 2^-18 */
 				volatile int dummy __unused;
 
@@ -299,13 +302,16 @@
 #ifdef lint
 				dummy = dummy;
 #endif
+
 				if (hx < 0x3e300000)
 					return (one + x);
+
 				return (one + x * (one + half * x));
 			}
+
 			t = x * x;
-			y = x + (t * (half + x * t2) +
-			    (t * t) * (t3 + x * t4 + t * t5));
+			y = x + (t * (half + x * t2) + (t * t) * (t3 + x * t4 +
+			    t * t5));
 			return (one + y);
 		}
 
@@ -313,32 +319,39 @@
 		k = hx >> 20;
 		j = (0x00100000 | (hx & 0x000fffff)) >> (0x40c - k);
 		j = (j - 1) & ~1;
+
 		if (ix < 0)
 			j += 134;
+
 		z = x - TBL2[j];
 		t = z * z;
-		y = z + (t * (half + z * t2) +
-		    (t * t) * (t3 + z * t4 + t * t5));
-		return (TBL2[j+1] + TBL2[j+1] * y);
+		y = z + (t * (half + z * t2) + (t * t) * (t3 + z * t4 + t *
+		    t5));
+		return (TBL2[j + 1] + TBL2[j + 1] * y);
 	}
 
-	if (hx >= 0x40862e42) {	/* x is large, infinite, or nan */
+	if (hx >= 0x40862e42) {		/* x is large, infinite, or nan */
 		if (hx >= 0x7ff00000) {
 			if (ix == 0xfff00000 && ((int *)&x)[LOWORD] == 0)
 				return (zero);
+
 			return (x * x);
 		}
+
 		if (x > threshold1)
 			return (_SVID_libm_err(x, x, 6));
+
 		if (-x > threshold2)
 			return (_SVID_libm_err(x, x, 7));
 	}
 
 	t = invln2_32 * x;
+
 	if (ix < 0)
 		t -= half;
 	else
 		t += half;
+
 	k = (int)t;
 	j = (k & 0x1f) << 1;
 	m = k >> 5;
@@ -347,11 +360,13 @@
 	/* z is now in primary range */
 	t = z * z;
 	y = z + (t * (half + z * t2) + (t * t) * (t3 + z * t4 + t * t5));
-	y = TBL[j] + (TBL[j+1] + TBL[j] * y);
+	y = TBL[j] + (TBL[j + 1] + TBL[j] * y);
+
 	if (m < -1021) {
 		((int *)&y)[HIWORD] += (m + 54) << 20;
 		return (twom54 * y);
 	}
+
 	((int *)&y)[HIWORD] += m << 20;
 	return (y);
 }
--- old/usr/src/lib/libm/common/C/exp10.c	2019-06-06 20:37:45.200719938 +0000
+++ new/usr/src/lib/libm/common/C/exp10.c	2019-06-06 20:37:45.218387078 +0000
@@ -18,15 +18,17 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * exp10(x)
  * Code by K.C. Ng for SUN 4.0 libm.
@@ -37,13 +39,12 @@
  *	If x is an integer < 23 then use repeat multiplication. For
  *	10**22 is the largest representable integer.
  */
-/* INDENT ON */
 
 #include "libm.h"
 
 static const double C[] = {
-	3.3219280948736234787,	/* log(10)/log(2) */
-	2.3025850929940456840,	/* log(10) */
+	3.3219280948736234787,		/* log(10)/log(2) */
+	2.3025850929940456840,		/* log(10) */
 	3.0102999565860955045E-1,	/* log(2)/log(10) high */
 	5.3716447674669983622E-12,	/* log(2)/log(10) low */
 	0.0,
@@ -54,32 +55,35 @@
 	1.0e-300,
 };
 
-#define	lg10	C[0]
-#define	ln10	C[1]
-#define	logt2hi	C[2]
-#define	logt2lo	C[3]
-#define	zero	C[4]
-#define	half	C[5]
-#define	one	C[6]
-#define	ten	C[7]
-#define	huge	C[8]
-#define	tiny	C[9]
+#define	lg10		C[0]
+#define	ln10		C[1]
+#define	logt2hi		C[2]
+#define	logt2lo		C[3]
+#define	zero		C[4]
+#define	half		C[5]
+#define	one		C[6]
+#define	ten		C[7]
+#define	huge		C[8]
+#define	tiny		C[9]
 
 double
-exp10(double x) {
-	double	t, pt;
-	int	ix, hx, k;
+exp10(double x)
+{
+	double t, pt;
+	int ix, hx, k;
 
 	ix = ((int *)&x)[HIWORD];
 	hx = ix & ~0x80000000;
 
-	if (hx >= 0x4074a000) {	/* |x| >= 330 or x is nan */
+	if (hx >= 0x4074a000) {		/* |x| >= 330 or x is nan */
 		if (hx >= 0x7ff00000) {	/* x is inf or nan */
 			if (ix == 0xfff00000 && ((int *)&x)[LOWORD] == 0)
 				return (zero);
+
 			return (x * x);
 		}
-		t = (ix < 0)? tiny : huge;
+
+		t = (ix < 0) ? tiny : huge;
 		return (t * t);
 	}
 
@@ -87,22 +91,30 @@
 		return (one + x);
 
 	k = (int)x;
+
 	if (0 <= k && k < 23 && (double)k == x) {
 		/* x is a small positive integer */
 		t = one;
 		pt = ten;
+
 		if (k & 1)
 			t = ten;
+
 		k >>= 1;
+
 		while (k) {
 			pt *= pt;
+
 			if (k & 1)
 				t *= pt;
+
 			k >>= 1;
 		}
+
 		return (t);
 	}
+
 	t = x * lg10;
-	k = (int)((ix < 0)? t - half : t + half);
+	k = (int)((ix < 0) ? t - half : t + half);
 	return (scalbn(exp(ln10 * ((x - k * logt2hi) - k * logt2lo)), k));
 }
--- old/usr/src/lib/libm/common/C/exp2.c	2019-06-06 20:37:45.702077139 +0000
+++ new/usr/src/lib/libm/common/C/exp2.c	2019-06-06 20:37:45.720542093 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __exp2 = exp2
 
-/* INDENT OFF */
+
 /*
  * exp2(x)
  * Code by K.C. Ng for SUN 4.0 libm.
@@ -37,7 +39,6 @@
  *		= 2**anint(x)*2**(x-anint(x))
  *		= 2**anint(x)*exp((x-anint(x))*ln2)
  */
-/* INDENT ON */
 
 #include "libm.h"
 
@@ -50,39 +51,45 @@
 	1.0e-300,
 };
 
-#define	zero	C[0]
-#define	one	C[1]
-#define	half	C[2]
-#define	ln2	C[3]
-#define	huge	C[4]
-#define	tiny	C[5]
+#define	zero		C[0]
+#define	one		C[1]
+#define	half		C[2]
+#define	ln2		C[3]
+#define	huge		C[4]
+#define	tiny		C[5]
 
 double
-exp2(double x) {
-	int	ix, hx, k;
-	double	t;
+exp2(double x)
+{
+	int ix, hx, k;
+	double t;
 
 	ix = ((int *)&x)[HIWORD];
 	hx = ix & ~0x80000000;
 
-	if (hx >= 0x4090e000) {	/* |x| >= 1080 or x is nan */
+	if (hx >= 0x4090e000) {		/* |x| >= 1080 or x is nan */
 		if (hx >= 0x7ff00000) {	/* x is inf or nan */
 			if (ix == 0xfff00000 && ((int *)&x)[LOWORD] == 0)
 				return (zero);
+
 			return (x * x);
 		}
-		t = (ix < 0)? tiny : huge;
+
+		t = (ix < 0) ? tiny : huge;
 		return (t * t);
 	}
 
-	if (hx < 0x3fe00000) {	/* |x| < 0.5 */
+	if (hx < 0x3fe00000) {		/* |x| < 0.5 */
 		if (hx < 0x3c000000)
 			return (one + x);
+
 		return (exp(ln2 * x));
 	}
 
 	k = (int)x;
+
 	if (x != (double)k)
-		k = (int)((ix < 0)? x - half : x + half);
+		k = (int)((ix < 0) ? x - half : x + half);
+
 	return (scalbn(exp(ln2 * (x - (double)k)), k));
 }
--- old/usr/src/lib/libm/common/C/expm1.c	2019-06-06 20:37:46.181992209 +0000
+++ new/usr/src/lib/libm/common/C/expm1.c	2019-06-06 20:37:46.198759792 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __expm1 = expm1
 
-/* INDENT OFF */
+
 /*
  * expm1(x)
  * Returns exp(x)-1, the exponential of x minus 1.
@@ -54,23 +55,23 @@
  *		     = 6/r * ( 1 + 2.0*(1/(exp(r)-1) - 1/r))
  *		     = 1 - r^2/60 + r^4/2520 - r^6/100800 + ...
  *      We use a special Reme algorithm on [0,0.347] to generate
- * 	a polynomial of degree 5 in r*r to approximate R1. The
+ *      a polynomial of degree 5 in r*r to approximate R1. The
  *	maximum error of this polynomial approximation is bounded
  *	by 2**-61. In other words,
  *	    R1(z) ~ 1.0 + Q1*z + Q2*z**2 + Q3*z**3 + Q4*z**4 + Q5*z**5
- *	where 	Q1  =  -1.6666666666666567384E-2,
- * 		Q2  =   3.9682539681370365873E-4,
- * 		Q3  =  -9.9206344733435987357E-6,
- * 		Q4  =   2.5051361420808517002E-7,
- * 		Q5  =  -6.2843505682382617102E-9;
- *  	(where z=r*r, and the values of Q1 to Q5 are listed below)
+ *	where   Q1  =  -1.6666666666666567384E-2,
+ *              Q2  =   3.9682539681370365873E-4,
+ *              Q3  =  -9.9206344733435987357E-6,
+ *              Q4  =   2.5051361420808517002E-7,
+ *              Q5  =  -6.2843505682382617102E-9;
+ *      (where z=r*r, and the values of Q1 to Q5 are listed below)
  *	with error bounded by
  *	    |                  5           |     -61
  *	    | 1.0+Q1*z+...+Q5*z   -  R1(z) | <= 2
  *	    |                              |
  *
  *	expm1(r) = exp(r)-1 is then computed by the following
- * 	specific way which minimize the accumulation rounding error:
+ *      specific way which minimize the accumulation rounding error:
  *			       2     3
  *			      r     r    [ 3 - (R1 + R1*r/2)  ]
  *	      expm1(r) = r + --- + --- * [--------------------]
@@ -81,7 +82,7 @@
  *			   ~ expm1(r) + c + r*c
  *	Thus c+r*c will be added in as the correction terms for
  *	expm1(r+c). Now rearrange the term to avoid optimization
- * 	screw up:
+ *      screw up:
  *		        (      2                                    2 )
  *		        ({  ( r    [ R1 -  (3 - R1*r/2) ]  )  }    r  )
  *	 expm1(r+c)~r - ({r*(--- * [--------------------]-c)-c} - --- )
@@ -125,79 +126,90 @@
  * compiler will convert from decimal to binary accurately enough
  * to produce the hexadecimal values shown.
  */
-/* INDENT ON */
 
 #include "libm_macros.h"
 #include <math.h>
 
 static const double xxx[] = {
-/* one */		 1.0,
-/* huge */		 1.0e+300,
-/* tiny */		 1.0e-300,
-/* o_threshold */	 7.09782712893383973096e+02,	/* 40862E42 FEFA39EF */
-/* ln2_hi */		 6.93147180369123816490e-01,	/* 3FE62E42 FEE00000 */
-/* ln2_lo */		 1.90821492927058770002e-10,	/* 3DEA39EF 35793C76 */
-/* invln2 */		 1.44269504088896338700e+00,	/* 3FF71547 652B82FE */
-/* scaled coefficients related to expm1 */
-/* Q1 */		-3.33333333333331316428e-02,	/* BFA11111 111110F4 */
-/* Q2 */		 1.58730158725481460165e-03,	/* 3F5A01A0 19FE5585 */
-/* Q3 */		-7.93650757867487942473e-05,	/* BF14CE19 9EAADBB7 */
-/* Q4 */		 4.00821782732936239552e-06,	/* 3ED0CFCA 86E65239 */
-/* Q5 */		-2.01099218183624371326e-07	/* BE8AFDB7 6E09C32D */
+/* one */
+	1.0,
+/* huge */ 1.0e+300,
+/* tiny */ 1.0e-300,
+/* o_threshold */ 7.09782712893383973096e+02,	/* 40862E42 FEFA39EF */
+/* ln2_hi */ 6.93147180369123816490e-01,	/* 3FE62E42 FEE00000 */
+/* ln2_lo */ 1.90821492927058770002e-10,	/* 3DEA39EF 35793C76 */
+/* invln2 */ 1.44269504088896338700e+00,	/* 3FF71547 652B82FE */
+
+/*
+ * scaled coefficients related to expm1
+ * Q1
+ */
+	-3.33333333333331316428e-02,		/* BFA11111 111110F4 */
+/* Q2 */ 1.58730158725481460165e-03,		/* 3F5A01A0 19FE5585 */
+/* Q3 */ -7.93650757867487942473e-05,		/* BF14CE19 9EAADBB7 */
+/* Q4 */ 4.00821782732936239552e-06,		/* 3ED0CFCA 86E65239 */
+/* Q5 */ -2.01099218183624371326e-07		/* BE8AFDB7 6E09C32D */
 };
-#define	one		xxx[0]
-#define	huge		xxx[1]
-#define	tiny		xxx[2]
-#define	o_threshold	xxx[3]
-#define	ln2_hi		xxx[4]
-#define	ln2_lo		xxx[5]
-#define	invln2		xxx[6]
-#define	Q1		xxx[7]
-#define	Q2		xxx[8]
-#define	Q3		xxx[9]
-#define	Q4		xxx[10]
-#define	Q5		xxx[11]
+
+#define	one			xxx[0]
+#define	huge			xxx[1]
+#define	tiny			xxx[2]
+#define	o_threshold		xxx[3]
+#define	ln2_hi			xxx[4]
+#define	ln2_lo			xxx[5]
+#define	invln2			xxx[6]
+#define	Q1			xxx[7]
+#define	Q2			xxx[8]
+#define	Q3			xxx[9]
+#define	Q4			xxx[10]
+#define	Q5			xxx[11]
 
 double
-expm1(double x) {
+expm1(double x)
+{
 	double y, hi, lo, c = 0.0L, t, e, hxs, hfx, r1;
 	int k, xsb;
 	unsigned hx;
 
-	hx = ((unsigned *) &x)[HIWORD];		/* high word of x */
-	xsb = hx & 0x80000000;			/* sign bit of x */
+	hx = ((unsigned *)&x)[HIWORD];	/* high word of x */
+	xsb = hx & 0x80000000;		/* sign bit of x */
+
 	if (xsb == 0)
 		y = x;
 	else
-		y = -x;				/* y = |x| */
-	hx &= 0x7fffffff;			/* high word of |x| */
+		y = -x;			/* y = |x| */
+
+	hx &= 0x7fffffff;		/* high word of |x| */
 
-	/* filter out huge and non-finite argument */
-	/* for example exp(38)-1 is approximately 3.1855932e+16 */
+	/*
+	 * filter out huge and non-finite argument
+	 * for example exp(38)-1 is approximately 3.1855932e+16
+	 */
 	if (hx >= 0x4043687A) {
 		/* if |x|>=56*ln2 (~38.8162...) */
-		if (hx >= 0x40862E42) {		/* if |x|>=709.78... -> inf */
+		if (hx >= 0x40862E42) {	/* if |x|>=709.78... -> inf */
 			if (hx >= 0x7ff00000) {
-				if (((hx & 0xfffff) | ((int *) &x)[LOWORD])
-					!= 0)
+				if (((hx & 0xfffff) | ((int *)&x)[LOWORD]) != 0)
 					return (x * x);	/* + -> * for Cheetah */
 				else
 					/* exp(+-inf)={inf,-1} */
 					return (xsb == 0 ? x : -1.0);
 			}
+
 			if (x > o_threshold)
 				return (huge * huge);	/* overflow */
 		}
-		if (xsb != 0) {		/* x < -56*ln2, return -1.0 w/inexact */
+
+		if (xsb != 0) {	/* x < -56*ln2, return -1.0 w/inexact */
 			if (x + tiny < 0.0)		/* raise inexact */
 				return (tiny - one);	/* return -1 */
 		}
 	}
 
 	/* argument reduction */
-	if (hx > 0x3fd62e42) {			/* if  |x| > 0.5 ln2 */
-		if (hx < 0x3FF0A2B2) {		/* and |x| < 1.5 ln2 */
-			if (xsb == 0) {		/* positive number */
+	if (hx > 0x3fd62e42) {		/* if  |x| > 0.5 ln2 */
+		if (hx < 0x3FF0A2B2) {	/* and |x| < 1.5 ln2 */
+			if (xsb == 0) {	/* positive number */
 				hi = x - ln2_hi;
 				lo = ln2_lo;
 				k = 1;
@@ -209,20 +221,22 @@
 			}
 		} else {
 			/* |x| > 1.5 ln2 */
-			k = (int) (invln2 * x + (xsb == 0 ? 0.5 : -0.5));
+			k = (int)(invln2 * x + (xsb == 0 ? 0.5 : -0.5));
 			t = k;
 			hi = x - t * ln2_hi;	/* t*ln2_hi is exact here */
 			lo = t * ln2_lo;
 		}
+
 		x = hi - lo;
-		c = (hi - x) - lo; /* still at |x| > 0.5 ln2 */
+		c = (hi - x) - lo;	/* still at |x| > 0.5 ln2 */
 	} else if (hx < 0x3c900000) {
 		/* when |x|<2**-54, return x */
 		t = huge + x;		/* return x w/inexact when x != 0 */
 		return (x - (t - (huge + x)));
-	} else
+	} else {
 		/* |x| <= 0.5 ln2 */
 		k = 0;
+	}
 
 	/* x is now in primary range */
 	hfx = 0.5 * x;
@@ -230,36 +244,43 @@
 	r1 = one + hxs * (Q1 + hxs * (Q2 + hxs * (Q3 + hxs * (Q4 + hxs * Q5))));
 	t = 3.0 - r1 * hfx;
 	e = hxs * ((r1 - t) / (6.0 - x * t));
-	if (k == 0) /* |x| <= 0.5 ln2 */
+
+	if (k == 0) {			/* |x| <= 0.5 ln2 */
 		return (x - (x * e - hxs));
-	else {		/* |x| > 0.5 ln2 */
+	} else {			/* |x| > 0.5 ln2 */
 		e = (x * (e - c) - c);
 		e -= hxs;
+
 		if (k == -1)
 			return (0.5 * (x - e) - 0.5);
+
 		if (k == 1) {
 			if (x < -0.25)
 				return (-2.0 * (e - (x + 0.5)));
 			else
 				return (one + 2.0 * (x - e));
 		}
+
 		if (k <= -2 || k > 56) {	/* suffice to return exp(x)-1 */
 			y = one - (e - x);
-			((int *) &y)[HIWORD] += k << 20;
+			((int *)&y)[HIWORD] += k << 20;
 			return (y - one);
 		}
+
 		t = one;
+
 		if (k < 20) {
-			((int *) &t)[HIWORD] = 0x3ff00000 - (0x200000 >> k);
-							/* t = 1 - 2^-k */
+			((int *)&t)[HIWORD] = 0x3ff00000 - (0x200000 >> k);
+			/* t = 1 - 2^-k */
 			y = t - (e - x);
-			((int *) &y)[HIWORD] += k << 20;
+			((int *)&y)[HIWORD] += k << 20;
 		} else {
-			((int *) &t)[HIWORD] = (0x3ff - k) << 20; /* 2^-k */
+			((int *)&t)[HIWORD] = (0x3ff - k) << 20; /* 2^-k */
 			y = x - (e + t);
 			y += one;
-			((int *) &y)[HIWORD] += k << 20;
+			((int *)&y)[HIWORD] += k << 20;
 		}
 	}
+
 	return (y);
 }
--- old/usr/src/lib/libm/common/C/fabs.c	2019-06-06 20:37:46.655366170 +0000
+++ new/usr/src/lib/libm/common/C/fabs.c	2019-06-06 20:37:46.672836458 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,8 +35,9 @@
 #include <math.h>
 
 double
-fabs(double x) {
-	int *px = (int *) &x;
+fabs(double x)
+{
+	int *px = (int *)&x;
 
 	px[HIWORD] &= ~0x80000000;
 	return (x);
--- old/usr/src/lib/libm/common/C/floor.c	2019-06-06 20:37:47.121570842 +0000
+++ new/usr/src/lib/libm/common/C/floor.c	2019-06-06 20:37:47.138008337 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,29 +39,31 @@
 
 #include "libm.h"
 
-static const double
-	zero = 0.0,
-	one = 1.0,
-	two52 = 4503599627370496.0;
+static const double zero = 0.0, one = 1.0, two52 = 4503599627370496.0;
 
 double
-floor(double x) {
-	double	t, w;
-	int	hx, lx, ix;
+floor(double x)
+{
+	double t, w;
+	int hx, lx, ix;
 
 	hx = ((int *)&x)[HIWORD];
 	lx = ((int *)&x)[LOWORD];
 	ix = hx & ~0x80000000;
+
 	if (ix >= 0x43300000)	/* return x if |x| >= 2^52, or x is NaN */
 		return (x * one);
-	t = (hx >= 0)? two52 : -two52;
+
+	t = (hx >= 0) ? two52 : -two52;
 	w = x + t;
 	t = w - t;
+
 	if (ix < 0x3ff00000) {
 		if ((ix | lx) == 0)
 			return (x);
 		else
-			return ((hx < 0)? -one : zero);
+			return ((hx < 0) ? -one : zero);
 	}
-	return ((t <= x)? t : t - one);
+
+	return ((t <= x) ? t : t - one);
 }
--- old/usr/src/lib/libm/common/C/fmod.c	2019-06-06 20:37:47.602774222 +0000
+++ new/usr/src/lib/libm/common/C/fmod.c	2019-06-06 20:37:47.620245192 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -40,10 +42,11 @@
  * 32-bit code, but we have assembly for x86, too.
  */
 double
-fmod(double x, double y) {
-	double		w;
-	long long	hx, ix, iy, iz;
-	int		nd, k, ny;
+fmod(double x, double y)
+{
+	double w;
+	long long hx, ix, iy, iz;
+	int nd, k, ny;
 
 	hx = *(long long *)&x;
 	ix = hx & ~0x8000000000000000ull;
@@ -57,7 +60,7 @@
 		return ((x * y) * zero);
 
 	if (ix <= iy)
-		return ((ix < iy)? x : x * zero);
+		return ((ix < iy) ? x : x *zero);
 
 	/*
 	 * Set:
@@ -68,16 +71,21 @@
 	 */
 	ny = iy >> 52;
 	k = ix >> 52;
+
 	if (ny == 0) {
 		/* y is subnormal, x could be normal or subnormal */
 		ny = 1;
+
 		while (iy < 0x0010000000000000ll) {
 			ny -= 1;
 			iy += iy;
 		}
+
 		nd = k - ny;
+
 		if (k == 0) {
 			nd += 1;
+
 			while (ix < 0x0010000000000000ll) {
 				nd -= 1;
 				ix += ix;
@@ -95,33 +103,41 @@
 	/* perform fixed point mod */
 	while (nd--) {
 		iz = ix - iy;
+
 		if (iz >= 0)
 			ix = iz;
+
 		ix += ix;
 	}
+
 	iz = ix - iy;
+
 	if (iz >= 0)
 		ix = iz;
 
 	/* convert back to floating point and restore the sign */
 	if (ix == 0ll)
 		return (x * zero);
+
 	while (ix < 0x0010000000000000ll) {
 		ix += ix;
 		ny -= 1;
 	}
+
 	while (ix > 0x0020000000000000ll) {	/* XXX can this ever happen? */
 		ny += 1;
 		ix >>= 1;
 	}
+
 	if (ny <= 0) {
 		/* result is subnormal */
 		k = -ny + 1;
 		ix >>= k;
-		*(long long *)&w = (hx & 0x8000000000000000ull) | ix;
+		*(long long *) &w = (hx & 0x8000000000000000ull) | ix;
 		return (w);
 	}
-	*(long long *)&w = (hx & 0x8000000000000000ull) |
-	    ((long long)ny << 52) | (ix & 0x000fffffffffffffll);
+
+	*(long long *) &w = (hx & 0x8000000000000000ull) | ((long long)ny <<
+	    52) | (ix & 0x000fffffffffffffll);
 	return (w);
 }
--- old/usr/src/lib/libm/common/C/gamma.c	2019-06-06 20:37:48.104978340 +0000
+++ new/usr/src/lib/libm/common/C/gamma.c	2019-06-06 20:37:48.125626073 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,20 +35,24 @@
 extern int signgam;
 
 double
-gamma(double x) {
-	double	g;
+gamma(double x)
+{
+	double g;
 
 	if (!finite(x))
 		return (x * x);
 
 	g = rint(x);
+
 	if (x == g && x <= 0.0) {
 		signgam = 1;
 		return (_SVID_libm_err(x, x, 41));
 	}
 
 	g = __k_lgamma(x, &signgam);
+
 	if (!finite(g))
-	    g = _SVID_libm_err(x, x, 40);
+		g = _SVID_libm_err(x, x, 40);
+
 	return (g);
 }
--- old/usr/src/lib/libm/common/C/gamma_r.c	2019-06-06 20:37:48.599474171 +0000
+++ new/usr/src/lib/libm/common/C/gamma_r.c	2019-06-06 20:37:48.617093529 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,6 +33,7 @@
 #include "libm.h"
 
 double
-gamma_r(double x, int *signgamp) {
+gamma_r(double x, int *signgamp)
+{
 	return (lgamma_r(x, signgamp));
 }
--- old/usr/src/lib/libm/common/C/hypot.c	2019-06-06 20:37:49.114374409 +0000
+++ new/usr/src/lib/libm/common/C/hypot.c	2019-06-06 20:37:49.135893362 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __hypot = hypot
 
-/* INDENT OFF */
+
 /*
  * Hypot(x, y)
  * by K.C. Ng for SUN 4.0 libm, updated 3/11/2003.
@@ -60,31 +61,31 @@
  *	hypot(x, y) is NAN if x or y is NAN.
  *
  * Accuracy:
- * 	hypot(x, y) returns sqrt(x^2+y^2) with error less than 1 ulps
+ *      hypot(x, y) returns sqrt(x^2+y^2) with error less than 1 ulps
  *	(units in the last place)
  */
 
 #include "libm.h"
 
-static const double
-	zero = 0.0,
+static const double zero = 0.0,
 	onep1u = 1.00000000000000022204e+00,	/* 0x3ff00000 1 = 1+2**-52 */
 	twom53 = 1.11022302462515654042e-16,	/* 0x3ca00000 0 = 2**-53 */
 	twom768 = 6.441148769597133308e-232,	/* 2^-768 */
-	two768  = 1.552518092300708935e+231;	/* 2^768 */
+	two768 = 1.552518092300708935e+231;	/* 2^768 */
 
-/* INDENT ON */
 
 double
-hypot(double x, double y) {
+hypot(double x, double y)
+{
 	double xh, yh, w, ax, ay;
 	int i, j, nx, ny, ix, iy, iscale = 0;
 	unsigned lx, ly;
 
-	ix = ((int *) &x)[HIWORD] & ~0x80000000;
-	lx = ((int *) &x)[LOWORD];
-	iy = ((int *) &y)[HIWORD] & ~0x80000000;
-	ly = ((int *) &y)[LOWORD];
+	ix = ((int *)&x)[HIWORD] & ~0x80000000;
+	lx = ((int *)&x)[LOWORD];
+	iy = ((int *)&y)[HIWORD] & ~0x80000000;
+	ly = ((int *)&y)[LOWORD];
+
 /*
  * Force ax = |x| ~>~ ay = |y|
  */
@@ -101,9 +102,11 @@
 		ax = fabs(x);
 		ay = fabs(y);
 	}
+
 	nx = ix >> 20;
 	ny = iy >> 20;
-	j  = nx - ny;
+	j = nx - ny;
+
 /*
  * x >= 2^500 (x*x or y*y may overflow)
  */
@@ -115,56 +118,75 @@
 				return (ay == ax ? ax : ay);
 			else
 				return (ax * ay);	/* + -> * for Cheetah */
-		} else if (j > 32) {	/* x >> y */
+		} else if (j > 32) {			/* x >> y */
 			if (j <= 53)
 				ay *= twom53;
+
 			ax += ay;
-			if (((int *) &ax)[HIWORD] == 0x7ff00000)
+
+			if (((int *)&ax)[HIWORD] == 0x7ff00000)
 				ax = _SVID_libm_err(x, y, 4);
+
 			return (ax);
 		}
+
 		ax *= twom768;
 		ay *= twom768;
 		iscale = 2;
 		ix -= 768 << 20;
 		iy -= 768 << 20;
 	}
+
 /*
  * y < 2^-450 (x*x or y*y may underflow)
  */
 	else if (ny < 0x23d) {
 		if ((ix | lx) == 0)
 			return (ay);
+
 		if ((iy | ly) == 0)
 			return (ax);
-		if (j > 53) 		/* x >> y */
+
+		if (j > 53)		/* x >> y */
 			return (ax + ay);
+
 		iscale = 1;
 		ax *= two768;
 		ay *= two768;
+
 		if (nx == 0) {
 			if (ax == zero)	/* guard subnormal flush to zero */
 				return (ax);
-			ix = ((int *) &ax)[HIWORD];
-		} else
+
+			ix = ((int *)&ax)[HIWORD];
+		} else {
 			ix += 768 << 20;
+		}
+
 		if (ny == 0) {
 			if (ay == zero)	/* guard subnormal flush to zero */
 				return (ax * twom768);
-			iy = ((int *) &ay)[HIWORD];
-		} else
+
+			iy = ((int *)&ay)[HIWORD];
+		} else {
 			iy += 768 << 20;
+		}
+
 		j = (ix >> 20) - (iy >> 20);
+
 		if (j > 32) {		/* x >> y */
 			if (j <= 53)
 				ay *= twom53;
+
 			return ((ax + ay) * twom768);
 		}
 	} else if (j > 32) {		/* x >> y */
 		if (j <= 53)
 			ay *= twom53;
+
 		return (ax + ay);
 	}
+
 /*
  * Medium range ax and ay with max{|ax/ay|,|ay/ax|} bounded by 2^32
  * First check rounding mode by comparing onep1u*onep1u with onep1u+twom53.
@@ -173,38 +195,43 @@
 	if (((lx | ly) << 5) == 0) {
 		ay = ay * ay;
 		ax += ay / (ax + sqrt(ax * ax + ay));
-	} else
-	if (onep1u * onep1u != onep1u + twom53) {
-	/* round-to-zero, positive, negative mode */
-	/* magic formula with less than an ulp error */
+	} else if (onep1u * onep1u != onep1u + twom53) {
+		/*
+		 * round-to-zero, positive, negative mode
+		 * magic formula with less than an ulp error
+		 */
 		w = sqrt(ax * ax + ay * ay);
 		ax += ay / ((ax + w) / ay);
 	} else {
-	/* round-to-nearest mode */
+		/* round-to-nearest mode */
 		w = ax - ay;
+
 		if (w > ay) {
-			((int *) &xh)[HIWORD] = ix;
-			((int *) &xh)[LOWORD] = 0;
+			((int *)&xh)[HIWORD] = ix;
+			((int *)&xh)[LOWORD] = 0;
 			ay = ay * ay + (ax - xh) * (ax + xh);
 			ax = sqrt(xh * xh + ay);
 		} else {
 			ax = ax + ax;
-			((int *) &xh)[HIWORD] = ix + 0x00100000;
-			((int *) &xh)[LOWORD] = 0;
-			((int *) &yh)[HIWORD] = iy;
-			((int *) &yh)[LOWORD] = 0;
+			((int *)&xh)[HIWORD] = ix + 0x00100000;
+			((int *)&xh)[LOWORD] = 0;
+			((int *)&yh)[HIWORD] = iy;
+			((int *)&yh)[LOWORD] = 0;
 			ay = w * w + ((ax - xh) * yh + (ay - yh) * ax);
 			ax = sqrt(xh * yh + ay);
 		}
 	}
+
 	if (iscale > 0) {
-		if (iscale == 1)
+		if (iscale == 1) {
 			ax *= twom768;
-		else {
+		} else {
 			ax *= two768;	/* must generate side effect here */
-			if (((int *) &ax)[HIWORD] == 0x7ff00000)
+
+			if (((int *)&ax)[HIWORD] == 0x7ff00000)
 				ax = _SVID_libm_err(x, y, 4);
 		}
 	}
+
 	return (ax);
 }
--- old/usr/src/lib/libm/common/C/ilogb.c	2019-06-06 20:37:49.642198342 +0000
+++ new/usr/src/lib/libm/common/C/ilogb.c	2019-06-06 20:37:49.660084704 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,7 +31,7 @@
 #pragma weak __ilogb = ilogb
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"			/* __xpg6 */
 
 #if defined(__x86)
 static const double two52 = 4503599627370496.0;
@@ -39,26 +40,32 @@
  * v: high part of a non-zero subnormal |x|; w: low part of |x|
  */
 static int
-ilogb_subnormal(unsigned v, unsigned w) {
+ilogb_subnormal(unsigned v, unsigned w)
+{
 	int r = -1022 - 52;
 
 	if (v)
 		r += 32;
 	else
 		v = w;
+
 	if (v & 0xffff0000)
 		r += 16, v >>= 16;
+
 	if (v & 0xff00)
 		r += 8, v >>= 8;
+
 	if (v & 0xf0)
 		r += 4, v >>= 4;
+
 	v <<= 1;
 	return (r + ((0xffffaa50 >> v) & 0x3));
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 static int
-raise_invalid(int v) {	/* SUSv3 requires ilogb(0,+/-Inf,NaN) raise invalid */
+raise_invalid(int v)	/* SUSv3 requires ilogb(0,+/-Inf,NaN) raise invalid */
+{
 #ifndef lint
 	if ((__xpg6 & _C99SUSv3_ilogb_0InfNaN_raises_invalid) != 0) {
 		static const double zero = 0.0;
@@ -71,13 +78,14 @@
 }
 
 int
-ilogb(double x) {
-	int *px = (int *) &x, k = px[HIWORD] & ~0x80000000;
+ilogb(double x)
+{
+	int *px = (int *)&x, k = px[HIWORD] & ~0x80000000;
 
 	if (k < 0x00100000) {
-		if ((px[LOWORD] | k) == 0)
+		if ((px[LOWORD] | k) == 0) {
 			return (raise_invalid(0x80000001));
-		else {
+		} else {
 #if defined(__x86)
 			x *= two52;
 			return (((px[HIWORD] & 0x7ff00000) >> 20) - 1075);
@@ -85,8 +93,9 @@
 			return (ilogb_subnormal(k, px[LOWORD]));
 #endif
 		}
-	} else if (k < 0x7ff00000)
+	} else if (k < 0x7ff00000) {
 		return ((k >> 20) - 1023);
-	else
+	} else {
 		return (raise_invalid(0x7fffffff));
+	}
 }
--- old/usr/src/lib/libm/common/C/isnan.c	2019-06-06 20:37:50.149305492 +0000
+++ new/usr/src/lib/libm/common/C/isnan.c	2019-06-06 20:37:50.168187832 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -40,8 +42,9 @@
  * be better to use 32-bit code, but we have assembly for x86.
  */
 int
-__isnan(double x) {
-	long long	llx;
+__isnan(double x)
+{
+	long long llx;
 
 	llx = *(long long *)&x & ~0x8000000000000000ull;
 	return ((unsigned long long)(0x7ff0000000000000ll - llx) >> 63);
--- old/usr/src/lib/libm/common/C/j0.c	2019-06-06 20:37:50.646132145 +0000
+++ new/usr/src/lib/libm/common/C/j0.c	2019-06-06 20:37:50.663594420 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,30 +45,34 @@
 #include <math.h>
 #include <values.h>
 
-#define	GENERIC double
-static const GENERIC
-zero    = 0.0,
-small	= 1.0e-5,
-tiny	= 1.0e-18,
-one	= 1.0,
-eight   = 8.0,
-invsqrtpi = 5.641895835477562869480794515607725858441e-0001,
-tpi	= 0.636619772367581343075535053490057448;
+#define	GENERIC	double
+
+static const GENERIC zero = 0.0,
+	small = 1.0e-5,
+	tiny = 1.0e-18,
+	one = 1.0,
+	eight = 8.0,
+	invsqrtpi = 5.641895835477562869480794515607725858441e-0001,
+	tpi = 0.636619772367581343075535053490057448;
+
+static GENERIC pzero(GENERIC);
+static GENERIC qzero(GENERIC);
 
-static GENERIC pzero(GENERIC), qzero(GENERIC);
-static const GENERIC r0[4] = {	/* [1.e-5, 1.28] */
+static const GENERIC r0[4] = {		/* [1.e-5, 1.28] */
 	-2.500000000000003622131880894830476755537e-0001,
 	1.095597547334830263234433855932375353303e-0002,
 	-1.819734750463320921799187258987098087697e-0004,
 	9.977001946806131657544212501069893930846e-0007,
 };
-static const GENERIC s0[4] = {	/* [1.e-5, 1.28] */
+
+static const GENERIC s0[4] = {		/* [1.e-5, 1.28] */
 	1.0,
 	1.867609810662950169966782360588199673741e-0002,
 	1.590389206181565490878430827706972074208e-0004,
 	6.520867386742583632375520147714499522721e-0007,
 };
-static const GENERIC r1[9] = {	/* [1.28,8] */
+
+static const GENERIC r1[9] = {		/* [1.28,8] */
 	9.999999999999999942156495584397047660949e-0001,
 	-2.389887722731319130476839836908143731281e-0001,
 	1.293359476138939027791270393439493640570e-0002,
@@ -78,7 +83,8 @@
 	-8.187060730684066824228914775146536139112e-0014,
 	5.422219326959949863954297860723723423842e-0017,
 };
-static const GENERIC s1[9] = {	/* [1.28,8] */
+
+static const GENERIC s1[9] = {		/* [1.28,8] */
 	1.0,
 	1.101122772686807702762104741932076228349e-0002,
 	6.140169310641649223411427764669143978228e-0005,
@@ -91,73 +97,88 @@
 };
 
 GENERIC
-j0(GENERIC x) {
+j0(GENERIC x)
+{
 	GENERIC z, s, c, ss, cc, r, u, v, ox;
 	int i;
 
 	if (isnan(x))
-		return (x*x);	/* + -> * for Cheetah */
+		return (x * x);		/* + -> * for Cheetah */
+
 	ox = x;
 	x = fabs(x);
+
 	if (x > 8.0) {
 		if (!finite(x))
 			return (zero);
+
 		s = sin(x);
 		c = cos(x);
-	/*
-	 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
-	 * where x0 = x-pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (cos(x) + sin(x))
-	 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (sin(x) - cos(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
+		 * where x0 = x-pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (cos(x) + sin(x))
+		 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (sin(x) - cos(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 8.9e307) {	/* x+x may overflow */
-			ss = s-c;
-			cc = s+c;
+			ss = s - c;
+			cc = s + c;
 		} else if (signbit(s) != signbit(c)) {
 			ss = s - c;
-			cc = -cos(x+x)/ss;
+			cc = -cos(x + x) / ss;
 		} else {
 			cc = s + c;
-			ss = -cos(x+x)/cc;
+			ss = -cos(x + x) / cc;
 		}
-	/*
-	 * j0(x) = 1/sqrt(pi) * (P(0,x)*cc - Q(0,x)*ss) / sqrt(x)
-	 * y0(x) = 1/sqrt(pi) * (P(0,x)*ss + Q(0,x)*cc) / sqrt(x)
-	 */
-		if (x > 1.0e40) z = (invsqrtpi*cc)/sqrt(x);
-		else {
-		    u = pzero(x); v = qzero(x);
-		    z = invsqrtpi*(u*cc-v*ss)/sqrt(x);
+
+		/*
+		 * j0(x) = 1/sqrt(pi) * (P(0,x)*cc - Q(0,x)*ss) / sqrt(x)
+		 * y0(x) = 1/sqrt(pi) * (P(0,x)*ss + Q(0,x)*cc) / sqrt(x)
+		 */
+		if (x > 1.0e40) {
+			z = (invsqrtpi * cc) / sqrt(x);
+		} else {
+			u = pzero(x);
+			v = qzero(x);
+			z = invsqrtpi * (u * cc - v * ss) / sqrt(x);
 		}
-	/* force to pass SVR4 even the result is wrong (sign) */
+
+		/* force to pass SVR4 even the result is wrong (sign) */
 		if (x > X_TLOSS)
-		    return (_SVID_libm_err(ox, z, 34));
+			return (_SVID_libm_err(ox, z, 34));
 		else
-		    return (z);
+			return (z);
 	}
+
 	if (x <= small) {
-	    if (x <= tiny)
-			return (one-x);
-	    else
-			return (one-x*x*0.25);
+		if (x <= tiny)
+			return (one - x);
+		else
+			return (one - x * x * 0.25);
 	}
-	z = x*x;
+
+	z = x * x;
+
 	if (x <= 1.28) {
-	    r =  r0[0]+z*(r0[1]+z*(r0[2]+z*r0[3]));
-	    s =  s0[0]+z*(s0[1]+z*(s0[2]+z*s0[3]));
-	    return (one + z*(r/s));
+		r = r0[0] + z * (r0[1] + z * (r0[2] + z * r0[3]));
+		s = s0[0] + z * (s0[1] + z * (s0[2] + z * s0[3]));
+		return (one + z * (r / s));
 	} else {
-	    for (r = r1[8], s = s1[8], i = 7; i >= 0; i--) {
-		r = r*z + r1[i];
-		s = s*z + s1[i];
-	    }
-	    return (r/s);
+		for (r = r1[8], s = s1[8], i = 7; i >= 0; i--) {
+			r = r * z + r1[i];
+			s = s * z + s1[i];
+		}
+
+		return (r / s);
 	}
 }
 
@@ -176,6 +197,7 @@
 	7.124435467408860515265552217131230511455e-0024,
 	-2.709726774636397615328813121715432044771e-0027,
 };
+
 static const GENERIC v0[5] = {
 	1.0,
 	4.678678931512549002587702477349214886475e-0003,
@@ -185,137 +207,152 @@
 };
 
 GENERIC
-y0(GENERIC x) {
+y0(GENERIC x)
+{
 	GENERIC z, /* d, */ s, c, ss, cc, u, v;
 	int i;
 
 	if (isnan(x))
-		return (x*x);	/* + -> * for Cheetah */
+		return (x * x);		/* + -> * for Cheetah */
+
 	if (x <= zero) {
 		if (x == zero)
-		    /* d= -one/(x-x); */
-		    return (_SVID_libm_err(x, x, 8));
+			/* d= -one/(x-x); */
+			return (_SVID_libm_err(x, x, 8));
 		else
-		    /* d = zero/(x-x); */
-		    return (_SVID_libm_err(x, x, 9));
+			/* d = zero/(x-x); */
+			return (_SVID_libm_err(x, x, 9));
 	}
+
 	if (x > 8.0) {
 		if (!finite(x))
 			return (zero);
+
 		s = sin(x);
 		c = cos(x);
-	/*
-	 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
-	 * where x0 = x-pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (cos(x) + sin(x))
-	 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (sin(x) - cos(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
+		 * where x0 = x-pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (cos(x) + sin(x))
+		 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (sin(x) - cos(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 8.9e307) {	/* x+x may overflow */
-			ss = s-c;
-			cc = s+c;
+			ss = s - c;
+			cc = s + c;
 		} else if (signbit(s) != signbit(c)) {
 			ss = s - c;
-			cc = -cos(x+x)/ss;
+			cc = -cos(x + x) / ss;
 		} else {
 			cc = s + c;
-			ss = -cos(x+x)/cc;
+			ss = -cos(x + x) / cc;
 		}
-	/*
-	 * j0(x) = 1/sqrt(pi*x) * (P(0,x)*cc - Q(0,x)*ss)
-	 * y0(x) = 1/sqrt(pi*x) * (P(0,x)*ss + Q(0,x)*cc)
-	 */
+
+		/*
+		 * j0(x) = 1/sqrt(pi*x) * (P(0,x)*cc - Q(0,x)*ss)
+		 * y0(x) = 1/sqrt(pi*x) * (P(0,x)*ss + Q(0,x)*cc)
+		 */
 		if (x > 1.0e40)
-		    z = (invsqrtpi*ss)/sqrt(x);
+			z = (invsqrtpi * ss) / sqrt(x);
 		else
-		    z =  invsqrtpi*(pzero(x)*ss+qzero(x)*cc)/sqrt(x);
+			z = invsqrtpi * (pzero(x) * ss + qzero(x) * cc) /
+			    sqrt(x);
+
 		if (x > X_TLOSS)
-		    return (_SVID_libm_err(x, z, 35));
+			return (_SVID_libm_err(x, z, 35));
 		else
-		    return (z);
-
-	}
-	if (x <= tiny) {
-	    return (u0[0] + tpi*log(x));
+			return (z);
 	}
-	z = x*x;
-	for (u = u0[12], i = 11; i >= 0; i--) u = u*z + u0[i];
-	v = v0[0]+z*(v0[1]+z*(v0[2]+z*(v0[3]+z*v0[4])));
-	return (u/v + tpi*(j0(x)*log(x)));
+
+	if (x <= tiny)
+		return (u0[0] + tpi * log(x));
+
+	z = x * x;
+
+	for (u = u0[12], i = 11; i >= 0; i--)
+		u = u * z + u0[i];
+
+	v = v0[0] + z * (v0[1] + z * (v0[2] + z * (v0[3] + z * v0[4])));
+	return (u / v + tpi * (j0(x) * log(x)));
 }
 
-static const GENERIC pr[7] = {	/* [8 -- inf]  pzero 6550 */
-	.4861344183386052721391238447e5,
-	.1377662549407112278133438945e6,
-	.1222466364088289731869114004e6,
-	.4107070084315176135583353374e5,
-	.5026073801860637125889039915e4,
-	.1783193659125479654541542419e3,
+static const GENERIC pr[7] = {		/* [8 -- inf]  pzero 6550 */
+	.4861344183386052721391238447e5, .1377662549407112278133438945e6,
+	.1222466364088289731869114004e6, .4107070084315176135583353374e5,
+	.5026073801860637125889039915e4, .1783193659125479654541542419e3,
 	.88010344055383421691677564e0,
 };
-static const GENERIC ps[7] = {	/* [8 -- inf] pzero 6550 */
-	.4861344183386052721414037058e5,
-	.1378196632630384670477582699e6,
-	.1223967185341006542748936787e6,
-	.4120150243795353639995862617e5,
-	.5068271181053546392490184353e4,
-	.1829817905472769960535671664e3,
+
+static const GENERIC ps[7] = {		/* [8 -- inf] pzero 6550 */
+	.4861344183386052721414037058e5, .1378196632630384670477582699e6,
+	.1223967185341006542748936787e6, .4120150243795353639995862617e5,
+	.5068271181053546392490184353e4, .1829817905472769960535671664e3,
 	1.0,
 };
-static const GENERIC huge    = 1.0e10;
 
+static const GENERIC huge = 1.0e10;
 static GENERIC
-pzero(GENERIC x) {
+pzero(GENERIC x)
+{
 	GENERIC s, r, t, z;
 	int i;
+
 	if (x > huge)
 		return (one);
-	t = eight/x; z = t*t;
-	r = pr[5]+z*pr[6];
-	s = ps[5]+z;
+
+	t = eight / x;
+	z = t * t;
+	r = pr[5] + z * pr[6];
+	s = ps[5] + z;
+
 	for (i = 4; i >= 0; i--) {
-	    r = r*z + pr[i];
-	    s = s*z + ps[i];
+		r = r * z + pr[i];
+		s = s * z + ps[i];
 	}
-	return (r/s);
+
+	return (r / s);
 }
 
-static const GENERIC qr[7] = {	/* [8 -- inf]  qzero 6950 */
-	-.1731210995701068539185611951e3,
-	-.5522559165936166961235240613e3,
-	-.5604935606637346590614529613e3,
-	-.2200430300226009379477365011e3,
-	-.323869355375648849771296746e2,
-	-.14294979207907956223499258e1,
+static const GENERIC qr[7] = {		/* [8 -- inf]  qzero 6950 */
+	-.1731210995701068539185611951e3, -.5522559165936166961235240613e3,
+	-.5604935606637346590614529613e3, -.2200430300226009379477365011e3,
+	-.323869355375648849771296746e2, -.14294979207907956223499258e1,
 	-.834690374102384988158918e-2,
 };
-static const GENERIC qs[7] = {	/* [8 -- inf] qzero 6950 */
-	.1107975037248683865326709645e5,
-	.3544581680627082674651471873e5,
-	.3619118937918394132179019059e5,
-	.1439895563565398007471485822e5,
-	.2190277023344363955930226234e4,
-	.106695157020407986137501682e3,
+
+static const GENERIC qs[7] = {		/* [8 -- inf] qzero 6950 */
+	.1107975037248683865326709645e5, .3544581680627082674651471873e5,
+	.3619118937918394132179019059e5, .1439895563565398007471485822e5,
+	.2190277023344363955930226234e4, .106695157020407986137501682e3,
 	1.0,
 };
 
 static GENERIC
-qzero(GENERIC x) {
+qzero(GENERIC x)
+{
 	GENERIC s, r, t, z;
 	int i;
+
 	if (x > huge)
-		return (-0.125/x);
-	t = eight/x; z = t*t;
-	r = qr[5]+z*qr[6];
-	s = qs[5]+z;
+		return (-0.125 / x);
+
+	t = eight / x;
+	z = t * t;
+	r = qr[5] + z * qr[6];
+	s = qs[5] + z;
+
 	for (i = 4; i >= 0; i--) {
-	    r = r*z + qr[i];
-	    s = s*z + qs[i];
+		r = r * z + qr[i];
+		s = s * z + qs[i];
 	}
-	return (t*(r/s));
+
+	return (t * (r / s));
 }
--- old/usr/src/lib/libm/common/C/j1.c	2019-06-06 20:37:51.155194065 +0000
+++ new/usr/src/lib/libm/common/C/j1.c	2019-06-06 20:37:51.173622186 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,28 +45,32 @@
 #include <math.h>
 #include <values.h>
 
-#define	GENERIC double
-static const GENERIC
-zero    = 0.0,
-small	= 1.0e-5,
-tiny 	= 1.0e-20,
-one	= 1.0,
-invsqrtpi = 5.641895835477562869480794515607725858441e-0001,
-tpi	= 0.636619772367581343075535053490057448;
+#define	GENERIC	double
+
+static const GENERIC zero = 0.0,
+	small = 1.0e-5,
+	tiny = 1.0e-20,
+	one = 1.0,
+	invsqrtpi = 5.641895835477562869480794515607725858441e-0001,
+	tpi = 0.636619772367581343075535053490057448;
+
+static GENERIC pone(GENERIC);
+static GENERIC qone(GENERIC);
 
-static GENERIC pone(GENERIC), qone(GENERIC);
 static const GENERIC r0[4] = {
 	-6.250000000000002203053200981413218949548e-0002,
 	1.600998455640072901321605101981501263762e-0003,
 	-1.963888815948313758552511884390162864930e-0005,
 	8.263917341093549759781339713418201620998e-0008,
 };
+
 static const GENERIC s0[7] = {
 	1.0e0,
 	1.605069137643004242395356851797873766927e-0002,
 	1.149454623251299996428500249509098499383e-0004,
 	3.849701673735260970379681807910852327825e-0007,
 };
+
 static const GENERIC r1[12] = {
 	4.999999999999999995517408894340485471724e-0001,
 	-6.003825028120475684835384519945468075423e-0002,
@@ -80,6 +85,7 @@
 	8.520158355824819796968771418801019930585e-0023,
 	-3.458159926081163274483854614601091361424e-0026,
 };
+
 static const GENERIC s1[5] = {
 	1.0e0,
 	4.923499437590484879081138588998986303306e-0003,
@@ -89,82 +95,103 @@
 };
 
 GENERIC
-j1(GENERIC x) {
+j1(GENERIC x)
+{
 	GENERIC z, d, s, c, ss, cc, r;
 	int i, sgn;
 
 	if (!finite(x))
-		return (one/x);
+		return (one / x);
+
 	sgn = signbit(x);
 	x = fabs(x);
+
 	if (x > 8.00) {
 		s = sin(x);
 		c = cos(x);
-	/*
-	 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
-	 * where x0 = x-3pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
-	 *			=  1/sqrt(2) * (sin(x) - cos(x))
-	 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
-	 *			= -1/sqrt(2) * (cos(x) + sin(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
+		 * where x0 = x-3pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
+		 *			=  1/sqrt(2) * (sin(x) - cos(x))
+		 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
+		 *			= -1/sqrt(2) * (cos(x) + sin(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 8.9e307) {	/* x+x may overflow */
-			ss = -s-c;
-			cc =  s-c;
+			ss = -s - c;
+			cc = s - c;
 		} else if (signbit(s) != signbit(c)) {
 			cc = s - c;
-			ss = cos(x+x)/cc;
+			ss = cos(x + x) / cc;
 		} else {
-			ss = -s-c;
-			cc = cos(x+x)/ss;
+			ss = -s - c;
+			cc = cos(x + x) / ss;
 		}
-	/*
-	 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
-	 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
-	 */
+
+		/*
+		 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
+		 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
+		 */
 		if (x > 1.0e40)
-		    d = (invsqrtpi*cc)/sqrt(x);
+			d = (invsqrtpi * cc) / sqrt(x);
 		else
-			d =  invsqrtpi*(pone(x)*cc-qone(x)*ss)/sqrt(x);
+			d = invsqrtpi * (pone(x) * cc - qone(x) * ss) / sqrt(x);
 
 		if (x > X_TLOSS) {
-		    if (sgn != 0) { d = -d; x = -x; }
+			if (sgn != 0) {
+				d = -d;
+				x = -x;
+			}
+
 			return (_SVID_libm_err(x, d, 36));
-		} else
-		    if (sgn == 0)
-				return (d);
-			else
-				return (-d);
+		} else if (sgn == 0) {
+			return (d);
+		} else {
+			return (-d);
+		}
 	}
+
 	if (x <= small) {
 		if (x <= tiny)
-			d = 0.5*x;
+			d = 0.5 * x;
 		else
-			d =  x*(0.5-x*x*0.125);
+			d = x * (0.5 - x * x * 0.125);
+
 		if (sgn == 0)
 			return (d);
 		else
 			return (-d);
 	}
-	z = x*x;
+
+	z = x * x;
+
 	if (x < 1.28) {
-	    r = r0[3];
-	    s = s0[3];
-	    for (i = 2; i >= 0; i--) {
-		r = r*z + r0[i];
-		s = s*z + s0[i];
-	    }
-	    d = x*0.5+x*(z*(r/s));
+		r = r0[3];
+		s = s0[3];
+
+		for (i = 2; i >= 0; i--) {
+			r = r * z + r0[i];
+			s = s * z + s0[i];
+		}
+
+		d = x * 0.5 + x * (z * (r / s));
 	} else {
-	    r = r1[11];
-	    for (i = 10; i >= 0; i--) r = r*z + r1[i];
-	    s = s1[0]+z*(s1[1]+z*(s1[2]+z*(s1[3]+z*s1[4])));
-	    d = x*(r/s);
+		r = r1[11];
+
+		for (i = 10; i >= 0; i--)
+			r = r * z + r1[i];
+
+		s = s1[0] + z * (s1[1] + z * (s1[2] + z * (s1[3] + z * s1[4])));
+		d = x * (r / s);
 	}
+
 	if (sgn == 0)
 		return (d);
 	else
@@ -177,6 +204,7 @@
 	-1.626975871565393656845930125424683008677e-0003,
 	1.359657517926394132692884168082224258360e-0005,
 };
+
 static const GENERIC v0[5] = {
 	1.0e0,
 	2.565807214838390835108224713630901653793e-0002,
@@ -184,6 +212,7 @@
 	2.840368571306070719539936935220728843177e-0006,
 	1.396387402048998277638900944415752207592e-0008,
 };
+
 static const GENERIC u1[12] = {
 	-1.960570906462389473336339614647555351626e-0001,
 	5.336268030335074494231369159933012844735e-0002,
@@ -198,6 +227,7 @@
 	-1.761371948595104156753045457888272716340e-0022,
 	7.352828391941157905175042420249225115816e-0026,
 };
+
 static const GENERIC v1[5] = {
 	1.0e0,
 	5.029187436727947764916247076102283399442e-0003,
@@ -206,146 +236,161 @@
 	6.579416271766610825192542295821308730206e-0012,
 };
 
-
 GENERIC
-y1(GENERIC x) {
+y1(GENERIC x)
+{
 	GENERIC z, d, s, c, ss, cc, u, v;
 	int i;
 
 	if (isnan(x))
-		return (x*x);	/* + -> * for Cheetah */
+		return (x * x);		/* + -> * for Cheetah */
+
 	if (x <= zero) {
 		if (x == zero)
-		    /* return -one/zero;  */
-		    return (_SVID_libm_err(x, x, 10));
+			/* return -one/zero;  */
+			return (_SVID_libm_err(x, x, 10));
 		else
-		    /* return zero/zero; */
-		    return (_SVID_libm_err(x, x, 11));
+			/* return zero/zero; */
+			return (_SVID_libm_err(x, x, 11));
 	}
+
 	if (x > 8.0) {
 		if (!finite(x))
 			return (zero);
+
 		s = sin(x);
 		c = cos(x);
-	/*
-	 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
-	 * where x0 = x-3pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
-	 *			=  1/sqrt(2) * (sin(x) - cos(x))
-	 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
-	 *			= -1/sqrt(2) * (cos(x) + sin(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
+		 * where x0 = x-3pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
+		 *			=  1/sqrt(2) * (sin(x) - cos(x))
+		 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
+		 *			= -1/sqrt(2) * (cos(x) + sin(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 8.9e307) {	/* x+x may overflow */
-			ss = -s-c;
-			cc =  s-c;
+			ss = -s - c;
+			cc = s - c;
 		} else if (signbit(s) != signbit(c)) {
 			cc = s - c;
-			ss = cos(x+x)/cc;
+			ss = cos(x + x) / cc;
 		} else {
-			ss = -s-c;
-			cc = cos(x+x)/ss;
+			ss = -s - c;
+			cc = cos(x + x) / ss;
 		}
-	/*
-	 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
-	 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
-	 */
+
+		/*
+		 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
+		 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
+		 */
 		if (x > 1.0e91)
-		    d =  (invsqrtpi*ss)/sqrt(x);
+			d = (invsqrtpi * ss) / sqrt(x);
 		else
-			d = invsqrtpi*(pone(x)*ss+qone(x)*cc)/sqrt(x);
+			d = invsqrtpi * (pone(x) * ss + qone(x) * cc) / sqrt(x);
 
 		if (x > X_TLOSS)
 			return (_SVID_libm_err(x, d, 37));
 		else
 			return (d);
 	}
-		if (x <= tiny) {
-			return (-tpi/x);
-		}
-	z = x*x;
+
+	if (x <= tiny)
+		return (-tpi / x);
+
+	z = x * x;
+
 	if (x < 1.28) {
-	    u = u0[3]; v = v0[3]+z*v0[4];
-	    for (i = 2; i >= 0; i--) {
-		u = u*z + u0[i];
-		v = v*z + v0[i];
-	    }
+		u = u0[3];
+		v = v0[3] + z * v0[4];
+
+		for (i = 2; i >= 0; i--) {
+			u = u * z + u0[i];
+			v = v * z + v0[i];
+		}
 	} else {
-	    for (u = u1[11], i = 10; i >= 0; i--) u = u*z+u1[i];
-	    v = v1[0]+z*(v1[1]+z*(v1[2]+z*(v1[3]+z*v1[4])));
+		for (u = u1[11], i = 10; i >= 0; i--)
+			u = u * z + u1[i];
+
+		v = v1[0] + z * (v1[1] + z * (v1[2] + z * (v1[3] + z * v1[4])));
 	}
-	return (x*(u/v) + tpi*(j1(x)*log(x)-one/x));
+
+	return (x * (u / v) + tpi * (j1(x) * log(x) - one / x));
 }
 
 static const GENERIC pr0[6] = {
-	-.4435757816794127857114720794e7,
-	-.9942246505077641195658377899e7,
-	-.6603373248364939109255245434e7,
-	-.1523529351181137383255105722e7,
-	-.1098240554345934672737413139e6,
-	-.1611616644324610116477412898e4,
+	-.4435757816794127857114720794e7, -.9942246505077641195658377899e7,
+	-.6603373248364939109255245434e7, -.1523529351181137383255105722e7,
+	-.1098240554345934672737413139e6, -.1611616644324610116477412898e4,
 };
+
 static const GENERIC ps0[6] = {
-	-.4435757816794127856828016962e7,
-	-.9934124389934585658967556309e7,
-	-.6585339479723087072826915069e7,
-	-.1511809506634160881644546358e7,
-	-.1072638599110382011903063867e6,
-	-.1455009440190496182453565068e4,
+	-.4435757816794127856828016962e7, -.9934124389934585658967556309e7,
+	-.6585339479723087072826915069e7, -.1511809506634160881644546358e7,
+	-.1072638599110382011903063867e6, -.1455009440190496182453565068e4,
 };
-static const GENERIC huge    = 1.0e10;
 
+static const GENERIC huge = 1.0e10;
 static GENERIC
-pone(GENERIC x) {
+pone(GENERIC x)
+{
 	GENERIC s, r, t, z;
 	int i;
-		/* assume x > 8 */
+
+	/* assume x > 8 */
 	if (x > huge)
 		return (one);
 
-	t = 8.0/x; z = t*t;
-	r = pr0[5]; s = ps0[5]+z;
+	t = 8.0 / x;
+	z = t * t;
+	r = pr0[5];
+	s = ps0[5] + z;
+
 	for (i = 4; i >= 0; i--) {
-		r = z*r + pr0[i];
-		s = z*s + ps0[i];
+		r = z * r + pr0[i];
+		s = z * s + ps0[i];
 	}
-	return (r/s);
-}
 
+	return (r / s);
+}
 
 static const GENERIC qr0[6] = {
-	0.3322091340985722351859704442e5,
-	0.8514516067533570196555001171e5,
-	0.6617883658127083517939992166e5,
-	0.1849426287322386679652009819e5,
-	0.1706375429020768002061283546e4,
-	0.3526513384663603218592175580e2,
+	0.3322091340985722351859704442e5, 0.8514516067533570196555001171e5,
+	0.6617883658127083517939992166e5, 0.1849426287322386679652009819e5,
+	0.1706375429020768002061283546e4, 0.3526513384663603218592175580e2,
 };
+
 static const GENERIC qs0[6] = {
-	0.7087128194102874357377502472e6,
-	0.1819458042243997298924553839e7,
-	0.1419460669603720892855755253e7,
-	0.4002944358226697511708610813e6,
-	0.3789022974577220264142952256e5,
-	0.8638367769604990967475517183e3,
+	0.7087128194102874357377502472e6, 0.1819458042243997298924553839e7,
+	0.1419460669603720892855755253e7, 0.4002944358226697511708610813e6,
+	0.3789022974577220264142952256e5, 0.8638367769604990967475517183e3,
 };
 
 static GENERIC
-qone(GENERIC x) {
+qone(GENERIC x)
+{
 	GENERIC s, r, t, z;
 	int i;
+
 	if (x > huge)
-		return (0.375/x);
+		return (0.375 / x);
+
+	t = 8.0 / x;
+	z = t * t;
+	/* assume x > 8 */
+	r = qr0[5];
+	s = qs0[5] + z;
 
-	t = 8.0/x; z = t*t;
-		/* assume x > 8 */
-	r = qr0[5]; s = qs0[5]+z;
 	for (i = 4; i >= 0; i--) {
-		r = z*r + qr0[i];
-		s = z*s + qs0[i];
+		r = z * r + qr0[i];
+		s = z * s + qs0[i];
 	}
-	return (t*(r/s));
+
+	return (t * (r / s));
 }
--- old/usr/src/lib/libm/common/C/jn.c	2019-06-06 20:37:51.673635562 +0000
+++ new/usr/src/lib/libm/common/C/jn.c	2019-06-06 20:37:51.693020674 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -56,17 +57,17 @@
  */
 
 #include "libm.h"
-#include <float.h>	/* DBL_MIN */
-#include <values.h>	/* X_TLOSS */
-#include "xpg6.h"	/* __xpg6 */
+#include <float.h>			/* DBL_MIN */
+#include <values.h>			/* X_TLOSS */
+#include "xpg6.h"			/* __xpg6 */
 
-#define	GENERIC double
+#define	GENERIC	double
 
 static const GENERIC
 	invsqrtpi = 5.641895835477562869480794515607725858441e-0001,
-	two	= 2.0,
-	zero	= 0.0,
-	one	= 1.0;
+	two = 2.0,
+	zero = 0.0,
+	one = 1.0;
 
 GENERIC
 jn(int n, GENERIC x)
@@ -86,75 +87,87 @@
 		n = -n;
 		x = -x;
 	}
+
 	if (isnan(x))
-		return (x*x);	/* + -> * for Cheetah */
-	if (!((int)_lib_version == libm_ieee ||
-	    (__xpg6 & _C99SUSv3_math_errexcept) != 0)) {
+		return (x * x);		/* + -> * for Cheetah */
+
+	if (!((int)_lib_version == libm_ieee || (__xpg6 &
+	    _C99SUSv3_math_errexcept) != 0)) {
 		if (fabs(x) > X_TLOSS)
 			return (_SVID_libm_err(on, ox, 38));
 	}
+
 	if (n == 0)
 		return (j0(x));
+
 	if (n == 1)
 		return (j1(x));
-	if ((n&1) == 0)
-		sgn = 0;			/* even n */
+
+	if ((n & 1) == 0)
+		sgn = 0;		/* even n */
 	else
 		sgn = signbit(x);	/* old n  */
+
 	x = fabs(x);
-	if (x == zero||!finite(x)) b = zero;
-	else if ((GENERIC)n <= x) {
-					/*
-					 * Safe to use
-					 *  J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
-					 */
+
+	if (x == zero || !finite(x)) {
+		b = zero;
+	} else if ((GENERIC)n <= x) {
+		/*
+		 * Safe to use
+		 *  J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
+		 */
 		if (x > 1.0e91) {
-				/*
-				 * x >> n**2
-				 *    Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *   Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *   Let s=sin(x), c=cos(x),
-				 *	xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
-				 *
-				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
-				 *	----------------------------------
-				 *	   0	 s-c		 c+s
-				 *	   1	-s-c		-c+s
-				 *	   2	-s+c		-c-s
-				 *	   3	 s+c		 c-s
-				 */
-			switch (n&3) {
+			/*
+			 * x >> n**2
+			 *    Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+			 *   Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+			 *   Let s=sin(x), c=cos(x),
+			 *	xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
+			 *
+			 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
+			 *	----------------------------------
+			 *	   0	 s-c		 c+s
+			 *	   1	-s-c		-c+s
+			 *	   2	-s+c		-c-s
+			 *	   3	 s+c		 c-s
+			 */
+			switch (n & 3) {
 			case 0:
-				temp =  cos(x)+sin(x);
+				temp = cos(x) + sin(x);
 				break;
 			case 1:
-				temp = -cos(x)+sin(x);
+				temp = -cos(x) + sin(x);
 				break;
 			case 2:
-				temp = -cos(x)-sin(x);
+				temp = -cos(x) - sin(x);
 				break;
 			case 3:
-				temp =  cos(x)-sin(x);
+				temp = cos(x) - sin(x);
 				break;
 			}
-			b = invsqrtpi*temp/sqrt(x);
+
+			b = invsqrtpi * temp / sqrt(x);
 		} else {
 			a = j0(x);
 			b = j1(x);
+
 			for (i = 1; i < n; i++) {
 				temp = b;
 				/* avoid underflow */
-				b = b*((GENERIC)(i+i)/x) - a;
+				b = b * ((GENERIC)(i + i) / x) - a;
 				a = temp;
 			}
 		}
 	} else {
-		if (x < 1e-9) {	/* use J(n,x) = 1/n!*(x/2)^n */
-			b = pow(0.5*x, (GENERIC) n);
+		if (x < 1e-9) {		/* use J(n,x) = 1/n!*(x/2)^n */
+			b = pow(0.5 * x, (GENERIC)n);
+
 			if (b != zero) {
 				for (a = one, i = 1; i <= n; i++)
 					a *= (GENERIC)i;
-				b = b/a;
+
+				b = b / a;
 			}
 		} else {
 			/*
@@ -190,25 +203,31 @@
 			GENERIC t, v;
 			double q0, q1, h, tmp;
 			int k, m;
-			w  = (n+n)/(double)x;
-			h = 2.0/(double)x;
+
+			w = (n + n) / (double)x;
+			h = 2.0 / (double)x;
 			q0 = w;
 			z = w + h;
-			q1 = w*z - 1.0;
+			q1 = w * z - 1.0;
 			k = 1;
 
 			while (q1 < 1.0e9) {
 				k += 1;
 				z += h;
-				tmp = z*q1 - q0;
+				tmp = z * q1 - q0;
 				q0 = q1;
 				q1 = tmp;
 			}
-			m = n+n;
-			for (t = zero, i = 2*(n+k); i >= m; i -= 2)
-				t = one/(i/x-t);
+
+			m = n + n;
+
+			for (t = zero, i = 2 * (n + k); i >= m; i -= 2)
+				t = one / (i / x - t);
+
 			a = t;
 			b = one;
+
+			/* BEGIN CSTYLED */
 			/*
 			 * estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
 			 * hence, if n*(log(2n/x)) > ...
@@ -221,30 +240,35 @@
 			 * then recurrent value may overflow and the result is
 			 * likely underflow to zero
 			 */
+			/* END CSTYLED */
 			tmp = n;
-			v = two/x;
-			tmp = tmp*log(fabs(v*tmp));
+			v = two / x;
+			tmp = tmp * log(fabs(v * tmp));
+
 			if (tmp < 7.09782712893383973096e+02) {
-				for (i = n-1; i > 0; i--) {
+				for (i = n - 1; i > 0; i--) {
 					temp = b;
-					b = ((i+i)/x)*b - a;
+					b = ((i + i) / x) * b - a;
 					a = temp;
 				}
 			} else {
-				for (i = n-1; i > 0; i--) {
+				for (i = n - 1; i > 0; i--) {
 					temp = b;
-					b = ((i+i)/x)*b - a;
+					b = ((i + i) / x) * b - a;
 					a = temp;
+
 					if (b > 1e100) {
 						a /= b;
 						t /= b;
-						b  = 1.0;
+						b = 1.0;
 					}
 				}
 			}
-			b = (t*j0(x)/b);
+
+			b = (t * j0(x) / b);
 		}
 	}
+
 	if (sgn != 0)
 		return (-b);
 	else
@@ -260,8 +284,10 @@
 
 	ox = x;
 	on = (GENERIC)n;
+
 	if (isnan(x))
-		return (x*x);	/* + -> * for Cheetah */
+		return (x * x);		/* + -> * for Cheetah */
+
 	if (x <= zero) {
 		if (x == zero) {
 			/* return -one/zero; */
@@ -271,68 +297,81 @@
 			return (_SVID_libm_err((GENERIC)n, x, 13));
 		}
 	}
-	if (!((int)_lib_version == libm_ieee ||
-	    (__xpg6 & _C99SUSv3_math_errexcept) != 0)) {
+
+	if (!((int)_lib_version == libm_ieee || (__xpg6 &
+	    _C99SUSv3_math_errexcept) != 0)) {
 		if (x > X_TLOSS)
 			return (_SVID_libm_err(on, ox, 39));
 	}
+
 	sign = 1;
+
 	if (n < 0) {
 		n = -n;
-		if ((n&1) == 1) sign = -1;
+
+		if ((n & 1) == 1)
+			sign = -1;
 	}
+
 	if (n == 0)
 		return (y0(x));
+
 	if (n == 1)
-		return (sign*y1(x));
+		return (sign * y1(x));
+
 	if (!finite(x))
 		return (zero);
 
 	if (x > 1.0e91) {
-				/*
-				 * x >> n**2
-				 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *  Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *  Let s = sin(x), c = cos(x),
-				 *  xn = x-(2n+1)*pi/4, sqt2 = sqrt(2), then
-				 *
-				 *    n	sin(xn)*sqt2	cos(xn)*sqt2
-				 *	----------------------------------
-				 *	 0	 s-c		 c+s
-				 *	 1	-s-c		-c+s
-				 *	 2	-s+c		-c-s
-				 *	 3	 s+c		 c-s
-				 */
-		switch (n&3) {
+		/*
+		 * x >> n**2
+		 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+		 *  Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+		 *  Let s = sin(x), c = cos(x),
+		 *  xn = x-(2n+1)*pi/4, sqt2 = sqrt(2), then
+		 *
+		 *    n	sin(xn)*sqt2	cos(xn)*sqt2
+		 *	----------------------------------
+		 *	 0	 s-c		 c+s
+		 *	 1	-s-c		-c+s
+		 *	 2	-s+c		-c-s
+		 *	 3	 s+c		 c-s
+		 */
+		switch (n & 3) {
 		case 0:
-			temp =  sin(x)-cos(x);
+			temp = sin(x) - cos(x);
 			break;
 		case 1:
-			temp = -sin(x)-cos(x);
+			temp = -sin(x) - cos(x);
 			break;
 		case 2:
-			temp = -sin(x)+cos(x);
+			temp = -sin(x) + cos(x);
 			break;
 		case 3:
-			temp =  sin(x)+cos(x);
+			temp = sin(x) + cos(x);
 			break;
 		}
-		b = invsqrtpi*temp/sqrt(x);
+
+		b = invsqrtpi * temp / sqrt(x);
 	} else {
 		a = y0(x);
 		b = y1(x);
+
 		/*
 		 * fix 1262058 and take care of non-default rounding
 		 */
 		for (i = 1; i < n; i++) {
 			temp = b;
-			b *= (GENERIC) (i + i) / x;
+			b *= (GENERIC)(i + i) / x;
+
 			if (b <= -DBL_MAX)
 				break;
+
 			b -= a;
 			a = temp;
 		}
 	}
+
 	if (sign > 0)
 		return (b);
 	else
--- old/usr/src/lib/libm/common/C/lgamma.c	2019-06-06 20:37:52.197253868 +0000
+++ new/usr/src/lib/libm/common/C/lgamma.c	2019-06-06 20:37:52.215236902 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,20 +35,24 @@
 extern int signgam;
 
 double
-lgamma(double x) {
-	double	g;
+lgamma(double x)
+{
+	double g;
 
 	if (!finite(x))
 		return (x * x);
 
 	g = rint(x);
+
 	if (x == g && x <= 0.0) {
 		signgam = 1;
 		return (_SVID_libm_err(x, x, 15));
 	}
 
 	g = __k_lgamma(x, &signgam);
+
 	if (!finite(g))
-	    g = _SVID_libm_err(x, x, 14);
+		g = _SVID_libm_err(x, x, 14);
+
 	return (g);
 }
--- old/usr/src/lib/libm/common/C/lgamma_r.c	2019-06-06 20:37:52.685663413 +0000
+++ new/usr/src/lib/libm/common/C/lgamma_r.c	2019-06-06 20:37:52.703075258 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,20 +33,24 @@
 #include "libm.h"
 
 double
-lgamma_r(double x, int *signgamp) {
-	double	g;
+lgamma_r(double x, int *signgamp)
+{
+	double g;
 
 	if (isnan(x))
 		return (x * x);
 
 	g = rint(x);
+
 	if (x == g && x <= 0.0) {
 		*signgamp = 1;
 		return (_SVID_libm_err(x, x, 15));
 	}
 
 	g = __k_lgamma(x, signgamp);
+
 	if (!finite(g))
-	    g = _SVID_libm_err(x, x, 14);
+		g = _SVID_libm_err(x, x, 14);
+
 	return (g);
 }
--- old/usr/src/lib/libm/common/C/libm.h	2019-06-06 20:37:53.155878544 +0000
+++ new/usr/src/lib/libm/common/C/libm.h	2019-06-06 20:37:53.172664423 +0000
@@ -27,7 +27,7 @@
  */
 
 #ifndef	_LIBM_H
-#define	_LIBM_H
+#define		_LIBM_H
 
 #include <sys/isa_defs.h>
 
@@ -43,21 +43,20 @@
 
 #include <sys/asm_linkage.h>
 
-#define	NAME(x) x
-#define	TEXT	.section	".text"
-#define	DATA	.section	".data"
-#define	RO_DATA	.section	".rodata"
-#define	IDENT(x)	.ident	x
+#define		NAME(x) x
+#define		TEXT	.section	".text"
+#define		DATA	.section	".data"
+#define		RO_DATA	.section	".rodata"
+#define		IDENT(x)	.ident	x
 
 #if defined(__sparc)
-
-#define	LIBM_ANSI_PRAGMA_WEAK(sym,stype) \
+#define		LIBM_ANSI_PRAGMA_WEAK(sym,stype) \
 	.weak __/**/sym;		 \
 	.type __/**/sym,#stype;		 \
 __/**/sym	= sym
 
 #ifndef SET_FILE
-#define	SET_FILE(x) \
+#define		SET_FILE(x) \
 	.file	x
 #endif	/* !defined(SET_FILE) */
 
@@ -65,7 +64,7 @@
 /*
  * One should *never* pass o7 to PIC_SETUP.
  */
-#define	PIC_SETUP(via) \
+#define		PIC_SETUP(via) \
 9:	call	8f; \
 	sethi	%hi(NAME(_GLOBAL_OFFSET_TABLE_)-(9b-.)),%via; \
 8:	or	%via,%lo(NAME(_GLOBAL_OFFSET_TABLE_)-(9b-.)),%via; \
@@ -73,7 +72,7 @@
 /*
  * Must save/restore %o7 in leaf routines; may *not* use jmpl!
  */
-#define	PIC_LEAF_SETUP(via) \
+#define		PIC_LEAF_SETUP(via) \
 	or	%g0,%o7,%g1; \
 9:	call	8f; \
 	sethi	%hi(NAME(_GLOBAL_OFFSET_TABLE_)-(9b-.)),%via; \
@@ -81,20 +80,20 @@
 	add	%via,%o7,%via; \
 	or	%g0,%g1,%o7
 #ifdef __sparcv9
-#define	PIC_SET(via,sym,dst)	ldx	[%via+sym],%dst
+#define		PIC_SET(via,sym,dst)	ldx	[%via+sym],%dst
 #else	/* defined(__sparcv9) */
-#define	PIC_SET(via,sym,dst)	ld	[%via+sym],%dst
+#define		PIC_SET(via,sym,dst)	ld	[%via+sym],%dst
 #endif	/* defined(__sparcv9) */
 #else	/* defined(PIC) */
-#define	PIC_SETUP(via)
-#define	PIC_LEAF_SETUP(via)
+#define		PIC_SETUP(via)
+#define		PIC_LEAF_SETUP(via)
 #ifdef __sparcv9
 /*
  * g1 is used as scratch register in V9 mode
  */
-#define	PIC_SET(via,sym,dst)	setx	sym,%g1,%dst
+#define		PIC_SET(via,sym,dst)	setx	sym,%g1,%dst
 #else	/* defined(__sparcv9) */
-#define	PIC_SET(via,sym,dst)	set	sym,%dst
+#define		PIC_SET(via,sym,dst)	set	sym,%dst
 #endif	/* defined(__sparcv9) */
 #endif	/* defined(PIC) */
 
@@ -102,13 +101,12 @@
  * Workaround for 4337025: MCOUNT in asm_linkage.h does not support __sparcv9
  */
 #if defined(PROF) && defined(__sparcv9)
-
 #undef MCOUNT_SIZE
 #undef MCOUNT
 
 #if !defined(PIC)
-#define	MCOUNT_SIZE	(9*4)	/* 9 instructions */
-#define	MCOUNT(x) \
+#define		MCOUNT_SIZE	(9*4)	/* 9 instructions */
+#define		MCOUNT(x) \
 	save	%sp, -SA(MINFRAME), %sp; \
 	sethi	%hh(.L_/**/x/**/1), %o0; \
 	sethi	%lm(.L_/**/x/**/1), %o1; \
@@ -120,8 +118,8 @@
 	restore; \
 	.common .L_/**/x/**/1, 8, 8
 #elif defined(PIC32)
-#define	MCOUNT_SIZE	(10*4)	/* 10 instructions */
-#define	MCOUNT(x) \
+#define		MCOUNT_SIZE	(10*4)	/* 10 instructions */
+#define		MCOUNT(x) \
 	save	%sp,-SA(MINFRAME),%sp; \
 1:	call	.+8; \
 	sethi	%hi(_GLOBAL_OFFSET_TABLE_-(1b-.)),%o0; \
@@ -134,8 +132,8 @@
 	restore; \
 	.common .L_/**/x/**/1,8,8
 #else	/* PIC13 */
-#define	MCOUNT_SIZE	(8*4)	/* 8 instructions */
-#define	MCOUNT(x) \
+#define		MCOUNT_SIZE	(8*4)	/* 8 instructions */
+#define		MCOUNT(x) \
 	save	%sp,-SA(MINFRAME),%sp; \
 1:	call	.+8; \
 	sethi	%hi(_GLOBAL_OFFSET_TABLE_-(1b-.)),%o0; \
@@ -147,54 +145,50 @@
 	.common .L_/**/x/**/1,8,8
 #endif	/* !defined(PIC) */
 #endif /* defined(PROF) && defined(__sparcv9) */
-
 #elif defined(__x86)
-
-#define	LIBM_ANSI_PRAGMA_WEAK(sym,stype) \
+#define		LIBM_ANSI_PRAGMA_WEAK(sym,stype) \
 	.weak __/**/sym;		 \
 	.type __/**/sym,@stype;		 \
 __/**/sym	= sym
 
 #ifdef PIC
 #if defined(__amd64)
-#define	PIC_SETUP(x)
-#define	PIC_WRAPUP
-#define	PIC_F(x)	x@PLT
-#define	PIC_G(x)	x@GOTPCREL(%rip)
-#define	PIC_L(x)	x(%rip)
-#define	PIC_G_LOAD(insn,sym,dst) \
+#define		PIC_SETUP(x)
+#define		PIC_WRAPUP
+#define		PIC_F(x)	x@PLT
+#define		PIC_G(x)	x@GOTPCREL(%rip)
+#define		PIC_L(x)	x(%rip)
+#define		PIC_G_LOAD(insn,sym,dst) \
 	movq	PIC_G(sym),%dst; \
 	insn	(%dst),%dst
 #else
-#define	PIC_SETUP(label) \
+#define		PIC_SETUP(label) \
 	pushl	%ebx; \
 	call	.label; \
 .label:	popl	%ebx; \
 	addl	$_GLOBAL_OFFSET_TABLE_+[.-.label],%ebx
-#define	PIC_WRAPUP	popl	%ebx
-#define	PIC_F(x)	x@PLT
-#define	PIC_G(x)	x@GOT(%ebx)
-#define	PIC_L(x)	x@GOTOFF(%ebx)
-#define	PIC_G_LOAD(insn,sym,dst) \
+#define		PIC_WRAPUP	popl	%ebx
+#define		PIC_F(x)	x@PLT
+#define		PIC_G(x)	x@GOT(%ebx)
+#define		PIC_L(x)	x@GOTOFF(%ebx)
+#define		PIC_G_LOAD(insn,sym,dst) \
 	mov	PIC_G(sym),%dst; \
 	insn	(%dst),%dst
 #endif
 #else	/* defined(PIC) */
-#define	PIC_SETUP(x)
-#define	PIC_WRAPUP
-#define	PIC_F(x)	x
-#define	PIC_G(x)	x
-#define	PIC_L(x)	x
-#define	PIC_G_LOAD(insn,sym,dst)	insn	sym,%dst
+#define		PIC_SETUP(x)
+#define		PIC_WRAPUP
+#define		PIC_F(x)	x
+#define		PIC_G(x)	x
+#define		PIC_L(x)	x
+#define		PIC_G_LOAD(insn,sym,dst)	insn	sym,%dst
 #endif	/* defined(PIC) */
-
 #else
 #error Unknown architecture
 #endif
 
 /* END CSTYLED */
 #else	/* defined(_ASM) */
-
 #include "libm_macros.h"
 #include "libm_protos.h"
 #include "libm_inlines.h"
@@ -202,7 +196,5 @@
 #if defined(__SUNPRO_C)
 #include <sunmath.h>
 #endif
-
 #endif	/* defined(_ASM) */
-
 #endif	/* _LIBM_H */
--- old/usr/src/lib/libm/common/C/libm_macros.h	2019-06-06 20:37:53.601553879 +0000
+++ new/usr/src/lib/libm/common/C/libm_macros.h	2019-06-06 20:37:53.618119401 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,17 +34,14 @@
 #include <sys/isa_defs.h>
 
 #if defined(__sparc)
-
 #define	HIWORD		0
 #define	LOWORD		1
 #define	HIXWORD		0		/* index of int containing exponent */
 #define	XSGNMSK		0x80000000	/* exponent bit mask within the int */
 #define	XBIASED_EXP(x)	((((int *)&x)[HIXWORD] & ~0x80000000) >> 16)
 #define	ISZEROL(x)	(((((int *)&x)[0] & ~XSGNMSK) | ((int *)&x)[1] | \
-				((int *)&x)[2] | ((int *)&x)[3]) == 0)
-
+	((int *)&x)[2] | ((int *)&x)[3]) == 0)
 #elif defined(__x86)
-
 #define	HIWORD		1
 #define	LOWORD		0
 #define	HIXWORD		2
@@ -58,22 +57,20 @@
  * x86 extended double precision value ("E"); the low-order bits
  * in the 12-byte quantity are left intact
  */
-#define	ITOX(I, E)       \
-		E[2] = 0xffff & ((I) >> 16); \
-		E[1] = (((I) & 0x7fff0000) == 0)? \
-		    (E[1] & 0x7fff) | (0x7fff8000 & ((I) << 15)) :\
-		    0x80000000 | (E[1] & 0x7fff) | (0x7fff8000 & ((I) << 15))
+#define	ITOX(I, E) \
+	E[2] = 0xffff & ((I) >> 16); \
+	E[1] = (((I) & 0x7fff0000) == 0) ? (E[1] & 0x7fff) | (0x7fff8000 & \
+	((I) << 15)) : 0x80000000 | (E[1] & 0x7fff) | (0x7fff8000 & ((I) << \
+	15))
 
 /*
  * "convert" the sign, exponent, and high-order bits of an x86
  * extended double precision value ("E") to the high-order 32 bits
  * of a SPARC quad precision value ("I")
  */
-#define	XTOI(E, I)	\
-		I = ((E[2]<<16) | (0xffff & (E[1]>>15)))
-
+#define	XTOI(E, I) \
+	I = ((E[2] << 16) | (0xffff & (E[1] >> 15)))
 #else
 #error Unknown architecture
 #endif
-
-#endif	/* _LIBM_MACROS_H */
+#endif /* _LIBM_MACROS_H */
--- old/usr/src/lib/libm/common/C/libm_protos.h	2019-06-06 20:37:54.080801885 +0000
+++ new/usr/src/lib/libm/common/C/libm_protos.h	2019-06-06 20:37:54.098759933 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,14 +38,14 @@
  *
  * For reasons unknown, these two are global (but private).
  */
-#define	__rem_pio2	__libm__rem_pio2
-#define	__rem_pio2m	__libm__rem_pio2m
+#define	__rem_pio2		__libm__rem_pio2
+#define	__rem_pio2m		__libm__rem_pio2m
 
 #ifndef _ASM
 #ifdef __STDC__
-#define	__P(p)	p
+#define	__P(p)			p
 #else
-#define	__P(p)	()
+#define	__P(p)			()
 #endif
 
 #include <sys/ieeefp.h>
@@ -138,6 +140,5 @@
 extern long long int llround __P((double));
 extern long long int llroundf __P((float));
 extern long long int llroundl __P((long double));
-#endif	/* _ASM */
-
-#endif	/* _C_LIBM_PROTOS_H */
+#endif /* _ASM */
+#endif /* _C_LIBM_PROTOS_H */
--- old/usr/src/lib/libm/common/C/log.c	2019-06-06 20:37:54.604328210 +0000
+++ new/usr/src/lib/libm/common/C/log.c	2019-06-06 20:37:54.622049212 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __log = log
 
-/* INDENT OFF */
+
 /*
  * log(x)
  * Table look-up algorithm with product polynomial approximation.
@@ -95,68 +97,69 @@
  * from decimal to binary accurately enough to produce the hexadecimal values
  * shown.
  */
-/* INDENT ON */
 
 #include "libm.h"
 
 extern const double _TBL_log[];
 
 static const double P[] = {
-/* ONE   */  1.0,
-/* TWO52 */  4503599627370496.0,
-/* LN2HI */  6.93147180369123816490e-01,	/* 3fe62e42, fee00000 */
-/* LN2LO */  1.90821492927058770002e-10,	/* 3dea39ef, 35793c76 */
+/* ONE   */
+	1.0,
+/* TWO52 */ 4503599627370496.0,
+/* LN2HI */ 6.93147180369123816490e-01,	/* 3fe62e42, fee00000 */
+/* LN2LO */ 1.90821492927058770002e-10,	/* 3dea39ef, 35793c76 */
 /* A1    */ -6.88821452420390473170286327331268694251775741577e-0002,
-/* A2    */  1.97493380704769294631262255279580131173133850098e+0000,
-/* A3    */  2.24963218866067560242072431719861924648284912109e+0000,
+/* A2    */ 1.97493380704769294631262255279580131173133850098e+0000,
+/* A3    */ 2.24963218866067560242072431719861924648284912109e+0000,
 /* A4    */ -9.02975906958474405783476868236903101205825805664e-0001,
 /* A5    */ -1.47391630715542865104339398385491222143173217773e+0000,
-/* A6    */  1.86846544648220058704168877738993614912033081055e+0000,
-/* A7    */  1.82277370459347465292410106485476717352867126465e+0000,
-/* A8    */  1.25295479915214102994980294170090928673744201660e+0000,
-/* A9    */  1.96709676945198275177517643896862864494323730469e+0000,
+/* A6    */ 1.86846544648220058704168877738993614912033081055e+0000,
+/* A7    */ 1.82277370459347465292410106485476717352867126465e+0000,
+/* A8    */ 1.25295479915214102994980294170090928673744201660e+0000,
+/* A9    */ 1.96709676945198275177517643896862864494323730469e+0000,
 /* A10   */ -4.00127989749189894030934055990655906498432159424e-0001,
-/* A11   */  3.01675528558798333733648178167641162872314453125e+0000,
+/* A11   */ 3.01675528558798333733648178167641162872314453125e+0000,
 /* A12   */ -9.52325445049240770778453679668018594384193420410e-0001,
 /* B1    */ -1.25041641589283658575482149899471551179885864258e-0001,
-/* B2    */  1.87161713283355151891381127914642725337613123482e+0000,
+/* B2    */ 1.87161713283355151891381127914642725337613123482e+0000,
 /* B3    */ -1.89082956295731507978530316904652863740921020508e+0000,
 /* B4    */ -2.50562891673640253387134180229622870683670043945e+0000,
-/* B5    */  1.64822828085258366037635369139024987816810607910e+0000,
+/* B5    */ 1.64822828085258366037635369139024987816810607910e+0000,
 /* B6    */ -1.24409107065868340669112512841820716857910156250e+0000,
-/* B7    */  1.70534231658220414296067701798165217041969299316e+0000,
-/* B8    */  1.99196833784655646937267192697618156671524047852e+0000,
+/* B7    */ 1.70534231658220414296067701798165217041969299316e+0000,
+/* B8    */ 1.99196833784655646937267192697618156671524047852e+0000,
 };
 
-#define	ONE   P[0]
-#define	TWO52 P[1]
-#define	LN2HI P[2]
-#define	LN2LO P[3]
-#define	A1    P[4]
-#define	A2    P[5]
-#define	A3    P[6]
-#define	A4    P[7]
-#define	A5    P[8]
-#define	A6    P[9]
-#define	A7    P[10]
-#define	A8    P[11]
-#define	A9    P[12]
-#define	A10   P[13]
-#define	A11   P[14]
-#define	A12   P[15]
-#define	B1    P[16]
-#define	B2    P[17]
-#define	B3    P[18]
-#define	B4    P[19]
-#define	B5    P[20]
-#define	B6    P[21]
-#define	B7    P[22]
-#define	B8    P[23]
+#define	ONE		P[0]
+#define	TWO52		P[1]
+#define	LN2HI		P[2]
+#define	LN2LO		P[3]
+#define	A1		P[4]
+#define	A2		P[5]
+#define	A3		P[6]
+#define	A4		P[7]
+#define	A5		P[8]
+#define	A6		P[9]
+#define	A7		P[10]
+#define	A8		P[11]
+#define	A9		P[12]
+#define	A10		P[13]
+#define	A11		P[14]
+#define	A12		P[15]
+#define	B1		P[16]
+#define	B2		P[17]
+#define	B3		P[18]
+#define	B4		P[19]
+#define	B5		P[20]
+#define	B6		P[21]
+#define	B7		P[22]
+#define	B8		P[23]
 
 double
-log(double x) {
-	double	*tb, dn, dn1, s, z, r, w;
-	int	i, hx, ix, n, lx;
+log(double x)
+{
+	double *tb, dn, dn1, s, z, r, w;
+	int i, hx, ix, n, lx;
 
 	n = 0;
 	hx = ((int *)&x)[HIWORD];
@@ -167,11 +170,14 @@
 	if ((hx + 0x100000) < 0x200000) {
 		if (ix > 0x7ff00000 || (ix == 0x7ff00000 && lx != 0)) /* nan */
 			return (x * x);
-		if (((hx << 1) | lx) == 0)		/* zero */
+
+		if (((hx << 1) | lx) == 0) /* zero */
 			return (_SVID_libm_err(x, x, 16));
-		if (hx < 0)				/* negative */
+
+		if (hx < 0)	/* negative */
 			return (_SVID_libm_err(x, x, 17));
-		if (((hx - 0x7ff00000) | lx) == 0)	/* +inf */
+
+		if (((hx - 0x7ff00000) | lx) == 0) /* +inf */
 			return (x);
 
 		/* x must be positive and subnormal */
@@ -182,27 +188,29 @@
 	}
 
 	i = ix >> 19;
+
 	if (i >= 0x7f7 && i <= 0x806) {
 		/* 0.09375 (0x3fb80000) <= x < 24 (0x40380000) */
 		if (ix >= 0x3fec0000 && ix < 0x3ff22000) {
 			/* 0.875 <= x < 1.125 */
 			s = x - ONE;
 			z = s * s;
-			if (((ix - 0x3ff00000) | lx) == 0) /* x = 1 */
+
+			if (((ix - 0x3ff00000) | lx) == 0)	/* x = 1 */
 				return (z);
+
 			r = (A10 * s) * (A11 + s);
 			w = z * s;
-			return (s + ((A1 * z) *
-				(A2 + ((A3 * s) * (A4 + s) + w * (A5 + s)))) *
-				((A6 + (s * (A7 + s) + w * (A8 + s))) *
-				(A9 + (r + w * (A12 + s)))));
+			return (s + ((A1 * z) * (A2 + ((A3 * s) * (A4 + s) + w *
+			    (A5 + s)))) * ((A6 + (s * (A7 + s) + w *
+			    (A8 + s))) * (A9 + (r + w * (A12 + s)))));
 		} else {
 			i = (ix - 0x3fb80000) >> 15;
 			tb = (double *)_TBL_log + (i + i + i);
 			s = (x - tb[0]) * tb[1];
-			return (tb[2] +  ((B1 * s) * (B2 + s * (B3 + s))) *
-				(((B4 + s * B5) + (s * s) * (B6 + s)) *
-				(B7 + s * (B8 + s))));
+			return (tb[2] + ((B1 * s) * (B2 + s * (B3 + s))) *
+			    (((B4 + s * B5) + (s * s) * (B6 + s)) *
+			    (B7 + s * (B8 + s))));
 		}
 	} else {
 		dn = (double)(n + ((ix >> 20) - 0x3ff));
@@ -214,7 +222,7 @@
 		s = (x - tb[0]) * tb[1];
 		dn = dn * LN2LO + tb[2];
 		return (dn1 + (dn + ((B1 * s) * (B2 + s * (B3 + s))) *
-			(((B4 + s * B5) + (s * s) * (B6 + s)) *
-			(B7 + s * (B8 + s)))));
+		    (((B4 + s * B5) + (s * s) * (B6 + s)) *
+		    (B7 + s * (B8 + s)))));
 	}
 }
--- old/usr/src/lib/libm/common/C/log10.c	2019-06-06 20:37:55.125303420 +0000
+++ new/usr/src/lib/libm/common/C/log10.c	2019-06-06 20:37:55.144285649 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __log10 = log10
 
-/* INDENT OFF */
+
 /*
  * log10(x) = log(x)/log10
  *
@@ -85,74 +87,75 @@
  * from decimal to binary accurately enough to produce the hexadecimal values
  * shown.
  */
-/* INDENT ON */
 
 #include "libm.h"
 
 extern const double _TBL_log[];
 
 static const double P[] = {
-/* ONE   */  1.0,
-/* TWO52 */  4503599627370496.0,
-/* LNAHI */  3.01029995607677847147e-01,	/* 3FD34413 50900000 */
-/* LNALO */  5.63033480667509769841e-11,	/* 3DCEF3FD E623E256 */
+/* ONE   */
+	1.0,
+/* TWO52 */ 4503599627370496.0,
+/* LNAHI */ 3.01029995607677847147e-01,	/* 3FD34413 50900000 */
+/* LNALO */ 5.63033480667509769841e-11,	/* 3DCEF3FD E623E256 */
 /* A1    */ -2.9142521960136582507385480707044582802184e-02,
-/* A2    */  1.99628461483039965074226529395673424005508422852e+0000,
-/* A3    */  2.26812367662950720159642514772713184356689453125e+0000,
+/* A2    */ 1.99628461483039965074226529395673424005508422852e+0000,
+/* A3    */ 2.26812367662950720159642514772713184356689453125e+0000,
 /* A4    */ -9.05030639084976384900471657601883634924888610840e-0001,
 /* A5    */ -1.48275767132434044270894446526654064655303955078e+0000,
-/* A6    */  1.88158320939722756293122074566781520843505859375e+0000,
-/* A7    */  1.83309386046986411145098827546462416648864746094e+0000,
-/* A8    */  1.24847063988317086291601754055591300129890441895e+0000,
-/* A9    */  1.98372421445537705508854742220137268304824829102e+0000,
+/* A6    */ 1.88158320939722756293122074566781520843505859375e+0000,
+/* A7    */ 1.83309386046986411145098827546462416648864746094e+0000,
+/* A8    */ 1.24847063988317086291601754055591300129890441895e+0000,
+/* A9    */ 1.98372421445537705508854742220137268304824829102e+0000,
 /* A10   */ -3.94711735767898475035764249696512706577777862549e-0001,
-/* A11   */  3.07890395362954372160402272129431366920471191406e+0000,
+/* A11   */ 3.07890395362954372160402272129431366920471191406e+0000,
 /* A12   */ -9.60099585275022149311041630426188930869102478027e-0001,
 /* B1    */ -5.4304894950350052960838096752491540286689e-02,
-/* B2    */  1.87161713283355151891381127914642725337613123482e+0000,
+/* B2    */ 1.87161713283355151891381127914642725337613123482e+0000,
 /* B3    */ -1.89082956295731507978530316904652863740921020508e+0000,
 /* B4    */ -2.50562891673640253387134180229622870683670043945e+0000,
-/* B5    */  1.64822828085258366037635369139024987816810607910e+0000,
+/* B5    */ 1.64822828085258366037635369139024987816810607910e+0000,
 /* B6    */ -1.24409107065868340669112512841820716857910156250e+0000,
-/* B7    */  1.70534231658220414296067701798165217041969299316e+0000,
-/* B8    */  1.99196833784655646937267192697618156671524047852e+0000,
-/* LGH   */  0.4375,
-/* LGL   */  0.003205518096748172348871081083395,
-/* LG10V */  0.43429448190325182765112891891660509576226,
+/* B7    */ 1.70534231658220414296067701798165217041969299316e+0000,
+/* B8    */ 1.99196833784655646937267192697618156671524047852e+0000,
+/* LGH   */ 0.4375,
+/* LGL   */ 0.003205518096748172348871081083395,
+/* LG10V */ 0.43429448190325182765112891891660509576226,
 };
 
-#define	ONE   P[0]
-#define	TWO52 P[1]
-#define	LNAHI P[2]
-#define	LNALO P[3]
-#define	A1    P[4]
-#define	A2    P[5]
-#define	A3    P[6]
-#define	A4    P[7]
-#define	A5    P[8]
-#define	A6    P[9]
-#define	A7    P[10]
-#define	A8    P[11]
-#define	A9    P[12]
-#define	A10   P[13]
-#define	A11   P[14]
-#define	A12   P[15]
-#define	B1    P[16]
-#define	B2    P[17]
-#define	B3    P[18]
-#define	B4    P[19]
-#define	B5    P[20]
-#define	B6    P[21]
-#define	B7    P[22]
-#define	B8    P[23]
-#define	LGH   P[24]
-#define	LGL   P[25]
-#define	LG10V P[26]
+#define	ONE		P[0]
+#define	TWO52		P[1]
+#define	LNAHI		P[2]
+#define	LNALO		P[3]
+#define	A1		P[4]
+#define	A2		P[5]
+#define	A3		P[6]
+#define	A4		P[7]
+#define	A5		P[8]
+#define	A6		P[9]
+#define	A7		P[10]
+#define	A8		P[11]
+#define	A9		P[12]
+#define	A10		P[13]
+#define	A11		P[14]
+#define	A12		P[15]
+#define	B1		P[16]
+#define	B2		P[17]
+#define	B3		P[18]
+#define	B4		P[19]
+#define	B5		P[20]
+#define	B6		P[21]
+#define	B7		P[22]
+#define	B8		P[23]
+#define	LGH		P[24]
+#define	LGL		P[25]
+#define	LG10V		P[26]
 
 double
-log10(double x) {
-	double	*tb, dn, dn1, s, z, r, w;
-	int	i, hx, ix, n, lx;
+log10(double x)
+{
+	double *tb, dn, dn1, s, z, r, w;
+	int i, hx, ix, n, lx;
 
 	n = 0;
 	hx = ((int *)&x)[HIWORD];
@@ -163,11 +166,14 @@
 	if ((hx + 0x100000) < 0x200000) {
 		if (ix > 0x7ff00000 || (ix == 0x7ff00000 && lx != 0)) /* nan */
 			return (x * x);
-		if (((hx << 1) | lx) == 0)		/* zero */
+
+		if (((hx << 1) | lx) == 0) /* zero */
 			return (_SVID_libm_err(x, x, 18));
-		if (hx < 0)				/* negative */
+
+		if (hx < 0)	/* negative */
 			return (_SVID_libm_err(x, x, 19));
-		if (((hx - 0x7ff00000) | lx) == 0)	/* +inf */
+
+		if (((hx - 0x7ff00000) | lx) == 0) /* +inf */
 			return (x);
 
 		/* x must be positive and subnormal */
@@ -178,28 +184,30 @@
 	}
 
 	i = ix >> 19;
+
 	if (i >= 0x7f7 && i <= 0x806) {
 		/* 0.09375 (0x3fb80000) <= x < 24 (0x40380000) */
 		if (ix >= 0x3fec0000 && ix < 0x3ff20000) {
 			/* 0.875 <= x < 1.125 */
 			s = x - ONE;
 			z = s * s;
-			if (((ix - 0x3ff00000) | lx) == 0) /* x = 1 */
+
+			if (((ix - 0x3ff00000) | lx) == 0)	/* x = 1 */
 				return (z);
+
 			r = (A10 * s) * (A11 + s);
 			w = z * s;
 			return (LGH * s - (LGL * s - ((A1 * z) *
-				((A2 + (A3 * s) * (A4 + s)) + w * (A5 + s))) *
-				(((A6 + s * (A7 + s)) + w * (A8 + s)) *
-				((A9 + r) + w * (A12 + s)))));
+			    ((A2 + (A3 * s) * (A4 + s)) + w * (A5 + s))) *
+			    (((A6 + s * (A7 + s)) + w * (A8 + s)) *
+			    ((A9 + r) + w * (A12 + s)))));
 		} else {
 			i = (ix - 0x3fb80000) >> 15;
 			tb = (double *)_TBL_log + (i + i + i);
 			s = (x - tb[0]) * tb[1];
 			return (LGH * tb[2] - (LGL * tb[2] - ((B1 * s) *
-				(B2 + s * (B3 + s))) *
-				(((B4 + s * B5) + (s * s) * (B6 + s)) *
-				(B7 + s * (B8 + s)))));
+			    (B2 + s * (B3 + s))) * (((B4 + s * B5) + (s * s) *
+			    (B6 + s)) * (B7 + s * (B8 + s)))));
 		}
 	} else {
 		dn = (double)(n + ((ix >> 20) - 0x3ff));
@@ -210,9 +218,8 @@
 		tb = (double *)_TBL_log + (i + i + i);
 		s = (x - tb[0]) * tb[1];
 		dn = dn * LNALO + tb[2] * LG10V;
-		return (dn1 + (dn + ((B1 * s) *
-			(B2 + s * (B3 + s))) *
-			(((B4 + s * B5) + (s * s) * (B6 + s)) *
-			(B7 + s * (B8 + s)))));
+		return (dn1 + (dn + ((B1 * s) * (B2 + s * (B3 + s))) *
+		    (((B4 + s * B5) + (s * s) * (B6 + s)) *
+		    (B7 + s * (B8 + s)))));
 	}
 }
--- old/usr/src/lib/libm/common/C/log1p.c	2019-06-06 20:37:55.623571211 +0000
+++ new/usr/src/lib/libm/common/C/log1p.c	2019-06-06 20:37:55.640947109 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __log1p = log1p
 
-/* INDENT OFF */
+
 /*
  * Method :
  *   1. Argument Reduction: find k and f such that
@@ -47,12 +49,12 @@
  *		 = 2s + 2/3 s**3 + 2/5 s**5 + .....,
  *		 = 2s + s*R
  *      We use a special Reme algorithm on [0,0.1716] to generate
- * 	a polynomial of degree 14 to approximate R The maximum error
+ *      a polynomial of degree 14 to approximate R The maximum error
  *	of this polynomial approximation is bounded by 2**-58.45. In
  *	other words,
  *		        2      4      6      8      10      12      14
  *	    R(z) ~ Lp1*s +Lp2*s +Lp3*s +Lp4*s +Lp5*s  +Lp6*s  +Lp7*s
- *  	(the values of Lp1 to Lp7 are listed in the program)
+ *      (the values of Lp1 to Lp7 are listed in the program)
  *	and
  *	    |      2          14          |     -58.45
  *	    | Lp1*s +...+Lp7*s    -  R(z) | <= 2
@@ -92,72 +94,80 @@
  *
  *	 See HP-15C Advanced Functions Handbook, p.193.
  */
-/* INDENT ON */
 
 #include "libm.h"
 
 static const double xxx[] = {
-/* ln2_hi */	6.93147180369123816490e-01,	/* 3fe62e42 fee00000 */
-/* ln2_lo */	1.90821492927058770002e-10,	/* 3dea39ef 35793c76 */
-/* two54 */	1.80143985094819840000e+16,	/* 43500000 00000000 */
-/* Lp1 */	6.666666666666735130e-01,	/* 3FE55555 55555593 */
-/* Lp2 */	3.999999999940941908e-01,	/* 3FD99999 9997FA04 */
-/* Lp3 */	2.857142874366239149e-01,	/* 3FD24924 94229359 */
-/* Lp4 */	2.222219843214978396e-01,	/* 3FCC71C5 1D8E78AF */
-/* Lp5 */	1.818357216161805012e-01,	/* 3FC74664 96CB03DE */
-/* Lp6 */	1.531383769920937332e-01,	/* 3FC39A09 D078C69F */
-/* Lp7 */	1.479819860511658591e-01,	/* 3FC2F112 DF3E5244 */
-/* zero */	0.0
+/* ln2_hi */
+	6.93147180369123816490e-01,		/* 3fe62e42 fee00000 */
+/* ln2_lo */ 1.90821492927058770002e-10,	/* 3dea39ef 35793c76 */
+/* two54 */ 1.80143985094819840000e+16,		/* 43500000 00000000 */
+/* Lp1 */ 6.666666666666735130e-01,		/* 3FE55555 55555593 */
+/* Lp2 */ 3.999999999940941908e-01,		/* 3FD99999 9997FA04 */
+/* Lp3 */ 2.857142874366239149e-01,		/* 3FD24924 94229359 */
+/* Lp4 */ 2.222219843214978396e-01,		/* 3FCC71C5 1D8E78AF */
+/* Lp5 */ 1.818357216161805012e-01,		/* 3FC74664 96CB03DE */
+/* Lp6 */ 1.531383769920937332e-01,		/* 3FC39A09 D078C69F */
+/* Lp7 */ 1.479819860511658591e-01,		/* 3FC2F112 DF3E5244 */
+/* zero */ 0.0
 };
-#define	ln2_hi	xxx[0]
-#define	ln2_lo	xxx[1]
-#define	two54	xxx[2]
-#define	Lp1	xxx[3]
-#define	Lp2	xxx[4]
-#define	Lp3	xxx[5]
-#define	Lp4	xxx[6]
-#define	Lp5	xxx[7]
-#define	Lp6	xxx[8]
-#define	Lp7	xxx[9]
-#define	zero	xxx[10]
+
+#define	ln2_hi		xxx[0]
+#define	ln2_lo		xxx[1]
+#define	two54		xxx[2]
+#define	Lp1		xxx[3]
+#define	Lp2		xxx[4]
+#define	Lp3		xxx[5]
+#define	Lp4		xxx[6]
+#define	Lp5		xxx[7]
+#define	Lp6		xxx[8]
+#define	Lp7		xxx[9]
+#define	zero		xxx[10]
 
 double
-log1p(double x) {
-	double	hfsq, f, c = 0.0, s, z, R, u;
-	int	k, hx, hu, ax;
+log1p(double x)
+{
+	double hfsq, f, c = 0.0, s, z, R, u;
+	int k, hx, hu, ax;
 
-	hx = ((int *)&x)[HIWORD];		/* high word of x */
+	hx = ((int *)&x)[HIWORD]; /* high word of x */
 	ax = hx & 0x7fffffff;
 
-	if (ax >= 0x7ff00000) { /* x is inf or nan */
+	if (ax >= 0x7ff00000) {	/* x is inf or nan */
 		if (((hx - 0xfff00000) | ((int *)&x)[LOWORD]) == 0) /* -inf */
 			return (_SVID_libm_err(x, x, 44));
+
 		return (x * x);
 	}
 
 	k = 1;
-	if (hx < 0x3FDA827A) {	/* x < 0.41422  */
-		if (ax >= 0x3ff00000)	/* x <= -1.0 */
+
+	if (hx < 0x3FDA827A) {			/* x < 0.41422  */
+		if (ax >= 0x3ff00000)		/* x <= -1.0 */
 			return (_SVID_libm_err(x, x, x == -1.0 ? 43 : 44));
-		if (ax < 0x3e200000) {	/* |x| < 2**-29 */
+
+		if (ax < 0x3e200000) {		/* |x| < 2**-29 */
 			if (two54 + x > zero &&	/* raise inexact */
 			    ax < 0x3c900000)	/* |x| < 2**-54 */
 				return (x);
 			else
 				return (x - x * x * 0.5);
 		}
+
 		if (hx > 0 || hx <= (int)0xbfd2bec3) {	/* -0.2929<x<0.41422 */
 			k = 0;
 			f = x;
 			hu = 1;
 		}
 	}
+
 	/* We will initialize 'c' here. */
 	if (k != 0) {
 		if (hx < 0x43400000) {
 			u = 1.0 + x;
 			hu = ((int *)&u)[HIWORD];	/* high word of u */
 			k = (hu >> 20) - 1023;
+
 			/*
 			 * correction term
 			 */
@@ -169,36 +179,48 @@
 			k = (hu >> 20) - 1023;
 			c = 0;
 		}
+
 		hu &= 0x000fffff;
+
 		if (hu < 0x6a09e) {	/* normalize u */
 			((int *)&u)[HIWORD] = hu | 0x3ff00000;
-		} else {			/* normalize u/2 */
+		} else {		/* normalize u/2 */
 			k += 1;
 			((int *)&u)[HIWORD] = hu | 0x3fe00000;
 			hu = (0x00100000 - hu) >> 2;
 		}
+
 		f = u - 1.0;
 	}
+
 	hfsq = 0.5 * f * f;
-	if (hu == 0) {		/* |f| < 2**-20 */
+
+	if (hu == 0) {			/* |f| < 2**-20 */
 		if (f == zero) {
 			if (k == 0)
 				return (zero);
+
 			/* We already initialized 'c' before, when (k != 0) */
 			c += k * ln2_lo;
 			return (k * ln2_hi + c);
 		}
+
 		R = hfsq * (1.0 - 0.66666666666666666 * f);
+
 		if (k == 0)
 			return (f - R);
+
 		return (k * ln2_hi - ((R - (k * ln2_lo + c)) - f));
 	}
+
 	s = f / (2.0 + f);
 	z = s * s;
-	R = z * (Lp1 + z * (Lp2 + z * (Lp3 + z * (Lp4 + z * (Lp5 +
-		z * (Lp6 + z * Lp7))))));
+	R = z * (Lp1 + z * (Lp2 + z * (Lp3 + z * (Lp4 + z * (Lp5 + z * (Lp6 +
+	    z * Lp7))))));
+
 	if (k == 0)
 		return (f - (hfsq - s * (hfsq + R)));
-	return (k * ln2_hi - ((hfsq - (s * (hfsq + R) +
-		(k * ln2_lo + c))) - f));
+
+	return (k * ln2_hi -
+	    ((hfsq - (s * (hfsq + R) + (k * ln2_lo + c))) - f));
 }
--- old/usr/src/lib/libm/common/C/log2.c	2019-06-06 20:37:56.130799979 +0000
+++ new/usr/src/lib/libm/common/C/log2.c	2019-06-06 20:37:56.148787027 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __log2 = log2
 
-/* INDENT OFF */
+
 /*
  * log2(x) = log(x)/log2
  *
@@ -85,7 +86,6 @@
  * from decimal to binary accurately enough to produce the hexadecimal values
  * shown.
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "libm_protos.h"
@@ -93,134 +93,153 @@
 extern const double _TBL_log[];
 
 static const double P[] = {
-/* ONE   */  1.0,
-/* TWO52 */  4503599627370496.0,
-/* LN10V */  1.4426950408889634073599246810018920433347,   /* 1/log10 */
-/* ZERO  */  0.0,
+/* ONE   */
+	1.0,
+/* TWO52 */ 4503599627370496.0,
+/* LN10V */ 1.4426950408889634073599246810018920433347,	/* 1/log10 */
+/* ZERO  */ 0.0,
 /* A1    */ -9.6809362455249638217841932228967194640116e-02,
-/* A2    */  1.99628461483039965074226529395673424005508422852e+0000,
-/* A3    */  2.26812367662950720159642514772713184356689453125e+0000,
+/* A2    */ 1.99628461483039965074226529395673424005508422852e+0000,
+/* A3    */ 2.26812367662950720159642514772713184356689453125e+0000,
 /* A4    */ -9.05030639084976384900471657601883634924888610840e-0001,
 /* A5    */ -1.48275767132434044270894446526654064655303955078e+0000,
-/* A6    */  1.88158320939722756293122074566781520843505859375e+0000,
-/* A7    */  1.83309386046986411145098827546462416648864746094e+0000,
-/* A8    */  1.24847063988317086291601754055591300129890441895e+0000,
-/* A9    */  1.98372421445537705508854742220137268304824829102e+0000,
+/* A6    */ 1.88158320939722756293122074566781520843505859375e+0000,
+/* A7    */ 1.83309386046986411145098827546462416648864746094e+0000,
+/* A8    */ 1.24847063988317086291601754055591300129890441895e+0000,
+/* A9    */ 1.98372421445537705508854742220137268304824829102e+0000,
 /* A10   */ -3.94711735767898475035764249696512706577777862549e-0001,
-/* A11   */  3.07890395362954372160402272129431366920471191406e+0000,
+/* A11   */ 3.07890395362954372160402272129431366920471191406e+0000,
 /* A12   */ -9.60099585275022149311041630426188930869102478027e-0001,
 /* B1    */ -1.8039695622547469514898963204616532885451e-01,
-/* B2    */  1.87161713283355151891381127914642725337613123482e+0000,
+/* B2    */ 1.87161713283355151891381127914642725337613123482e+0000,
 /* B3    */ -1.89082956295731507978530316904652863740921020508e+0000,
 /* B4    */ -2.50562891673640253387134180229622870683670043945e+0000,
-/* B5    */  1.64822828085258366037635369139024987816810607910e+0000,
+/* B5    */ 1.64822828085258366037635369139024987816810607910e+0000,
 /* B6    */ -1.24409107065868340669112512841820716857910156250e+0000,
-/* B7    */  1.70534231658220414296067701798165217041969299316e+0000,
-/* B8    */  1.99196833784655646937267192697618156671524047852e+0000,
-/* LGH   */  1.5,
-/* LGL   */  0.057304959111036592640075318998107956665325,
+/* B7    */ 1.70534231658220414296067701798165217041969299316e+0000,
+/* B8    */ 1.99196833784655646937267192697618156671524047852e+0000,
+/* LGH   */ 1.5,
+/* LGL   */ 0.057304959111036592640075318998107956665325,
 };
 
-#define	ONE   P[0]
-#define	TWO52 P[1]
-#define	LN10V P[2]
-#define	ZERO  P[3]
-#define	A1    P[4]
-#define	A2    P[5]
-#define	A3    P[6]
-#define	A4    P[7]
-#define	A5    P[8]
-#define	A6    P[9]
-#define	A7    P[10]
-#define	A8    P[11]
-#define	A9    P[12]
-#define	A10   P[13]
-#define	A11   P[14]
-#define	A12   P[15]
-#define	B1    P[16]
-#define	B2    P[17]
-#define	B3    P[18]
-#define	B4    P[19]
-#define	B5    P[20]
-#define	B6    P[21]
-#define	B7    P[22]
-#define	B8    P[23]
-#define	LGH   P[24]
-#define	LGL   P[25]
+#define	ONE		P[0]
+#define	TWO52		P[1]
+#define	LN10V		P[2]
+#define	ZERO		P[3]
+#define	A1		P[4]
+#define	A2		P[5]
+#define	A3		P[6]
+#define	A4		P[7]
+#define	A5		P[8]
+#define	A6		P[9]
+#define	A7		P[10]
+#define	A8		P[11]
+#define	A9		P[12]
+#define	A10		P[13]
+#define	A11		P[14]
+#define	A12		P[15]
+#define	B1		P[16]
+#define	B2		P[17]
+#define	B3		P[18]
+#define	B4		P[19]
+#define	B5		P[20]
+#define	B6		P[21]
+#define	B7		P[22]
+#define	B8		P[23]
+#define	LGH		P[24]
+#define	LGL		P[25]
 
 double
-log2(double x) {
+log2(double x)
+{
 	int i, hx, ix, n, lx;
 
 	n = 0;
-	hx = ((int *) &x)[HIWORD]; ix = hx & 0x7fffffff;
-	lx = ((int *) &x)[LOWORD];
+	hx = ((int *)&x)[HIWORD];
+	ix = hx & 0x7fffffff;
+	lx = ((int *)&x)[LOWORD];
 
 	/* subnormal,0,negative,inf,nan */
 	if ((hx + 0x100000) < 0x200000) {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
-		if (ix >= 0x7ff80000)		/* assumes sparc-like QNaN */
-			return (x);		/* for Cheetah when x is QNaN */
+		if (ix >= 0x7ff80000) /* assumes sparc-like QNaN */
+			return (x);   /* for Cheetah when x is QNaN */
 #endif
-		if (((hx << 1) | lx) == 0)	/* log(0.0) = -inf */
+
+		if (((hx << 1) | lx) == 0)		/* log(0.0) = -inf */
 			return (A5 / fabs(x));
-		if (hx < 0) {	/* x < 0 */
+
+		if (hx < 0) {				/* x < 0 */
 			if (ix >= 0x7ff00000)
-				return (x - x);	/* x is -inf or NaN */
+				return (x - x);		/* x is -inf or NaN */
 			else
 				return (ZERO / (x - x));
 		}
+
 		if (((hx - 0x7ff00000) | lx) == 0)	/* log(inf) = inf */
 			return (x);
-		if (ix >= 0x7ff00000)		/* log(NaN) = NaN */
+
+		if (ix >= 0x7ff00000)			/* log(NaN) = NaN */
 			return (x - x);
+
 		x *= TWO52;
 		n = -52;
-		hx = ((int *) &x)[HIWORD]; ix = hx & 0x7fffffff;
-		lx = ((int *) &x)[LOWORD];
+		hx = ((int *)&x)[HIWORD];
+		ix = hx & 0x7fffffff;
+		lx = ((int *)&x)[LOWORD];
 	}
 
 	/* 0.09375 (0x3fb80000) <= x < 24 (0x40380000) */
 	i = ix >> 19;
+
 	if (i >= 0x7f7 && i <= 0x806) {
 		/* 0.875 <= x < 1.125 */
 		if (ix >= 0x3fec0000 && ix < 0x3ff20000) {
 			double s, z, r, w;
-			s = x - ONE; z = s * s; r = (A10 * s) * (A11 + s);
+
+			s = x - ONE;
+			z = s * s;
+			r = (A10 * s) * (A11 + s);
 			w = z * s;
-			if (((ix << 12) | lx) == 0)
+
+			if (((ix << 12) | lx) == 0) {
 				return (z);
-			else
-				return (LGH * s - (LGL * s - ((A1 * z) *
-				((A2 + (A3 * s) * (A4 + s)) + w * (A5 + s))) *
-				(((A6 + s * (A7 + s)) + w * (A8 + s)) *
-				((A9 + r) + w * (A12 + s)))));
+			} else {
+				return (LGH * s - (LGL * s - ((A1 * z) * ((A2 +
+				    (A3 * s) * (A4 + s)) + w * (A5 + s))) *
+				    (((A6 + s * (A7 + s)) + w * (A8 + s)) *
+				    ((A9 + r) + w * (A12 + s)))));
+			}
 		} else {
 			double *tb, s;
+
 			i = (ix - 0x3fb80000) >> 15;
-			tb = (double *) _TBL_log + (i + i + i);
+			tb = (double *)_TBL_log + (i + i + i);
+
 			if (((ix << 12) | lx) == 0)	/* 2's power */
-				return ((double) ((ix >> 20) - 0x3ff));
+				return ((double)((ix >> 20) - 0x3ff));
+
 			s = (x - tb[0]) * tb[1];
 			return (LGH * tb[2] - (LGL * tb[2] - ((B1 * s) *
-				(B2 + s * (B3 + s))) *
-				(((B4 + s * B5) + (s * s) * (B6 + s)) *
-				(B7 + s * (B8 + s)))));
+			    (B2 + s * (B3 + s))) * (((B4 + s * B5) + (s * s) *
+			    (B6 + s)) * (B7 + s * (B8 + s)))));
 		}
 	} else {
 		double *tb, dn, s;
-		dn = (double) (n + ((ix >> 20) - 0x3ff));
+
+		dn = (double)(n + ((ix >> 20) - 0x3ff));
 		ix <<= 12;
+
 		if ((ix | lx) == 0)
 			return (dn);
-		i = ((unsigned) ix >> 12) | 0x3ff00000;	/* scale x to [1,2) */
-		((int *) &x)[HIWORD] = i;
+
+		i = ((unsigned)ix >> 12) | 0x3ff00000;	/* scale x to [1,2) */
+		((int *)&x)[HIWORD] = i;
 		i = (i - 0x3fb80000) >> 15;
-		tb = (double *) _TBL_log + (i + i + i);
+		tb = (double *)_TBL_log + (i + i + i);
 		s = (x - tb[0]) * tb[1];
-		return (dn + (tb[2] * LN10V + ((B1 * s) *
-			(B2 + s * (B3 + s))) *
-			(((B4 + s * B5) + (s * s) * (B6 + s)) *
-			(B7 + s * (B8 + s)))));
+		return (dn + (tb[2] * LN10V + ((B1 * s) * (B2 + s * (B3 + s))) *
+		    (((B4 + s * B5) + (s * s) * (B6 + s)) *
+		    (B7 + s * (B8 + s)))));
 	}
 }
--- old/usr/src/lib/libm/common/C/logb.c	2019-06-06 20:37:56.641674106 +0000
+++ new/usr/src/lib/libm/common/C/logb.c	2019-06-06 20:37:56.659759480 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,7 +32,7 @@
 #pragma weak _logb = logb
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"			/* __xpg6 */
 #define	_C99SUSv3_logb	_C99SUSv3_logb_subnormal_is_like_ilogb
 
 #if defined(__x86)
@@ -41,43 +42,51 @@
  * v: high part of a non-zero subnormal |x|; w: low part of |x|
  */
 static int
-ilogb_subnormal(unsigned v, unsigned w) {
+ilogb_subnormal(unsigned v, unsigned w)
+{
 	int r = -1022 - 52;
 
 	if (v)
 		r += 32;
 	else
 		v = w;
+
 	if (v & 0xffff0000)
 		r += 16, v >>= 16;
+
 	if (v & 0xff00)
 		r += 8, v >>= 8;
+
 	if (v & 0xf0)
 		r += 4, v >>= 4;
+
 	v <<= 1;
 	return (r + ((0xffffaa50 >> v) & 0x3));
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 double
-logb(double x) {
-	int *px = (int *) &x, k = px[HIWORD] & ~0x80000000;
+logb(double x)
+{
+	int *px = (int *)&x, k = px[HIWORD] & ~0x80000000;
 
 	if (k < 0x00100000) {
-		if ((px[LOWORD] | k) == 0)
+		if ((px[LOWORD] | k) == 0) {
 			return (_SVID_libm_err(x, x, 45));
-		else if ((__xpg6 & _C99SUSv3_logb) != 0) {
+		} else if ((__xpg6 & _C99SUSv3_logb) != 0) {
 #if defined(__x86)
 			x *= two52;
-			return ((double) (((px[HIWORD] & 0x7ff00000) >> 20)
-				- 1075));
+			return ((double)(((px[HIWORD] & 0x7ff00000) >> 20) -
+			    1075));
 #else
-			return ((double) ilogb_subnormal(k, px[LOWORD]));
+			return ((double)ilogb_subnormal(k, px[LOWORD]));
 #endif
-		} else
+		} else {
 			return (-1022.0);
-	} else if (k < 0x7ff00000)
-		return ((double) ((k >> 20) - 1023));
-	else
+		}
+	} else if (k < 0x7ff00000) {
+		return ((double)((k >> 20) - 1023));
+	} else {
 		return (x * x);
+	}
 }
--- old/usr/src/lib/libm/common/C/matherr.c	2019-06-06 20:37:57.149081906 +0000
+++ new/usr/src/lib/libm/common/C/matherr.c	2019-06-06 20:37:57.167026805 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 
 /* ARGSUSED0 */
 int
-__matherr(struct exception *x) {
+__matherr(struct exception *x)
+{
 	return (0);
 }
--- old/usr/src/lib/libm/common/C/nextafter.c	2019-06-06 20:37:57.621606833 +0000
+++ new/usr/src/lib/libm/common/C/nextafter.c	2019-06-06 20:37:57.639227362 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,13 +32,14 @@
 #pragma weak _nextafter = nextafter
 
 #include "libm.h"
-#include <float.h>		/* DBL_MIN */
+#include <float.h>			/* DBL_MIN */
 
 double
-nextafter(double x, double y) {
-	int		hx, hy, k;
-	double		ans;
-	unsigned	lx;
+nextafter(double x, double y)
+{
+	int hx, hy, k;
+	double ans;
+	unsigned lx;
 	volatile double dummy __unused;
 
 	hx = ((int *)&x)[HIWORD];
@@ -46,8 +49,10 @@
 
 	if (x == y)
 		return (y);		/* C99 requirement */
+
 	if (x != x || y != y)
 		return (x * y);
+
 	if (k == 0) {			/* x = 0 */
 		k = hy & 0x80000000;
 		((int *)&ans)[HIWORD] = k;
@@ -55,25 +60,27 @@
 	} else if (hx >= 0) {
 		if (x > y) {
 			((int *)&ans)[LOWORD] = lx - 1;
-			k = (lx == 0)? hx - 1 : hx;
+			k = (lx == 0) ? hx - 1 : hx;
 			((int *)&ans)[HIWORD] = k;
 		} else {
 			((int *)&ans)[LOWORD] = lx + 1;
-			k  = (lx == 0xffffffff)? hx + 1 : hx;
+			k = (lx == 0xffffffff) ? hx + 1 : hx;
 			((int *)&ans)[HIWORD] = k;
 		}
 	} else {
 		if (x < y) {
 			((int *)&ans)[LOWORD] = lx - 1;
-			k = (lx == 0)? hx - 1 : hx;
+			k = (lx == 0) ? hx - 1 : hx;
 			((int *)&ans)[HIWORD] = k;
 		} else {
 			((int *)&ans)[LOWORD] = lx + 1;
-			k  = (lx == 0xffffffff)? hx + 1 : hx;
+			k = (lx == 0xffffffff) ? hx + 1 : hx;
 			((int *)&ans)[HIWORD] = k;
 		}
 	}
+
 	k = (k >> 20) & 0x7ff;
+
 	if (k == 0x7ff) {
 		/* overflow */
 		return (_SVID_libm_err(x, y, 46));
@@ -83,5 +90,6 @@
 		dummy = DBL_MIN * copysign(DBL_MIN, x);
 #endif
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/C/pow.c	2019-06-06 20:37:58.123010985 +0000
+++ new/usr/src/lib/libm/common/C/pow.c	2019-06-06 20:37:58.140656483 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -68,14 +69,16 @@
  */
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"			/* __xpg6 */
 #define	_C99SUSv3_pow	_C99SUSv3_pow_treats_Inf_as_an_even_int
 
-static const double zero = 0.0, one = 1.0, two = 2.0;
+static const double zero = 0.0,
+	one = 1.0,
+	two = 2.0;
 
 extern const double _TBL_log2_hi[], _TBL_log2_lo[];
-static const double
-	two53 = 9007199254740992.0,
+
+static const double two53 = 9007199254740992.0,
 	A1_hi = 2.8853900432586669921875,
 	A1_lo = 3.8519259825035041963606002e-8,
 	A1 = 2.885390081777926817222541963606002026086e+0000,
@@ -90,43 +93,50 @@
 	B4 = 3.207590534812432970433641789022666850193e-0001;
 
 static double
-log2_x(double x, double *w) {
+log2_x(double x, double *w)
+{
 	double f, s, z, qn, h, t;
-	int *px = (int *) &x;
-	int *pz = (int *) &z;
+	int *px = (int *)&x;
+	int *pz = (int *)&z;
 	int i, j, ix, n;
 
 	n = 0;
 	ix = px[HIWORD];
+
 	if (ix >= 0x3fef03f1 && ix < 0x3ff08208) {	/* 65/63 > x > 63/65 */
 		double f1, v;
+
 		f = x - one;
+
 		if (((ix - 0x3ff00000) | px[LOWORD]) == 0) {
 			*w = zero;
-			return (zero);		/* log2(1)= +0 */
+			return (zero);	/* log2(1)= +0 */
 		}
+
 		qn = one / (two + f);
-		s = f * qn;				/* |s|<2**-6 */
+		s = f * qn;		/* |s|<2**-6 */
 		v = s * s;
-		h = (double) ((float) s);
-		f1 = (double) ((float) f);
+		h = (double)((float)s);
+		f1 = (double)((float)f);
 		t = qn * (((f - two * h) - h * f1) - h * (f - f1));
-								/* s = h+t */
+		/* s = h+t */
 		f1 = h * B0_lo + s * (v * (B1 + v * (B2 + v * (B3 + v * B4))));
 		t = f1 + t * B0;
 		h *= B0_hi;
-		s = (double) ((float) (h + t));
+		s = (double)((float)(h + t));
 		*w = t - (s - h);
 		return (s);
 	}
-	if (ix < 0x00100000) {				/* subnormal x */
+
+	if (ix < 0x00100000) {		/* subnormal x */
 		x *= two53;
 		n = -53;
 		ix = px[HIWORD];
 	}
+
 	/* LARGE N */
 	n += ((ix + 0x1000) >> 20) - 0x3ff;
-	ix = (ix & 0x000fffff) | 0x3ff00000;		/* scale x to [1,2] */
+	ix = (ix & 0x000fffff) | 0x3ff00000;	/* scale x to [1,2] */
 	px[HIWORD] = ix;
 	i = ix + 0x1000;
 	pz[HIWORD] = i & 0xffffe000;
@@ -134,7 +144,7 @@
 	qn = one / (x + z);
 	f = x - z;
 	s = f * qn;
-	h = (double) ((float) s);
+	h = (double)((float)s);
 	t = qn * ((f - (h + h) * z) - h * f);
 	j = (i >> 13) & 0x7f;
 	f = s * s;
@@ -144,7 +154,7 @@
 	s = n + _TBL_log2_hi[j];
 	h = qn + s;
 	t += _TBL_log2_lo[j] - ((h - s) - qn);
-	f = (double) ((float) (h + t));
+	f = (double)((float)(h + t));
 	*w = t - (f - h);
 	return (f);
 }
@@ -158,37 +168,42 @@
 	E5 = 1.333357676549940345096774122231849082991e-0003;
 
 double
-pow(double x, double y) {
+pow(double x, double y)
+{
 	double z, ax;
 	double y1, y2, w1, w2;
 	int sbx, sby, j, k, yisint;
 	int hx, hy, ahx, ahy;
 	unsigned lx, ly;
-	int *pz = (int *) &z;
+	int *pz = (int *)&z;
 
-	hx = ((int *) &x)[HIWORD];
-	lx = ((unsigned *) &x)[LOWORD];
-	hy = ((int *) &y)[HIWORD];
-	ly = ((unsigned *) &y)[LOWORD];
+	hx = ((int *)&x)[HIWORD];
+	lx = ((unsigned *)&x)[LOWORD];
+	hy = ((int *)&y)[HIWORD];
+	ly = ((unsigned *)&y)[LOWORD];
 	ahx = hx & ~0x80000000;
 	ahy = hy & ~0x80000000;
-	if ((ahy | ly) == 0) {	/* y==zero  */
+
+	if ((ahy | ly) == 0) {				/* y==zero  */
 		if ((ahx | lx) == 0)
 			z = _SVID_libm_err(x, y, 20);	/* +-0**+-0 */
 		else if ((ahx | (((lx | -lx) >> 31) & 1)) > 0x7ff00000)
 			z = _SVID_libm_err(x, y, 42);	/* NaN**+-0 */
 		else
 			z = one;			/* x**+-0 = 1 */
+
 		return (z);
-	} else if (hx == 0x3ff00000 && lx == 0 &&
-		(__xpg6 & _C99SUSv3_pow) != 0)
-		return (one);			/* C99: 1**anything = 1 */
-	else if (ahx > 0x7ff00000 || (ahx == 0x7ff00000 && lx != 0) ||
-		ahy > 0x7ff00000 || (ahy == 0x7ff00000 && ly != 0))
+	} else if (hx == 0x3ff00000 && lx == 0 && (__xpg6 & _C99SUSv3_pow) !=
+	    0) {
+		return (one);		/* C99: 1**anything = 1 */
+	} else if (ahx > 0x7ff00000 || (ahx == 0x7ff00000 && lx != 0) || ahy >
+	    0x7ff00000 || (ahy == 0x7ff00000 && ly != 0)) {
 		return (x * y);	/* +-NaN return x*y; + -> * for Cheetah */
-				/* includes Sun: 1**NaN = NaN */
-	sbx = (unsigned) hx >> 31;
-	sby = (unsigned) hy >> 31;
+	}
+
+	/* includes Sun: 1**NaN = NaN */
+	sbx = (unsigned)hx >> 31;
+	sby = (unsigned)hy >> 31;
 	ax = fabs(x);
 
 	/*
@@ -198,144 +213,173 @@
 	 * yisint = 2 ... y is an even int
 	 */
 	yisint = 0;
+
 	if (sbx) {
-		if (ahy >= 0x43400000)
-			yisint = 2;		/* even integer y */
-		else if (ahy >= 0x3ff00000) {
+		if (ahy >= 0x43400000) {
+			yisint = 2;			/* even integer y */
+		} else if (ahy >= 0x3ff00000) {
 			k = (ahy >> 20) - 0x3ff;	/* exponent */
+
 			if (k > 20) {
 				j = ly >> (52 - k);
+
 				if ((j << (52 - k)) == ly)
 					yisint = 2 - (j & 1);
 			} else if (ly == 0) {
 				j = ahy >> (20 - k);
+
 				if ((j << (20 - k)) == ahy)
 					yisint = 2 - (j & 1);
 			}
 		}
 	}
+
 	/* special value of y */
 	if (ly == 0) {
 		if (ahy == 0x7ff00000) {	/* y is +-inf */
 			if (((ahx - 0x3ff00000) | lx) == 0) {
 				if ((__xpg6 & _C99SUSv3_pow) != 0)
 					return (one);
-						/* C99: (-1)**+-inf = 1 */
+				/* C99: (-1)**+-inf = 1 */
 				else
 					return (y - y);
-						/* Sun: (+-1)**+-inf = NaN */
-			} else if (ahx >= 0x3ff00000)
-						/* (|x|>1)**+,-inf = inf,0 */
+
+				/* Sun: (+-1)**+-inf = NaN */
+			} else if (ahx >= 0x3ff00000) {
+				/* (|x|>1)**+,-inf = inf,0 */
 				return (sby == 0 ? y : zero);
-			else			/* (|x|<1)**-,+inf = inf,0 */
+			} else {	/* (|x|<1)**-,+inf = inf,0 */
 				return (sby != 0 ? -y : zero);
+			}
 		}
+
 		if (ahy == 0x3ff00000) {	/* y is  +-1 */
-			if (sby != 0) {	/* y is -1 */
+			if (sby != 0) {		/* y is -1 */
 				if (x == zero)	/* divided by zero */
 					return (_SVID_libm_err(x, y, 23));
 				else if (ahx < 0x40000 || ((ahx - 0x40000) |
-					lx) == 0)	/* overflow */
+				    lx) == 0)	/* overflow */
 					return (_SVID_libm_err(x, y, 21));
 				else
 					return (one / x);
-			} else
+			} else {
 				return (x);
+			}
 		}
-		if (hy == 0x40000000) {		/* y is  2 */
+
+		if (hy == 0x40000000) {	/* y is  2 */
 			if (ahx >= 0x5ff00000 && ahx < 0x7ff00000)
 				return (_SVID_libm_err(x, y, 21));
-							/* x*x overflow */
+			/* x*x overflow */
 			else if ((ahx < 0x1e56a09e && (ahx | lx) != 0) ||
-				(ahx == 0x1e56a09e && lx < 0x667f3bcd))
+			    (ahx == 0x1e56a09e && lx < 0x667f3bcd))
 				return (_SVID_libm_err(x, y, 22));
-							/* x*x underflow */
+			/* x*x underflow */
 			else
 				return (x * x);
 		}
+
 		if (hy == 0x3fe00000) {
 			if (!((ahx | lx) == 0 || ((ahx - 0x7ff00000) | lx) ==
-				0 || sbx == 1))
+			    0 || sbx == 1))
 				return (sqrt(x));	/* y is 0.5 and x > 0 */
 		}
 	}
+
 	/* special value of x */
 	if (lx == 0) {
 		if (ahx == 0x7ff00000 || ahx == 0 || ahx == 0x3ff00000) {
 			/* x is +-0,+-inf,-1 */
 			z = ax;
+
 			if (sby == 1) {
 				z = one / z;	/* z = |x|**y */
+
 				if (ahx == 0)
 					return (_SVID_libm_err(x, y, 23));
 			}
+
 			if (sbx == 1) {
 				if (ahx == 0x3ff00000 && yisint == 0)
 					z = _SVID_libm_err(x, y, 24);
-					/* neg**non-integral is NaN + invalid */
+				/* neg**non-integral is NaN + invalid */
 				else if (yisint == 1)
 					z = -z;	/* (x<0)**odd = -(|x|**odd) */
 			}
+
 			return (z);
 		}
 	}
+
 	/* (x<0)**(non-int) is NaN */
 	if (sbx == 1 && yisint == 0)
 		return (_SVID_libm_err(x, y, 24));
-	/* Now ax is finite, y is finite */
-	/* first compute log2(ax) = w1+w2, with 24 bits w1 */
+
+	/*
+	 * Now ax is finite, y is finite
+	 * first compute log2(ax) = w1+w2, with 24 bits w1
+	 */
 	w1 = log2_x(ax, &w2);
 
 	/* split up y into y1+y2 and compute (y1+y2)*(w1+w2) */
-	if (((ly & 0x07ffffff) == 0) || ahy >= 0x47e00000 ||
-		ahy <= 0x38100000) {
+	if (((ly & 0x07ffffff) == 0) || ahy >= 0x47e00000 || ahy <=
+	    0x38100000) {
 		/* no need to split if y is short or too large or too small */
 		y1 = y * w1;
 		y2 = y * w2;
 	} else {
-		y1 = (double) ((float) y);
+		y1 = (double)((float)y);
 		y2 = (y - y1) * w1 + y * w2;
 		y1 *= w1;
 	}
+
 	z = y1 + y2;
 	j = pz[HIWORD];
-	if (j >= 0x40900000) {				/* z >= 1024 */
-		if (!(j == 0x40900000 && pz[LOWORD] == 0))	/* z > 1024 */
+
+	if (j >= 0x40900000) {					/* z >= 1024 */
+		if (!(j == 0x40900000 && pz[LOWORD] == 0)) {	/* z > 1024 */
 			return (_SVID_libm_err(x, y, 21));	/* overflow */
-		else {
+		} else {
 			w2 = y1 - z;
 			w2 += y2;
-							/* rounded to inf */
+
+			/* rounded to inf */
 			if (w2 >= -8.008566259537296567160e-17)
 				return (_SVID_libm_err(x, y, 21));
-								/* overflow */
+
+			/* overflow */
 		}
-	} else if ((j & ~0x80000000) >= 0x4090cc00) {	/* z <= -1075 */
-		if (!(j == 0xc090cc00 && pz[LOWORD] == 0))	/* z < -1075 */
+	} else if ((j & ~0x80000000) >= 0x4090cc00) {		/* z <= -1075 */
+		if (!(j == 0xc090cc00 && pz[LOWORD] == 0)) {	/* z < -1075 */
 			return (_SVID_libm_err(x, y, 22));	/* underflow */
-		else {
+		} else {
 			w2 = y1 - z;
 			w2 += y2;
-			if (w2 <= zero)			/* underflow */
+
+			if (w2 <= zero)	/* underflow */
 				return (_SVID_libm_err(x, y, 22));
 		}
 	}
+
 	/*
 	 * compute 2**(k+f[j]+g)
 	 */
-	k = (int) (z * 64.0 + (((hy ^ (ahx - 0x3ff00000)) > 0) ? 0.5 : -0.5));
+	k = (int)(z * 64.0 + (((hy ^ (ahx - 0x3ff00000)) > 0) ? 0.5 : -0.5));
 	j = k & 63;
-	w1 = y2 - ((double) k * 0.015625 - y1);
+	w1 = y2 - ((double)k * 0.015625 - y1);
 	w2 = _TBL_exp2_hi[j];
-	z = _TBL_exp2_lo[j] + (w2 * w1) * (E1 + w1 * (E2 + w1 * (E3 + w1 *
-		(E4 + w1 * E5))));
+	z = _TBL_exp2_lo[j] + (w2 * w1) * (E1 + w1 * (E2 + w1 * (E3 + w1 * (E4 +
+	    w1 * E5))));
 	z += w2;
 	k >>= 6;
+
 	if (k < -1021)
 		z = scalbn(z, k);
-	else			/* subnormal output */
+	else				/* subnormal output */
 		pz[HIWORD] += k << 20;
+
 	if (sbx == 1 && yisint == 1)
-		z = -z;		/* (-ve)**(odd int) */
+		z = -z;			/* (-ve)**(odd int) */
+
 	return (z);
 }
--- old/usr/src/lib/libm/common/C/remainder.c	2019-06-06 20:37:58.613973841 +0000
+++ new/usr/src/lib/libm/common/C/remainder.c	2019-06-06 20:37:58.630761800 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +35,7 @@
  * Code originated from 4.3bsd.
  * Modified by K.C. Ng for SUN 4.0 libm.
  * Return :
- * 	returns  x REM p  =  x - [x/p]*p as if in infinite precise arithmetic,
+ *      returns  x REM p  =  x - [x/p]*p as if in infinite precise arithmetic,
  *	where [x/p] is the (inifinite bit) integer nearest x/p (in half way
  *	case choose the even one).
  * Method :
@@ -45,9 +47,10 @@
 static const double zero = 0.0, half = 0.5;
 
 double
-remainder(double x, double p) {
-	double	halfp;
-	int	ix, hx, hp;
+remainder(double x, double p)
+{
+	double halfp;
+	int ix, hx, hp;
 
 	ix = ((int *)&x)[HIWORD];
 	hx = ix & ~0x80000000;
@@ -55,6 +58,7 @@
 
 	if (hp > 0x7ff00000 || (hp == 0x7ff00000 && ((int *)&p)[LOWORD] != 0))
 		return (x * p);
+
 	if (hx > 0x7ff00000 || (hx == 0x7ff00000 && ((int *)&x)[LOWORD] != 0))
 		return (x * p);
 
@@ -62,26 +66,35 @@
 		return (_SVID_libm_err(x, p, 28));
 
 	p = fabs(p);
+
 	if (hp < 0x7fe00000)
 		x = fmod(x, p + p);
+
 	x = fabs(x);
+
 	if (hp < 0x00200000) {
 		if (x + x > p) {
 			if (x == p)	/* avoid x-x=-0 in RM mode */
-				return ((ix < 0)? -zero : zero);
+				return ((ix < 0) ? -zero : zero);
+
 			x -= p;
+
 			if (x + x >= p)
 				x -= p;
 		}
 	} else {
 		halfp = half * p;
+
 		if (x > halfp) {
 			if (x == p)	/* avoid x-x=-0 in RM mode */
-				return ((ix < 0)? -zero : zero);
+				return ((ix < 0) ? -zero : zero);
+
 			x -= p;
+
 			if (x >= halfp)
 				x -= p;
 		}
 	}
-	return ((ix < 0)? -x : x);
+
+	return ((ix < 0) ? -x : x);
 }
--- old/usr/src/lib/libm/common/C/rint.c	2019-06-06 20:37:59.122106965 +0000
+++ new/usr/src/lib/libm/common/C/rint.c	2019-06-06 20:37:59.140615700 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,37 +39,40 @@
 
 #if defined(__i386) && !defined(__amd64) && (!defined(__FLT_EVAL_METHOD__) || \
 	__FLT_EVAL_METHOD__ != 0)
+
 extern enum fp_precision_type __swapRP(enum fp_precision_type);
-#define	DECLRP(x)	enum fp_precision_type x;
-#define	SWAPRP(new, x)	x = __swapRP(new);
-#define	RESTRP(x)	(void) __swapRP(x);
+
+#define	DECLRP(x)		enum fp_precision_type x;
+#define	SWAPRP(new, x)		x = __swapRP(new);
+#define	RESTRP(x)		(void) __swapRP(x);
 #else
 #define	DECLRP(x)
 #define	SWAPRP(new, x)
 #define	RESTRP(x)
 #endif
 
-static const double
-	two52 = 4503599627370496.0,
-	zero = 0.0,
-	one = 1.0;
+static const double two52 = 4503599627370496.0, zero = 0.0, one = 1.0;
 
 double
-rint(double x) {
+rint(double x)
+{
 	DECLRP(rp)
-	double	t, w;
-	int	ix, hx;
+	double t, w;
+	int ix, hx;
 
 	ix = ((int *)&x)[HIWORD];
 	hx = ix & ~0x80000000;
 
 	if (hx >= 0x43300000)
 		return (x * one);
-	t = (ix < 0)? -two52 : two52;
+
+	t = (ix < 0) ? -two52 : two52;
 	SWAPRP(fp_double, rp)		/* set precision mode to double */
 	w = x + t;			/* x+sign(x)*2**52 rounded */
 	RESTRP(rp)			/* restore precision mode */
+
 	if (w == t)
-		return ((ix < 0)? -zero : zero);
+		return ((ix < 0) ? -zero : zero);
+
 	return (w - t);
 }
--- old/usr/src/lib/libm/common/C/scalb.c	2019-06-06 20:37:59.631661139 +0000
+++ new/usr/src/lib/libm/common/C/scalb.c	2019-06-06 20:37:59.649438841 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,42 +34,50 @@
 #include "libm.h"
 
 double
-scalb(double x, double fn) {
-	int	hn, in, n;
-	double	z;
+scalb(double x, double fn)
+{
+	int hn, in, n;
+	double z;
 
 	if (isnan(x) || isnan(fn))
 		return (x * fn);
 
 	in = ((int *)&fn)[HIWORD];
 	hn = in & ~0x80000000;
-	if (hn == 0x7ff00000)	/* fn is inf */
+
+	if (hn == 0x7ff00000)		/* fn is inf */
 		return (_SVID_libm_err(x, fn, 47));
 
 	/* see if fn is an integer without raising inexact */
 	if (hn >= 0x43300000) {
 		/* |fn| >= 2^52, so it must be an integer */
-		n = (in < 0)? -65000 : 65000;
+		n = (in < 0) ? -65000 : 65000;
 	} else if (hn < 0x3ff00000) {
 		/* |fn| < 1, so it must be zero or non-integer */
-		return ((fn == 0.0)? x : (x - x) / (x - x));
+		return ((fn == 0.0) ? x : (x - x) / (x - x));
 	} else if (hn < 0x41400000) {
 		/* |fn| < 2^21 */
-		if ((hn & ((1 << (0x413 - (hn >> 20))) - 1))
-		    | ((int *)&fn)[LOWORD])
+		if ((hn & ((1 << (0x413 - (hn >> 20))) - 1)) |
+		    ((int *)&fn)[LOWORD])
 			return ((x - x) / (x - x));
+
 		n = (int)fn;
 	} else {
 		if (((int *)&fn)[LOWORD] & ((1 << (0x433 - (hn >> 20))) - 1))
 			return ((x - x) / (x - x));
-		n = (in < 0)? -65000 : 65000;
+
+		n = (in < 0) ? -65000 : 65000;
 	}
+
 	z = scalbn(x, n);
+
 	if (z != x) {
 		if (z == 0.0)
 			return (_SVID_libm_err(x, fn, 33));
+
 		if (!finite(z))
 			return (_SVID_libm_err(x, fn, 32));
 	}
+
 	return (z);
 }
--- old/usr/src/lib/libm/common/C/scalbn.c	2019-06-06 20:38:00.116691676 +0000
+++ new/usr/src/lib/libm/common/C/scalbn.c	2019-06-06 20:38:00.135983415 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,11 +32,10 @@
 
 #include "libm.h"
 
-static const double
-	one	= 1.0,
-	huge	= 1.0e300,
-	tiny	= 1.0e-300,
-	twom54	= 5.5511151231257827021181583404541015625e-17;
+static const double one = 1.0,
+	huge = 1.0e300,
+	tiny = 1.0e-300,
+	twom54 = 5.5511151231257827021181583404541015625e-17;
 
 #if defined(__x86)
 static const double two52 = 4503599627370496.0;
@@ -43,7 +44,8 @@
  * Normalize non-zero subnormal x and return biased exponent of x in [-51,0]
  */
 static int
-ilogb_biased(unsigned *px) {
+ilogb_biased(unsigned *px)
+{
 	int s = 52;
 	unsigned v = px[HIWORD] & ~0x80000000, w = px[LOWORD], t = v;
 
@@ -51,14 +53,19 @@
 		s -= 32;
 	else
 		t = w;
+
 	if (t & 0xffff0000)
 		s -= 16, t >>= 16;
+
 	if (t & 0xff00)
 		s -= 8, t >>= 8;
+
 	if (t & 0xf0)
 		s -= 4, t >>= 4;
+
 	t <<= 1;
 	s -= (0xffffaa50 >> t) & 0x3;
+
 	if (s < 32) {
 		v = (v << s) | w >> (32 - s);
 		w <<= s;
@@ -66,27 +73,30 @@
 		v = w << (s - 32);
 		w = 0;
 	}
+
 	px[HIWORD] = (px[HIWORD] & 0x80000000) | v;
 	px[LOWORD] = w;
 	return (1 - s);
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 double
-scalbn(double x, int n) {
-	int	*px, ix, hx, k;
+scalbn(double x, int n)
+{
+	int *px, ix, hx, k;
 
 	px = (int *)&x;
 	ix = px[HIWORD];
 	hx = ix & ~0x80000000;
 	k = hx >> 20;
 
-	if (k == 0x7ff)	/* x is inf or NaN */
+	if (k == 0x7ff)			/* x is inf or NaN */
 		return (x * one);
 
 	if (k == 0) {
 		if ((hx | px[LOWORD]) == 0 || n == 0)
 			return (x);
+
 #if defined(__x86)
 		x *= two52;
 		ix = px[HIWORD];
@@ -97,24 +107,29 @@
 #endif
 		/* now k is in the range -51..0 */
 		k += n;
-		if (k > n)	/* integer overflow occurred */
+
+		if (k > n)		/* integer overflow occurred */
 			k = -100;
 	} else {
 		/* k is in the range 1..1023 */
 		k += n;
-		if (k < n)	/* integer overflow occurred */
+
+		if (k < n)		/* integer overflow occurred */
 			k = 0x7ff;
 	}
 
 	if (k > 0x7fe)
-		return (huge * ((ix < 0)? -huge : huge));
+		return (huge * ((ix < 0) ? -huge : huge));
+
 	if (k < 1) {
 		if (k <= -54)
-			return (tiny * ((ix < 0)? -tiny : tiny));
+			return (tiny * ((ix < 0) ? -tiny : tiny));
+
 		k += 54;
 		px[HIWORD] = (ix & ~0x7ff00000) | (k << 20);
 		return (x * twom54);
 	}
+
 	px[HIWORD] = (ix & ~0x7ff00000) | (k << 20);
 	return (x);
 }
--- old/usr/src/lib/libm/common/C/signgam.c	2019-06-06 20:38:00.620597111 +0000
+++ new/usr/src/lib/libm/common/C/signgam.c	2019-06-06 20:38:00.639298921 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/C/significand.c	2019-06-06 20:38:01.115993721 +0000
+++ new/usr/src/lib/libm/common/C/significand.c	2019-06-06 20:38:01.134758140 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,14 +33,16 @@
 #include "libm.h"
 
 double
-significand(double x) {
-	int ix = ((int *) &x)[HIWORD] & ~0x80000000;
+significand(double x)
+{
+	int ix = ((int *)&x)[HIWORD] & ~0x80000000;
 
 	/* weed out 0/+-Inf/NaN because C99 ilogb raises invalid on them */
-	if ((ix | ((int *) &x)[LOWORD]) == 0 || ix >= 0x7ff00000)
+	if ((ix | ((int *)&x)[LOWORD]) == 0 || ix >= 0x7ff00000)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return ((ix & 0x80000) != 0 ? x : x + x);
-		/* assumes sparc-like QNaN */
+
+	/* assumes sparc-like QNaN */
 #else
 		return (x + x);
 #endif
--- old/usr/src/lib/libm/common/C/sin.c	2019-06-06 20:38:01.617040614 +0000
+++ new/usr/src/lib/libm/common/C/sin.c	2019-06-06 20:38:01.634749589 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __sin = sin
 
-/* INDENT OFF */
+
 /*
  * sin(x)
  * Accurate Table look-up algorithm by K.C. Ng, May, 1995.
@@ -39,143 +41,165 @@
 #include "libm.h"
 
 static const double sc[] = {
-/* ONE	= */  1.0,
+/* ONE	= */
+	1.0,
 /* NONE	= */ -1.0,
+
 /*
  * |sin(x) - (x+pp1*x^3+pp2*x^5)| <= 2^-58.79 for |x| < 0.008
  */
-/* PP1	= */ -0.166666666666316558867252052378889521480627858683055567,
-/* PP2	= */   .008333315652997472323564894248466758248475374977974017927,
+/* PP1	= */-0.166666666666316558867252052378889521480627858683055567,
+/* PP2	= */.008333315652997472323564894248466758248475374977974017927,
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p4*x^9)|
  * |------------------------------ | <= 2^-57.63 for |x| < 0.1953125
  * |                 x             |
  */
-/* P1  	= */ -1.666666666666629669805215138920301589656e-0001,
-/* P2  	= */  8.333333332390951295683993455280336376663e-0003,
-/* P3  	= */ -1.984126237997976692791551778230098403960e-0004,
-/* P4  	= */  2.753403624854277237649987622848330351110e-0006,
+/* P1   = */ -1.666666666666629669805215138920301589656e-0001,
+/* P2   = */ 8.333333332390951295683993455280336376663e-0003,
+/* P3   = */ -1.984126237997976692791551778230098403960e-0004,
+/* P4   = */ 2.753403624854277237649987622848330351110e-0006,
+
 /*
  * |cos(x) - (1+qq1*x^2+qq2*x^4)| <= 2^-55.99 for |x| <= 0.008 (0x3f80624d)
  */
-/* QQ1	= */ -0.4999999999975492381842911981948418542742729,
-/* QQ2	= */  0.041666542904352059294545209158357640398771740,
-/* PI_H	= */  3.1415926535897931159979634685,
-/* PI_L    = */  1.22464679914735317722606593227425e-16,
-/* PI_L0   = */  1.22464679914558443311283879205095e-16,
-/* PI_L1   = */  1.768744113227140223300005233735517376e-28,
-/* PI2_H   = */  6.2831853071795862319959269370,
-/* PI2_L   = */  2.44929359829470635445213186454850e-16,
-/* PI2_L0  = */  2.44929359829116886622567758410190e-16,
-/* PI2_L1  = */  3.537488226454280446600010467471034752e-28,
+/* QQ1	= */-0.4999999999975492381842911981948418542742729,
+/* QQ2	= */0.041666542904352059294545209158357640398771740,
+/* PI_H	= */ 3.1415926535897931159979634685,
+/* PI_L    = */ 1.22464679914735317722606593227425e-16,
+/* PI_L0   = */ 1.22464679914558443311283879205095e-16,
+/* PI_L1   = */ 1.768744113227140223300005233735517376e-28,
+/* PI2_H   = */ 6.2831853071795862319959269370,
+/* PI2_L   = */ 2.44929359829470635445213186454850e-16,
+/* PI2_L0  = */ 2.44929359829116886622567758410190e-16,
+/* PI2_L1  = */ 3.537488226454280446600010467471034752e-28,
 };
-/* INDENT ON */
 
-#define	ONEA	sc
-#define	ONE	sc[0]
-#define	NONE	sc[1]
-#define	PP1	sc[2]
-#define	PP2	sc[3]
-#define	P1	sc[4]
-#define	P2	sc[5]
-#define	P3	sc[6]
-#define	P4	sc[7]
-#define	QQ1	sc[8]
-#define	QQ2	sc[9]
-#define	PI_H	sc[10]
-#define	PI_L	sc[11]
-#define	PI_L0	sc[12]
-#define	PI_L1	sc[13]
-#define	PI2_H	sc[14]
-#define	PI2_L	sc[15]
-#define	PI2_L0	sc[16]
-#define	PI2_L1	sc[17]
 
-extern const double  _TBL_sincos[], _TBL_sincosx[];
+#define	ONEA		sc
+#define	ONE		sc[0]
+#define	NONE		sc[1]
+#define	PP1		sc[2]
+#define	PP2		sc[3]
+#define	P1		sc[4]
+#define	P2		sc[5]
+#define	P3		sc[6]
+#define	P4		sc[7]
+#define	QQ1		sc[8]
+#define	QQ2		sc[9]
+#define	PI_H		sc[10]
+#define	PI_L		sc[11]
+#define	PI_L0		sc[12]
+#define	PI_L1		sc[13]
+#define	PI2_H		sc[14]
+#define	PI2_L		sc[15]
+#define	PI2_L0		sc[16]
+#define	PI2_L1		sc[17]
+
+extern const double _TBL_sincos[], _TBL_sincosx[];
 
 double
-sin(double x) {
-	double	z, y[2], w, s, v, p, q;
-	int	i, j, n, hx, ix, lx;
+sin(double x)
+{
+	double z, y[2], w, s, v, p, q;
+	int i, j, n, hx, ix, lx;
 
 	hx = ((int *)&x)[HIWORD];
 	lx = ((int *)&x)[LOWORD];
 	ix = hx & ~0x80000000;
 
-	if (ix <= 0x3fc50000) {	/* |x| < .1640625 */
+	if (ix <= 0x3fc50000) {		/* |x| < .1640625 */
 		if (ix < 0x3e400000)	/* |x| < 2**-27 */
 			if ((int)x == 0)
 				return (x);
+
 		z = x * x;
+
 		if (ix < 0x3f800000)	/* |x| < 2**-8 */
 			w = (z * x) * (PP1 + z * PP2);
 		else
 			w = (x * z) * ((P1 + z * P2) + (z * z) * (P3 + z * P4));
+
 		return (x + w);
 	}
 
 	/* for .1640625 < x < M, */
 	n = ix >> 20;
-	if (n < 0x402) {	/* x < 8 */
+
+	if (n < 0x402) {		/* x < 8 */
 		i = (((ix >> 12) & 0xff) | 0x100) >> (0x401 - n);
 		j = i - 10;
 		x = fabs(x);
 		v = x - _TBL_sincosx[j];
+
 		if (((j - 181) ^ (j - 201)) < 0) {
 			/* near pi, sin(x) = sin(pi-x) */
 			p = PI_H - x;
 			i = ix - 0x400921fb;
 			x = p + PI_L;
+
 			if ((i | ((lx - 0x54442D00) & 0xffffff00)) == 0) {
 				/* very close to pi */
 				x = p + PI_L0;
-				return ((hx >= 0)? x + PI_L1 : -(x + PI_L1));
+				return ((hx >= 0) ? x + PI_L1 : -(x + PI_L1));
 			}
+
 			z = x * x;
+
 			if (((ix - 0x40092000) >> 11) == 0) {
 				/* |pi-x|<2**-8 */
 				w = PI_L + (z * x) * (PP1 + z * PP2);
 			} else {
-				w = PI_L + (z * x) * ((P1 + z * P2) +
-				    (z * z) * (P3 + z * P4));
+				w = PI_L + (z * x) * ((P1 + z * P2) + (z * z) *
+				    (P3 + z * P4));
 			}
-			return ((hx >= 0)? p + w : -p - w);
+
+			return ((hx >= 0) ? p + w : -p - w);
 		}
+
 		s = v * v;
+
 		if (((j - 382) ^ (j - 402)) < 0) {
 			/* near 2pi, sin(x) = sin(x-2pi) */
 			p = x - PI2_H;
 			i = ix - 0x401921fb;
 			x = p - PI2_L;
+
 			if ((i | ((lx - 0x54442D00) & 0xffffff00)) == 0) {
 				/* very close to 2pi */
 				x = p - PI2_L0;
-				return ((hx >= 0)? x - PI2_L1 : -(x - PI2_L1));
+				return ((hx >= 0) ? x - PI2_L1 : -(x - PI2_L1));
 			}
+
 			z = x * x;
+
 			if (((ix - 0x40192000) >> 10) == 0) {
 				/* |x-2pi|<2**-8 */
 				w = (z * x) * (PP1 + z * PP2) - PI2_L;
 			} else {
-				w = (z * x) * ((P1 + z * P2) +
-				    (z * z) * (P3 + z * P4)) - PI2_L;
+				w = (z * x) * ((P1 + z * P2) + (z * z) * (P3 +
+				    z * P4)) - PI2_L;
 			}
-			return ((hx >= 0)? p + w : -p - w);
+
+			return ((hx >= 0) ? p + w : -p - w);
 		}
+
 		j <<= 1;
-		w = _TBL_sincos[j+1];
+		w = _TBL_sincos[j + 1];
 		z = _TBL_sincos[j];
 		p = v + (v * s) * (PP1 + s * PP2);
 		q = s * (QQ1 + s * QQ2);
 		v = w * p + z * q;
-		return ((hx >= 0)? z + v : -z - v);
+		return ((hx >= 0) ? z + v : -z - v);
 	}
 
-	if (ix >= 0x7ff00000)	/* sin(Inf or NaN) is NaN */
+	if (ix >= 0x7ff00000)		/* sin(Inf or NaN) is NaN */
 		return (x / x);
 
 	/* argument reduction needed */
 	n = __rem_pio2(x, y);
+
 	switch (n & 3) {
 	case 0:
 		return (__k_sin(y[0], y[1]));
--- old/usr/src/lib/libm/common/C/sincos.c	2019-06-06 20:38:02.112477060 +0000
+++ new/usr/src/lib/libm/common/C/sincos.c	2019-06-06 20:38:02.129351405 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,6 @@
 
 #pragma weak __sincos = sincos
 
-/* INDENT OFF */
 /*
  * sincos(x,s,c)
  * Accurate Table look-up algorithm by K.C. Ng, 2000.
@@ -91,159 +92,173 @@
 
 #include "libm.h"
 
+/* BEGIN CSTYLED */
 static const double sc[] = {
-/* ONE	= */  1.0,
+/* ONE	= */
+	1.0,
 /* NONE	= */ -1.0,
+
 /*
  * |sin(x) - (x+pp1*x^3+pp2*x^5)| <= 2^-58.79 for |x| < 0.008
  */
-/* PP1	= */ -0.166666666666316558867252052378889521480627858683055567,
-/* PP2	= */   .008333315652997472323564894248466758248475374977974017927,
+/* PP1	= */-0.166666666666316558867252052378889521480627858683055567,
+/* PP2	= */.008333315652997472323564894248466758248475374977974017927,
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p4*x^9)|
  * |------------------------------ | <= 2^-57.63 for |x| < 0.1953125
  * |                 x             |
  */
-/* P1  	= */ -1.666666666666629669805215138920301589656e-0001,
-/* P2  	= */  8.333333332390951295683993455280336376663e-0003,
-/* P3  	= */ -1.984126237997976692791551778230098403960e-0004,
-/* P4  	= */  2.753403624854277237649987622848330351110e-0006,
+/* P1   = */ -1.666666666666629669805215138920301589656e-0001,
+/* P2   = */ 8.333333332390951295683993455280336376663e-0003,
+/* P3   = */ -1.984126237997976692791551778230098403960e-0004,
+/* P4   = */ 2.753403624854277237649987622848330351110e-0006,
+
 /*
  * |cos(x) - (1+qq1*x^2+qq2*x^4)| <= 2^-55.99 for |x| <= 0.008 (0x3f80624d)
  */
-/* QQ1	= */ -0.4999999999975492381842911981948418542742729,
-/* QQ2	= */  0.041666542904352059294545209158357640398771740,
-/* Q1  	= */ -0.5,
-/* Q2  	= */  4.166666666500350703680945520860748617445e-0002,
-/* Q3  	= */ -1.388888596436972210694266290577848696006e-0003,
-/* Q4  	= */  2.478563078858589473679519517892953492192e-0005,
-/* PIO2_H    = */  1.570796326794896557999,
-/* PIO2_L    = */  6.123233995736765886130e-17,
-/* PIO2_L0   = */  6.123233995727922165564e-17,
-/* PIO2_L1   = */  8.843720566135701120255e-29,
-/* PI_H      = */  3.1415926535897931159979634685,
-/* PI_L      = */  1.22464679914735317722606593227425e-16,
-/* PI_L0     = */  1.22464679914558443311283879205095e-16,
-/* PI_L1     = */  1.768744113227140223300005233735517376e-28,
-/* PI3O2_H   = */  4.712388980384689673997,
-/* PI3O2_L   = */  1.836970198721029765839e-16,
-/* PI3O2_L0  = */  1.836970198720396133587e-16,
-/* PI3O2_L1  = */  6.336322524749201142226e-29,
-/* PI2_H     = */  6.2831853071795862319959269370,
-/* PI2_L     = */  2.44929359829470635445213186454850e-16,
-/* PI2_L0    = */  2.44929359829116886622567758410190e-16,
-/* PI2_L1    = */  3.537488226454280446600010467471034752e-28,
-/* PI5O2_H   = */  7.853981633974482789995,
-/* PI5O2_L   = */  3.061616997868382943065e-16,
-/* PI5O2_L0  = */  3.061616997861941598865e-16,
-/* PI5O2_L1  = */  6.441344200433640781982e-28,
+/* QQ1	= */-0.4999999999975492381842911981948418542742729,
+/* QQ2	= */0.041666542904352059294545209158357640398771740,
+/* Q1   = */ -0.5,
+/* Q2   = */ 4.166666666500350703680945520860748617445e-0002,
+/* Q3   = */ -1.388888596436972210694266290577848696006e-0003,
+/* Q4   = */ 2.478563078858589473679519517892953492192e-0005,
+/* PIO2_H    = */ 1.570796326794896557999,
+/* PIO2_L    = */ 6.123233995736765886130e-17,
+/* PIO2_L0   = */ 6.123233995727922165564e-17,
+/* PIO2_L1   = */ 8.843720566135701120255e-29,
+/* PI_H      = */ 3.1415926535897931159979634685,
+/* PI_L      = */ 1.22464679914735317722606593227425e-16,
+/* PI_L0     = */ 1.22464679914558443311283879205095e-16,
+/* PI_L1     = */ 1.768744113227140223300005233735517376e-28,
+/* PI3O2_H   = */ 4.712388980384689673997,
+/* PI3O2_L   = */ 1.836970198721029765839e-16,
+/* PI3O2_L0  = */ 1.836970198720396133587e-16,
+/* PI3O2_L1  = */ 6.336322524749201142226e-29,
+/* PI2_H     = */ 6.2831853071795862319959269370,
+/* PI2_L     = */ 2.44929359829470635445213186454850e-16,
+/* PI2_L0    = */ 2.44929359829116886622567758410190e-16,
+/* PI2_L1    = */ 3.537488226454280446600010467471034752e-28,
+/* PI5O2_H   = */ 7.853981633974482789995,
+/* PI5O2_L   = */ 3.061616997868382943065e-16,
+/* PI5O2_L0  = */ 3.061616997861941598865e-16,
+/* PI5O2_L1  = */ 6.441344200433640781982e-28,
 };
-/* INDENT ON */
+/* END CSTYLED */
 
-#define	ONE		sc[0]
-#define	PP1		sc[2]
-#define	PP2		sc[3]
-#define	P1		sc[4]
-#define	P2		sc[5]
-#define	P3		sc[6]
-#define	P4		sc[7]
-#define	QQ1		sc[8]
-#define	QQ2		sc[9]
-#define	Q1		sc[10]
-#define	Q2		sc[11]
-#define	Q3		sc[12]
-#define	Q4		sc[13]
-#define	PIO2_H		sc[14]
-#define	PIO2_L		sc[15]
-#define	PIO2_L0		sc[16]
-#define	PIO2_L1		sc[17]
-#define	PI_H		sc[18]
-#define	PI_L		sc[19]
-#define	PI_L0		sc[20]
-#define	PI_L1		sc[21]
-#define	PI3O2_H		sc[22]
-#define	PI3O2_L		sc[23]
-#define	PI3O2_L0	sc[24]
-#define	PI3O2_L1	sc[25]
-#define	PI2_H		sc[26]
-#define	PI2_L		sc[27]
-#define	PI2_L0		sc[28]
-#define	PI2_L1		sc[29]
-#define	PI5O2_H		sc[30]
-#define	PI5O2_L		sc[31]
-#define	PI5O2_L0	sc[32]
-#define	PI5O2_L1	sc[33]
-#define	PoS(x, z)	((x * z) * (PP1 + z * PP2))
-#define	PoL(x, z)	((x * z) * ((P1 + z * P2) + (z * z) * (P3 + z * P4)))
+#define	ONE			sc[0]
+#define	PP1			sc[2]
+#define	PP2			sc[3]
+#define	P1			sc[4]
+#define	P2			sc[5]
+#define	P3			sc[6]
+#define	P4			sc[7]
+#define	QQ1			sc[8]
+#define	QQ2			sc[9]
+#define	Q1			sc[10]
+#define	Q2			sc[11]
+#define	Q3			sc[12]
+#define	Q4			sc[13]
+#define	PIO2_H			sc[14]
+#define	PIO2_L			sc[15]
+#define	PIO2_L0			sc[16]
+#define	PIO2_L1			sc[17]
+#define	PI_H			sc[18]
+#define	PI_L			sc[19]
+#define	PI_L0			sc[20]
+#define	PI_L1			sc[21]
+#define	PI3O2_H			sc[22]
+#define	PI3O2_L			sc[23]
+#define	PI3O2_L0		sc[24]
+#define	PI3O2_L1		sc[25]
+#define	PI2_H			sc[26]
+#define	PI2_L			sc[27]
+#define	PI2_L0			sc[28]
+#define	PI2_L1			sc[29]
+#define	PI5O2_H			sc[30]
+#define	PI5O2_L			sc[31]
+#define	PI5O2_L0		sc[32]
+#define	PI5O2_L1		sc[33]
+#define	PoS(x, z)		((x * z) * (PP1 + z * PP2))
+#define	PoL(x, z)		((x * z) * ((P1 + z * P2) + (z * z) * \
+	(P3 + z * P4)))
 
 extern const double _TBL_sincos[], _TBL_sincosx[];
 
 void
-sincos(double x, double *s, double *c) {
-	double	z, y[2], w, t, v, p, q;
-	int	i, j, n, hx, ix, lx;
+sincos(double x, double *s, double *c)
+{
+	double z, y[2], w, t, v, p, q;
+	int i, j, n, hx, ix, lx;
 
 	hx = ((int *)&x)[HIWORD];
 	lx = ((int *)&x)[LOWORD];
 	ix = hx & ~0x80000000;
 
-	if (ix <= 0x3fc50000) {	/* |x| < 10.5/64 = 0.164062500 */
+	if (ix <= 0x3fc50000) {		/* |x| < 10.5/64 = 0.164062500 */
 		if (ix < 0x3e400000) {	/* |x| < 2**-27 */
 			if ((int)x == 0)
 				*c = ONE;
+
 			*s = x;
 		} else {
 			z = x * x;
+
 			if (ix < 0x3f800000) {	/* |x| < 0.008 */
 				q = z * (QQ1 + z * QQ2);
 				p = PoS(x, z);
 			} else {
-				q = z * ((Q1 + z * Q2) + (z * z) *
-				    (Q3 + z * Q4));
+				q = z * ((Q1 + z * Q2) + (z * z) * (Q3 + z *
+				    Q4));
 				p = PoL(x, z);
 			}
+
 			*c = ONE + q;
 			*s = x + p;
 		}
+
 		return;
 	}
 
 	n = ix >> 20;
 	i = (((ix >> 12) & 0xff) | 0x100) >> (0x401 - n);
 	j = i - 10;
-	if (n < 0x402) {	/* |x| < 8 */
+
+	if (n < 0x402) {		/* |x| < 8 */
 		x = fabs(x);
 		v = x - _TBL_sincosx[j];
 		t = v * v;
-		w = _TBL_sincos[(j<<1)];
-		z = _TBL_sincos[(j<<1)+1];
+		w = _TBL_sincos[(j << 1)];
+		z = _TBL_sincos[(j << 1) + 1];
 		p = v + PoS(v, t);
 		q = t * (QQ1 + t * QQ2);
-		if ((((j - 81) ^ (j - 101)) |
-		    ((j - 282) ^ (j - 302)) |
-		    ((j - 483) ^ (j - 503)) |
-		    ((j - 181) ^ (j - 201)) |
-		    ((j - 382) ^ (j - 402))) < 0) {
+
+		if ((((j - 81) ^ (j - 101)) | ((j - 282) ^ (j - 302)) | ((j -
+		    483) ^ (j - 503)) | ((j - 181) ^ (j - 201)) | ((j - 382) ^
+		    (j - 402))) < 0) {
 			if (j <= 101) {
 				/* near pi/2, cos(x) = sin(pi/2-x) */
 				t = w * q + z * p;
-				*s = (hx >= 0)? w + t : -w - t;
+				*s = (hx >= 0) ? w + t : -w - t;
 				p = PIO2_H - x;
 				i = ix - 0x3ff921fb;
 				x = p + PIO2_L;
-				if ((i | ((lx - 0x54442D00) &
-				    0xffffff00)) == 0) {
+
+				if ((i | ((lx - 0x54442D00) & 0xffffff00)) ==
+				    0) {
 					/* very close to pi/2 */
 					x = p + PIO2_L0;
 					*c = x + PIO2_L1;
 				} else {
 					z = x * x;
+
 					if (((ix - 0x3ff92000) >> 12) == 0) {
 						/* |pi/2-x|<2**-8 */
 						w = PIO2_L + PoS(x, z);
 					} else {
 						w = PIO2_L + PoL(x, z);
 					}
+
 					*c = p + w;
 				}
 			} else if (j <= 201) {
@@ -252,42 +267,48 @@
 				p = PI_H - x;
 				i = ix - 0x400921fb;
 				x = p + PI_L;
-				if ((i | ((lx - 0x54442D00) &
-				    0xffffff00)) == 0) {
+
+				if ((i | ((lx - 0x54442D00) & 0xffffff00)) ==
+				    0) {
 					/* very close to pi */
 					x = p + PI_L0;
-					*s = (hx >= 0)? x + PI_L1 :
-					    -(x + PI_L1);
+					*s = (hx >= 0) ? x + PI_L1 : -(x +
+					    PI_L1);
 				} else {
 					z = x * x;
+
 					if (((ix - 0x40092000) >> 11) == 0) {
 						/* |pi-x|<2**-8 */
 						w = PI_L + PoS(x, z);
 					} else {
 						w = PI_L + PoL(x, z);
 					}
-					*s = (hx >= 0)? p + w : -p - w;
+
+					*s = (hx >= 0) ? p + w : -p - w;
 				}
 			} else if (j <= 302) {
 				/* near 3/2pi, cos(x)=sin(x-3/2pi) */
 				t = w * q + z * p;
-				*s = (hx >= 0)? w + t : -w - t;
+				*s = (hx >= 0) ? w + t : -w - t;
 				p = x - PI3O2_H;
 				i = ix - 0x4012D97C;
 				x = p - PI3O2_L;
-				if ((i | ((lx - 0x7f332100) &
-				    0xffffff00)) == 0) {
+
+				if ((i | ((lx - 0x7f332100) & 0xffffff00)) ==
+				    0) {
 					/* very close to 3/2pi */
 					x = p - PI3O2_L0;
 					*c = x - PI3O2_L1;
 				} else {
 					z = x * x;
+
 					if (((ix - 0x4012D800) >> 9) == 0) {
 						/* |3/2pi-x|<2**-8 */
 						w = PoS(x, z) - PI3O2_L;
 					} else {
 						w = PoL(x, z) - PI3O2_L;
 					}
+
 					*c = p + w;
 				}
 			} else if (j <= 402) {
@@ -296,50 +317,57 @@
 				p = x - PI2_H;
 				i = ix - 0x401921fb;
 				x = p - PI2_L;
-				if ((i | ((lx - 0x54442D00) &
-				    0xffffff00)) == 0) {
+
+				if ((i | ((lx - 0x54442D00) & 0xffffff00)) ==
+				    0) {
 					/* very close to 2pi */
 					x = p - PI2_L0;
-					*s = (hx >= 0)? x - PI2_L1 :
-					    -(x - PI2_L1);
+					*s = (hx >= 0) ? x - PI2_L1 : -(x -
+					    PI2_L1);
 				} else {
 					z = x * x;
+
 					if (((ix - 0x40192000) >> 10) == 0) {
 						/* |x-2pi|<2**-8 */
 						w = PoS(x, z) - PI2_L;
 					} else {
 						w = PoL(x, z) - PI2_L;
 					}
-					*s = (hx >= 0)? p + w : -p - w;
+
+					*s = (hx >= 0) ? p + w : -p - w;
 				}
 			} else {
 				/* near 5pi/2, cos(x) = sin(5pi/2-x) */
 				t = w * q + z * p;
-				*s = (hx >= 0)? w + t : -w - t;
+				*s = (hx >= 0) ? w + t : -w - t;
 				p = PI5O2_H - x;
 				i = ix - 0x401F6A7A;
 				x = p + PI5O2_L;
-				if ((i | ((lx - 0x29553800) &
-				    0xffffff00)) == 0) {
+
+				if ((i | ((lx - 0x29553800) & 0xffffff00)) ==
+				    0) {
 					/* very close to pi/2 */
 					x = p + PI5O2_L0;
 					*c = x + PI5O2_L1;
 				} else {
 					z = x * x;
+
 					if (((ix - 0x401F6A7A) >> 7) == 0) {
 						/* |5pi/2-x|<2**-8 */
 						w = PI5O2_L + PoS(x, z);
 					} else {
 						w = PI5O2_L + PoL(x, z);
 					}
+
 					*c = p + w;
 				}
 			}
 		} else {
 			*c = z - (w * p - z * q);
 			t = w * q + z * p;
-			*s = (hx >= 0)? w + t : -w - t;
+			*s = (hx >= 0) ? w + t : -w - t;
 		}
+
 		return;
 	}
 
@@ -350,6 +378,7 @@
 
 	/* argument reduction needed */
 	n = __rem_pio2(x, y);
+
 	switch (n & 3) {
 	case 0:
 		*s = __k_sincos(y[0], y[1], c);
--- old/usr/src/lib/libm/common/C/sincospi.c	2019-06-06 20:38:02.599923376 +0000
+++ new/usr/src/lib/libm/common/C/sincospi.c	2019-06-06 20:38:02.617053683 +0000
@@ -22,12 +22,12 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
 /*
  * void sincospi(double x, double *s, double *c)
  * *s = sin(pi*x); *c = cos(pi*x);
@@ -77,11 +77,11 @@
 #include <sunmath.h>
 #endif
 
-static const double
-	pi 	= 3.14159265358979323846,	/* 400921FB,54442D18 */
+/* BEGIN CSTYLEd */
+static const double pi = 3.14159265358979323846,	/* 400921FB,54442D18 */
 	sqrth_h = 0.70710678118654757273731092936941422522068023681640625,
 	sqrth_l = -4.8336466567264565185935844299127932213411660131004e-17;
-/* INDENT ON */
+/* END CSTYLED */
 
 void
 sincospi(double x, double *s, double *c)
@@ -93,6 +93,7 @@
 
 	ix = hx & ~0x80000000;
 	n = (ix >> 20) - 0x3ff;
+
 	if (n >= 51) {			/* |x| >= 2**51 */
 		if (n >= 1024) {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
@@ -121,23 +122,24 @@
 					*s = 1.0;
 					*c = 0.0;
 				}
+
 				if ((lx & 2) != 0) {
 					*s = -*s;
 					*c = -*c;
 				}
 			}
 		}
-	} else if (n < -2)	/* |x| < 0.25 */
+	} else if (n < -2) {		/* |x| < 0.25 */
 		*s = __k_sincos(pi * fabs(x), 0.0, c);
-	else {
+	} else {
 		/* y = |4x|, z = floor(y), and n = (int)(z mod 8.0) */
-		if (ix < 0x41C00000) {		/* |x| < 2**29 */
+		if (ix < 0x41C00000) {	/* |x| < 2**29 */
 			y = 4.0 * fabs(x);
-			n = (int)y;		/* exact */
+			n = (int)y;	/* exact */
 			z = (double)n;
 			k = z == y;
 			t = (y - z) * 0.25;
-		} else {			/* 2**29 <= |x| < 2**51 */
+		} else {		/* 2**29 <= |x| < 2**51 */
 			y = fabs(x);
 			k = 50 - n;
 			n = lx >> k;
@@ -147,7 +149,8 @@
 			k = h == lx;
 			t = y - z;
 		}
-		if (k) {			/* x = N/4 */
+
+		if (k) {		/* x = N/4 */
 			if ((n & 1) != 0) {
 				*s = *c = sqrth_h + sqrth_l;
 			} else {
@@ -159,23 +162,29 @@
 					*c = 0.0;
 				}
 			}
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 1) & 4) != 0)
 				*c = -*c;
 		} else {
 			if ((n & 1) != 0)
 				t = 0.25 - t;
+
 			if (((n + (n & 1)) & 2) == 0)
 				*s = __k_sincos(pi * t, 0.0, c);
 			else
 				*c = __k_sincos(pi * t, 0.0, s);
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 2) & 4) != 0)
 				*c = -*c;
 		}
 	}
+
 	if (hx < 0)
 		*s = -*s;
 }
--- old/usr/src/lib/libm/common/C/sinh.c	2019-06-06 20:38:03.074556948 +0000
+++ new/usr/src/lib/libm/common/C/sinh.c	2019-06-06 20:38:03.087464968 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __sinh = sinh
 
-/* INDENT OFF */
+
 /*
  * sinh(x)
  * Code originated from 4.3bsd.
@@ -48,32 +50,36 @@
  *	only sinh(0)=0 is exact for finite argument.
  *
  */
-/* INDENT ON */
 
 #include "libm.h"
 
-static const double
-	ln2hi = 6.93147180369123816490e-01,
+static const double ln2hi = 6.93147180369123816490e-01,
 	ln2lo = 1.90821492927058770002e-10,
 	lnovft = 7.09782712893383973096e+02;
 
 double
-sinh(double x) {
-	double	ox, r, t;
+sinh(double x)
+{
+	double ox, r, t;
 
 	ox = x;
 	r = fabs(x);
+
 	if (!finite(x))
 		return (x * r);
+
 	if (r < lnovft) {
 		t = expm1(r);
 		r = copysign((t + t / (1.0 + t)) * 0.5, x);
 	} else {
 		if (r < 1000.0)
 			x = copysign(exp((r - 1024 * ln2hi) - 1024 * ln2lo), x);
+
 		r = scalbn(x, 1023);
 	}
+
 	if (!finite(r))
 		r = _SVID_libm_err(ox, ox, 25);
+
 	return (r);
 }
--- old/usr/src/lib/libm/common/C/sqrt.c	2019-06-06 20:38:03.483542019 +0000
+++ new/usr/src/lib/libm/common/C/sqrt.c	2019-06-06 20:38:03.499690298 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,15 +32,15 @@
 
 #include "libm.h"
 
-
 extern double __inline_sqrt(double);
 
 double
-sqrt(double x) {
-	double	z = __inline_sqrt(x);
+sqrt(double x)
+{
+	double z = __inline_sqrt(x);
 
 	if (isnan(x))
 		return (z);
-	return ((x < 0.0)? _SVID_libm_err(x, x, 26) : z);
-}
 
+	return ((x < 0.0) ? _SVID_libm_err(x, x, 26) : z);
+}
--- old/usr/src/lib/libm/common/C/tan.c	2019-06-06 20:38:03.948843150 +0000
+++ new/usr/src/lib/libm/common/C/tan.c	2019-06-06 20:38:03.965265982 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __tan = tan
 
-/* INDENT OFF */
+
 /*
  * tan(x)
  * Table look-up algorithm by K.C. Ng, November, 1989.
@@ -38,25 +39,26 @@
  *	__k_tan		... tangent function on [-pi/4,pi/4]
  *	__rem_pio2	... argument reduction routine
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "libm_protos.h"
 #include <math.h>
 
 double
-tan(double x) {
+tan(double x)
+{
 	double y[2], z = 0.0;
 	int n, ix;
 
 	/* high word of x */
-	ix = ((int *) &x)[HIWORD];
+	ix = ((int *)&x)[HIWORD];
 
 	/* |x| ~< pi/4 */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3fe921fb)
-		return (__k_tan(x, z, 0));
 
+	if (ix <= 0x3fe921fb) {
+		return (__k_tan(x, z, 0));
+	}
 	/* tan(Inf or NaN) is NaN */
 	else if (ix >= 0x7ff00000) {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
@@ -66,7 +68,6 @@
 		return (x - x);				/* NaN */
 #endif
 	}
-
 	/* argument reduction needed */
 	else {
 		n = __rem_pio2(x, y);
--- old/usr/src/lib/libm/common/C/tanh.c	2019-06-06 20:38:04.427949915 +0000
+++ new/usr/src/lib/libm/common/C/tanh.c	2019-06-06 20:38:04.449533585 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __tanh = tanh
 
-/* INDENT OFF */
+
 /*
  * TANH(X)
  * RETURN THE HYPERBOLIC TANGENT OF X
@@ -59,12 +60,8 @@
 #include "libm_protos.h"
 #include <math.h>
 
-static const double
-	one = 1.0,
-	two = 2.0,
-	small = 1.0e-10,
-	big = 1.0e10;
-/* INDENT ON */
+static const double one = 1.0, two = 2.0, small = 1.0e-10, big = 1.0e10;
+
 
 double
 tanh(double x)
@@ -74,14 +71,16 @@
 	volatile double dummy __unused;
 
 	if (isnan(x))
-		return (x * x);	/* + -> * for Cheetah */
+		return (x * x);		/* + -> * for Cheetah */
+
 	signx = signbit(x);
 	t = fabs(x);
 	z = one;
+
 	if (t <= 22.0) {
-		if (t > one)
+		if (t > one) {
 			z = one - two / (expm1(t + t) + two);
-		else if (t > small) {
+		} else if (t > small) {
 			y = expm1(-t - t);
 			z = -y / (y + two);
 		} else {
@@ -92,10 +91,11 @@
 #endif
 			return (x);
 		}
-	} else if (!finite(t))
+	} else if (!finite(t)) {
 		return (copysign(1.0, x));
-	else
+	} else {
 		return ((signx != 0) ? -z + small * small : z - small * small);
+	}
 
 	return ((signx != 0) ? -z : z);
 }
--- old/usr/src/lib/libm/common/C/xpg6.h	2019-06-06 20:38:04.899914160 +0000
+++ new/usr/src/lib/libm/common/C/xpg6.h	2019-06-06 20:38:04.917469768 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,31 +40,33 @@
  * cases as per SUSv3 spec where math_errhandling is set to MATH_ERREXCEPT;
  * otherwise they behave as per SUSv2 spec.
  */
-#define	_C99SUSv3_math_errexcept		0x00000400
+#define	_C99SUSv3_math_errexcept			0x00000400
+
 /*
  * If set, pow(+/-1,+/-Inf) & pow(1,NaN) return 1; otherwise NaN is returned.
  * Analogous comment applies to powf and powl.
  */
-#define	_C99SUSv3_pow_treats_Inf_as_an_even_int	0x00000080
+#define	_C99SUSv3_pow_treats_Inf_as_an_even_int		0x00000080
+
 /*
  * If set, logb(subnormal) returns (double) ilogb(subnormal); otherwise
  * logb(subnormal) returns logb(DBL_MIN).  Analogous comment applies to
  * logbf and logbl.
  */
-#define	_C99SUSv3_logb_subnormal_is_like_ilogb	0x00000040
+#define	_C99SUSv3_logb_subnormal_is_like_ilogb		0x00000040
+
 /*
  * If set, ilogb(0/+Inf/-Inf/NaN) raises FE_INVALID as per SUSv3; otherwise
  * no exception is raised.  Analogous comment applies to ilogbf and ilogbl.
  */
-#define	_C99SUSv3_ilogb_0InfNaN_raises_invalid	0x00000020
+#define	_C99SUSv3_ilogb_0InfNaN_raises_invalid		0x00000020
 
 /*
  * __xpg6 = _C99SUSv3_mode_OFF disables C99/SUSv3 standards conformance mode.
  */
-#define	_C99SUSv3_mode_OFF	0xFFFF0000
+#define	_C99SUSv3_mode_OFF				0xFFFF0000
 
 #if !defined(_ASM)
 extern unsigned int __xpg6;
 #endif
-
 #endif /* _XPG6_H */
--- old/usr/src/lib/libm/common/LD/_TBL_cosl.c	2019-06-06 20:38:05.395252553 +0000
+++ new/usr/src/lib/libm/common/LD/_TBL_cosl.c	2019-06-06 20:38:05.412948411 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,156 +40,88 @@
 #include "libm.h"
 
 const long double _TBL_cosl_hi[] = {
-	 9.8781778381647194407734133e-01L,
-	 9.8720237785483049041453801e-01L,
-	 9.8657190839949758873065125e-01L,
-	 9.8592638507066143575569700e-01L,
-	 9.8526581771821381618451860e-01L,
-	 9.8459021642159980601798769e-01L,
-	 9.8389959148966397219646454e-01L,
-	 9.8319395346049307253706584e-01L,
-	 9.8247331310125525749262290e-01L,
-	 9.8173768140803577633441562e-01L,
-	 9.8098706960566919046918752e-01L,
-	 9.8022148914756809622147657e-01L,
-	 9.7944095171554836000860772e-01L,
-	 9.7864546921965086785991095e-01L,
-	 9.7783505379795979334592304e-01L,
-	 9.7700971781641738478493484e-01L,
-	 9.7616947386863527671421389e-01L,
-	 9.7531433477570232649326437e-01L,
-	 9.7444431358598898037593275e-01L,
-	 9.7355942357494817143660423e-01L,
-	 9.7265967824491275265730642e-01L,
-	 9.7174509132488946761517512e-01L,
-	 9.7081567677034946294446077e-01L,
-	 9.6987144876301534501253018e-01L,
-	 9.6891242171064478417089050e-01L,
-	 9.6695002923067782202260975e-01L,
-	 9.6492861910477100957986285e-01L,
-	 9.6284831470937969988364152e-01L,
-	 9.6070924301556190306409372e-01L,
-	 9.5851153458122862729886421e-01L,
-	 9.5625532354317529696403552e-01L,
-	 9.5394074760889473397129298e-01L,
-	 9.5156794804817220216272555e-01L,
-	 9.4913706968446302764510006e-01L,
-	 9.4664826088605332182323443e-01L,
-	 9.4410167355700434565568893e-01L,
-	 9.4149746312788106861798448e-01L,
-	 9.3883578854626548865214275e-01L,
-	 9.3611681226705529027757452e-01L,
-	 9.3334070024254843565662820e-01L,
-	 9.3050762191231429116015580e-01L,
-	 9.2761775019285190965094914e-01L,
-	 9.2467126146703609851492875e-01L,
-	 9.2166833557335191816090730e-01L,
-	 9.1860915579491826785281383e-01L,
-	 9.1549390884830122858606058e-01L,
-	 9.1232278487211784648910212e-01L,
-	 9.0909597741543105166956915e-01L,
-	 9.0581368342593642076004609e-01L,
-	 9.0247610323794150491687888e-01L,
-	 8.9908344056013845619268129e-01L,
-	 8.9563590246317069891836618e-01L,
-	 8.9213369936699440471096142e-01L,
-	 8.8857704502803554333020819e-01L,
-	 8.8496615652614329169001889e-01L,
-	 8.8130125425134059916022419e-01L,
-	 8.7758256189037271613028607e-01L,
-	 8.6998471805841738884335773e-01L,
-	 8.6217447993488050434493855e-01L,
-	 8.5415375427738538514389754e-01L,
-	 8.4592449923106795446874767e-01L,
-	 8.3748872385052368529220410e-01L,
-	 8.2884848760932573481351876e-01L,
-	 8.2000589989723400824016969e-01L,
-	 8.1096311950521790220310775e-01L,
-	 8.0172235409841845058843968e-01L,
-	 7.9228585967717854313466241e-01L,
-	 7.8265594002627279692635431e-01L,
-	 7.7283494615247154478458735e-01L,
-	 7.6282527571057625053081719e-01L,
-	 7.5262937241806647606931838e-01L,
-	 7.4224972545850130697074609e-01L,
-	 7.3168886887382088632511210e-01L,
-	 7.2094938094569641805946583e-01L,
-	 7.1003388356607967499180972e-01L,
+	9.8781778381647194407734133e-01L, 9.8720237785483049041453801e-01L,
+	9.8657190839949758873065125e-01L, 9.8592638507066143575569700e-01L,
+	9.8526581771821381618451860e-01L, 9.8459021642159980601798769e-01L,
+	9.8389959148966397219646454e-01L, 9.8319395346049307253706584e-01L,
+	9.8247331310125525749262290e-01L, 9.8173768140803577633441562e-01L,
+	9.8098706960566919046918752e-01L, 9.8022148914756809622147657e-01L,
+	9.7944095171554836000860772e-01L, 9.7864546921965086785991095e-01L,
+	9.7783505379795979334592304e-01L, 9.7700971781641738478493484e-01L,
+	9.7616947386863527671421389e-01L, 9.7531433477570232649326437e-01L,
+	9.7444431358598898037593275e-01L, 9.7355942357494817143660423e-01L,
+	9.7265967824491275265730642e-01L, 9.7174509132488946761517512e-01L,
+	9.7081567677034946294446077e-01L, 9.6987144876301534501253018e-01L,
+	9.6891242171064478417089050e-01L, 9.6695002923067782202260975e-01L,
+	9.6492861910477100957986285e-01L, 9.6284831470937969988364152e-01L,
+	9.6070924301556190306409372e-01L, 9.5851153458122862729886421e-01L,
+	9.5625532354317529696403552e-01L, 9.5394074760889473397129298e-01L,
+	9.5156794804817220216272555e-01L, 9.4913706968446302764510006e-01L,
+	9.4664826088605332182323443e-01L, 9.4410167355700434565568893e-01L,
+	9.4149746312788106861798448e-01L, 9.3883578854626548865214275e-01L,
+	9.3611681226705529027757452e-01L, 9.3334070024254843565662820e-01L,
+	9.3050762191231429116015580e-01L, 9.2761775019285190965094914e-01L,
+	9.2467126146703609851492875e-01L, 9.2166833557335191816090730e-01L,
+	9.1860915579491826785281383e-01L, 9.1549390884830122858606058e-01L,
+	9.1232278487211784648910212e-01L, 9.0909597741543105166956915e-01L,
+	9.0581368342593642076004609e-01L, 9.0247610323794150491687888e-01L,
+	8.9908344056013845619268129e-01L, 8.9563590246317069891836618e-01L,
+	8.9213369936699440471096142e-01L, 8.8857704502803554333020819e-01L,
+	8.8496615652614329169001889e-01L, 8.8130125425134059916022419e-01L,
+	8.7758256189037271613028607e-01L, 8.6998471805841738884335773e-01L,
+	8.6217447993488050434493855e-01L, 8.5415375427738538514389754e-01L,
+	8.4592449923106795446874767e-01L, 8.3748872385052368529220410e-01L,
+	8.2884848760932573481351876e-01L, 8.2000589989723400824016969e-01L,
+	8.1096311950521790220310775e-01L, 8.0172235409841845058843968e-01L,
+	7.9228585967717854313466241e-01L, 7.8265594002627279692635431e-01L,
+	7.7283494615247154478458735e-01L, 7.6282527571057625053081719e-01L,
+	7.5262937241806647606931838e-01L, 7.4224972545850130697074609e-01L,
+	7.3168886887382088632511210e-01L, 7.2094938094569641805946583e-01L,
+	7.1003388356607967499180972e-01L,
 };
 
 const long double _TBL_cosl_lo[] = {
-	 2.3161701550475222913914987e-20L,
-	-1.8449479910096732184579231e-20L,
-	 2.6686158961121436032543157e-20L,
-	-8.6377467693509323999412576e-21L,
-	 1.9776110020628332806497627e-20L,
-	-3.5925805070704800589322274e-21L,
+	2.3161701550475222913914987e-20L, -1.8449479910096732184579231e-20L,
+	2.6686158961121436032543157e-20L, -8.6377467693509323999412576e-21L,
+	1.9776110020628332806497627e-20L, -3.5925805070704800589322274e-21L,
 	-1.8155190558460064943241466e-20L,
 	-9.1900782344860461108346151e-21L,
-	-5.2952188498928572418662889e-21L,
-	 1.8052490350294447403358175e-22L,
-	 1.4237809112451219388907461e-22L,
-	 2.6375298402937478119012648e-20L,
-	-1.0076765547845230197228052e-20L,
-	 2.4356732099577389276048253e-20L,
-	-1.3951467830437376437362152e-20L,
-	 1.7110854885636746562043992e-20L,
-	 9.7751412348794551526570426e-21L,
-	-1.5984515732024779414075399e-20L,
-	-2.6221693743524256098098490e-20L,
-	 2.1708281645344702813143892e-20L,
-	 1.3606643184793342931047312e-20L,
-	 4.0913737251026449191179388e-21L,
-	 3.0297735892921952471510043e-21L,
-	-2.0186136916357220892889611e-20L,
+	-5.2952188498928572418662889e-21L, 1.8052490350294447403358175e-22L,
+	1.4237809112451219388907461e-22L, 2.6375298402937478119012648e-20L,
+	-1.0076765547845230197228052e-20L, 2.4356732099577389276048253e-20L,
+	-1.3951467830437376437362152e-20L, 1.7110854885636746562043992e-20L,
+	9.7751412348794551526570426e-21L, -1.5984515732024779414075399e-20L,
+	-2.6221693743524256098098490e-20L, 2.1708281645344702813143892e-20L,
+	1.3606643184793342931047312e-20L, 4.0913737251026449191179388e-21L,
+	3.0297735892921952471510043e-21L, -2.0186136916357220892889611e-20L,
 	-2.6295048282251297741856903e-20L,
-	-1.4268128384616571293099177e-20L,
-	 1.2118148575499258442724515e-21L,
-	 1.6059569963428104840244296e-20L,
-	 2.5656322072743666174102425e-21L,
-	 3.1051993049709377435678279e-21L,
-	 1.1564422287617245178214769e-20L,
-	 1.0031811944878086819339264e-20L,
-	-1.7237335190163247756143591e-20L,
-	 2.0747363423904458194504323e-20L,
-	 2.2865077385189808827392339e-20L,
-	-2.5671240384658541701793951e-20L,
-	 2.6526752505060021072717663e-20L,
-	-1.9564443985440576261207264e-20L,
-	 1.6662891366649668957364366e-20L,
+	-1.4268128384616571293099177e-20L, 1.2118148575499258442724515e-21L,
+	1.6059569963428104840244296e-20L, 2.5656322072743666174102425e-21L,
+	3.1051993049709377435678279e-21L, 1.1564422287617245178214769e-20L,
+	1.0031811944878086819339264e-20L, -1.7237335190163247756143591e-20L,
+	2.0747363423904458194504323e-20L, 2.2865077385189808827392339e-20L,
+	-2.5671240384658541701793951e-20L, 2.6526752505060021072717663e-20L,
+	-1.9564443985440576261207264e-20L, 1.6662891366649668957364366e-20L,
 	-1.3289734577249155895809888e-21L,
 	-1.0679012486769670465318810e-20L,
 	-2.2918344926389240849631303e-20L,
-	-1.2815734598986502345856155e-20L,
-	 1.4504064768242345767590746e-20L,
+	-1.2815734598986502345856155e-20L, 1.4504064768242345767590746e-20L,
 	-1.4988853557132440148049946e-20L,
-	-2.2142847270523120702212966e-20L,
-	 2.9274200155749021994272015e-21L,
+	-2.2142847270523120702212966e-20L, 2.9274200155749021994272015e-21L,
 	-1.9187410072234352245854903e-20L,
-	-1.5529430996486684056198058e-20L,
-	 8.3043961792850937525987774e-21L,
-	 2.3863634821654097616646090e-20L,
-	-1.7796180005854437467836689e-20L,
-	 1.2938828814644961764053094e-20L,
-	-1.2599167110905505919738134e-20L,
-	 7.2776486597245992496949283e-21L,
-	-2.0062284600282808092832087e-20L,
+	-1.5529430996486684056198058e-20L, 8.3043961792850937525987774e-21L,
+	2.3863634821654097616646090e-20L, -1.7796180005854437467836689e-20L,
+	1.2938828814644961764053094e-20L, -1.2599167110905505919738134e-20L,
+	7.2776486597245992496949283e-21L, -2.0062284600282808092832087e-20L,
 	-1.4004485599673539406695080e-20L,
-	-1.4442131618989703782137918e-20L,
-	 2.2223959244287650022010583e-20L,
+	-1.4442131618989703782137918e-20L, 2.2223959244287650022010583e-20L,
 	-4.4575975223558432505505015e-22L,
-	-9.0245930394257121787744934e-21L,
-	 2.3149253152495269264191463e-20L,
-	-3.3469699832521350974745777e-21L,
-	 1.5380944635427999356502468e-20L,
-	-1.3572945384913555811651506e-20L,
-	 1.9052929123346841342486920e-20L,
-	 6.8389097769442269862154625e-21L,
-	 4.4331336879906155675581769e-21L,
-	 2.6264491975559389159451170e-20L,
-	-2.3718434730140290189643472e-20L,
-	-1.4777051948748214572130603e-20L,
-	 2.0601161465229389031848878e-20L,
+	-9.0245930394257121787744934e-21L, 2.3149253152495269264191463e-20L,
+	-3.3469699832521350974745777e-21L, 1.5380944635427999356502468e-20L,
+	-1.3572945384913555811651506e-20L, 1.9052929123346841342486920e-20L,
+	6.8389097769442269862154625e-21L, 4.4331336879906155675581769e-21L,
+	2.6264491975559389159451170e-20L, -2.3718434730140290189643472e-20L,
+	-1.4777051948748214572130603e-20L, 2.0601161465229389031848878e-20L,
 	-1.3273342027649427778913402e-20L,
 	-1.5653047869359238584973515e-20L,
 	-1.7688078635602856653655125e-20L,
--- old/usr/src/lib/libm/common/LD/_TBL_ipio2l.c	2019-06-06 20:38:05.900494989 +0000
+++ new/usr/src/lib/libm/common/LD/_TBL_ipio2l.c	2019-06-06 20:38:05.919273150 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,7 +35,7 @@
 
 #include "libm.h"
 
-const int _TBL_ipio2l_inf[] = { /* by DHBailey MP package */
+const int _TBL_ipio2l_inf[] = {		/* by DHBailey MP package */
 	0xA2F983, 0x6E4E44, 0x1529FC, 0x2757D1, 0xF534DD, 0xC0DB62,
 	0x95993C, 0x439041, 0xFE5163, 0xABDEBB, 0xC561B7, 0x246E3A,
 	0x424DD2, 0xE00649, 0x2EEA09, 0xD1921C, 0xFE1DEB, 0x1CB129,
@@ -346,6 +347,7 @@
 	0xF129DE, 0x49C2D6, 0x9641D2, 0xC4747C, 0x220804, 0x503F05,
 	0x7E274F, 0xCA83D9, 0x9D6495, 0x0E5039,
 };
+
 const int _TBL_ipio2l_53[] = {
 	0xA2F983, 0x6E4E44, 0x16F3C4, 0xEA69B5, 0xD3E131, 0x60E1D2,
 	0xD7982A, 0xC031F5, 0xD67BCC, 0xFD1375, 0x60919B, 0x3FA0BB,
--- old/usr/src/lib/libm/common/LD/_TBL_sinl.c	2019-06-06 20:38:06.422693726 +0000
+++ new/usr/src/lib/libm/common/LD/_TBL_sinl.c	2019-06-06 20:38:06.440540953 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,81 +40,81 @@
 #include "libm.h"
 
 const long double _TBL_sinl_hi[] = {
-	 1.5561499277355604121432509e-01L,
-	 1.5947245893184341994353297e-01L,
-	 1.6332749173661285085207024e-01L,
-	 1.6718003236480673437500555e-01L,
-	 1.7103002203139501927501524e-01L,
-	 1.7487740199027218989302670e-01L,
-	 1.7872211353515365937804412e-01L,
-	 1.8256409800047155539783929e-01L,
-	 1.8640329676226988454758749e-01L,
-	 1.9023965123909906176839606e-01L,
-	 1.9407310289290979115543571e-01L,
-	 1.9790359322994628465735775e-01L,
-	 2.0173106380163880472144652e-01L,
-	 2.0555545620549551765724079e-01L,
-	 2.0937671208599364370531084e-01L,
-	 2.1319477313546989061102989e-01L,
-	 2.1700958109501015675778940e-01L,
-	 2.2082107775533849055107655e-01L,
-	 2.2462920495770529235180901e-01L,
-	 2.2843390459477474541995223e-01L,
-	 2.3223511861151146241076006e-01L,
-	 2.3603278900606633373558587e-01L,
-	 2.3982685783066156443802536e-01L,
-	 2.4361726719247488600575847e-01L,
-	 2.4740395925452292959266856e-01L,
-	 2.5496596041587846749013231e-01L,
-	 2.6251239976915328146124702e-01L,
-	 2.7004281671858503154006088e-01L,
-	 2.7755675164633632592044860e-01L,
-	 2.8505374594054742458945975e-01L,
-	 2.9253334202332754361585744e-01L,
-	 2.9999508337868305117438275e-01L,
-	 3.0743851458038085066887951e-01L,
-	 3.1486318131974525087106269e-01L,
-	 3.2226863043338662567511427e-01L,
-	 3.2965440993086017192298214e-01L,
-	 3.3702006902225307624892253e-01L,
-	 3.4436515814569840820730424e-01L,
-	 3.5168922899481405922451731e-01L,
-	 3.5899183454606505366498749e-01L,
-	 3.6627252908604756136416898e-01L,
-	 3.7353086823869294642950362e-01L,
-	 3.8076640899239019207055991e-01L,
-	 3.8797870972702504604426484e-01L,
-	 3.9516733024093423623426119e-01L,
-	 4.0233183177777311122311904e-01L,
-	 4.0947177705329506611003562e-01L,
-	 4.1658673028204111924766885e-01L,
-	 4.2367625720393801036934428e-01L,
-	 4.3073992511080319721861361e-01L,
-	 4.3777730287275513286178799e-01L,
-	 4.4478796096452721142060563e-01L,
-	 4.5177147149168377657582618e-01L,
-	 4.5872740821673659236961014e-01L,
-	 4.6565534658516018269211988e-01L,
-	 4.7255486375130445115036980e-01L,
-	 4.7942553860420300028150759e-01L,
-	 4.9307868575392305727079882e-01L,
-	 5.0661145481425736764773474e-01L,
-	 5.2002054195372700474845132e-01L,
-	 5.3330267353602017331871271e-01L,
-	 5.4645460691920356440616155e-01L,
-	 5.5947313124736687740433047e-01L,
-	 5.7235506823450724037203458e-01L,
-	 5.8509727294046215482874185e-01L,
-	 5.9769663453870153121657086e-01L,
-	 6.1015007707579137127265265e-01L,
-	 6.2245456022234368301943030e-01L,
-	 6.3460708001526929683284300e-01L,
-	 6.4660466959115237050095826e-01L,
-	 6.5844439991056754159573505e-01L,
-	 6.7012338047316289465094724e-01L,
-	 6.8163876002333416675559724e-01L,
-	 6.9298772724631791026551897e-01L,
-	 7.0416751145453367277888060e-01L,
+	1.5561499277355604121432509e-01L,
+	1.5947245893184341994353297e-01L,
+	1.6332749173661285085207024e-01L,
+	1.6718003236480673437500555e-01L,
+	1.7103002203139501927501524e-01L,
+	1.7487740199027218989302670e-01L,
+	1.7872211353515365937804412e-01L,
+	1.8256409800047155539783929e-01L,
+	1.8640329676226988454758749e-01L,
+	1.9023965123909906176839606e-01L,
+	1.9407310289290979115543571e-01L,
+	1.9790359322994628465735775e-01L,
+	2.0173106380163880472144652e-01L,
+	2.0555545620549551765724079e-01L,
+	2.0937671208599364370531084e-01L,
+	2.1319477313546989061102989e-01L,
+	2.1700958109501015675778940e-01L,
+	2.2082107775533849055107655e-01L,
+	2.2462920495770529235180901e-01L,
+	2.2843390459477474541995223e-01L,
+	2.3223511861151146241076006e-01L,
+	2.3603278900606633373558587e-01L,
+	2.3982685783066156443802536e-01L,
+	2.4361726719247488600575847e-01L,
+	2.4740395925452292959266856e-01L,
+	2.5496596041587846749013231e-01L,
+	2.6251239976915328146124702e-01L,
+	2.7004281671858503154006088e-01L,
+	2.7755675164633632592044860e-01L,
+	2.8505374594054742458945975e-01L,
+	2.9253334202332754361585744e-01L,
+	2.9999508337868305117438275e-01L,
+	3.0743851458038085066887951e-01L,
+	3.1486318131974525087106269e-01L,
+	3.2226863043338662567511427e-01L,
+	3.2965440993086017192298214e-01L,
+	3.3702006902225307624892253e-01L,
+	3.4436515814569840820730424e-01L,
+	3.5168922899481405922451731e-01L,
+	3.5899183454606505366498749e-01L,
+	3.6627252908604756136416898e-01L,
+	3.7353086823869294642950362e-01L,
+	3.8076640899239019207055991e-01L,
+	3.8797870972702504604426484e-01L,
+	3.9516733024093423623426119e-01L,
+	4.0233183177777311122311904e-01L,
+	4.0947177705329506611003562e-01L,
+	4.1658673028204111924766885e-01L,
+	4.2367625720393801036934428e-01L,
+	4.3073992511080319721861361e-01L,
+	4.3777730287275513286178799e-01L,
+	4.4478796096452721142060563e-01L,
+	4.5177147149168377657582618e-01L,
+	4.5872740821673659236961014e-01L,
+	4.6565534658516018269211988e-01L,
+	4.7255486375130445115036980e-01L,
+	4.7942553860420300028150759e-01L,
+	4.9307868575392305727079882e-01L,
+	5.0661145481425736764773474e-01L,
+	5.2002054195372700474845132e-01L,
+	5.3330267353602017331871271e-01L,
+	5.4645460691920356440616155e-01L,
+	5.5947313124736687740433047e-01L,
+	5.7235506823450724037203458e-01L,
+	5.8509727294046215482874185e-01L,
+	5.9769663453870153121657086e-01L,
+	6.1015007707579137127265265e-01L,
+	6.2245456022234368301943030e-01L,
+	6.3460708001526929683284300e-01L,
+	6.4660466959115237050095826e-01L,
+	6.5844439991056754159573505e-01L,
+	6.7012338047316289465094724e-01L,
+	6.8163876002333416675559724e-01L,
+	6.9298772724631791026551897e-01L,
+	7.0416751145453367277888060e-01L,
 };
 
 const long double _TBL_sinl_lo[] = {
@@ -121,75 +122,75 @@
 	-9.3658505779466794663857779e-22L,
 	-5.2040678607071393508410817e-21L,
 	-4.0395267481940078256007650e-21L,
-	 6.3327332576496468315469778e-21L,
-	 2.6586707822142093837984364e-21L,
+	6.3327332576496468315469778e-21L,
+	2.6586707822142093837984364e-21L,
 	-2.6878787450050744237345282e-21L,
-	 1.7063635662305595250654237e-21L,
-	 4.7924921282538555045455343e-21L,
+	1.7063635662305595250654237e-21L,
+	4.7924921282538555045455343e-21L,
 	-4.4101691066939302183010470e-21L,
-	 6.1948600915447822830980496e-22L,
+	6.1948600915447822830980496e-22L,
 	-4.9638413649749502251618971e-21L,
-	 3.5916271597651546227926473e-21L,
+	3.5916271597651546227926473e-21L,
 	-4.0777150323673712797756569e-22L,
-	 6.5799136599779898603647660e-21L,
-	 5.0431441802236271279596547e-21L,
-	 2.7886967636804383702412094e-21L,
-	 1.7797941915507094664564119e-21L,
+	6.5799136599779898603647660e-21L,
+	5.0431441802236271279596547e-21L,
+	2.7886967636804383702412094e-21L,
+	1.7797941915507094664564119e-21L,
 	-1.3804554392939635583829251e-21L,
-	 4.7855981187615466625152631e-21L,
-	 3.1708211390406997503004900e-21L,
+	4.7855981187615466625152631e-21L,
+	3.1708211390406997503004900e-21L,
 	-1.5157834044725652569873263e-22L,
-	 3.3438946731684019204631903e-21L,
-	 6.4724798056855877111175401e-21L,
-	 4.1801428671953314697839700e-21L,
+	3.3438946731684019204631903e-21L,
+	6.4724798056855877111175401e-21L,
+	4.1801428671953314697839700e-21L,
 	-2.5757365367012227482016023e-21L,
 	-1.0297394515771810295074032e-20L,
-	 1.2694179637735656722464528e-20L,
-	 1.5748512781011179565308673e-21L,
+	1.2694179637735656722464528e-20L,
+	1.5748512781011179565308673e-21L,
 	-1.6967184859202905792705521e-21L,
-	 8.8448858652331336251731737e-21L,
+	8.8448858652331336251731737e-21L,
 	-1.1134468969040340293241825e-20L,
-	 1.6234471791025321420471804e-21L,
+	1.6234471791025321420471804e-21L,
 	-6.0263738196054484651751291e-21L,
-	 1.2631652295822646843414172e-20L,
+	1.2631652295822646843414172e-20L,
 	-8.6644101687582762853694906e-21L,
-	 1.2359222174923859397271358e-20L,
+	1.2359222174923859397271358e-20L,
 	-1.3219821587241831508027981e-22L,
 	-1.9324110998995296922101291e-21L,
-	 1.2722808830089214240915385e-20L,
-	 8.7403704479785940299212466e-21L,
+	1.2722808830089214240915385e-20L,
+	8.7403704479785940299212466e-21L,
 	-1.2663863629342751015966219e-20L,
 	-1.3359206065200525634208487e-20L,
-	 6.8148547822187652382727319e-21L,
-	 1.0571450573402892191582257e-20L,
+	6.8148547822187652382727319e-21L,
+	1.0571450573402892191582257e-20L,
 	-6.0134413552023063129130024e-21L,
-	 1.2658405457632407447211937e-20L,
-	 1.1443598275137284797608912e-20L,
+	1.2658405457632407447211937e-20L,
+	1.1443598275137284797608912e-20L,
 	-7.6602922503647693246330011e-21L,
 	-2.2920876394624080624512678e-21L,
 	-1.6901640257671788285214336e-22L,
-	 1.2450383440926973698285013e-20L,
-	 5.8625687909310643361252782e-21L,
-	 7.6848891207540014891539434e-21L,
+	1.2450383440926973698285013e-20L,
+	5.8625687909310643361252782e-21L,
+	7.6848891207540014891539434e-21L,
 	-1.0920363727912466924531705e-20L,
 	-3.8184802762435242280438906e-21L,
 	-8.2196498741416868399433703e-21L,
 	-5.6622687407305065056015130e-21L,
 	-5.4387357437209102117877930e-21L,
-	 1.1762381857741709383097597e-20L,
-	 1.0418391756080576218864700e-20L,
+	1.1762381857741709383097597e-20L,
+	1.0418391756080576218864700e-20L,
 	-2.8119958331524728369894697e-21L,
 	-1.9486464776808433575964276e-20L,
-	 1.2919131320458122775352322e-20L,
+	1.2919131320458122775352322e-20L,
 	-2.3342533395278737494836457e-20L,
-	 2.2076763147253802020227787e-20L,
-	 1.0897468372542621634126622e-21L,
-	 2.2496400209117994020651730e-20L,
-	 1.7466909662624346932394383e-20L,
-	 2.3083902445127091336067492e-20L,
+	2.2076763147253802020227787e-20L,
+	1.0897468372542621634126622e-21L,
+	2.2496400209117994020651730e-20L,
+	1.7466909662624346932394383e-20L,
+	2.3083902445127091336067492e-20L,
 	-6.1510978111621596519832919e-21L,
-	 3.5843424075843715436394953e-21L,
+	3.5843424075843715436394953e-21L,
 	-2.2355288181001597796661994e-20L,
-	 1.6296521874464521140945741e-20L,
-	 1.1789113655896899561477559e-21L,
+	1.6296521874464521140945741e-20L,
+	1.1789113655896899561477559e-21L,
 };
--- old/usr/src/lib/libm/common/LD/_TBL_tanl.c	2019-06-06 20:38:06.944070195 +0000
+++ new/usr/src/lib/libm/common/LD/_TBL_tanl.c	2019-06-06 20:38:06.963586196 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,157 +40,157 @@
 #include "libm.h"
 
 const long double _TBL_tanl_hi[] = {
-	 1.5753410732527161068790289e-01L,
-	 1.6153978404952147631388516e-01L,
-	 1.6555051927393397620861225e-01L,
-	 1.6956644521976651014845677e-01L,
-	 1.7358769476798152084980487e-01L,
-	 1.7761440147744672763405801e-01L,
-	 1.8164669960332142765752766e-01L,
-	 1.8568472411563441162006289e-01L,
-	 1.8972861071805913288790962e-01L,
-	 1.9377849586689186352228293e-01L,
-	 1.9783451679023866881187727e-01L,
-	 2.0189681150741713288741981e-01L,
-	 2.0596551884857887210688535e-01L,
-	 2.1004077847455898084587031e-01L,
-	 2.1412273089695866488913964e-01L,
-	 2.1821151749846743250413339e-01L,
-	 2.2230728055343133087249762e-01L,
-	 2.2641016324867383747423879e-01L,
-	 2.3052030970457614146129199e-01L,
-	 2.3463786499642367899603687e-01L,
-	 2.3876297517602592026663300e-01L,
-	 2.4289578729361654240565243e-01L,
-	 2.4703644942004126466383960e-01L,
-	 2.5118511066924076739260464e-01L,
-	 2.5534192122103626651019939e-01L,
-	 2.6368059641999679984405817e-01L,
-	 2.7205369865877088343545168e-01L,
-	 2.8046247014525140317325012e-01L,
-	 2.8890817244051472599780488e-01L,
-	 2.9739208726902458947518627e-01L,
-	 3.0591551735305926411887835e-01L,
-	 3.1447978727257151616261872e-01L,
-	 3.2308624435174552010563084e-01L,
-	 3.3173625957357276734381764e-01L,
-	 3.4043122852383038743446717e-01L,
-	 3.4917257236591035224446307e-01L,
-	 3.5796173884801699838350761e-01L,
-	 3.6680020334432342273152904e-01L,
-	 3.7568946993175484041940608e-01L,
-	 3.8463107250414922303567364e-01L,
-	 3.9362657592563275821902387e-01L,
-	 4.0267757722514021178576021e-01L,
-	 4.1178570683410847577655099e-01L,
-	 4.2095262986947582208789413e-01L,
-	 4.3018004746423004901363651e-01L,
-	 4.3946969814786624047050871e-01L,
-	 4.4882335927923970884728319e-01L,
-	 4.5824284853443236696884759e-01L,
-	 4.6773002545239179993303603e-01L,
-	 4.7728679304125226171028919e-01L,
-	 4.8691509944840632450355038e-01L,
-	 4.9661693969756562569970761e-01L,
-	 5.0639435749622981205141092e-01L,
-	 5.1624944711717514451250130e-01L,
-	 5.2618435535777914417981255e-01L,
-	 5.3620128358121603136601796e-01L,
-	 5.4630248984379051326943158e-01L,
-	 5.6676706558058644568054429e-01L,
-	 5.8759736759144322142123240e-01L,
-	 6.0881374032438072139072557e-01L,
-	 6.3043767383588476685765678e-01L,
-	 6.5249189792880799270563541e-01L,
-	 6.7500048514424290766085257e-01L,
-	 6.9798896362359925515245207e-01L,
-	 7.2148444099090441996918396e-01L,
-	 7.4551574055939199512374818e-01L,
-	 7.7011355134420870501661335e-01L,
-	 7.9531059356867418562312202e-01L,
-	 8.2114180158989412189243090e-01L,
-	 8.4764452644655265410892839e-01L,
-	 8.7485876055448234952464232e-01L,
-	 9.0282738745267350217570818e-01L,
-	 9.3159645994407246116005700e-01L,
-	 9.6121551049437041616208335e-01L,
-	 9.9173789836326868026407724e-01L,
+	1.5753410732527161068790289e-01L,
+	1.6153978404952147631388516e-01L,
+	1.6555051927393397620861225e-01L,
+	1.6956644521976651014845677e-01L,
+	1.7358769476798152084980487e-01L,
+	1.7761440147744672763405801e-01L,
+	1.8164669960332142765752766e-01L,
+	1.8568472411563441162006289e-01L,
+	1.8972861071805913288790962e-01L,
+	1.9377849586689186352228293e-01L,
+	1.9783451679023866881187727e-01L,
+	2.0189681150741713288741981e-01L,
+	2.0596551884857887210688535e-01L,
+	2.1004077847455898084587031e-01L,
+	2.1412273089695866488913964e-01L,
+	2.1821151749846743250413339e-01L,
+	2.2230728055343133087249762e-01L,
+	2.2641016324867383747423879e-01L,
+	2.3052030970457614146129199e-01L,
+	2.3463786499642367899603687e-01L,
+	2.3876297517602592026663300e-01L,
+	2.4289578729361654240565243e-01L,
+	2.4703644942004126466383960e-01L,
+	2.5118511066924076739260464e-01L,
+	2.5534192122103626651019939e-01L,
+	2.6368059641999679984405817e-01L,
+	2.7205369865877088343545168e-01L,
+	2.8046247014525140317325012e-01L,
+	2.8890817244051472599780488e-01L,
+	2.9739208726902458947518627e-01L,
+	3.0591551735305926411887835e-01L,
+	3.1447978727257151616261872e-01L,
+	3.2308624435174552010563084e-01L,
+	3.3173625957357276734381764e-01L,
+	3.4043122852383038743446717e-01L,
+	3.4917257236591035224446307e-01L,
+	3.5796173884801699838350761e-01L,
+	3.6680020334432342273152904e-01L,
+	3.7568946993175484041940608e-01L,
+	3.8463107250414922303567364e-01L,
+	3.9362657592563275821902387e-01L,
+	4.0267757722514021178576021e-01L,
+	4.1178570683410847577655099e-01L,
+	4.2095262986947582208789413e-01L,
+	4.3018004746423004901363651e-01L,
+	4.3946969814786624047050871e-01L,
+	4.4882335927923970884728319e-01L,
+	4.5824284853443236696884759e-01L,
+	4.6773002545239179993303603e-01L,
+	4.7728679304125226171028919e-01L,
+	4.8691509944840632450355038e-01L,
+	4.9661693969756562569970761e-01L,
+	5.0639435749622981205141092e-01L,
+	5.1624944711717514451250130e-01L,
+	5.2618435535777914417981255e-01L,
+	5.3620128358121603136601796e-01L,
+	5.4630248984379051326943158e-01L,
+	5.6676706558058644568054429e-01L,
+	5.8759736759144322142123240e-01L,
+	6.0881374032438072139072557e-01L,
+	6.3043767383588476685765678e-01L,
+	6.5249189792880799270563541e-01L,
+	6.7500048514424290766085257e-01L,
+	6.9798896362359925515245207e-01L,
+	7.2148444099090441996918396e-01L,
+	7.4551574055939199512374818e-01L,
+	7.7011355134420870501661335e-01L,
+	7.9531059356867418562312202e-01L,
+	8.2114180158989412189243090e-01L,
+	8.4764452644655265410892839e-01L,
+	8.7485876055448234952464232e-01L,
+	9.0282738745267350217570818e-01L,
+	9.3159645994407246116005700e-01L,
+	9.6121551049437041616208335e-01L,
+	9.9173789836326868026407724e-01L,
 };
 
 const long double _TBL_tanl_lo[] = {
 	-2.6771159409105731701405510e-21L,
 	-4.6099226789741262900210606e-21L,
-	 5.3186644140375322820802458e-21L,
-	 2.5138405830938633735686839e-21L,
+	5.3186644140375322820802458e-21L,
+	2.5138405830938633735686839e-21L,
 	-5.1314617057806432706999694e-21L,
 	-2.3150818458524320771936317e-21L,
-	 7.4823150688409589857878346e-22L,
-	 6.5983384951777057330962451e-21L,
-	 3.1737465070309238679637904e-21L,
+	7.4823150688409589857878346e-22L,
+	6.5983384951777057330962451e-21L,
+	3.1737465070309238679637904e-21L,
 	-6.2605330413009742107992404e-21L,
 	-3.4708968895421512574248288e-21L,
 	-3.3508177722855547163047103e-21L,
-	 1.8539761255947162282442845e-21L,
+	1.8539761255947162282442845e-21L,
 	-4.3527863815358994574071238e-21L,
 	-3.0729582373746958079080308e-21L,
-	 1.7486583794617176080777995e-21L,
+	1.7486583794617176080777995e-21L,
 	-2.0880427643688559927261666e-22L,
-	 3.4326156341633317484064051e-21L,
+	3.4326156341633317484064051e-21L,
 	-5.8444712515543005993510667e-21L,
-	 3.3308393583864583403400180e-21L,
-	 1.5180609545016167494014088e-21L,
+	3.3308393583864583403400180e-21L,
+	1.5180609545016167494014088e-21L,
 	-4.5664864992230118395870971e-21L,
 	-3.4486635382887607253671356e-22L,
-	 6.4992471510018586950169590e-21L,
+	6.4992471510018586950169590e-21L,
 	-5.7171552644357921603079772e-21L,
-	 1.0767820312749142840542796e-20L,
+	1.0767820312749142840542796e-20L,
 	-8.8873094864264944929118678e-21L,
 	-3.6458345495736833933253427e-21L,
-	 3.7835691968285101289024150e-21L,
+	3.7835691968285101289024150e-21L,
 	-7.9922577212991920007926665e-21L,
 	-1.1639426061963512311797196e-20L,
-	 1.0819496381458482697046145e-20L,
-	 1.2669812351932848585361942e-20L,
+	1.0819496381458482697046145e-20L,
+	1.2669812351932848585361942e-20L,
 	-4.3879352642165387665557942e-21L,
 	-6.2397232294970361376981025e-21L,
-	 1.0249894624181563425318369e-20L,
-	 4.8883545518509990780582976e-21L,
+	1.0249894624181563425318369e-20L,
+	4.8883545518509990780582976e-21L,
 	-1.0924217224719888561366811e-20L,
 	-1.0160304466598813882209781e-20L,
-	 5.1826415091471411711448075e-21L,
-	 1.0389918683332972349077236e-20L,
+	5.1826415091471411711448075e-21L,
+	1.0389918683332972349077236e-20L,
 	-7.1664776574714262163862363e-21L,
-	 1.2298884220333748071625466e-20L,
+	1.2298884220333748071625466e-20L,
 	-1.3099990378137383497651040e-20L,
-	 6.6930911371536844477108605e-21L,
-	 1.3154437144468699485999317e-20L,
+	6.6930911371536844477108605e-21L,
+	1.3154437144468699485999317e-20L,
 	-6.7276672708135125503950130e-21L,
 	-9.6583948799780933132703713e-21L,
 	-1.1693327591353762422287158e-20L,
-	 1.2115072030396340314945014e-20L,
+	1.2115072030396340314945014e-20L,
 	-4.8328734014430698289025015e-21L,
-	 1.0852973061445293626693228e-20L,
-	 1.9411831283588255256712679e-20L,
+	1.0852973061445293626693228e-20L,
+	1.9411831283588255256712679e-20L,
 	-2.0725962316575506668083850e-20L,
 	-9.1991091819589918968351350e-21L,
 	-1.8439030785497371079388971e-20L,
 	-1.4252114398617735096821730e-20L,
 	-3.6634999903039053547935623e-22L,
 	-2.7073538111310219812185487e-20L,
-	 2.1768400635771833866020006e-20L,
+	2.1768400635771833866020006e-20L,
 	-5.0453509036808273670769239e-21L,
-	 1.8262326404957249986102613e-20L,
-	 2.3253788272891224529527726e-21L,
+	1.8262326404957249986102613e-20L,
+	2.3253788272891224529527726e-21L,
 	-2.6863465601726641017825874e-21L,
-	 2.0333919445169836552474035e-20L,
-	 1.2381983326738354735338055e-20L,
+	2.0333919445169836552474035e-20L,
+	1.2381983326738354735338055e-20L,
 	-1.0629693225258909983165405e-20L,
-	 2.2479666845586239075466463e-20L,
-	 1.8993064919061156630226362e-20L,
+	2.2479666845586239075466463e-20L,
+	1.8993064919061156630226362e-20L,
 	-1.8140078592138587341953739e-20L,
-	 1.5029592868184122759494625e-20L,
-	 2.0466189644006868146496769e-20L,
-	 5.1457594757697525471406575e-21L,
-	 2.3217272240793119168128789e-20L,
+	1.5029592868184122759494625e-20L,
+	2.0466189644006868146496769e-20L,
+	5.1457594757697525471406575e-21L,
+	2.3217272240793119168128789e-20L,
 	-7.2198528398134119662230907e-21L,
 };
--- old/usr/src/lib/libm/common/LD/__cosl.c	2019-06-06 20:38:07.454883847 +0000
+++ new/usr/src/lib/libm/common/LD/__cosl.c	2019-06-06 20:38:07.473741088 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+/* BEGIN CSTYLED */
 /*
  * __k_cosl( long double x;  long double y )
  * kernel cos function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -47,7 +48,7 @@
  *		ht = (hx + 0x400)&0x7ffff800	(round x to a break point t)
  *		lt = 0
  *		i  = (hy-0x3ffc4000)>>11;	(i<=64)
- *		x' = (x - t)+y 			(|x'| ~<= 2^-7
+ *		x' = (x - t)+y                  (|x'| ~<= 2^-7
  *	   By
  *		cos(t+x')
  *		  = cos(t)cos(x')-sin(t)sin(x')
@@ -61,48 +62,56 @@
  *		z = x*x;
  *		cos(t+x) = a+(b+ (-c*x*(1+z*(pp1+z*pp2))+a*(z*(qq1+z*qq2)))
  */
+/* END CSTYLED */
 
 #include "libm.h"
 
 #include <sys/isa_defs.h>
 
 extern const long double _TBL_cosl_hi[], _TBL_cosl_lo[], _TBL_sinl_hi[];
-static const long double
-one	= 1.0,
+static const long double one = 1.0;
+
 /*
  * |sin(x) - (x+pp1*x^3+...+ pp5*x^11 )| <= 2^-122.32 for |x|<1/64
  */
-pp1	= -1.666666666666666666666666666586782940810e-0001L,
-pp2	=  8.333333333333333333333003723660929317540e-0003L,
-pp3	= -1.984126984126984076045903483778337804470e-0004L,
-pp4	=  2.755731922361906641319723106210900949413e-0006L,
-pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = 8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = 2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  *
  * |cos(x) - (1+q1*x^2+...+q8*x^16)| <= 2^-117.11 for |x|<= 0.15625
  */
-q1	=  -4.999999999999999999999999999999756416975e-0001L,
-q2	=   4.166666666666666666666666664006066577258e-0002L,
-q3	=  -1.388888888888888888888877700363937169637e-0003L,
-q4	=   2.480158730158730158494468463031814083559e-0005L,
-q5	=  -2.755731922398586276322819250356005542871e-0007L,
-q6	=   2.087675698767424261441959760729854017855e-0009L,
-q7	=  -1.147074481239662089072452129010790774761e-0011L,
-q8	=   4.777761647399651599730663422263531034782e-0014L,
+static const long double
+	q1 = -4.999999999999999999999999999999756416975e-0001L,
+	q2 = 4.166666666666666666666666664006066577258e-0002L,
+	q3 = -1.388888888888888888888877700363937169637e-0003L,
+	q4 = 2.480158730158730158494468463031814083559e-0005L,
+	q5 = -2.755731922398586276322819250356005542871e-0007L,
+	q6 = 2.087675698767424261441959760729854017855e-0009L,
+	q7 = -1.147074481239662089072452129010790774761e-0011L,
+	q8 = 4.777761647399651599730663422263531034782e-0014L;
+
 /*
  *
  * |cos(x) - (1+qq1*x^2+...+ qq5*x^10)| <= 2^-123.84 for |x|<=1/128
  */
-qq1	=  -4.999999999999999999999999999999378373641e-0001L,
-qq2	=   4.166666666666666666666665478399327703130e-0002L,
-qq3	=  -1.388888888888888888058211230618051613494e-0003L,
-qq4	=   2.480158730156105377771585658905303111866e-0005L,
-qq5	=  -2.755728099762526325736488376695157008736e-0007L;
-/* INDENT ON */
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = 4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = 2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
+
+
 long double
-__k_cosl(long double x, long double y) {
+__k_cosl(long double x, long double y)
+{
 	long double a, t, z, w;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0;
@@ -112,19 +121,23 @@
 	hx = px[0];
 #endif
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc4000) {
 		if (ix < 0x3fc60000)
-			if ((i = (int) x) == 0)
-				return (one);	/* generate inexact */
+			if ((i = (int)x) == 0)
+				return (one);
+
+		/* generate inexact */
 		z = x * x;
 
 		if (ix < 0x3ff80000)	/* 0.0078125 */
 			return (one + z * (qq1 + z * (qq2 + z * (qq3 + z *
-				(qq4 + z * qq5)))));
+			    (qq4 + z * qq5)))));
 		else
 			return (one + z * (q1 + z * (q2 + z * (q3 + z * (q4 +
-				z * (q5 + z * (q6 + z * (q7 + z * q8))))))));
+			    z * (q5 + z * (q6 + z * (q7 + z * q8))))))));
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 #if defined(__i386) || defined(__amd64)
@@ -132,15 +145,16 @@
 #else
 	pt[0] = j;
 #endif
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a = _TBL_cosl_hi[i];
 	z = x * x;
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
-	w = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z *
-		pp5)))));
+	w = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z * pp5)))));
 	t = _TBL_cosl_lo[i] - (_TBL_sinl_hi[i] * w - a * t);
 	return (a + t);
 }
--- old/usr/src/lib/libm/common/LD/__lgammal.c	2019-06-06 20:38:07.946627594 +0000
+++ new/usr/src/lib/libm/common/LD/__lgammal.c	2019-06-06 20:38:07.963996968 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -56,71 +57,79 @@
 static long double polytail(long double);
 static long double primary(long double);
 
-static const long double
-c0 =	 0.0L,
-ch =	 0.5L,
-c1 =	 1.0L,
-c2 =	 2.0L,
-c3 =	 3.0L,
-c4 =	 4.0L,
-c5 =	 5.0L,
-c6 =	 6.0L,
-pi =	 3.1415926535897932384626433832795028841971L,
-tiny =   1.0e-40L;
+static const long double c0 = 0.0L,
+	ch = 0.5L,
+	c1 = 1.0L,
+	c2 = 2.0L,
+	c3 = 3.0L,
+	c4 = 4.0L,
+	c5 = 5.0L,
+	c6 = 6.0L,
+	pi = 3.1415926535897932384626433832795028841971L,
+	tiny = 1.0e-40L;
 
 long double
-__k_lgammal(long double x, int *signgamlp) {
+__k_lgammal(long double x, int *signgamlp)
+{
 	long double t, y;
 	int i;
 
 	/* purge off +-inf, NaN and negative arguments */
 	if (!finitel(x))
-		return (x*x);
+		return (x * x);
+
 	*signgamlp = 1;
+
 	if (signbitl(x))
 		return (neg(x, signgamlp));
 
 	/* for x < 8.0 */
 	if (x < 8.0L) {
-	    y = anintl(x);
-	    i = (int) y;
-	    switch (i) {
-	    case 0:
-		if (x < 1.0e-40L)
-			return (-logl(x));
-		else
-			return (primary(x)-log1pl(x))-logl(x);
-	    case 1:
-		return (primary(x-y)-logl(x));
-	    case 2:
-		return (primary(x-y));
-	    case 3:
-		return (primary(x-y)+logl(x-c1));
-	    case 4:
-		return (primary(x-y)+logl((x-c1)*(x-c2)));
-	    case 5:
-		return (primary(x-y)+logl((x-c1)*(x-c2)*(x-c3)));
-	    case 6:
-		return (primary(x-y)+logl((x-c1)*(x-c2)*(x-c3)*(x-c4)));
-	    case 7:
-		return (primary(x-y)+logl((x-c1)*(x-c2)*(x-c3)*(x-c4)*(x-c5)));
-	    case 8:
-		return primary(x-y)+
-			logl((x-c1)*(x-c2)*(x-c3)*(x-c4)*(x-c5)*(x-c6));
-	    }
+		y = anintl(x);
+		i = (int)y;
+
+		switch (i) {
+		case 0:
+
+			if (x < 1.0e-40L)
+				return (-logl(x));
+			else
+				return ((primary(x) - log1pl(x)) - logl(x));
+
+		case 1:
+			return (primary(x - y) - logl(x));
+		case 2:
+			return (primary(x - y));
+		case 3:
+			return (primary(x - y) + logl(x - c1));
+		case 4:
+			return (primary(x - y) + logl((x - c1) * (x - c2)));
+		case 5:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3)));
+		case 6:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3) * (x - c4)));
+		case 7:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3) * (x - c4) * (x - c5)));
+		case 8:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3) * (x - c4) * (x - c5) * (x - c6)));
+		}
 	}
 
 	/* 8.0 <= x < 1.0e40 */
 	if (x < 1.0e40L) {
-	    t = logl(x);
-	    return (x*(t-c1)-(ch*t-polytail(c1/x)));
+		t = logl(x);
+		return (x * (t - c1) - (ch * t - polytail(c1 / x)));
 	}
 
 	/* 1.0e40 <= x <= inf */
-	return (x*(logl(x)-c1));
+	return (x * (logl(x) - c1));
 }
 
-static const long double an1[] = {		/* 20 terms */
+static const long double an1[] = {	/* 20 terms */
 	-0.0772156649015328606065120900824024309741L,
 	3.224670334241132182362075833230130289059e-0001L,
 	-6.735230105319809513324605383668929964120e-0002L,
@@ -143,235 +152,258 @@
 	8.777317930927149922056782132706238921648e-0008L,
 };
 
-static const long double an2[] = {		/* 20 terms */
-  -.0772156649015328606062692723698127607018L,
-   3.224670334241132182635552349060279118047e-0001L,
-  -6.735230105319809367555642883133994818325e-0002L,
-   2.058080842778459676880822202762143671813e-0002L,
-  -7.385551028672828216011343150077846918930e-0003L,
-   2.890510330762060607399561536905727853178e-0003L,
-  -1.192753911419623262328187532759756368041e-0003L,
-   5.096695278636456678258091134532258618614e-0004L,
-  -2.231547306817535743052975194022893369135e-0004L,
-   9.945771461633313282744264853986643877087e-0005L,
-  -4.492503279458972037926876061257489481619e-0005L,
-   2.051311416812082875492678651369394595613e-0005L,
-  -9.415778282365955203915850761537462941165e-0006L,
-   4.452428829045147098722932981088650055919e-0006L,
-  -1.835024727987632579886951760650722695781e-0006L,
-   1.379783080658545009579060714946381462565e-0006L,
-   2.282637532109775156769736768748402175238e-0007L,
-   1.002577375515900191362119718128149880168e-0006L,
-   5.177028794262638311939991106423220002463e-0007L,
-   3.127947245174847104122426445937830555755e-0007L,
+static const long double an2[] = {	/* 20 terms */
+	-.0772156649015328606062692723698127607018L,
+	3.224670334241132182635552349060279118047e-0001L,
+	-6.735230105319809367555642883133994818325e-0002L,
+	2.058080842778459676880822202762143671813e-0002L,
+	-7.385551028672828216011343150077846918930e-0003L,
+	2.890510330762060607399561536905727853178e-0003L,
+	-1.192753911419623262328187532759756368041e-0003L,
+	5.096695278636456678258091134532258618614e-0004L,
+	-2.231547306817535743052975194022893369135e-0004L,
+	9.945771461633313282744264853986643877087e-0005L,
+	-4.492503279458972037926876061257489481619e-0005L,
+	2.051311416812082875492678651369394595613e-0005L,
+	-9.415778282365955203915850761537462941165e-0006L,
+	4.452428829045147098722932981088650055919e-0006L,
+	-1.835024727987632579886951760650722695781e-0006L,
+	1.379783080658545009579060714946381462565e-0006L,
+	2.282637532109775156769736768748402175238e-0007L,
+	1.002577375515900191362119718128149880168e-0006L,
+	5.177028794262638311939991106423220002463e-0007L,
+	3.127947245174847104122426445937830555755e-0007L,
 };
 
-static const long double an3[] = {		/* 20 terms */
-  -.0772156649015328227870646417729220690875L,
-   3.224670334241156699881788955959915250365e-0001L,
-  -6.735230105312273571375431059744975563170e-0002L,
-   2.058080842924464587662846071337083809005e-0002L,
-  -7.385551008677271654723604653956131791619e-0003L,
-   2.890510536479782086197110272583833176602e-0003L,
-  -1.192752262076857692740571567808259138697e-0003L,
-   5.096800771149805289371135155128380707889e-0004L,
-  -2.231000836682831335505058492409860123647e-0004L,
-   9.968912171073936803871803966360595275047e-0005L,
-  -4.412020779327746243544387946167256187258e-0005L,
-   2.281374113541454151067016632998630209049e-0005L,
-  -4.028361291428629491824694655287954266830e-0006L,
-   1.470694920619518924598956849226530750139e-0005L,
-   1.381686137617987197975289545582377713772e-0005L,
-   2.012493539265777728944759982054970441601e-0005L,
-   1.723917864208965490251560644681933675799e-0005L,
-   1.202954035243788300138608765425123713395e-0005L,
-   5.079851887558623092776296577030850938146e-0006L,
-   1.220657945824153751555138592006604026282e-0006L,
+static const long double an3[] = {	/* 20 terms */
+	-.0772156649015328227870646417729220690875L,
+	3.224670334241156699881788955959915250365e-0001L,
+	-6.735230105312273571375431059744975563170e-0002L,
+	2.058080842924464587662846071337083809005e-0002L,
+	-7.385551008677271654723604653956131791619e-0003L,
+	2.890510536479782086197110272583833176602e-0003L,
+	-1.192752262076857692740571567808259138697e-0003L,
+	5.096800771149805289371135155128380707889e-0004L,
+	-2.231000836682831335505058492409860123647e-0004L,
+	9.968912171073936803871803966360595275047e-0005L,
+	-4.412020779327746243544387946167256187258e-0005L,
+	2.281374113541454151067016632998630209049e-0005L,
+	-4.028361291428629491824694655287954266830e-0006L,
+	1.470694920619518924598956849226530750139e-0005L,
+	1.381686137617987197975289545582377713772e-0005L,
+	2.012493539265777728944759982054970441601e-0005L,
+	1.723917864208965490251560644681933675799e-0005L,
+	1.202954035243788300138608765425123713395e-0005L,
+	5.079851887558623092776296577030850938146e-0006L,
+	1.220657945824153751555138592006604026282e-0006L,
 };
 
-static const long double an4[] = {		/* 21 terms */
-  -.0772156649015732285350261816697540392371L,
-   3.224670334221752060691751340365212226097e-0001L,
-  -6.735230109744009693977755991488196368279e-0002L,
-   2.058080778913037626909954141611580783216e-0002L,
-  -7.385557567931505621170483708950557506819e-0003L,
-   2.890459838416254326340844289785254883436e-0003L,
-  -1.193059036207136762877351596966718455737e-0003L,
-   5.081914708100372836613371356529568937869e-0004L,
-  -2.289855016133600313131553005982542045338e-0004L,
-   8.053454537980585879620331053833498511491e-0005L,
-  -9.574620532104845821243493405855672438998e-0005L,
-  -9.269085628207107155601445001196317715686e-0005L,
-  -2.183276779859490461716196344776208220180e-0004L,
-  -3.134834305597571096452454999737269668868e-0004L,
-  -3.973878894951937437018305986901392888619e-0004L,
-  -3.953352414899222799161275564386488057119e-0004L,
-  -3.136740932204038779362660900621212816511e-0004L,
-  -1.884502253819634073946130825196078627664e-0004L,
-  -8.192655799958926853585332542123631379301e-0005L,
-  -2.292183750010571062891605074281744854436e-0005L,
-  -3.223980628729716864927724265781406614294e-0006L,
+static const long double an4[] = {	/* 21 terms */
+	-.0772156649015732285350261816697540392371L,
+	3.224670334221752060691751340365212226097e-0001L,
+	-6.735230109744009693977755991488196368279e-0002L,
+	2.058080778913037626909954141611580783216e-0002L,
+	-7.385557567931505621170483708950557506819e-0003L,
+	2.890459838416254326340844289785254883436e-0003L,
+	-1.193059036207136762877351596966718455737e-0003L,
+	5.081914708100372836613371356529568937869e-0004L,
+	-2.289855016133600313131553005982542045338e-0004L,
+	8.053454537980585879620331053833498511491e-0005L,
+	-9.574620532104845821243493405855672438998e-0005L,
+	-9.269085628207107155601445001196317715686e-0005L,
+	-2.183276779859490461716196344776208220180e-0004L,
+	-3.134834305597571096452454999737269668868e-0004L,
+	-3.973878894951937437018305986901392888619e-0004L,
+	-3.953352414899222799161275564386488057119e-0004L,
+	-3.136740932204038779362660900621212816511e-0004L,
+	-1.884502253819634073946130825196078627664e-0004L,
+	-8.192655799958926853585332542123631379301e-0005L,
+	-2.292183750010571062891605074281744854436e-0005L,
+	-3.223980628729716864927724265781406614294e-0006L,
 };
 
-static const long double ap1[] = {			/* 19 terms */
-  -0.0772156649015328606065120900824024296961L,
-   3.224670334241132182362075833230047956465e-0001L,
-  -6.735230105319809513324605382963943777301e-0002L,
-   2.058080842778454787900092126606252375465e-0002L,
-  -7.385551028673985266272518231365020063941e-0003L,
-   2.890510330741523285681704570797770736423e-0003L,
-  -1.192753911703260971285304221165990244515e-0003L,
-   5.096695247430420878696018188830886972245e-0004L,
-  -2.231547584535654004647639737841526025095e-0004L,
-   9.945751278137201960636098805852315982919e-0005L,
-  -4.492623672777606053587919463929044226280e-0005L,
-   2.050721258703289487603702670753053765201e-0005L,
-  -9.439485626565616989352750672499008021041e-0006L,
-   4.374838162403994645138200419356844574219e-0006L,
-  -2.038979492862555348577006944451002161496e-0006L,
-   9.536763152382263548086981191378885102802e-0007L,
-  -4.426111214332434049863595231916564014913e-0007L,
-   1.911148847512947464234633846270287546882e-0007L,
-  -5.788673944861923038157839080272303519671e-0008L,
+static const long double ap1[] = {	/* 19 terms */
+	-0.0772156649015328606065120900824024296961L,
+	3.224670334241132182362075833230047956465e-0001L,
+	-6.735230105319809513324605382963943777301e-0002L,
+	2.058080842778454787900092126606252375465e-0002L,
+	-7.385551028673985266272518231365020063941e-0003L,
+	2.890510330741523285681704570797770736423e-0003L,
+	-1.192753911703260971285304221165990244515e-0003L,
+	5.096695247430420878696018188830886972245e-0004L,
+	-2.231547584535654004647639737841526025095e-0004L,
+	9.945751278137201960636098805852315982919e-0005L,
+	-4.492623672777606053587919463929044226280e-0005L,
+	2.050721258703289487603702670753053765201e-0005L,
+	-9.439485626565616989352750672499008021041e-0006L,
+	4.374838162403994645138200419356844574219e-0006L,
+	-2.038979492862555348577006944451002161496e-0006L,
+	9.536763152382263548086981191378885102802e-0007L,
+	-4.426111214332434049863595231916564014913e-0007L,
+	1.911148847512947464234633846270287546882e-0007L,
+	-5.788673944861923038157839080272303519671e-0008L,
 };
 
-static const long double ap2[] = {			/* 19 terms */
-  -0.077215664901532860606428624449354836087L,
-   3.224670334241132182271948744265855440139e-0001L,
-  -6.735230105319809467356126599005051676203e-0002L,
-   2.058080842778453315716389815213496002588e-0002L,
-  -7.385551028673653323064118422580096222959e-0003L,
-   2.890510330735923572088003424849289006039e-0003L,
-  -1.192753911629952368606185543945790688144e-0003L,
-   5.096695239806718875364547587043220998766e-0004L,
-  -2.231547520600616108991867127392089144886e-0004L,
-   9.945746913898151120612322833059416008973e-0005L,
-  -4.492599307461977003570224943054585729684e-0005L,
-   2.050609891889165453592046505651759999090e-0005L,
-  -9.435329866734193796540515247917165988579e-0006L,
-   4.362267138522223236241016136585565144581e-0006L,
-  -2.008556356653246579300491601497510230557e-0006L,
-   8.961498103387207161105347118042844354395e-0007L,
-  -3.614187228330216282235692806488341157741e-0007L,
-   1.136978988247816860500420915014777753153e-0007L,
-  -2.000532786387196664019286514899782691776e-0008L,
+static const long double ap2[] = {	/* 19 terms */
+	-0.077215664901532860606428624449354836087L,
+	3.224670334241132182271948744265855440139e-0001L,
+	-6.735230105319809467356126599005051676203e-0002L,
+	2.058080842778453315716389815213496002588e-0002L,
+	-7.385551028673653323064118422580096222959e-0003L,
+	2.890510330735923572088003424849289006039e-0003L,
+	-1.192753911629952368606185543945790688144e-0003L,
+	5.096695239806718875364547587043220998766e-0004L,
+	-2.231547520600616108991867127392089144886e-0004L,
+	9.945746913898151120612322833059416008973e-0005L,
+	-4.492599307461977003570224943054585729684e-0005L,
+	2.050609891889165453592046505651759999090e-0005L,
+	-9.435329866734193796540515247917165988579e-0006L,
+	4.362267138522223236241016136585565144581e-0006L,
+	-2.008556356653246579300491601497510230557e-0006L,
+	8.961498103387207161105347118042844354395e-0007L,
+	-3.614187228330216282235692806488341157741e-0007L,
+	1.136978988247816860500420915014777753153e-0007L,
+	-2.000532786387196664019286514899782691776e-0008L,
 };
 
-static const long double ap3[] = {			/* 19 terms */
-  -0.077215664901532859888521470795348856446L,
-   3.224670334241131733364048614484228443077e-0001L,
-  -6.735230105319676541660495145259038151576e-0002L,
-   2.058080842775975461837768839015444273830e-0002L,
-  -7.385551028347615729728618066663566606906e-0003L,
-   2.890510327517954083379032008643080256676e-0003L,
-  -1.192753886919470728001821137439430882603e-0003L,
-   5.096693728898932234814903769146577482912e-0004L,
-  -2.231540055048827662528594010961874258037e-0004L,
-   9.945446210018649311491619999438833843723e-0005L,
-  -4.491608206598064519190236245753867697750e-0005L,
-   2.047939071322271016498065052853746466669e-0005L,
-  -9.376824046522786006677541036631536790762e-0006L,
-   4.259329829498149111582277209189150127347e-0006L,
-  -1.866064770421594266702176289764212873428e-0006L,
-   7.462066721137579592928128104534957135669e-0007L,
-  -2.483546217529077735074007138457678727371e-0007L,
-   5.915166576378161473299324673649144297574e-0008L,
-  -7.334139641706988966966252333759604701905e-0009L,
+static const long double ap3[] = {	/* 19 terms */
+	-0.077215664901532859888521470795348856446L,
+	3.224670334241131733364048614484228443077e-0001L,
+	-6.735230105319676541660495145259038151576e-0002L,
+	2.058080842775975461837768839015444273830e-0002L,
+	-7.385551028347615729728618066663566606906e-0003L,
+	2.890510327517954083379032008643080256676e-0003L,
+	-1.192753886919470728001821137439430882603e-0003L,
+	5.096693728898932234814903769146577482912e-0004L,
+	-2.231540055048827662528594010961874258037e-0004L,
+	9.945446210018649311491619999438833843723e-0005L,
+	-4.491608206598064519190236245753867697750e-0005L,
+	2.047939071322271016498065052853746466669e-0005L,
+	-9.376824046522786006677541036631536790762e-0006L,
+	4.259329829498149111582277209189150127347e-0006L,
+	-1.866064770421594266702176289764212873428e-0006L,
+	7.462066721137579592928128104534957135669e-0007L,
+	-2.483546217529077735074007138457678727371e-0007L,
+	5.915166576378161473299324673649144297574e-0008L,
+	-7.334139641706988966966252333759604701905e-0009L,
 };
 
-static const long double ap4[] = {			/* 19 terms */
-  -0.0772156649015326785569313252637238673675L,
-   3.224670334241051435008842685722468344822e-0001L,
-  -6.735230105302832007479431772160948499254e-0002L,
-   2.058080842553481183648529360967441889912e-0002L,
-  -7.385551007602909242024706804659879199244e-0003L,
-   2.890510182473907253939821312248303471206e-0003L,
-  -1.192753098427856770847894497586825614450e-0003L,
-   5.096659636418811568063339214203693550804e-0004L,
-  -2.231421144004355691166194259675004483639e-0004L,
-   9.942073842343832132754332881883387625136e-0005L,
-  -4.483809261973204531263252655050701205397e-0005L,
-   2.033260142610284888319116654931994447173e-0005L,
-  -9.153539544026646699870528191410440585796e-0006L,
-   3.988460469925482725894144688699584997971e-0006L,
-  -1.609692980087029172567957221850825977621e-0006L,
-   5.634916377249975825399706694496688803488e-0007L,
-  -1.560065465929518563549083208482591437696e-0007L,
-   2.961350193868935325526962209019387821584e-0008L,
-  -2.834602215195368130104649234505033159842e-0009L,
+static const long double ap4[] = {	/* 19 terms */
+	-0.0772156649015326785569313252637238673675L,
+	3.224670334241051435008842685722468344822e-0001L,
+	-6.735230105302832007479431772160948499254e-0002L,
+	2.058080842553481183648529360967441889912e-0002L,
+	-7.385551007602909242024706804659879199244e-0003L,
+	2.890510182473907253939821312248303471206e-0003L,
+	-1.192753098427856770847894497586825614450e-0003L,
+	5.096659636418811568063339214203693550804e-0004L,
+	-2.231421144004355691166194259675004483639e-0004L,
+	9.942073842343832132754332881883387625136e-0005L,
+	-4.483809261973204531263252655050701205397e-0005L,
+	2.033260142610284888319116654931994447173e-0005L,
+	-9.153539544026646699870528191410440585796e-0006L,
+	3.988460469925482725894144688699584997971e-0006L,
+	-1.609692980087029172567957221850825977621e-0006L,
+	5.634916377249975825399706694496688803488e-0007L,
+	-1.560065465929518563549083208482591437696e-0007L,
+	2.961350193868935325526962209019387821584e-0008L,
+	-2.834602215195368130104649234505033159842e-0009L,
 };
 
 static long double
-primary(long double s) {	/* assume |s|<=0.5 */
+primary(long double s)			/* assume |s|<=0.5 */
+{
 	int i;
 
-	i = (int) (8.0L * (s + 0.5L));
+	i = (int)(8.0L * (s + 0.5L));
+
 	switch (i) {
-	case 0:	return ch*s+s*poly(s, an4, 21);
-	case 1:	return ch*s+s*poly(s, an3, 20);
-	case 2:	return ch*s+s*poly(s, an2, 20);
-	case 3:	return ch*s+s*poly(s, an1, 20);
-	case 4:	return ch*s+s*poly(s, ap1, 19);
-	case 5:	return ch*s+s*poly(s, ap2, 19);
-	case 6:	return ch*s+s*poly(s, ap3, 19);
-	case 7:	return ch*s+s*poly(s, ap4, 19);
+	case 0:
+		return (ch * s + s * poly(s, an4, 21));
+	case 1:
+		return (ch * s + s * poly(s, an3, 20));
+	case 2:
+		return (ch * s + s * poly(s, an2, 20));
+	case 3:
+		return (ch * s + s * poly(s, an1, 20));
+	case 4:
+		return (ch * s + s * poly(s, ap1, 19));
+	case 5:
+		return (ch * s + s * poly(s, ap2, 19));
+	case 6:
+		return (ch * s + s * poly(s, ap3, 19));
+	case 7:
+		return (ch * s + s * poly(s, ap4, 19));
 	}
+
 	/* NOTREACHED */
-    return (0.0L);
+	return (0.0L);
 }
 
 static long double
-poly(long double s, const long double *p, int n) {
+poly(long double s, const long double *p, int n)
+{
 	long double y;
 	int i;
-	y = p[n-1];
-	for (i = n-2; i >= 0; i--) y = p[i]+s*y;
+
+	y = p[n - 1];
+
+	for (i = n - 2; i >= 0; i--)
+		y = p[i] + s * y;
+
 	return (y);
 }
 
 static const long double pt[] = {
-   9.189385332046727417803297364056176804663e-0001L,
-   8.333333333333333333333333333331286969123e-0002L,
-  -2.777777777777777777777777553194796036402e-0003L,
-   7.936507936507936507927283071433584248176e-0004L,
-  -5.952380952380952362351042163192634108297e-0004L,
-   8.417508417508395661774286645578379460131e-0004L,
-  -1.917526917525263651186066417934685675649e-0003L,
-   6.410256409395203164659292973142293199083e-0003L,
-  -2.955065327248303301763594514012418438188e-0002L,
-   1.796442830099067542945998615411893822886e-0001L,
-  -1.392413465829723742489974310411118662919e+0000L,
-   1.339984238037267658352656597960492029261e+0001L,
-  -1.564707657605373662425785904278645727813e+0002L,
-   2.156323807499211356127813962223067079300e+0003L,
-  -3.330486427626223184647299834137041307569e+0004L,
-   5.235535072011889213611369254140123518699e+0005L,
-  -7.258160984602220710491988573430212593080e+0006L,
-   7.316526934569686459641438882340322673357e+0007L,
-  -3.806450279064900548836571789284896711473e+0008L,
+	9.189385332046727417803297364056176804663e-0001L,
+	8.333333333333333333333333333331286969123e-0002L,
+	-2.777777777777777777777777553194796036402e-0003L,
+	7.936507936507936507927283071433584248176e-0004L,
+	-5.952380952380952362351042163192634108297e-0004L,
+	8.417508417508395661774286645578379460131e-0004L,
+	-1.917526917525263651186066417934685675649e-0003L,
+	6.410256409395203164659292973142293199083e-0003L,
+	-2.955065327248303301763594514012418438188e-0002L,
+	1.796442830099067542945998615411893822886e-0001L,
+	-1.392413465829723742489974310411118662919e+0000L,
+	1.339984238037267658352656597960492029261e+0001L,
+	-1.564707657605373662425785904278645727813e+0002L,
+	2.156323807499211356127813962223067079300e+0003L,
+	-3.330486427626223184647299834137041307569e+0004L,
+	5.235535072011889213611369254140123518699e+0005L,
+	-7.258160984602220710491988573430212593080e+0006L,
+	7.316526934569686459641438882340322673357e+0007L,
+	-3.806450279064900548836571789284896711473e+0008L,
 };
 
 static long double
-polytail(long double s) {
+polytail(long double s)
+{
 	long double t, z;
 	int i;
-	z = s*s;
+
+	z = s * s;
 	t = pt[18];
-	for (i = 17; i >= 1; i--) t = pt[i]+z*t;
-	return (pt[0]+s*t);
+
+	for (i = 17; i >= 1; i--)
+		t = pt[i] + z * t;
+
+	return (pt[0] + s * t);
 }
 
 static long double
-neg(long double z, int *signgamlp) {
+neg(long double z, int *signgamlp)
+{
 	long double t, p;
 
+	/* BEGIN CSTYLED */
 	/*
 	 * written by K.C. Ng,  Feb 2, 1989.
 	 *
 	 * Since
 	 *		-z*G(-z)*G(z) = pi/sin(pi*z),
 	 * we have
-	 * 	G(-z) = -pi/(sin(pi*z)*G(z)*z)
+	 *      G(-z) = -pi/(sin(pi*z)*G(z)*z)
 	 *		  =  pi/(sin(pi*(-z))*G(z)*z)
 	 * Algorithm
 	 *		z = |z|
@@ -386,16 +418,22 @@
 	 *		    return log(pi/(t*z))-lgamma(z);
 	 *
 	 */
+	/* END CSTYLED */
 
 	t = sinpil(z);			/* t := sin(pi*z) */
-	if (t == c0)  			/* return   1.0/0.0 =  +INF */
-	    return (c1/c0);
+
+	if (t == c0)			/* return   1.0/0.0 =  +INF */
+		return (c1 / c0);
 
 	z = -z;
+
 	if (z <= tiny)
-	    p = -logl(z);
+		p = -logl(z);
 	else
-		p = logl(pi/(fabsl(t)*z)) - __k_lgammal(z, signgamlp);
-	if (t < c0) *signgamlp = -1;
+		p = logl(pi / (fabsl(t) * z)) - __k_lgammal(z, signgamlp);
+
+	if (t < c0)
+		*signgamlp = -1;
+
 	return (p);
 }
--- old/usr/src/lib/libm/common/LD/__poly_libmq.c	2019-06-06 20:38:08.470407616 +0000
+++ new/usr/src/lib/libm/common/LD/__poly_libmq.c	2019-06-06 20:38:08.488467624 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,12 +30,16 @@
 
 #include "libm.h"
 
-long double __poly_libmq(x,n,p)
-long double x,p[];
-int n;
+long double
+__poly_libmq(long double x, int n, long double p[])
 {
-	long double t; int i;
-	t = p[n-1];
-	for(i=n-2;i>=0;i--) t = p[i] + x*t;
-	return t;
+	long double t;
+	int i;
+
+	t = p[n - 1];
+
+	for (i = n - 2; i >= 0; i--)
+		t = p[i] + x * t;
+
+	return (t);
 }
--- old/usr/src/lib/libm/common/LD/__rem_pio2l.c	2019-06-06 20:38:08.966100061 +0000
+++ new/usr/src/lib/libm/common/LD/__rem_pio2l.c	2019-06-06 20:38:08.984361091 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,43 +39,49 @@
 #include "longdouble.h"
 
 extern const int _TBL_ipio2l_inf[];
-
-static const long double
-    two24l = 16777216.0L,
-    pio4   = 0.7853981633974483096156608458198757210495L;
+static const long double two24l = 16777216.0L,
+	pio4 = 0.7853981633974483096156608458198757210495L;
 
 int
 __rem_pio2l(long double x, long double *y)
 {
-	long double	z, w;
-	double		t[3], v[5];
-	int		e0, i, nx, n, sign;
+	long double z, w;
+	double t[3], v[5];
+	int e0, i, nx, n, sign;
 
 	sign = signbitl(x);
 	z = fabsl(x);
+
 	if (z <= pio4) {
 		y[0] = x;
 		y[1] = 0;
 		return (0);
 	}
+
 	e0 = ilogbl(z) - 23;
 	z = scalbnl(z, -e0);
+
 	for (i = 0; i < 3; i++) {
 		t[i] = (double)((int)(z));
 		z = (z - (long double)t[i]) * two24l;
 	}
+
 	nx = 3;
-	while (t[nx-1] == 0.0)
-		nx--;	/* omit trailing zeros */
+
+	while (t[nx - 1] == 0.0)
+		nx--;			/* omit trailing zeros */
+
 	n = __rem_pio2m(t, v, e0, nx, 2, _TBL_ipio2l_inf);
 	z = (long double)v[1];
 	w = (long double)v[0];
 	y[0] = z + w;
 	y[1] = z - (y[0] - w);
+
 	if (sign != 0) {
 		y[0] = -y[0];
 		y[1] = -y[1];
 		return (-n);
 	}
+
 	return (n);
 }
--- old/usr/src/lib/libm/common/LD/__sincosl.c	2019-06-06 20:38:09.479561128 +0000
+++ new/usr/src/lib/libm/common/LD/__sincosl.c	2019-06-06 20:38:09.498943069 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * long double __k_sincos( long double x, long double y, long double *c )
  * kernel sincosl function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -45,55 +46,64 @@
 
 extern const long double _TBL_sinl_hi[], _TBL_sinl_lo[], _TBL_cosl_hi[],
 	_TBL_cosl_lo[];
-static const long double
-one	= 1.0,
+static const long double one = 1.0;
+
 /*
  * |sin(x) - (x+pp1*x^3+...+pp5*x^11)| <= 2^-122.32 for |x|<1/64
  */
-pp1	= -1.666666666666666666666666666586782940810e-0001L,
-pp2	=  8.333333333333333333333003723660929317540e-0003L,
-pp3	= -1.984126984126984076045903483778337804470e-0004L,
-pp4	=  2.755731922361906641319723106210900949413e-0006L,
-pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = 8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = 2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p8*x^17)|
  * |------------------------------- | <= 2^-116.17 for |x|<0.1953125
  * |                 x              |
  */
-p1	=  -1.666666666666666666666666666666211262297e-0001L,
-p2	=   8.333333333333333333333333301497876908541e-0003L,
-p3	=  -1.984126984126984126984041302881180621922e-0004L,
-p4	=   2.755731922398589064100587351307269621093e-0006L,
-p5	=  -2.505210838544163129378906953765595393873e-0008L,
-p6	=   1.605904383643244375050998243778534074273e-0010L,
-p7	=  -7.647162722800685516901456114270824622699e-0013L,
-p8	=   2.810046428661902961725428841068844462603e-0015L,
+static const long double
+	p1 = -1.666666666666666666666666666666211262297e-0001L,
+	p2 = 8.333333333333333333333333301497876908541e-0003L,
+	p3 = -1.984126984126984126984041302881180621922e-0004L,
+	p4 = 2.755731922398589064100587351307269621093e-0006L,
+	p5 = -2.505210838544163129378906953765595393873e-0008L,
+	p6 = 1.605904383643244375050998243778534074273e-0010L,
+	p7 = -7.647162722800685516901456114270824622699e-0013L,
+	p8 = 2.810046428661902961725428841068844462603e-0015L;
+
 /*
  *
  * |cos(x) - (1+qq1*x^2+...+ qq5*x^10)| <= 2^-123.84 for |x|<=1/128
  */
-qq1	=  -4.999999999999999999999999999999378373641e-0001L,
-qq2	=   4.166666666666666666666665478399327703130e-0002L,
-qq3	=  -1.388888888888888888058211230618051613494e-0003L,
-qq4	=   2.480158730156105377771585658905303111866e-0005L,
-qq5	=  -2.755728099762526325736488376695157008736e-0007L,
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = 4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = 2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
+
 /*
  *
  * |cos(x) - (1+q1*x^2+...+ q8*x^16)| <= 2^-117.11 for |x|<= 0.15625
  */
-q1	=  -4.999999999999999999999999999999756416975e-0001L,
-q2	=   4.166666666666666666666666664006066577258e-0002L,
-q3	=  -1.388888888888888888888877700363937169637e-0003L,
-q4	=   2.480158730158730158494468463031814083559e-0005L,
-q5	=  -2.755731922398586276322819250356005542871e-0007L,
-q6	=   2.087675698767424261441959760729854017855e-0009L,
-q7	=  -1.147074481239662089072452129010790774761e-0011L,
-q8	=   4.777761647399651599730663422263531034782e-0014L;
-/* INDENT ON */
+static const long double
+	q1 = -4.999999999999999999999999999999756416975e-0001L,
+	q2 = 4.166666666666666666666666664006066577258e-0002L,
+	q3 = -1.388888888888888888888877700363937169637e-0003L,
+	q4 = 2.480158730158730158494468463031814083559e-0005L,
+	q5 = -2.755731922398586276322819250356005542871e-0007L,
+	q6 = 2.087675698767424261441959760729854017855e-0009L,
+	q7 = -1.147074481239662089072452129010790774761e-0011L,
+	q8 = 4.777761647399651599730663422263531034782e-0014L;
+
+
 long double
-__k_sincosl(long double x, long double y, long double *c) {
+__k_sincosl(long double x, long double y, long double *c)
+{
 	long double a1, a2, t, t1, t2, z, w;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0;
@@ -103,29 +113,33 @@
 	hx = px[0];
 #endif
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc4000) {
-		if (ix < 0x3fc60000)
-			if (((int) x) == 0) {
+		if (ix < 0x3fc60000) {
+			if (((int)x) == 0) {
 				*c = one;
 				return (x);
-			}	/* generate inexact */
+			}		/* generate inexact */
+		}
+
 		z = x * x;
 
 		if (ix < 0x3ff80000) {
 			*c = one + z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 +
-				z * qq5))));
+			    z * qq5))));
 			t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 +
-				z * p6)))));
+			    z * p6)))));
 		} else {
 			*c = one + z * (q1 + z * (q2 + z * (q3 + z * (q4 + z *
-				(q5 + z * (q6 + z * (q7 + z * q8)))))));
+			    (q5 + z * (q6 + z * (q7 + z * q8)))))));
 			t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 +
-				z * (p6 + z * (p7 + z * p8)))))));
+			    z * (p6 + z * (p7 + z * p8)))))));
 		}
 
 		t = y + x * t;
 		return (x + t);
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 #if defined(__i386) || defined(__amd64)
@@ -133,20 +147,22 @@
 #else
 	pt[0] = j;
 #endif
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a1 = _TBL_sinl_hi[i];
 	z = x * x;
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
-	w = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z *
-		pp5)))));
+	w = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z * pp5)))));
 	a2 = _TBL_cosl_hi[i];
 	t2 = _TBL_cosl_lo[i] - (a1 * w - a2 * t);
 	*c = a2 + t2;
 	t1 = a2 * w + a1 * t;
 	t1 += _TBL_sinl_lo[i];
+
 	if (hx < 0)
 		return (-a1 - t1);
 	else
--- old/usr/src/lib/libm/common/LD/__sinl.c	2019-06-06 20:38:09.986930383 +0000
+++ new/usr/src/lib/libm/common/LD/__sinl.c	2019-06-06 20:38:10.006327069 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * __k_sinl( long double x;  long double y )
  * kernel sin function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -47,7 +48,7 @@
  *		ht = (hx + 0x400)&0x7ffff800	(round x to a break point t)
  *		lt = 0
  *		i  = (hy-0x3ffc4000)>>11;	(i<=64)
- *		x' = (x - t)+y 			(|x'| ~<= 2^-7
+ *		x' = (x - t)+y                  (|x'| ~<= 2^-7
  *	   By
  *		sin(t+x')
  *		  = sin(t)cos(x')+cos(t)sin(x')
@@ -67,43 +68,50 @@
 #include <sys/isa_defs.h>
 
 extern const long double _TBL_sinl_hi[], _TBL_sinl_lo[], _TBL_cosl_hi[];
-static const long double
-one	= 1.0,
+static const long double one = 1.0;
+
 /*
  * |sin(x) - (x+pp1*x^3+...+ pp5*x^11)| <= 2^-122.32 for |x|<1/64
  */
-pp1	= -1.666666666666666666666666666586782940810e-0001L,
-pp2	=  8.333333333333333333333003723660929317540e-0003L,
-pp3	= -1.984126984126984076045903483778337804470e-0004L,
-pp4	=  2.755731922361906641319723106210900949413e-0006L,
-pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = 8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = 2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p8*x^17)|
  * |------------------------------- | <= 2^-116.17 for |x|<0.1953125
  * |                 x              |
  */
-p1	= -1.666666666666666666666666666666211262297e-0001L,
-p2	=  8.333333333333333333333333301497876908541e-0003L,
-p3	= -1.984126984126984126984041302881180621922e-0004L,
-p4	=  2.755731922398589064100587351307269621093e-0006L,
-p5	= -2.505210838544163129378906953765595393873e-0008L,
-p6	=  1.605904383643244375050998243778534074273e-0010L,
-p7	= -7.647162722800685516901456114270824622699e-0013L,
-p8	=  2.810046428661902961725428841068844462603e-0015L,
+static const long double
+	p1 = -1.666666666666666666666666666666211262297e-0001L,
+	p2 = 8.333333333333333333333333301497876908541e-0003L,
+	p3 = -1.984126984126984126984041302881180621922e-0004L,
+	p4 = 2.755731922398589064100587351307269621093e-0006L,
+	p5 = -2.505210838544163129378906953765595393873e-0008L,
+	p6 = 1.605904383643244375050998243778534074273e-0010L,
+	p7 = -7.647162722800685516901456114270824622699e-0013L,
+	p8 = 2.810046428661902961725428841068844462603e-0015L;
+
 /*
  *		     2	         10        -123.84
  * |cos(x) - (1+qq1*x +...+ qq5*x  )| <= 2        for |x|<=1/128
  */
-qq1	= -4.999999999999999999999999999999378373641e-0001L,
-qq2	=  4.166666666666666666666665478399327703130e-0002L,
-qq3	= -1.388888888888888888058211230618051613494e-0003L,
-qq4	=  2.480158730156105377771585658905303111866e-0005L,
-qq5	= -2.755728099762526325736488376695157008736e-0007L;
-/* INDENT ON */
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = 4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = 2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
+
+
 long double
-__k_sinl(long double x, long double y) {
+__k_sinl(long double x, long double y)
+{
 	long double a, t, z, w;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0L;
@@ -113,16 +121,20 @@
 	hx = px[0];
 #endif
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc9000) {
 		if (ix < 0x3fc60000)
-			if (((int) x) == 0)
-				return (x);	/* generate inexact */
+			if (((int)x) == 0)
+				return (x);
+
+		/* generate inexact */
 		z = x * x;
-		t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 + z *
-			(p6 + z * (p7 + z * p8)))))));
+		t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 + z * (p6 +
+		    z * (p7 + z * p8)))))));
 		t = y + x * t;
 		return (x + t);
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 #if defined(__i386) || defined(__amd64)
@@ -130,17 +142,19 @@
 #else
 	pt[0] = j;
 #endif
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a = _TBL_sinl_hi[i];
 	z = x * x;
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
-	w = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z *
-		pp5)))));
+	w = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z * pp5)))));
 	t = _TBL_cosl_hi[i] * w + a * t;
 	t += _TBL_sinl_lo[i];
+
 	if (hx < 0)
 		return (-a - t);
 	else
--- old/usr/src/lib/libm/common/LD/__tanl.c	2019-06-06 20:38:10.491034539 +0000
+++ new/usr/src/lib/libm/common/LD/__tanl.c	2019-06-06 20:38:10.508872764 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * __k_tanl( long double x;  long double y; int k )
  * kernel tan/cotan function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -47,7 +48,7 @@
  *		ht = (hx + 0x400)&0x7ffff800	(round x to a break point t)
  *		lt = 0
  *		i  = (hy-0x3ffc4000)>>11;	(i<=64)
- *		x' = (x - t)+y 			(|x'| ~<= 2^-7)
+ *		x' = (x - t)+y                  (|x'| ~<= 2^-7)
  *	   By
  *		tan(t+x')
  *		  = (tan(t)+tan(x'))/(1-tan(x')tan(t))
@@ -61,7 +62,7 @@
  *		       tan(t) + tan(t)*(cos(x')-1) + sin(x')
  *
  *
- *	   where 	tan(t) is from the table,
+ *	   where        tan(t) is from the table,
  *			sin(x') = x + pp1*x^3 + ...+ pp5*x^11
  *			cos(x') = 1 + qq1*x^2 + ...+ qq5*x^10
  */
@@ -71,48 +72,55 @@
 #include <sys/isa_defs.h>
 
 extern const long double _TBL_tanl_hi[], _TBL_tanl_lo[];
-static const long double
-one	= 1.0,
+static const long double one = 1.0;
+
 /*
  * |sin(x) - (x+pp1*x^3+...+ pp5*x^11)| <= 2^-122.32 for |x|<1/64
  */
-pp1	= -1.666666666666666666666666666586782940810e-0001L,
-pp2	=  8.333333333333333333333003723660929317540e-0003L,
-pp3	= -1.984126984126984076045903483778337804470e-0004L,
-pp4	=  2.755731922361906641319723106210900949413e-0006L,
-pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = 8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = 2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  *                   2           10        -123.84
  * |cos(x) - (1+qq1*x +...+ qq5*x  )| <= 2        for |x|<=1/128
  */
-qq1	= -4.999999999999999999999999999999378373641e-0001L,
-qq2	=  4.166666666666666666666665478399327703130e-0002L,
-qq3	= -1.388888888888888888058211230618051613494e-0003L,
-qq4	=  2.480158730156105377771585658905303111866e-0005L,
-qq5	= -2.755728099762526325736488376695157008736e-0007L,
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = 4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = 2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
+
 /*
  * |tan(x) - (x+t1*x^3+...+t6*x^13)|
  * |------------------------------ | <= 2^-59.73 for |x|<0.15625
  * |                x              |
  */
-t1	=  3.333333333333333333333333333333423342490e-0001L,
-t2	=  1.333333333333333333333333333093838744537e-0001L,
-t3	=  5.396825396825396825396827906318682662250e-0002L,
-t4	=  2.186948853615520282185576976994418486911e-0002L,
-t5	=  8.863235529902196573354554519991152936246e-0003L,
-t6	=  3.592128036572480064652191427543994878790e-0003L,
-t7	=  1.455834387051455257856833807581901305474e-0003L,
-t8	=  5.900274409318599857829983256201725587477e-0004L,
-t9	=  2.391291152117265181501116961901122362937e-0004L,
-t10	=  9.691533169382729742394024173194981882375e-0005L,
-t11	=  3.927994733186415603228178184225780859951e-0005L,
-t12	=  1.588300018848323824227640064883334101288e-0005L,
-t13	=  6.916271223396808311166202285131722231723e-0006L;
-/* INDENT ON */
+static const long double
+	t1 = 3.333333333333333333333333333333423342490e-0001L,
+	t2 = 1.333333333333333333333333333093838744537e-0001L,
+	t3 = 5.396825396825396825396827906318682662250e-0002L,
+	t4 = 2.186948853615520282185576976994418486911e-0002L,
+	t5 = 8.863235529902196573354554519991152936246e-0003L,
+	t6 = 3.592128036572480064652191427543994878790e-0003L,
+	t7 = 1.455834387051455257856833807581901305474e-0003L,
+	t8 = 5.900274409318599857829983256201725587477e-0004L,
+	t9 = 2.391291152117265181501116961901122362937e-0004L,
+	t10 = 9.691533169382729742394024173194981882375e-0005L,
+	t11 = 3.927994733186415603228178184225780859951e-0005L,
+	t12 = 1.588300018848323824227640064883334101288e-0005L,
+	t13 = 6.916271223396808311166202285131722231723e-0006L;
+
+
 long double
-__k_tanl(long double x, long double y, int k) {
+__k_tanl(long double x, long double y, int k)
+{
 	long double a, t, z, w = 0.0, s, c;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0;
@@ -122,24 +130,30 @@
 	hx = px[0];
 #endif
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc4000) {
 		if (ix < 0x3fc60000) {
-			if ((i = (int) x) == 0)	/* generate inexact */
+			if ((i = (int)x) == 0)	/* generate inexact */
 				w = x;
 		} else {
 			z = x * x;
-			if (ix < 0x3ff30000)	/* 2**-12 */
+
+			if (ix < 0x3ff30000) {	/* 2**-12 */
 				t = z * (t1 + z * (t2 + z * (t3 + z * t4)));
-			else
-				t = z * (t1 + z * (t2 + z * (t3 + z * (t4 +
-					z * (t5 + z * (t6 + z * (t7 + z *
-					(t8 + z * (t9 + z * (t10 + z * (t11 +
-					z * (t12 + z * t13))))))))))));
+			} else {
+				t = z * (t1 + z * (t2 + z * (t3 + z * (t4 + z *
+				    (t5 + z * (t6 + z * (t7 + z * (t8 + z *
+				    (t9 + z * (t10 + z * (t11 + z * (t12 + z *
+				    t13))))))))))));
+			}
+
 			t = y + x * t;
 			w = x + t;
 		}
+
 		return (k == 0 ? w : -one / w);
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 #if defined(__i386) || defined(__amd64)
@@ -147,17 +161,19 @@
 #else
 	pt[0] = j;
 #endif
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a = _TBL_tanl_hi[i];
 	z = x * x;
 	/* cos(x)-1 */
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
 	/* sin(x) */
-	s = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z *
-		pp5)))));
+	s = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z * pp5)))));
+
 	if (k == 0) {
 		w = a * s;
 		t = _TBL_tanl_lo[i] + (s + a * w) / (one - (w - t));
--- old/usr/src/lib/libm/common/LD/acoshl.c	2019-06-06 20:38:10.998751981 +0000
+++ new/usr/src/lib/libm/common/LD/acoshl.c	2019-06-06 20:38:11.018571743 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,25 +32,26 @@
 
 #include "libm.h"
 
-static const long double
-	zero	= 0.0L,
-	ln2	= 6.931471805599453094172321214581765680755e-0001L,
-	one	= 1.0L,
-	big	= 1.e+20L;
+static const long double zero = 0.0L,
+	ln2 = 6.931471805599453094172321214581765680755e-0001L,
+	one = 1.0L,
+	big = 1.e+20L;
 
 long double
-acoshl(long double x) {
+acoshl(long double x)
+{
 	long double t;
 
-	if (isnanl(x))
+	if (isnanl(x)) {
 		return (x + x);
-	else if (x > big)
+	} else if (x > big) {
 		return (logl(x) + ln2);
-	else if (x > one) {
+	} else if (x > one) {
 		t = sqrtl(x - one);
 		return (log1pl(t * (t + sqrtl(x + one))));
-	} else if (x == one)
+	} else if (x == one) {
 		return (zero);
-	else
+	} else {
 		return ((x - x) / (x - x));
+	}
 }
--- old/usr/src/lib/libm/common/LD/asinhl.c	2019-06-06 20:38:11.490221189 +0000
+++ new/usr/src/lib/libm/common/LD/asinhl.c	2019-06-06 20:38:11.507533148 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,29 +33,34 @@
 #include "libm.h"
 
 static const long double
-	ln2	= 6.931471805599453094172321214581765680755e-0001L,
-	one	= 1.0L,
-	big	= 1.0e+20L,
-	tiny	= 1.0e-20L;
+	ln2 = 6.931471805599453094172321214581765680755e-0001L,
+	one = 1.0L,
+	big = 1.0e+20L,
+	tiny = 1.0e-20L;
 
 long double
-asinhl(long double x) {
+asinhl(long double x)
+{
 	long double t, w;
+
 #ifndef lint
 	volatile long double dummy __unused;
 #endif
 
 	w = fabsl(x);
+
 	if (isnanl(x))
-		return (x + x);	/* x is NaN */
+		return (x + x);		/* x is NaN */
+
 	if (w < tiny) {
 #ifndef lint
 		dummy = x + big;	/* inexact if x != 0 */
 #endif
-		return (x);	/* tiny x */
+		return (x);		/* tiny x */
 	} else if (w < big) {
 		t = one / w;
 		return (copysignl(log1pl(w + w / (t + sqrtl(one + t * t))), x));
-	} else
+	} else {
 		return (copysignl(logl(w) + ln2, x));
+	}
 }
--- old/usr/src/lib/libm/common/LD/atan2pil.c	2019-06-06 20:38:11.977221529 +0000
+++ new/usr/src/lib/libm/common/LD/atan2pil.c	2019-06-06 20:38:11.994864353 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,22 +30,22 @@
 
 #include "libm.h"
 
-#define GENERIC	long double
-#define ATAN2PI	atan2pil
-#define ATAN2	atan2l
+#define	GENERIC		long double
+#define	ATAN2PI		atan2pil
+#define	ATAN2		atan2l
 
-/* ATAN2PI(y,x)
+/*
+ * ATAN2PI(y, x)
  *
- *	ATAN2PI(y,x) = ATAN2(y,x)/pi
+ *	ATAN2PI(y, x) = ATAN2(y, x) / pi
  */
 
-extern GENERIC 	ATAN2();
-
-static GENERIC
-invpi = (GENERIC) 3.183098861837906715377675267450287240689e-0001L;
+extern GENERIC ATAN2();
+static GENERIC invpi =
+	(GENERIC)3.183098861837906715377675267450287240689e-0001L;
 
-GENERIC ATAN2PI(y,x)
-GENERIC y,x;
+GENERIC
+ATAN2PI(GENERIC y, GENERIC x)
 {
-	return ATAN2(y,x)*invpi;
+	return (ATAN2(y, x) * invpi);
 }
--- old/usr/src/lib/libm/common/LD/atanhl.c	2019-06-06 20:38:12.471038040 +0000
+++ new/usr/src/lib/libm/common/LD/atanhl.c	2019-06-06 20:38:12.488421393 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,10 +32,12 @@
 
 #include "libm.h"
 
-#define GENERIC	long double
-#define	ATANH 	atanhl
+#define	GENERIC		long double
+#define	ATANH		atanhl
 
-/* ATANH(x)
+/* BEGIN CSTYLED */
+/*
+ * ATANH(x)
  *                  1              2x                          x
  *	ATANH(x) = --- * LOG(1 + -------) = 0.5 * LOG1P(2 * --------)
  *                  2             1 - x                      1 - x
@@ -49,25 +52,26 @@
  *	ATANH(+-1) is +-INF with signal.
  *
  */
+/* END CSTYLED */
 
-#define	FABS 	fabsl
-#define	LOG1P 	log1pl
-#define	COPYSIGN 	copysignl
-
+#define	FABS		fabsl
+#define	LOG1P		log1pl
+#define	COPYSIGN	copysignl
 
-extern GENERIC 	FABS(),LOG1P(),COPYSIGN();
+extern GENERIC FABS(), LOG1P(), COPYSIGN();
 
-static GENERIC
-zero	= (GENERIC) 0.0,
-half 	= (GENERIC) 0.5,
-one	= (GENERIC) 1.0;
+static GENERIC zero = (GENERIC)0.0, half = (GENERIC)0.5, one = (GENERIC)1.0;
 
-GENERIC ATANH(x)
-GENERIC x;
+GENERIC
+ATANH(GENERIC x)
 {
 	GENERIC t;
+
 	t = FABS(x);
-	if (t == one) return x/zero;
-	t = t/(one-t);
-	return COPYSIGN(half,x)*LOG1P(t+t);
+
+	if (t == one)
+		return (x / zero);
+
+	t = t / (one - t);
+	return (COPYSIGN(half, x) * LOG1P(t + t));
 }
--- old/usr/src/lib/libm/common/LD/cbrtl.c	2019-06-06 20:38:12.977540782 +0000
+++ new/usr/src/lib/libm/common/LD/cbrtl.c	2019-06-06 20:38:12.996291185 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,35 +34,40 @@
 #include "longdouble.h"
 
 static const double d_one = 1.0;
-
 long double
-cbrtl(long double x) {
+cbrtl(long double x)
+{
 	long double s, t, r, w, y;
 	double dx, dy;
-	int *py = (int *) &dy;
+	int *py = (int *)&dy;
 	int n, m, m3, n0, sx;
 
 	if (!finitel(x))
 		return (x + x);
+
 	if (iszerol(x))
 		return (x);
+
 	n0 = 0;
-	if (*((int *) &d_one) == 0)
+
+	if (*((int *)&d_one) == 0)
 		n0 = 1;
+
 	sx = signbitl(x);
 	x = fabsl(x);
 	n = ilogbl(x);
 	m = n / 3;
 	m3 = m + m + m;
 	y = scalbnl(x, -m3);
-	dx = (double) y;
+	dx = (double)y;
 	dy = cbrt(dx);
 	py[1 - n0] += 2;
+
 	if (py[1 - n0] == 0)
 		py[n0] += 1;
 
 	/* one step newton iteration to 113 bits with error < 0.667ulps */
-	t = (long double) dy;
+	t = (long double)dy;
 	t = scalbnl(t, m);
 	s = t * t;
 	r = x / s;
--- old/usr/src/lib/libm/common/LD/coshl.c	2019-06-06 20:38:13.459307917 +0000
+++ new/usr/src/lib/libm/common/LD/coshl.c	2019-06-06 20:38:13.476698168 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -71,37 +72,44 @@
 	45.0L,
 	1.135652340629414394879149e+04L,
 	7.004447686242549087858985e-16L,
-	2.710505431213761085018632e-20L,		/* 2^-65 */
+	2.710505431213761085018632e-20L, /* 2^-65 */
 };
 
-#define	half	C[0]
-#define	one	C[1]
-#define	thr1	C[2]
-#define	thr2	C[3]
-#define	lnovft	C[4]
-#define	lnovlo	C[5]
-#define	tinyl	C[6]
+#define	half		C[0]
+#define	one		C[1]
+#define	thr1		C[2]
+#define	thr2		C[3]
+#define	lnovft		C[4]
+#define	lnovlo		C[5]
+#define	tinyl		C[6]
 
 long double
-coshl(long double x) {
+coshl(long double x)
+{
 	long double w, t;
 
 	w = fabsl(x);
+
 	if (!finitel(w))
-		return (w + w);	/* x is INF or NaN */
+		return (w + w);		/* x is INF or NaN */
+
 	if (w < thr1) {
 		if (w < tinyl)
 			return (one + w);	/* inexact+directed rounding */
+
 		t = expm1l(w);
 		w = one + t;
 		w = one + (t * t) / (w + w);
 		return (w);
 	}
+
 	if (w < thr2) {
 		t = expl(w);
 		return (half * (t + one / t));
 	}
+
 	if (w <= lnovft)
 		return (half * expl(w));
+
 	return (scalbnl(expl((w - lnovft) - lnovlo), 16383));
 }
--- old/usr/src/lib/libm/common/LD/cosl.c	2019-06-06 20:38:13.956539935 +0000
+++ new/usr/src/lib/libm/common/LD/cosl.c	2019-06-06 20:38:13.974057470 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,8 +30,9 @@
 
 #pragma weak __cosl = cosl
 
-/* INDENT OFF */
-/* cosl(x)
+/* BEGIN CSTYLED */
+/*
+ * cosl(x)
  * Table look-up algorithm by K.C. Ng, November, 1989.
  *
  * kernel function:
@@ -60,7 +62,7 @@
  * Accuracy:
  *	computer TRIG(x) returns trig(x) nearly rounded.
  */
-/* INDENT ON */
+/* END CSTYLED */
 
 #include "libm.h"
 #include "longdouble.h"
@@ -68,14 +70,15 @@
 #include <sys/isa_defs.h>
 
 long double
-cosl(long double x) {
+cosl(long double x)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
-	int *px = (int *) &x;
+	int *px = (int *)&x;
 
 	/* trig(Inf or NaN) is NaN */
 	if (!finitel(x))
-		return x - x;
+		return (x - x);
 
 	/* High word of x. */
 #if defined(__i386) || defined(__amd64)
@@ -86,23 +89,26 @@
 
 	/* |x| ~< pi/4 */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)
-		return __k_cosl(x, z);
 
+	if (ix <= 0x3ffe9220) {
+		return (__k_cosl(x, z));
+	}
 	/* argument reduction needed */
 	else {
 		n = __rem_pio2l(x, y);
+
 		switch (n & 3) {
 		case 0:
-			return __k_cosl(y[0], y[1]);
+			return (__k_cosl(y[0], y[1]));
 		case 1:
-			return -__k_sinl(y[0], y[1]);
+			return (-__k_sinl(y[0], y[1]));
 		case 2:
-			return -__k_cosl(y[0], y[1]);
+			return (-__k_cosl(y[0], y[1]));
 		case 3:
-			return __k_sinl(y[0], y[1]);
-		/* NOTREACHED */
+			return (__k_sinl(y[0], y[1]));
+			/* NOTREACHED */
 		}
 	}
-    return 0.0L;
+
+	return (0.0L);
 }
--- old/usr/src/lib/libm/common/LD/erfl.c	2019-06-06 20:38:14.504897148 +0000
+++ new/usr/src/lib/libm/common/LD/erfl.c	2019-06-06 20:38:14.524092879 +0000
@@ -22,28 +22,31 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* long double function erf,erfc (long double x)
+/* BEGIN CSTYLED */
+/*
+ * long double function erf,erfc (long double x)
  * K.C. Ng, September, 1989.
  *			     x
  *		      2      |\
  *     erf(x)  =  ---------  | exp(-t*t)dt
- *	 	   sqrt(pi) \|
+ *	           sqrt(pi) \|
  *			     0
  *
  *     erfc(x) =  1-erf(x)
  *
  * method:
- * 	Since erf(-x) = -erf(x), we assume x>=0.
+ *      Since erf(-x) = -erf(x), we assume x>=0.
  *	For x near 0, we have the expansion
  *
- *     	    erf(x) = (2/sqrt(pi))*(x - x^3/3 + x^5/10 - x^7/42 + ....).
+ *          erf(x) = (2/sqrt(pi))*(x - x^3/3 + x^5/10 - x^7/42 + ....).
  *
- * 	Since 2/sqrt(pi) = 1.128379167095512573896158903121545171688,
+ *      Since 2/sqrt(pi) = 1.128379167095512573896158903121545171688,
  *	we use x + x*P(x^2) to approximate erf(x). This formula will
  *	guarantee the error less than one ulp where x is not too far
  *	away from 0. We note that erf(x)=x at x = 0.6174...... After
@@ -52,10 +55,10 @@
  *
  *	For x in [0,0.84375]
  *		   2		    2        4		     40
- *	   P = 	P(x ) = (p0 + p1 * x + p2 * x + ... + p20 * x  )
+ *	   P =  P(x ) = (p0 + p1 * x + p2 * x + ... + p20 * x  )
  *
  *	   erf(x)  = x + x*P
- *	   erfc(x) = 1 - erf(x) 	  if x<=0.25
+ *	   erfc(x) = 1 - erf(x)           if x<=0.25
  *		   = 0.5 + ((0.5-x)-x*P)  if x in [0.25,0.84375]
  *	precision: |P(x^2)-(erf(x)-x)/x| <= 2**-122.50
  *
@@ -91,6 +94,7 @@
  *	   erf(inf)  = 1
  *	   erfc(inf) = 0
  */
+/* END CSTYLED */
 
 #pragma weak __erfl = erfl
 #pragma weak __erfcl = erfcl
@@ -98,251 +102,285 @@
 #include "libm.h"
 #include "longdouble.h"
 
-static long double
-tiny	    = 1e-40L,
-nearunfl    = 1e-4000L,
-half	    = 0.5L,
-one	    = 1.0L,
-onehalf	    = 1.5L,
-L16_3	    = 16.0L/3.0L;
+static long double tiny = 1e-40L,
+	nearunfl = 1e-4000L,
+	half = 0.5L,
+	one = 1.0L,
+	onehalf = 1.5L,
+	L16_3 = 16.0L / 3.0L;
+
 /*
  * Coefficients for even polynomial P for erf(x)=x+x*P(x^2) on [0,0.84375]
  */
-static long double P[] = { 	/* 21 coeffs */
-   1.283791670955125738961589031215451715556e-0001L,
-  -3.761263890318375246320529677071815594603e-0001L,
-   1.128379167095512573896158903121205899135e-0001L,
-  -2.686617064513125175943235483344625046092e-0002L,
-   5.223977625442187842111846652980454568389e-0003L,
-  -8.548327023450852832546626271083862724358e-0004L,
-   1.205533298178966425102164715902231976672e-0004L,
-  -1.492565035840625097674944905027897838996e-0005L,
-   1.646211436588924733604648849172936692024e-0006L,
-  -1.636584469123491976815834704799733514987e-0007L,
-   1.480719281587897445302529007144770739305e-0008L,
-  -1.229055530170782843046467986464722047175e-0009L,
-   9.422759064320307357553954945760654341633e-0011L,
-  -6.711366846653439036162105104991433380926e-0012L,
-   4.463224090341893165100275380693843116240e-0013L,
-  -2.783513452582658245422635662559779162312e-0014L,
-   1.634227412586960195251346878863754661546e-0015L,
-  -9.060782672889577722765711455623117802795e-0017L,
-   4.741341801266246873412159213893613602354e-0018L,
-  -2.272417596497826188374846636534317381203e-0019L,
-   8.069088733716068462496835658928566920933e-0021L,
+static long double P[] = {		/* 21 coeffs */
+	1.283791670955125738961589031215451715556e-0001L,
+	-3.761263890318375246320529677071815594603e-0001L,
+	1.128379167095512573896158903121205899135e-0001L,
+	-2.686617064513125175943235483344625046092e-0002L,
+	5.223977625442187842111846652980454568389e-0003L,
+	-8.548327023450852832546626271083862724358e-0004L,
+	1.205533298178966425102164715902231976672e-0004L,
+	-1.492565035840625097674944905027897838996e-0005L,
+	1.646211436588924733604648849172936692024e-0006L,
+	-1.636584469123491976815834704799733514987e-0007L,
+	1.480719281587897445302529007144770739305e-0008L,
+	-1.229055530170782843046467986464722047175e-0009L,
+	9.422759064320307357553954945760654341633e-0011L,
+	-6.711366846653439036162105104991433380926e-0012L,
+	4.463224090341893165100275380693843116240e-0013L,
+	-2.783513452582658245422635662559779162312e-0014L,
+	1.634227412586960195251346878863754661546e-0015L,
+	-9.060782672889577722765711455623117802795e-0017L,
+	4.741341801266246873412159213893613602354e-0018L,
+	-2.272417596497826188374846636534317381203e-0019L,
+	8.069088733716068462496835658928566920933e-0021L,
 };
 
 /*
  * Rational erf(x) = ((float)0.84506291151) + P1(x-1)/Q1(x-1) on [0.84375,1.25]
  */
-static long double C1   = (long double)((float)0.84506291151);
-static long double P1[] = { 	/*  12 top coeffs */
-  -2.362118560752659955654364917390741930316e-0003L,
-   4.129623379624420034078926610650759979146e-0001L,
-  -3.973857505403547283109417923182669976904e-0002L,
-   4.357503184084022439763567513078036755183e-0002L,
-   8.015593623388421371247676683754171456950e-0002L,
-  -1.034459310403352486685467221776778474602e-0002L,
-   5.671850295381046679675355719017720821383e-0003L,
-   1.219262563232763998351452194968781174318e-0003L,
-   5.390833481581033423020320734201065475098e-0004L,
-  -1.978853912815115495053119023517805528300e-0004L,
-   6.184234513953600118335017885706420552487e-0005L,
-  -5.331802711697810861017518515816271808286e-0006L,
+static long double C1 = (long double)((float)0.84506291151);
+static long double P1[] = {		/*  12 top coeffs */
+	-2.362118560752659955654364917390741930316e-0003L,
+	4.129623379624420034078926610650759979146e-0001L,
+	-3.973857505403547283109417923182669976904e-0002L,
+	4.357503184084022439763567513078036755183e-0002L,
+	8.015593623388421371247676683754171456950e-0002L,
+	-1.034459310403352486685467221776778474602e-0002L,
+	5.671850295381046679675355719017720821383e-0003L,
+	1.219262563232763998351452194968781174318e-0003L,
+	5.390833481581033423020320734201065475098e-0004L,
+	-1.978853912815115495053119023517805528300e-0004L,
+	6.184234513953600118335017885706420552487e-0005L,
+	-5.331802711697810861017518515816271808286e-0006L,
 };
-static long double Q1[] = { 	/*  12 bottom coeffs with leading 1.0 hidden */
-   9.081506296064882195280178373107623196655e-0001L,
-   6.821049531968204097604392183650687642520e-0001L,
-   4.067869178233539502315055970743271822838e-0001L,
-   1.702332233546316765818144723063881095577e-0001L,
-   7.498098377690553934266423088708614219356e-0002L,
-   2.050154396918178697056927234366372760310e-0002L,
-   7.012988534031999899054782333851905939379e-0003L,
-   1.149904787014400354649843451234570731076e-0003L,
-   3.185620255011299476196039491205159718620e-0004L,
-   1.273405072153008775426376193374105840517e-0005L,
-   4.753866999959432971956781228148402971454e-0006L,
-  -1.002287602111660026053981728549540200683e-0006L,
+
+static long double Q1[] = {    /*  12 bottom coeffs with leading 1.0 hidden */
+	9.081506296064882195280178373107623196655e-0001L,
+	6.821049531968204097604392183650687642520e-0001L,
+	4.067869178233539502315055970743271822838e-0001L,
+	1.702332233546316765818144723063881095577e-0001L,
+	7.498098377690553934266423088708614219356e-0002L,
+	2.050154396918178697056927234366372760310e-0002L,
+	7.012988534031999899054782333851905939379e-0003L,
+	1.149904787014400354649843451234570731076e-0003L,
+	3.185620255011299476196039491205159718620e-0004L,
+	1.273405072153008775426376193374105840517e-0005L,
+	4.753866999959432971956781228148402971454e-0006L,
+	-1.002287602111660026053981728549540200683e-0006L,
 };
+
 /*
  * Rational erf(x) = ((float)0.95478588343) + P2(x-1.5)/Q2(x-1.5)
  * on [1.25,1.75]
  */
-static long double C2   = (long double)((float)0.95478588343);
-static long double P2[] = { 	/*  12 top coeffs */
-   1.131926304864446730135126164594785863512e-0002L,
-   1.273617996967754151544330055186210322832e-0001L,
-  -8.169980734667512519897816907190281143423e-0002L,
-   9.512267486090321197833634271787944271746e-0002L,
-  -2.394251569804872160005274999735914368170e-0002L,
-   1.108768660227528667525252333184520222905e-0002L,
-   3.527435492933902414662043314373277494221e-0004L,
-   4.946116273341953463584319006669474625971e-0004L,
-  -4.289851942513144714600285769022420962418e-0005L,
-   8.304719841341952705874781636002085119978e-0005L,
-  -1.040460226177309338781902252282849903189e-0005L,
-   2.122913331584921470381327583672044434087e-0006L,
+static long double C2 = (long double)((float)0.95478588343);
+static long double P2[] = {		/*  12 top coeffs */
+	1.131926304864446730135126164594785863512e-0002L,
+	1.273617996967754151544330055186210322832e-0001L,
+	-8.169980734667512519897816907190281143423e-0002L,
+	9.512267486090321197833634271787944271746e-0002L,
+	-2.394251569804872160005274999735914368170e-0002L,
+	1.108768660227528667525252333184520222905e-0002L,
+	3.527435492933902414662043314373277494221e-0004L,
+	4.946116273341953463584319006669474625971e-0004L,
+	-4.289851942513144714600285769022420962418e-0005L,
+	8.304719841341952705874781636002085119978e-0005L,
+	-1.040460226177309338781902252282849903189e-0005L,
+	2.122913331584921470381327583672044434087e-0006L,
 };
-static long double Q2[] = { 	/*  13 bottom coeffs with leading 1.0 hidden */
-   7.448815737306992749168727691042003832150e-0001L,
-   7.161813850236008294484744312430122188043e-0001L,
-   3.603134756584225766144922727405641236121e-0001L,
-   1.955811609133766478080550795194535852653e-0001L,
-   7.253059963716225972479693813787810711233e-0002L,
-   2.752391253757421424212770221541238324978e-0002L,
-   7.677654852085240257439050673446546828005e-0003L,
-   2.141102244555509687346497060326630061069e-0003L,
-   4.342123013830957093949563339130674364271e-0004L,
-   8.664587895570043348530991997272212150316e-0005L,
-   1.109201582511752087060167429397033701988e-0005L,
-   1.357834375781831062713347000030984364311e-0006L,
-   4.957746280594384997273090385060680016451e-0008L,
+
+static long double Q2[] = {    /*  13 bottom coeffs with leading 1.0 hidden */
+	7.448815737306992749168727691042003832150e-0001L,
+	7.161813850236008294484744312430122188043e-0001L,
+	3.603134756584225766144922727405641236121e-0001L,
+	1.955811609133766478080550795194535852653e-0001L,
+	7.253059963716225972479693813787810711233e-0002L,
+	2.752391253757421424212770221541238324978e-0002L,
+	7.677654852085240257439050673446546828005e-0003L,
+	2.141102244555509687346497060326630061069e-0003L,
+	4.342123013830957093949563339130674364271e-0004L,
+	8.664587895570043348530991997272212150316e-0005L,
+	1.109201582511752087060167429397033701988e-0005L,
+	1.357834375781831062713347000030984364311e-0006L,
+	4.957746280594384997273090385060680016451e-0008L,
 };
+
 /*
  * erfc(x) = exp(-x*x)/x * R1(1/x)/S1(1/x) on [1.75, 16/3]
  */
-static long double R1[] = { 	/*  14 top coeffs */
-   4.630195122654315016370705767621550602948e+0006L,
-   1.257949521746494830700654204488675713628e+0007L,
-   1.704153822720260272814743497376181625707e+0007L,
-   1.502600568706061872381577539537315739943e+0007L,
-   9.543710793431995284827024445387333922861e+0006L,
-   4.589344808584091011652238164935949522427e+0006L,
-   1.714660662941745791190907071920671844289e+0006L,
-   5.034802147768798894307672256192466283867e+0005L,
-   1.162286400443554670553152110447126850725e+0005L,
-   2.086643834548901681362757308058660399137e+0004L,
-   2.839793161868140305907004392890348777338e+0003L,
-   2.786687241658423601778258694498655680778e+0002L,
-   1.779177837102695602425897452623985786464e+0001L,
-   5.641895835477470769043614623819144434731e-0001L,
+static long double R1[] = {		/*  14 top coeffs */
+	4.630195122654315016370705767621550602948e+0006L,
+	1.257949521746494830700654204488675713628e+0007L,
+	1.704153822720260272814743497376181625707e+0007L,
+	1.502600568706061872381577539537315739943e+0007L,
+	9.543710793431995284827024445387333922861e+0006L,
+	4.589344808584091011652238164935949522427e+0006L,
+	1.714660662941745791190907071920671844289e+0006L,
+	5.034802147768798894307672256192466283867e+0005L,
+	1.162286400443554670553152110447126850725e+0005L,
+	2.086643834548901681362757308058660399137e+0004L,
+	2.839793161868140305907004392890348777338e+0003L,
+	2.786687241658423601778258694498655680778e+0002L,
+	1.779177837102695602425897452623985786464e+0001L,
+	5.641895835477470769043614623819144434731e-0001L,
 };
-static long double S1[] = { 	/* 15 bottom coeffs with leading 1.0 hidden */
-   4.630195122654331529595606896287596843110e+0006L,
-   1.780411093345512024324781084220509055058e+0007L,
-   3.250113097051800703707108623715776848283e+0007L,
-   3.737857099176755050912193712123489115755e+0007L,
-   3.029787497516578821459174055870781168593e+0007L,
-   1.833850619965384765005769632103205777227e+0007L,
-   8.562719999736915722210391222639186586498e+0006L,
-   3.139684562074658971315545539760008136973e+0006L,
-   9.106421313731384880027703627454366930945e+0005L,
-   2.085108342384266508613267136003194920001e+0005L,
-   3.723126272693120340730491416449539290600e+0004L,
-   5.049169878567344046145695360784436929802e+0003L,
-   4.944274532748010767670150730035392093899e+0002L,
-   3.153510608818213929982940249162268971412e+0001L,
-   1.0e00L,
+
+static long double S1[] = {	/* 15 bottom coeffs with leading 1.0 hidden */
+	4.630195122654331529595606896287596843110e+0006L,
+	1.780411093345512024324781084220509055058e+0007L,
+	3.250113097051800703707108623715776848283e+0007L,
+	3.737857099176755050912193712123489115755e+0007L,
+	3.029787497516578821459174055870781168593e+0007L,
+	1.833850619965384765005769632103205777227e+0007L,
+	8.562719999736915722210391222639186586498e+0006L,
+	3.139684562074658971315545539760008136973e+0006L,
+	9.106421313731384880027703627454366930945e+0005L,
+	2.085108342384266508613267136003194920001e+0005L,
+	3.723126272693120340730491416449539290600e+0004L,
+	5.049169878567344046145695360784436929802e+0003L,
+	4.944274532748010767670150730035392093899e+0002L,
+	3.153510608818213929982940249162268971412e+0001L,
+	1.0e00L,
 };
 
 /*
  * erfc(x) = exp(-x*x)/x * R2(1/x)/S2(1/x) on [16/3, 107]
  */
-static long double R2[] = { 	/*  15 top coeffs in reverse order!!*/
-   2.447288012254302966796326587537136931669e+0005L,
-   8.768592567189861896653369912716538739016e+0005L,
-   1.552293152581780065761497908005779524953e+0006L,
-   1.792075924835942935864231657504259926729e+0006L,
-   1.504001463155897344947500222052694835875e+0006L,
-   9.699485556326891411801230186016013019935e+0005L,
-   4.961449933661807969863435013364796037700e+0005L,
-   2.048726544693474028061176764716228273791e+0005L,
-   6.891532964330949722479061090551896886635e+0004L,
-   1.888014709010307507771964047905823237985e+0004L,
-   4.189692064988957745054734809642495644502e+0003L,
-   7.362346487427048068212968889642741734621e+0002L,
-   9.980359714211411423007641056580813116207e+0001L,
-   9.426910895135379181107191962193485174159e+0000L,
-   5.641895835477562869480794515623601280429e-0001L,
+static long double R2[] = {	/*  15 top coeffs in reverse order!! */
+	2.447288012254302966796326587537136931669e+0005L,
+	8.768592567189861896653369912716538739016e+0005L,
+	1.552293152581780065761497908005779524953e+0006L,
+	1.792075924835942935864231657504259926729e+0006L,
+	1.504001463155897344947500222052694835875e+0006L,
+	9.699485556326891411801230186016013019935e+0005L,
+	4.961449933661807969863435013364796037700e+0005L,
+	2.048726544693474028061176764716228273791e+0005L,
+	6.891532964330949722479061090551896886635e+0004L,
+	1.888014709010307507771964047905823237985e+0004L,
+	4.189692064988957745054734809642495644502e+0003L,
+	7.362346487427048068212968889642741734621e+0002L,
+	9.980359714211411423007641056580813116207e+0001L,
+	9.426910895135379181107191962193485174159e+0000L,
+	5.641895835477562869480794515623601280429e-0001L,
 };
-static long double S2[] = { 	/* 16 coefficients */
-   2.447282203601902971246004716790604686880e+0005L,
-   1.153009852759385309367759460934808489833e+0006L,
-   2.608580649612639131548966265078663384849e+0006L,
-   3.766673917346623308850202792390569025740e+0006L,
-   3.890566255138383910789924920541335370691e+0006L,
-   3.052882073900746207613166259994150527732e+0006L,
-   1.885574519970380988460241047248519418407e+0006L,
-   9.369722034759943185851450846811445012922e+0005L,
-   3.792278350536686111444869752624492443659e+0005L,
-   1.257750606950115799965366001773094058720e+0005L,
-   3.410830600242369370645608634643620355058e+0004L,
-   7.513984469742343134851326863175067271240e+0003L,
-   1.313296320593190002554779998138695507840e+0003L,
-   1.773972700887629157006326333696896516769e+0002L,
-   1.670876451822586800422009013880457094162e+0001L,
-   1.000L,
+
+static long double S2[] = {		/* 16 coefficients */
+	2.447282203601902971246004716790604686880e+0005L,
+	1.153009852759385309367759460934808489833e+0006L,
+	2.608580649612639131548966265078663384849e+0006L,
+	3.766673917346623308850202792390569025740e+0006L,
+	3.890566255138383910789924920541335370691e+0006L,
+	3.052882073900746207613166259994150527732e+0006L,
+	1.885574519970380988460241047248519418407e+0006L,
+	9.369722034759943185851450846811445012922e+0005L,
+	3.792278350536686111444869752624492443659e+0005L,
+	1.257750606950115799965366001773094058720e+0005L,
+	3.410830600242369370645608634643620355058e+0004L,
+	7.513984469742343134851326863175067271240e+0003L,
+	1.313296320593190002554779998138695507840e+0003L,
+	1.773972700887629157006326333696896516769e+0002L,
+	1.670876451822586800422009013880457094162e+0001L,
+	1.000L,
 };
 
-long double erfl(x)
-long double x;
+long double
+erfl(long double x)
 {
-	long double erfcl(long double),s,y,t;
+	long double erfcl(long double), s, y, t;
 
 	if (!finitel(x)) {
-	    if (x != x) return x+x; 	/* NaN */
-	    return copysignl(one,x);	/* return +-1.0 is x=Inf */
+		if (x != x)
+			return (x + x);		/* NaN */
+
+		return (copysignl(one, x));	/* return +-1.0 is x=Inf */
 	}
 
 	y = fabsl(x);
+
 	if (y <= 0.84375L) {
-	    if (y<=tiny) return x+P[0]*x;
-	    s = y*y;
-	    t = __poly_libmq(s,21,P);
-	    return  x+x*t;
+		if (y <= tiny)
+			return (x + P[0] * x);
+
+		s = y * y;
+		t = __poly_libmq(s, 21, P);
+		return (x + x * t);
 	}
-	if (y<=1.25L) {
-	    s = y-one;
-	    t = C1+__poly_libmq(s,12,P1)/(one+s*__poly_libmq(s,12,Q1));
-	    return (signbitl(x))? -t: t;
-	} else if (y<=1.75L) {
-	    s = y-onehalf;
-	    t = C2+__poly_libmq(s,12,P2)/(one+s*__poly_libmq(s,13,Q2));
-	    return (signbitl(x))? -t: t;
+
+	if (y <= 1.25L) {
+		s = y - one;
+		t = C1 + __poly_libmq(s, 12, P1) / (one + s * __poly_libmq(s,
+		    12, Q1));
+		return ((signbitl(x)) ? -t : t);
+	} else if (y <= 1.75L) {
+		s = y - onehalf;
+		t = C2 + __poly_libmq(s, 12, P2) / (one + s * __poly_libmq(s,
+		    13, Q2));
+		return ((signbitl(x)) ? -t : t);
 	}
-	if (y<=9.0L) t = erfcl(y); else t = tiny;
-	return (signbitl(x))? t-one: one-t;
+
+	if (y <= 9.0L)
+		t = erfcl(y);
+	else
+		t = tiny;
+
+	return ((signbitl(x)) ? t - one : one - t);
 }
 
-long double erfcl(x)
-long double x;
+long double
+erfcl(long double x)
 {
-	long double erfl(long double),s,y,t;
+	long double s, y, t;
 
 	if (!finitel(x)) {
-	    if (x != x) return x+x; 	/* NaN */
-	    				/* return 2.0 if x= -inf
-						  0.0 if x= +inf */
-	    if (x<0.0L) return 2.0L; else return 0.0L;
+		if (x != x)
+			return (x + x);		/* NaN */
+
+		/*
+		 * return 2.0 if x = -inf
+		 *	  0.0 if x = +inf
+		 */
+		if (x < 0.0L)
+			return (2.0L);
+		else
+			return (0.0L);
 	}
 
 	if (x <= 0.84375L) {
-	    if (x<=0.25) return one-erfl(x);
-	    s = x*x;
-	    t = half-x;
-	    t = t - x*__poly_libmq(s,21,P);
-	    return  half+t;
+		if (x <= 0.25)
+			return (one - erfl(x));
+
+		s = x * x;
+		t = half - x;
+		t = t - x * __poly_libmq(s, 21, P);
+		return (half + t);
 	}
-	if (x<=1.25L) {
-	    s = x-one;
-	    t = one-C1;
-	    return t - __poly_libmq(s,12,P1)/(one+s*__poly_libmq(s,12,Q1));
-	} else if (x<=1.75L) {
-	    s = x-onehalf;
-	    t = one-C2;
-	    return t - __poly_libmq(s,12,P2)/(one+s*__poly_libmq(s,13,Q2));
+
+	if (x <= 1.25L) {
+		s = x - one;
+		t = one - C1;
+		return (t - __poly_libmq(s, 12, P1) / (one + s * __poly_libmq(s,
+		    12, Q1)));
+	} else if (x <= 1.75L) {
+		s = x - onehalf;
+		t = one - C2;
+		return (t - __poly_libmq(s, 12, P2) / (one + s * __poly_libmq(s,
+		    13, Q2)));
 	}
-	if (x>=107.0L) return nearunfl*nearunfl;		/* underflow */
-	else if (x >= L16_3) {
-	    y = __poly_libmq(x,15,R2);
-	    t = y/__poly_libmq(x,16,S2);
+
+	if (x >= 107.0L) {
+		return (nearunfl * nearunfl);	/* underflow */
+	} else if (x >= L16_3) {
+		y = __poly_libmq(x, 15, R2);
+		t = y / __poly_libmq(x, 16, S2);
 	} else {
-	    y = __poly_libmq(x,14,R1);
-	    t = y/__poly_libmq(x,15,S1);
+		y = __poly_libmq(x, 14, R1);
+		t = y / __poly_libmq(x, 15, S1);
 	}
+
 	/* see comment in ../Q/erfl.c */
 	y = x;
-	*(int*)&y = 0;
-	t *= expl(-y*y)*expl(-(x-y)*(x+y));
-	return  t;
+	*(int *)&y = 0;
+	t *= expl(-y * y) * expl(-(x - y) * (x + y));
+	return (t);
 }
--- old/usr/src/lib/libm/common/LD/finitel.c	2019-06-06 20:38:14.991036925 +0000
+++ new/usr/src/lib/libm/common/LD/finitel.c	2019-06-06 20:38:15.006119155 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,18 +32,22 @@
 
 #if defined(__sparc)
 int
-finitel(long double x) {
-	int *px = (int *) &x;
+finitel(long double x)
+{
+	int *px = (int *)&x;
+
 	return ((px[0] & ~0x80000000) < 0x7fff0000);
 }
 #elif defined(__x86)
 int
-finitel(long double x) {
-	int *px = (int *) &x, t = px[2] & 0x7fff;
+finitel(long double x)
+{
+	int *px = (int *)&x, t = px[2] & 0x7fff;
+
 #if defined(HANDLE_UNSUPPORTED)
 	return (t != 0x7fff && ((px[1] & 0x80000000) != 0 || t == 0));
 #else
 	return (t != 0x7fff);
 #endif
 }
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
--- old/usr/src/lib/libm/common/LD/gammal.c	2019-06-06 20:38:15.402818897 +0000
+++ new/usr/src/lib/libm/common/LD/gammal.c	2019-06-06 20:38:15.418763621 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,11 +39,11 @@
 
 extern int signgam;
 extern int signgaml;
-
 long double
-gammal(long double x) {
+gammal(long double x)
+{
 	long double y = __k_lgammal(x, &signgaml);
 
 	signgam = signgaml;	/* SUSv3 requires the setting of signgam */
-	return y;
+	return (y);
 }
--- old/usr/src/lib/libm/common/LD/gammal_r.c	2019-06-06 20:38:15.865117086 +0000
+++ new/usr/src/lib/libm/common/LD/gammal_r.c	2019-06-06 20:38:15.883527638 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,6 +38,7 @@
 #include "longdouble.h"
 
 long double
-gammal_r(long double x, int *signgamlp) {
-	return __k_lgammal(x, signgamlp);
+gammal_r(long double x, int *signgamlp)
+{
+	return (__k_lgammal(x, signgamlp));
 }
--- old/usr/src/lib/libm/common/LD/hypotl.c	2019-06-06 20:38:16.332046856 +0000
+++ new/usr/src/lib/libm/common/LD/hypotl.c	2019-06-06 20:38:16.348902306 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -52,7 +53,7 @@
  *	hypot(x,y) is NAN if x or y is NAN.
  *
  * Accuracy:
- * 	hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
+ *      hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
  *	in the last place)
  */
 
@@ -64,10 +65,11 @@
 #define	k	0x7fff
 
 long double
-hypotl(long double x, long double y) {
+hypotl(long double x, long double y)
+{
 	long double t1, t2, y1, y2, w;
-	int *px = (int *) &x, *py = (int *) &y;
-	int *pt1 = (int *) &t1, *py1 = (int *) &y1;
+	int *px = (int *)&x, *py = (int *)&y;
+	int *pt1 = (int *)&t1, *py1 = (int *)&y1;
 	enum fp_direction_type rd;
 	int j, nx, ny, nz;
 
@@ -75,6 +77,7 @@
 	py[2] &= 0x7fff;
 	nx = px[2];		/* biased exponent of x and y */
 	ny = py[2];
+
 	if (ny > nx) {
 		w = x;
 		x = y;
@@ -82,13 +85,16 @@
 		nz = ny;
 		ny = nx;
 		nx = nz;
-	}			/* force nx >= ny */
+	}				/* force nx >= ny */
+
 	if (nx - ny >= 66)
 		return (x + y);	/* x / y >= 2**65 */
+
 	if (nx < 0x5ff3 && ny > 0x205b) {	/* medium x,y */
 		/* save and set RD to Rounding to nearest */
 		rd = __swap87RD(fp_nearest);
 		w = x - y;
+
 		if (w > y) {
 			pt1[2] = px[2];
 			pt1[1] = px[1];
@@ -107,8 +113,10 @@
 			t2 = x - t1;
 			x = sqrtl(t1 * y1 - (w * (-w) - (t2 * y1 + y2 * x)));
 		}
+
 		if (rd != fp_nearest)
-			__swap87RD(rd);	/* restore rounding mode */
+			__swap87RD(rd);		/* restore rounding mode */
+
 		return (x);
 	} else {
 		if (nx == k || ny == k) {	/* x or y is INF or NaN */
@@ -120,9 +128,11 @@
 			else
 				return (x + y);
 		}
+
 		if (ny == 0) {
 			if (y == 0.L || x == 0.L)
 				return (x + y);
+
 			pt1[2] = 0x3fff + 16381;
 			pt1[1] = 0x80000000;
 			pt1[0] = 0;
@@ -133,6 +143,7 @@
 			y *= t1;
 			return (y1 * hypotl(x, y));
 		}
+
 		j = nx - 0x3fff;
 		px[2] -= j;
 		py[2] -= j;
--- old/usr/src/lib/libm/common/LD/isnanl.c	2019-06-06 20:38:16.832385015 +0000
+++ new/usr/src/lib/libm/common/LD/isnanl.c	2019-06-06 20:38:16.850055340 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,20 +34,24 @@
 
 #if defined(__sparc)
 int
-isnanl(long double x) {
-	int *px = (int *) &x;
-	return ((px[0] & ~0x80000000) >= 0x7fff0000 &&
-		((px[0] & ~0xffff0000) | px[1] | px[2] | px[3]) != 0);
+isnanl(long double x)
+{
+	int *px = (int *)&x;
+
+	return ((px[0] & ~0x80000000) >= 0x7fff0000 && ((px[0] & ~0xffff0000) |
+	    px[1] | px[2] | px[3]) != 0);
 }
 #elif defined(__x86)
 int
-isnanl(long double x) {
-	int *px = (int *) &x, t = px[2] & 0x7fff;
+isnanl(long double x)
+{
+	int *px = (int *)&x, t = px[2] & 0x7fff;
+
 #if defined(HANDLE_UNSUPPORTED)
-	return ((t == 0x7fff && ((px[1] & ~0x80000000) | px[0]) != 0) ||
-		(t != 0 && (px[1] & 0x80000000) == 0));
+	return ((t == 0x7fff && ((px[1] & ~0x80000000) | px[0]) != 0) || (t !=
+	    0 && (px[1] & 0x80000000) == 0));
 #else
 	return (t == 0x7fff && ((px[1] & ~0x80000000) | px[0]) != 0);
 #endif
 }
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
--- old/usr/src/lib/libm/common/LD/j0l.c	2019-06-06 20:38:17.356624657 +0000
+++ new/usr/src/lib/libm/common/LD/j0l.c	2019-06-06 20:38:17.377637857 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -48,115 +49,133 @@
 #include <sunmath.h>
 #endif
 
-#define	GENERIC long double
-static GENERIC
-zero    = 0.0L,
-small	= 1.0e-9L,
-tiny	= 1.0e-38L,
-one	= 1.0L,
-five	= 5.0L,
-eight   = 8.0L,
-invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
-tpi	= 0.636619772367581343075535053490057448L;
+#define	GENERIC	long double
+
+static GENERIC zero = 0.0L,
+	small = 1.0e-9L,
+	tiny = 1.0e-38L,
+	one = 1.0L,
+	five = 5.0L,
+	eight = 8.0L,
+	invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
+	tpi = 0.636619772367581343075535053490057448L;
 
 static GENERIC pzero(), qzero();
+
 static GENERIC r0[7] = {
-  -2.499999999999999999999999999999998934492e-0001L,
-   1.272657927360049786327618451133763714880e-0002L,
-  -2.694499763712963276900636693400659600898e-0004L,
-   2.724877475058977576903234070919616447883e-0006L,
-  -1.432617103214330236967477495393076320281e-0008L,
-   3.823248804080079168706683540513792224471e-0011L,
-  -4.183174277567983647337568504286313665065e-0014L,
+	-2.499999999999999999999999999999998934492e-0001L,
+	1.272657927360049786327618451133763714880e-0002L,
+	-2.694499763712963276900636693400659600898e-0004L,
+	2.724877475058977576903234070919616447883e-0006L,
+	-1.432617103214330236967477495393076320281e-0008L,
+	3.823248804080079168706683540513792224471e-0011L,
+	-4.183174277567983647337568504286313665065e-0014L,
 };
+
 static GENERIC s0[7] = {
-   1.0e0L,
-   1.159368290559800854689526195462884666395e-0002L,
-   6.629397597394973383009743876169946772559e-0005L,
-   2.426779981394054406305431142501735094340e-0007L,
-   6.097663491248511069094400469635449749883e-0010L,
-   1.017019133340929220238747413216052224036e-0012L,
-   9.012593179306197579518374581969371278481e-0016L,
+	1.0e0L,
+	1.159368290559800854689526195462884666395e-0002L,
+	6.629397597394973383009743876169946772559e-0005L,
+	2.426779981394054406305431142501735094340e-0007L,
+	6.097663491248511069094400469635449749883e-0010L,
+	1.017019133340929220238747413216052224036e-0012L,
+	9.012593179306197579518374581969371278481e-0016L,
 };
 
 GENERIC
-j0l(x) GENERIC x; {
+j0l(GENERIC x)
+{
 	GENERIC z, s, c, ss, cc, r, u, v;
 	int i;
 
 	if (isnanl(x))
-		return (x+x);
+		return (x + x);
+
 	x = fabsl(x);
+
 	if (x > 1.28L) {
 		if (!finitel(x))
 			return (zero);
+
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
-	 * where x0 = x-pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (cos(x) + sin(x))
-	 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (sin(x) - cos(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
+		 * where x0 = x-pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (cos(x) + sin(x))
+		 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (sin(x) - cos(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 1.0e2450L) {	/* x+x may overflow */
-			ss = s-c;
-			cc = s+c;
+			ss = s - c;
+			cc = s + c;
 		} else if (signbitl(s) != signbitl(c)) {
 			ss = s - c;
-			cc = -cosl(x+x)/ss;
+			cc = -cosl(x + x) / ss;
 		} else {
 			cc = s + c;
-			ss = -cosl(x+x)/cc;
+			ss = -cosl(x + x) / cc;
 		}
-	/*
-	 * j0(x) = 1/sqrt(pi) * (P(0,x)*cc - Q(0,x)*ss) / sqrt(x)
-	 * y0(x) = 1/sqrt(pi) * (P(0,x)*ss + Q(0,x)*cc) / sqrt(x)
-	 */
+
+		/*
+		 * j0(x) = 1/sqrt(pi) * (P(0,x)*cc - Q(0,x)*ss) / sqrt(x)
+		 * y0(x) = 1/sqrt(pi) * (P(0,x)*ss + Q(0,x)*cc) / sqrt(x)
+		 */
 		if (x > 1.0e120L)
-			return (invsqrtpi*cc)/sqrtl(x);
-		u = pzero(x); v = qzero(x);
-		return (invsqrtpi*(u*cc-v*ss)/sqrtl(x));
+			return ((invsqrtpi * cc) / sqrtl(x));
+
+		u = pzero(x);
+		v = qzero(x);
+		return (invsqrtpi * (u * cc - v * ss) / sqrtl(x));
 	}
+
 	if (x <= small) {
-	    if (x <= tiny)
-			return (one-x);
-	    else
-			return (one-x*x*0.25L);
+		if (x <= tiny)
+			return (one - x);
+		else
+			return (one - x * x * 0.25L);
 	}
-	z = x*x;
-	r = r0[6]; s = s0[6];
+
+	z = x * x;
+	r = r0[6];
+	s = s0[6];
+
 	for (i = 5; i >= 0; i--) {
-	    r = r*z + r0[i];
-	    s = s*z + s0[i];
+		r = r * z + r0[i];
+		s = s * z + s0[i];
 	}
-	return (one+z*(r/s));
+
+	return (one + z * (r / s));
 }
 
 static GENERIC u0[8] = {
-  -7.380429510868722527434392794848301631220e-0002L,
-   1.766855559625940791857536949301981816513e-0001L,
-  -1.386470722701047923235553251240162839408e-0002L,
-   3.520149242724811578636970811631224862615e-0004L,
-  -3.978599663243790049853642275624951870025e-0006L,
-   2.228801153263957224547222556806915479763e-0008L,
-  -6.121246764298785018658597179498837316177e-0011L,
-   6.677103629722678833475965810525587396596e-0014L,
+	-7.380429510868722527434392794848301631220e-0002L,
+	1.766855559625940791857536949301981816513e-0001L,
+	-1.386470722701047923235553251240162839408e-0002L,
+	3.520149242724811578636970811631224862615e-0004L,
+	-3.978599663243790049853642275624951870025e-0006L,
+	2.228801153263957224547222556806915479763e-0008L,
+	-6.121246764298785018658597179498837316177e-0011L,
+	6.677103629722678833475965810525587396596e-0014L,
 };
+
 static GENERIC v0[8] = {
-   1.0e0L,
-   1.247164416539111311571676766127767127970e-0002L,
-   7.829144749639791500052900281489367443576e-0005L,
-   3.247126540422245330511218321013360336606e-0007L,
-   9.750516724789499678567062572549568447869e-0010L,
-   2.156713223173591212250543390258458098776e-0012L,
-   3.322169561597890004231482431236452752624e-0015L,
-   2.821213295314000924252226486305726805093e-0018L,
+	1.0e0L,
+	1.247164416539111311571676766127767127970e-0002L,
+	7.829144749639791500052900281489367443576e-0005L,
+	3.247126540422245330511218321013360336606e-0007L,
+	9.750516724789499678567062572549568447869e-0010L,
+	2.156713223173591212250543390258458098776e-0012L,
+	3.322169561597890004231482431236452752624e-0015L,
+	2.821213295314000924252226486305726805093e-0018L,
 };
 
 GENERIC
@@ -167,584 +186,660 @@
 	int i;
 
 	if (isnanl(x))
-		return (x+x);
+		return (x + x);
+
 	if (x <= zero) {
 		if (x == zero)
-		    d = -one/(x-x);
+			d = -one / (x - x);
 		else
-		    d = zero/(x-x);
+			d = zero / (x - x);
 	}
+
 	if (x > 1.28L) {
 		if (!finitel(x))
 			return (zero);
+
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
-	 * where x0 = x-pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (cos(x) + sin(x))
-	 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (sin(x) - cos(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
+		 * where x0 = x-pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (cos(x) + sin(x))
+		 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (sin(x) - cos(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 1.0e2450L) {	/* x+x may overflow */
-			ss = s-c;
-			cc = s+c;
+			ss = s - c;
+			cc = s + c;
 		} else if (signbitl(s) != signbitl(c)) {
 			ss = s - c;
-			cc = -cosl(x+x)/ss;
+			cc = -cosl(x + x) / ss;
 		} else {
 			cc = s + c;
-			ss = -cosl(x+x)/cc;
+			ss = -cosl(x + x) / cc;
 		}
-	/*
-	 * j0(x) = 1/sqrt(pi*x) * (P(0,x)*cc - Q(0,x)*ss)
-	 * y0(x) = 1/sqrt(pi*x) * (P(0,x)*ss + Q(0,x)*cc)
-	 */
+
+		/*
+		 * j0(x) = 1/sqrt(pi*x) * (P(0,x)*cc - Q(0,x)*ss)
+		 * y0(x) = 1/sqrt(pi*x) * (P(0,x)*ss + Q(0,x)*cc)
+		 */
 		if (x > 1.0e120L)
-			return (invsqrtpi*ss)/sqrtl(x);
-		return (invsqrtpi*(pzero(x)*ss+qzero(x)*cc)/sqrtl(x));
+			return ((invsqrtpi * ss) / sqrtl(x));
 
+		return (invsqrtpi * (pzero(x) * ss + qzero(x) * cc) / sqrtl(x));
 	}
-	if (x <= tiny) {
-	    return (u0[0] + tpi*logl(x));
-	}
-	z = x*x;
-	u = u0[7]; v = v0[7];
+
+	if (x <= tiny)
+		return (u0[0] + tpi * logl(x));
+
+	z = x * x;
+	u = u0[7];
+	v = v0[7];
+
 	for (i = 6; i >= 0; i--) {
-	    u = u*z + u0[i];
-	    v = v*z + v0[i];
+		u = u * z + u0[i];
+		v = v * z + v0[i];
 	}
-	return (u/v + tpi*(j0l(x)*logl(x)));
+
+	return (u / v + tpi * (j0l(x) * logl(x)));
 }
 
-static GENERIC pr0[12] = {	/* [16 -- inf] */
-   9.999999999999999999999999999999999997515e-0001L,
-   1.065981615377273376425365823967550598358e+0003L,
-   4.390991200927588978306374718984240719130e+0005L,
-   9.072086218607986711847069407339321363103e+0007L,
-   1.022552886177375367408408501046461671528e+0010L,
-   6.420766912243658241570635854089597269031e+0011L,
-   2.206451725126933913591080211081242266908e+0013L,
-   3.928369596816895077363705478743346298368e+0014L,
-   3.258159928874124597286701119721482876596e+0015L,
-   1.025715808134188978860679130140685101348e+0016L,
-   7.537170874795721255796001687024031280685e+0015L,
-  -1.579413901450157332307745586004207687796e+0014L,
+static GENERIC pr0[12] = {		/* [16 -- inf] */
+	9.999999999999999999999999999999999997515e-0001L,
+	1.065981615377273376425365823967550598358e+0003L,
+	4.390991200927588978306374718984240719130e+0005L,
+	9.072086218607986711847069407339321363103e+0007L,
+	1.022552886177375367408408501046461671528e+0010L,
+	6.420766912243658241570635854089597269031e+0011L,
+	2.206451725126933913591080211081242266908e+0013L,
+	3.928369596816895077363705478743346298368e+0014L,
+	3.258159928874124597286701119721482876596e+0015L,
+	1.025715808134188978860679130140685101348e+0016L,
+	7.537170874795721255796001687024031280685e+0015L,
+	-1.579413901450157332307745586004207687796e+0014L,
 };
+
 static GENERIC ps0[11] = {
-   1.0e0L,
-   1.066051927877273376425365823967550512687e+0003L,
-   4.391739647168381592399173804329266353038e+0005L,
-   9.075162261801343671805658294123888867884e+0007L,
-   1.023186118519904751819581912075985995058e+0010L,
-   6.427861860414223746340515376512730275061e+0011L,
-   2.210861503237823589735481303627993406235e+0013L,
-   3.943247335784292905915956840901818177989e+0014L,
-   3.283720976777545142150200110647270004481e+0015L,
-   1.045346918812754048903645641538728986759e+0016L,
-   8.043455468065618900750599584291193680463e+0015L,
-};
-static GENERIC pr1[12] = {	/* [8 -- 16] */
-   9.999999999999999999999784422701108683618e-0001L,
-   6.796098532948334207755488692777907062894e+0002L,
-   1.840036112605722168824530758797169836042e+0005L,
-   2.598490483191916637264894340635847598122e+0007L,
-   2.105774863242707025525730249472054578523e+0009L,
-   1.015822044230542426666314997796944979959e+0011L,
-   2.931557457008110436764077699944189071875e+0012L,
-   4.962885121125457633655259224179322808824e+0013L,
-   4.705424055148223269155430598563351566279e+0014L,
-   2.294439854910747229152056080910427001110e+0015L,
-   4.905531843137486691500950019322475458629e+0015L,
-   3.187543169710339218793442542845735994565e+0015L,
+	1.0e0L,
+	1.066051927877273376425365823967550512687e+0003L,
+	4.391739647168381592399173804329266353038e+0005L,
+	9.075162261801343671805658294123888867884e+0007L,
+	1.023186118519904751819581912075985995058e+0010L,
+	6.427861860414223746340515376512730275061e+0011L,
+	2.210861503237823589735481303627993406235e+0013L,
+	3.943247335784292905915956840901818177989e+0014L,
+	3.283720976777545142150200110647270004481e+0015L,
+	1.045346918812754048903645641538728986759e+0016L,
+	8.043455468065618900750599584291193680463e+0015L,
+};
+
+static GENERIC pr1[12] = {		/* [8 -- 16] */
+	9.999999999999999999999784422701108683618e-0001L,
+	6.796098532948334207755488692777907062894e+0002L,
+	1.840036112605722168824530758797169836042e+0005L,
+	2.598490483191916637264894340635847598122e+0007L,
+	2.105774863242707025525730249472054578523e+0009L,
+	1.015822044230542426666314997796944979959e+0011L,
+	2.931557457008110436764077699944189071875e+0012L,
+	4.962885121125457633655259224179322808824e+0013L,
+	4.705424055148223269155430598563351566279e+0014L,
+	2.294439854910747229152056080910427001110e+0015L,
+	4.905531843137486691500950019322475458629e+0015L,
+	3.187543169710339218793442542845735994565e+0015L,
 };
+
 static GENERIC ps1[14] = {
-   1.0e0L,
-   6.796801657948334207754571576066758180288e+0002L,
-   1.840512891201300567325421059826676366447e+0005L,
-   2.599777028312918975306252167127695075221e+0007L,
-   2.107582572771047636846811284634244892537e+0009L,
-   1.017275794694156108975782763889979940348e+0011L,
-   2.938487645192463845428059755454762316011e+0012L,
-   4.982512164735557054521042916182317924466e+0013L,
-   4.737639900153703274792677468264564361437e+0014L,
-   2.323398719123742743524249528275097100646e+0015L,
-   5.033419107069210577868909797896984419391e+0015L,
-   3.409036105931068609601317076759804716059e+0015L,
-   7.505655364352679737585745147753521662166e+0013L,
-  -9.976837153983688250780198248297109118313e+0012L,
-};
-static GENERIC pr2[12] = {	/* [5 -- 8 ] */
-   9.999999999999999937857236789277366320220e-0001L,
-   3.692848765268649571651602420376358849214e+0002L,
-   5.373022067535476576926715900057760985410e+0004L,
-   4.038738891191314969971504035057219430725e+0006L,
-   1.728285706306940523397385566659762646999e+0008L,
-   4.375400819645889911158688737206054788534e+0009L,
-   6.598950418204912408375591217782088567076e+0010L,
-   5.827182039183238492480275401520072793783e+0011L,
-   2.884222642913492390887572414999490975844e+0012L,
-   7.373278873797767721932837830628688632775e+0012L,
-   8.338295457568973761205077964397969230489e+0012L,
-   2.911383183467288345772308817209806922143e+0012L,
+	1.0e0L,
+	6.796801657948334207754571576066758180288e+0002L,
+	1.840512891201300567325421059826676366447e+0005L,
+	2.599777028312918975306252167127695075221e+0007L,
+	2.107582572771047636846811284634244892537e+0009L,
+	1.017275794694156108975782763889979940348e+0011L,
+	2.938487645192463845428059755454762316011e+0012L,
+	4.982512164735557054521042916182317924466e+0013L,
+	4.737639900153703274792677468264564361437e+0014L,
+	2.323398719123742743524249528275097100646e+0015L,
+	5.033419107069210577868909797896984419391e+0015L,
+	3.409036105931068609601317076759804716059e+0015L,
+	7.505655364352679737585745147753521662166e+0013L,
+	-9.976837153983688250780198248297109118313e+0012L,
+};
+
+static GENERIC pr2[12] = {		/* [5 -- 8 ] */
+	9.999999999999999937857236789277366320220e-0001L,
+	3.692848765268649571651602420376358849214e+0002L,
+	5.373022067535476576926715900057760985410e+0004L,
+	4.038738891191314969971504035057219430725e+0006L,
+	1.728285706306940523397385566659762646999e+0008L,
+	4.375400819645889911158688737206054788534e+0009L,
+	6.598950418204912408375591217782088567076e+0010L,
+	5.827182039183238492480275401520072793783e+0011L,
+	2.884222642913492390887572414999490975844e+0012L,
+	7.373278873797767721932837830628688632775e+0012L,
+	8.338295457568973761205077964397969230489e+0012L,
+	2.911383183467288345772308817209806922143e+0012L,
 };
+
 static GENERIC ps2[14] = {
-   1.0e0L,
-   3.693551890268649477288896267171993213102e+0002L,
-   5.375607880998361502474715133828068514297e+0004L,
-   4.042477764024108249744998862572786367328e+0006L,
-   1.731069838737016956685839588670132939513e+0008L,
-   4.387147674049898778738226585935491417728e+0009L,
-   6.628058659620653765349556940567715258165e+0010L,
-   5.869659904164177740471685856367322160664e+0011L,
-   2.919839445622817017058977559638969436383e+0012L,
-   7.535314897696671402628203718612309253907e+0012L,
-   8.696355561452933775773309859748610658935e+0012L,
-   3.216155103141537221173601557697083216257e+0012L,
-   4.756857081068942248246880159213789086363e+0010L,
-  -3.496356619666608032231074866481472824067e+0009L,
-};
-static GENERIC pr3[13] = {	/* [3.5 -- 5 ] */
-   9.999999999999916693107285612398196588247e-0001L,
-   2.263975921282917721194425320484974336945e+0002L,
-   1.994358386744245848889492762781484199966e+0004L,
-   8.980067458430542243559962493831661323168e+0005L,
-   2.282213787521372663705567756420087553508e+0007L,
-   3.409784374889063618250288699908375135923e+0008L,
-   3.024380857401448589254343517589811711108e+0009L,
-   1.571110368046740246895071721443082286379e+0010L,
-   4.603187020243604632153685300463160593768e+0010L,
-   7.087196453409712719449549280664058793403e+0010L,
-   5.046196021776346356803687409644239065041e+0010L,
-   1.287758439080165765709154276618854799932e+0010L,
-   5.900679773415023433787846658096813590784e+0008L,
+	1.0e0L,
+	3.693551890268649477288896267171993213102e+0002L,
+	5.375607880998361502474715133828068514297e+0004L,
+	4.042477764024108249744998862572786367328e+0006L,
+	1.731069838737016956685839588670132939513e+0008L,
+	4.387147674049898778738226585935491417728e+0009L,
+	6.628058659620653765349556940567715258165e+0010L,
+	5.869659904164177740471685856367322160664e+0011L,
+	2.919839445622817017058977559638969436383e+0012L,
+	7.535314897696671402628203718612309253907e+0012L,
+	8.696355561452933775773309859748610658935e+0012L,
+	3.216155103141537221173601557697083216257e+0012L,
+	4.756857081068942248246880159213789086363e+0010L,
+	-3.496356619666608032231074866481472824067e+0009L,
+};
+
+static GENERIC pr3[13] = {		/* [3.5 -- 5 ] */
+	9.999999999999916693107285612398196588247e-0001L,
+	2.263975921282917721194425320484974336945e+0002L,
+	1.994358386744245848889492762781484199966e+0004L,
+	8.980067458430542243559962493831661323168e+0005L,
+	2.282213787521372663705567756420087553508e+0007L,
+	3.409784374889063618250288699908375135923e+0008L,
+	3.024380857401448589254343517589811711108e+0009L,
+	1.571110368046740246895071721443082286379e+0010L,
+	4.603187020243604632153685300463160593768e+0010L,
+	7.087196453409712719449549280664058793403e+0010L,
+	5.046196021776346356803687409644239065041e+0010L,
+	1.287758439080165765709154276618854799932e+0010L,
+	5.900679773415023433787846658096813590784e+0008L,
 };
+
 static GENERIC ps3[13] = {
-   1.0e0L,
-   2.264679046282855061328604619231774747116e+0002L,
-   1.995939523988944553755653255389812103448e+0004L,
-   8.993853144706348727038389967490183236820e+0005L,
-   2.288326099634588843906989983704795468773e+0007L,
-   3.424967100255240885169240956804790118282e+0008L,
-   3.046311797972463991368023759640028910016e+0009L,
-   1.589614961932826812790222479700797224003e+0010L,
-   4.692406624527744816497089139325073939927e+0010L,
-   7.320486495902008912866462849073108323948e+0010L,
-   5.345945972828978289935309597742981360994e+0010L,
-   1.444033091910423754121309915092247171008e+0010L,
-   7.987714685115314668378957273824383610525e+0008L,
-};
-static GENERIC pr4[13] = {	/* [2.5, 3.5] */
-   9.999999999986736677961118722747757712260e-0001L,
-   1.453824980703800559037873123568378845663e+0002L,
-   8.097327216430682288267610447006508661032e+0003L,
-   2.273847252038264370231169686380192662135e+0005L,
-   3.561056728046211111354759998976985449622e+0006L,
-   3.244933588800096378434627029369680378599e+0007L,
-   1.740112392860717950376210038908476792588e+0008L,
-   5.426170187455893285197878563881579269524e+0008L,
-   9.490107486454362321004377336020526281371e+0008L,
-   8.688872439428470049801714121070005313806e+0008L,
-   3.673315853166437222811910656900123215515e+0008L,
-   5.577770470359303305164877446339693270239e+0007L,
-   1.540438642031689641308197880181291865714e+0006L,
-};
-static GENERIC ps4[13] = {	/* [2.5, 3.5] */
-   1.0e0L,
-   1.454528105698159439773035951959131799816e+0002L,
-   8.107442215200392397172179900434987859618e+0003L,
-   2.279390393778242887574177096606328994140e+0005L,
-   3.576251625592252008424781111770934135844e+0006L,
-   3.267909499056932631405942058670933813863e+0007L,
-   1.760021515330805537499778238099704648805e+0008L,
-   5.525553787667353981242060222587465726729e+0008L,
-   9.769870295912820457889384082671269328511e+0008L,
-   9.110582071004774279226905629624018008454e+0008L,
-   3.981857678621955599371967680343918454345e+0008L,
-   6.482404686230769399073192961667697036706e+0007L,
-   2.210046943095878402443535460329391782298e+0006L,
-};
-static GENERIC pr5[13] = {	/* [1.777..., 2.5] */
-   9.999999999114986107951817871144655880699e-0001L,
-   9.252583736048588342568344570315435947614e+0001L,
-   3.218726757856078715214631502407386264637e+0003L,
-   5.554009964621111656479588505862577040831e+0004L,
-   5.269993115643664338253196944523510290175e+0005L,
-   2.874613773778430691192912190618220544575e+0006L,
-   9.133538151103658353874146919613442436035e+0006L,
-   1.673067041410338922825193013077354249193e+0007L,
-   1.706913873848398011744790289200151840498e+0007L,
-   9.067766583853288534551600235576747618679e+0006L,
-   2.216746733457884568532695355036338655872e+0006L,
-   1.945753880802872541235703812722344514405e+0005L,
-   3.132374412921948071539195638885330951749e+0003L,
-};
-static GENERIC ps5[13] = {	/* [1.777..., 2.5] */
-   1.0e0L,
-   9.259614983862181118883831670990340052982e+0001L,
-   3.225125275462903384842124075132609290304e+0003L,
-   5.575705362829101545292760055941855246492e+0004L,
-   5.306049863037087855496170121958448492522e+0005L,
-   2.907060758873509564309729903109018597215e+0006L,
-   9.298059206584995898298257827131208539289e+0006L,
-   1.720391071006963176836108026556547062980e+0007L,
-   1.782614812922865190479394509487941920612e+0007L,
-   9.708016389605273153536452032839879950155e+0006L,
-   2.476495084688170096480215640962175140027e+0006L,
-   2.363200660365585759668077790194604917187e+0005L,
-   4.803239569848196077121203575704356936731e+0003L,
-};
-static GENERIC pr6[13] = {	/* [1.28, 1.777...] */
-   9.999999969777095495998606925524322559556e-0001L,
-   5.825486719466194430503283824096872219216e+0001L,
-   1.248155491637757281915184824965379905380e+0003L,
-   1.302093199842358609321338417071710477615e+0004L,
-   7.353835804186292782840961999810543016039e+0004L,
-   2.356471661113686180549195092555751341757e+0005L,
-   4.350553267429009581632987060942780847101e+0005L,
-   4.588762661876600638719159826652389418235e+0005L,
-   2.675796398548523436544221045225290128611e+0005L,
-   8.077649557108971388298292919988449940464e+0004L,
-   1.117640459221306873519068741664054573776e+0004L,
-   5.544400072396814695175787511557757885585e+0002L,
-   5.072550541191480498431289089905822910718e+0000L,
-};
-static GENERIC ps6[13] = {	/* [1.28, 1.777...] */
-   1.0e0L,
-   5.832517925357165050639075848183613063291e+0001L,
-   1.252144364743592128171256104364976466898e+0003L,
-   1.310300234342216813579118022415585740772e+0004L,
-   7.434667697093812197817292154032863632923e+0004L,
-   2.398706595587719165726469002404004614711e+0005L,
-   4.472737517625103157004869372427480602511e+0005L,
-   4.786313523337761975294171429067037723611e+0005L,
-   2.851161872872731228472536061865365370192e+0005L,
-   8.891648269899148412331918021801385815586e+0004L,
-   1.297097489535351517572978123584751042287e+0004L,
-   7.096761640545975756202184143400469812618e+0002L,
-   8.378049338590233325977702401733340820351e+0000L,
+	1.0e0L,
+	2.264679046282855061328604619231774747116e+0002L,
+	1.995939523988944553755653255389812103448e+0004L,
+	8.993853144706348727038389967490183236820e+0005L,
+	2.288326099634588843906989983704795468773e+0007L,
+	3.424967100255240885169240956804790118282e+0008L,
+	3.046311797972463991368023759640028910016e+0009L,
+	1.589614961932826812790222479700797224003e+0010L,
+	4.692406624527744816497089139325073939927e+0010L,
+	7.320486495902008912866462849073108323948e+0010L,
+	5.345945972828978289935309597742981360994e+0010L,
+	1.444033091910423754121309915092247171008e+0010L,
+	7.987714685115314668378957273824383610525e+0008L,
+};
+
+static GENERIC pr4[13] = {		/* [2.5, 3.5] */
+	9.999999999986736677961118722747757712260e-0001L,
+	1.453824980703800559037873123568378845663e+0002L,
+	8.097327216430682288267610447006508661032e+0003L,
+	2.273847252038264370231169686380192662135e+0005L,
+	3.561056728046211111354759998976985449622e+0006L,
+	3.244933588800096378434627029369680378599e+0007L,
+	1.740112392860717950376210038908476792588e+0008L,
+	5.426170187455893285197878563881579269524e+0008L,
+	9.490107486454362321004377336020526281371e+0008L,
+	8.688872439428470049801714121070005313806e+0008L,
+	3.673315853166437222811910656900123215515e+0008L,
+	5.577770470359303305164877446339693270239e+0007L,
+	1.540438642031689641308197880181291865714e+0006L,
+};
+
+static GENERIC ps4[13] = {		/* [2.5, 3.5] */
+	1.0e0L,
+	1.454528105698159439773035951959131799816e+0002L,
+	8.107442215200392397172179900434987859618e+0003L,
+	2.279390393778242887574177096606328994140e+0005L,
+	3.576251625592252008424781111770934135844e+0006L,
+	3.267909499056932631405942058670933813863e+0007L,
+	1.760021515330805537499778238099704648805e+0008L,
+	5.525553787667353981242060222587465726729e+0008L,
+	9.769870295912820457889384082671269328511e+0008L,
+	9.110582071004774279226905629624018008454e+0008L,
+	3.981857678621955599371967680343918454345e+0008L,
+	6.482404686230769399073192961667697036706e+0007L,
+	2.210046943095878402443535460329391782298e+0006L,
+};
+
+static GENERIC pr5[13] = {		/* [1.777..., 2.5] */
+	9.999999999114986107951817871144655880699e-0001L,
+	9.252583736048588342568344570315435947614e+0001L,
+	3.218726757856078715214631502407386264637e+0003L,
+	5.554009964621111656479588505862577040831e+0004L,
+	5.269993115643664338253196944523510290175e+0005L,
+	2.874613773778430691192912190618220544575e+0006L,
+	9.133538151103658353874146919613442436035e+0006L,
+	1.673067041410338922825193013077354249193e+0007L,
+	1.706913873848398011744790289200151840498e+0007L,
+	9.067766583853288534551600235576747618679e+0006L,
+	2.216746733457884568532695355036338655872e+0006L,
+	1.945753880802872541235703812722344514405e+0005L,
+	3.132374412921948071539195638885330951749e+0003L,
+};
+
+static GENERIC ps5[13] = {		/* [1.777..., 2.5] */
+	1.0e0L,
+	9.259614983862181118883831670990340052982e+0001L,
+	3.225125275462903384842124075132609290304e+0003L,
+	5.575705362829101545292760055941855246492e+0004L,
+	5.306049863037087855496170121958448492522e+0005L,
+	2.907060758873509564309729903109018597215e+0006L,
+	9.298059206584995898298257827131208539289e+0006L,
+	1.720391071006963176836108026556547062980e+0007L,
+	1.782614812922865190479394509487941920612e+0007L,
+	9.708016389605273153536452032839879950155e+0006L,
+	2.476495084688170096480215640962175140027e+0006L,
+	2.363200660365585759668077790194604917187e+0005L,
+	4.803239569848196077121203575704356936731e+0003L,
+};
+
+static GENERIC pr6[13] = {		/* [1.28, 1.777...] */
+	9.999999969777095495998606925524322559556e-0001L,
+	5.825486719466194430503283824096872219216e+0001L,
+	1.248155491637757281915184824965379905380e+0003L,
+	1.302093199842358609321338417071710477615e+0004L,
+	7.353835804186292782840961999810543016039e+0004L,
+	2.356471661113686180549195092555751341757e+0005L,
+	4.350553267429009581632987060942780847101e+0005L,
+	4.588762661876600638719159826652389418235e+0005L,
+	2.675796398548523436544221045225290128611e+0005L,
+	8.077649557108971388298292919988449940464e+0004L,
+	1.117640459221306873519068741664054573776e+0004L,
+	5.544400072396814695175787511557757885585e+0002L,
+	5.072550541191480498431289089905822910718e+0000L,
+};
+
+static GENERIC ps6[13] = {		/* [1.28, 1.777...] */
+	1.0e0L,
+	5.832517925357165050639075848183613063291e+0001L,
+	1.252144364743592128171256104364976466898e+0003L,
+	1.310300234342216813579118022415585740772e+0004L,
+	7.434667697093812197817292154032863632923e+0004L,
+	2.398706595587719165726469002404004614711e+0005L,
+	4.472737517625103157004869372427480602511e+0005L,
+	4.786313523337761975294171429067037723611e+0005L,
+	2.851161872872731228472536061865365370192e+0005L,
+	8.891648269899148412331918021801385815586e+0004L,
+	1.297097489535351517572978123584751042287e+0004L,
+	7.096761640545975756202184143400469812618e+0002L,
+	8.378049338590233325977702401733340820351e+0000L,
 };
+
 static GENERIC sixteen = 16.0L;
-static GENERIC huge    = 1.0e30L;
+static GENERIC huge = 1.0e30L;
 
-static GENERIC pzero(x)
-GENERIC x;
+static GENERIC
+pzero(x)
+    GENERIC x;
 {
 	GENERIC s, r, t, z;
 	int i;
+
 	if (x > huge)
 		return (one);
-	t = one/x; z = t*t;
+
+	t = one / x;
+	z = t * t;
+
 	if (x > sixteen) {
-	    r = z*pr0[11]+pr0[10]; s = ps0[10];
-	    for (i = 9; i >= 0; i--) {
-		r = z*r + pr0[i];
-		s = z*s + ps0[i];
-	    }
+		r = z * pr0[11] + pr0[10];
+		s = ps0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + pr0[i];
+			s = z * s + ps0[i];
+		}
 	} else if (x > eight) {
-	    r = pr1[11]; s = ps1[11]+z*(ps1[12]+z*ps1[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + pr1[i];
-		s = z*s + ps1[i];
-	    }
-	} else if (x > five) { 	/* x > 5.0 */
-	    r = pr2[11]; s = ps2[11]+z*(ps2[12]+z*ps2[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + pr2[i];
-		s = z*s + ps2[i];
-	    }
+		r = pr1[11];
+		s = ps1[11] + z * (ps1[12] + z * ps1[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr1[i];
+			s = z * s + ps1[i];
+		}
+	} else if (x > five) {		/* x > 5.0 */
+		r = pr2[11];
+		s = ps2[11] + z * (ps2[12] + z * ps2[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr2[i];
+			s = z * s + ps2[i];
+		}
 	} else if (x > 3.5L) {
-	    r = pr3[12]; s = ps3[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + pr3[i];
-		s = z*s + ps3[i];
-	    }
+		r = pr3[12];
+		s = ps3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr3[i];
+			s = z * s + ps3[i];
+		}
 	} else if (x > 2.5L) {
-	    r = pr4[12]; s = ps4[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + pr4[i];
-		s = z*s + ps4[i];
-	    }
-	} else if (x > (1.0L/0.5625L)) {
-	    r = pr5[12]; s = ps5[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + pr5[i];
-		s = z*s + ps5[i];
-	    }
-	} else {	/* assume x > 1.28 */
-	    r = pr6[12]; s = ps6[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + pr6[i];
-		s = z*s + ps6[i];
-	    }
-	}
-	return (r/s);
-}
+		r = pr4[12];
+		s = ps4[12];
 
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr4[i];
+			s = z * s + ps4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = pr5[12];
+		s = ps5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr5[i];
+			s = z * s + ps5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = pr6[12];
+		s = ps6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr6[i];
+			s = z * s + ps6[i];
+		}
+	}
 
-static GENERIC qr0[12] = {	/* [16, inf] */
-  -1.249999999999999999999999999999999972972e-0001L,
-  -1.425179595545670577414395762503991596897e+0002L,
-  -6.312499645625970845534460257936222407219e+0004L,
-  -1.411374326457208384315121243698814446848e+0007L,
-  -1.735034212758873581410984757860787252842e+0009L,
-  -1.199777647512789489421826342485055280680e+0011L,
-  -4.596025334081655714499860409699100373644e+0012L,
-  -9.262525628201284107792924477031653399187e+0013L,
-  -8.858394728685039245344398842180662867639e+0014L,
-  -3.267527953687534887623740622709505972113e+0015L,
-  -2.664222971186311967587129347029450062019e+0015L,
-   3.442464060723987869585180095344504100204e+0014L,
+	return (r / s);
+}
+static GENERIC qr0[12] = {		/* [16, inf] */
+	-1.249999999999999999999999999999999972972e-0001L,
+	-1.425179595545670577414395762503991596897e+0002L,
+	-6.312499645625970845534460257936222407219e+0004L,
+	-1.411374326457208384315121243698814446848e+0007L,
+	-1.735034212758873581410984757860787252842e+0009L,
+	-1.199777647512789489421826342485055280680e+0011L,
+	-4.596025334081655714499860409699100373644e+0012L,
+	-9.262525628201284107792924477031653399187e+0013L,
+	-8.858394728685039245344398842180662867639e+0014L,
+	-3.267527953687534887623740622709505972113e+0015L,
+	-2.664222971186311967587129347029450062019e+0015L,
+	3.442464060723987869585180095344504100204e+0014L,
 };
+
 static GENERIC qs0[11] = {
-   1.0e0L,
-   1.140729613936536461931516610003185687881e+0003L,
-   5.056665510442299351009198186490085803580e+0005L,
-   1.132041763825642787943941650522718199115e+0008L,
-   1.394570111872581606392620678214246479767e+0010L,
-   9.677945218152264789534431079563744378421e+0011L,
-   3.731140327851536828225143058896348502096e+0013L,
-   7.612785951064869291722846681020881676410e+0014L,
-   7.476077016406764891730191004811863975940e+0015L,
-   2.951246482613592035421503427100393831709e+0016L,
-   3.108361803691811711136854587074302034901e+0016L,
-};
-static GENERIC qr1[12] = {	/* [8, 16 ] */
-  -1.249999999999999999997949010383433818157e-0001L,
-  -9.051215166393822640636752244895124126934e+0001L,
-  -2.620782703428148837671179031904208303947e+0004L,
-  -3.975571261553504457766177974508785790884e+0006L,
-  -3.479029330759311306270072218074074994090e+0008L,
-  -1.823955008124268573036216746186239829089e+0010L,
-  -5.765932697111801375765156029221568664435e+0011L,
-  -1.079843680798742592954002192417934779114e+0013L,
-  -1.146893630504592739082205764611581332897e+0014L,
-  -6.367016059683898464936104447282880704182e+0014L,
-  -1.583109041961213490464459111903484209098e+0015L,
-  -1.230149555764242473103128650135795639412e+0015L,
+	1.0e0L,
+	1.140729613936536461931516610003185687881e+0003L,
+	5.056665510442299351009198186490085803580e+0005L,
+	1.132041763825642787943941650522718199115e+0008L,
+	1.394570111872581606392620678214246479767e+0010L,
+	9.677945218152264789534431079563744378421e+0011L,
+	3.731140327851536828225143058896348502096e+0013L,
+	7.612785951064869291722846681020881676410e+0014L,
+	7.476077016406764891730191004811863975940e+0015L,
+	2.951246482613592035421503427100393831709e+0016L,
+	3.108361803691811711136854587074302034901e+0016L,
+};
+
+static GENERIC qr1[12] = {		/* [8, 16 ] */
+	-1.249999999999999999997949010383433818157e-0001L,
+	-9.051215166393822640636752244895124126934e+0001L,
+	-2.620782703428148837671179031904208303947e+0004L,
+	-3.975571261553504457766177974508785790884e+0006L,
+	-3.479029330759311306270072218074074994090e+0008L,
+	-1.823955008124268573036216746186239829089e+0010L,
+	-5.765932697111801375765156029221568664435e+0011L,
+	-1.079843680798742592954002192417934779114e+0013L,
+	-1.146893630504592739082205764611581332897e+0014L,
+	-6.367016059683898464936104447282880704182e+0014L,
+	-1.583109041961213490464459111903484209098e+0015L,
+	-1.230149555764242473103128650135795639412e+0015L,
 };
+
 static GENERIC qs1[14] = {
-   1.0e0L,
-   7.246831508115058112438579847778014458432e+0002L,
-   2.100854184439168518399383786306927037611e+0005L,
-   3.192636418837951507430188285940994235122e+0007L,
-   2.801558443383354674538443461124434216152e+0009L,
-   1.475026997664373739293483927250653467487e+0011L,
-   4.694486824913954608552363821799927145318e+0012L,
-   8.890350100919200250838438709601547334021e+0013L,
-   9.626844429082905144874701068760469752067e+0014L,
-   5.541110744600460773528263862687521642140e+0015L,
-   1.486500494789452556727470329232123096563e+0016L,
-   1.415840104845959400365430773732093899210e+0016L,
-   1.780866095241517418081312567239682336483e+0015L,
-  -2.359230917384889357887631544079990129494e+0014L,
-};
-static GENERIC qr2[12] = {	/* [5, 8] */
-  -1.249999999999999531937744362527772181614e-0001L,
-  -4.944373897356969774839375977239241573966e+0001L,
-  -7.728449175433465285314261650078450473909e+0003L,
-  -6.262574329612752346336901434651220705903e+0005L,
-  -2.900948220220943306027235217424380672732e+0007L,
-  -7.988719647634192770463917157562874119535e+0008L,
-  -1.318228171927181389547760026626357012375e+0010L,
-  -1.282439773983029245309263271945424928196e+0011L,
-  -7.050925570827818040186149940257918845138e+0011L,
-  -2.021751882573871990004205616874202684429e+0012L,
-  -2.592939962400668552384333900573812635658e+0012L,
-  -1.038267109518891262840601514932972850326e+0012L,
+	1.0e0L,
+	7.246831508115058112438579847778014458432e+0002L,
+	2.100854184439168518399383786306927037611e+0005L,
+	3.192636418837951507430188285940994235122e+0007L,
+	2.801558443383354674538443461124434216152e+0009L,
+	1.475026997664373739293483927250653467487e+0011L,
+	4.694486824913954608552363821799927145318e+0012L,
+	8.890350100919200250838438709601547334021e+0013L,
+	9.626844429082905144874701068760469752067e+0014L,
+	5.541110744600460773528263862687521642140e+0015L,
+	1.486500494789452556727470329232123096563e+0016L,
+	1.415840104845959400365430773732093899210e+0016L,
+	1.780866095241517418081312567239682336483e+0015L,
+	-2.359230917384889357887631544079990129494e+0014L,
+};
+
+static GENERIC qr2[12] = {		/* [5, 8] */
+	-1.249999999999999531937744362527772181614e-0001L,
+	-4.944373897356969774839375977239241573966e+0001L,
+	-7.728449175433465285314261650078450473909e+0003L,
+	-6.262574329612752346336901434651220705903e+0005L,
+	-2.900948220220943306027235217424380672732e+0007L,
+	-7.988719647634192770463917157562874119535e+0008L,
+	-1.318228171927181389547760026626357012375e+0010L,
+	-1.282439773983029245309263271945424928196e+0011L,
+	-7.050925570827818040186149940257918845138e+0011L,
+	-2.021751882573871990004205616874202684429e+0012L,
+	-2.592939962400668552384333900573812635658e+0012L,
+	-1.038267109518891262840601514932972850326e+0012L,
 };
+
 static GENERIC qs2[14] = {
-   1.0e0L,
-   3.961358492885570003202784022894248952116e+0002L,
-   6.205788738864701882828752634586510926968e+0004L,
-   5.045715603932670286550673813011764406749e+0006L,
-   2.349248611362658323353343389430968751429e+0008L,
-   6.520244524415828635917683553721880063911e+0009L,
-   1.089111211223507719337067159886281887722e+0011L,
-   1.080406000905359867958779409414903018610e+0012L,
-   6.135645280895514703514154680623769562148e+0012L,
-   1.862433040246625874245867151368643668215e+0013L,
-   2.667780805786648888840777888702193708994e+0013L,
-   1.394401107289087774765300711809313112824e+0013L,
-   1.093247500616320375562898297156722445484e+0012L,
-  -7.228875530378928722826604216491493780775e+0010L,
-};
-static GENERIC qr3[13] = {	/* [3.5 5] */
-  -1.249999999999473067748420379578481661075e-0001L,
-  -3.044549048635289351913574324803250977998e+0001L,
-  -2.890081140649769078496693003524681440869e+0003L,
-  -1.404922456817202235879343275330529107684e+0005L,
-  -3.862746614385573443518177403617349281869e+0006L,
-  -6.257517309110249049201133708911155047689e+0007L,
-  -6.031451330920839916987079782727323477520e+0008L,
-  -3.411542405173830611454025765755854382346e+0009L,
-  -1.089392478149726672133014498723021526099e+0010L,
-  -1.824934078420210941290140903415956782726e+0010L,
-  -1.400780278304358710423481070486939531139e+0010L,
-  -3.716484136064917363926635716743771092093e+0009L,
-  -1.397591075296425529970434890954904331580e+0008L,
+	1.0e0L,
+	3.961358492885570003202784022894248952116e+0002L,
+	6.205788738864701882828752634586510926968e+0004L,
+	5.045715603932670286550673813011764406749e+0006L,
+	2.349248611362658323353343389430968751429e+0008L,
+	6.520244524415828635917683553721880063911e+0009L,
+	1.089111211223507719337067159886281887722e+0011L,
+	1.080406000905359867958779409414903018610e+0012L,
+	6.135645280895514703514154680623769562148e+0012L,
+	1.862433040246625874245867151368643668215e+0013L,
+	2.667780805786648888840777888702193708994e+0013L,
+	1.394401107289087774765300711809313112824e+0013L,
+	1.093247500616320375562898297156722445484e+0012L,
+	-7.228875530378928722826604216491493780775e+0010L,
+};
+
+static GENERIC qr3[13] = {		/* [3.5 5] */
+	-1.249999999999473067748420379578481661075e-0001L,
+	-3.044549048635289351913574324803250977998e+0001L,
+	-2.890081140649769078496693003524681440869e+0003L,
+	-1.404922456817202235879343275330529107684e+0005L,
+	-3.862746614385573443518177403617349281869e+0006L,
+	-6.257517309110249049201133708911155047689e+0007L,
+	-6.031451330920839916987079782727323477520e+0008L,
+	-3.411542405173830611454025765755854382346e+0009L,
+	-1.089392478149726672133014498723021526099e+0010L,
+	-1.824934078420210941290140903415956782726e+0010L,
+	-1.400780278304358710423481070486939531139e+0010L,
+	-3.716484136064917363926635716743771092093e+0009L,
+	-1.397591075296425529970434890954904331580e+0008L,
 };
+
 static GENERIC qs3[13] = {
-   1.0e0L,
-   2.441498613904962049391000187014945858042e+0002L,
-   2.326188882072370711500164222341514337043e+0004L,
-   1.137138213121231338494977104659239578165e+0006L,
-   3.152918070735662728722998452605364253517e+0007L,
-   5.172877993426507259314270488444013595108e+0008L,
-   5.083086439731669807455961078856470774115e+0009L,
-   2.961842732066434123119325521139476909941e+0010L,
-   9.912185866862440735829781856081353151390e+0010L,
-   1.793560561251622234430564181567297983598e+0011L,
-   1.577090119341228122525265108497940403073e+0011L,
-   5.509910306780166194333889999985463681636e+0010L,
-   4.761691134078874491202320181517936758141e+0009L,
-};
-static GENERIC qr4[13] = {	/* [2.5 3.5] */
-  -1.249999999928567734339745043490705340835e-0001L,
-  -1.967201748731419063051601624435565528481e+0001L,
-  -1.186329146714562236407099740615528170707e+0003L,
-  -3.607736959222941810356301491152457934060e+0004L,
-  -6.119200717978104904932828468575194267125e+0005L,
-  -6.037847781158358226670305078652205586384e+0006L,
-  -3.503558153336140359700536720393565984740e+0007L,
-  -1.180196478268225718757218523746787309773e+0008L,
-  -2.221860232085134915841426363505169680528e+0008L,
-  -2.173372505452747585296176761701746236760e+0008L,
-  -9.649364865061237558517730539506568013963e+0007L,
-  -1.465429227847933034546039640094862650385e+0007L,
-  -3.083003197920262085170581866246663380607e+0005L,
-};
-static GENERIC qs4[13] = {	/* [2.5 3.5] */
-   1.0e0L,
-   1.579620773732259142752614142139986854055e+0002L,
-   9.581372220329138733203879503753685054968e+0003L,
-   2.939598672379108095776114131010825885308e+0005L,
-   5.052183049314542218630341818692588448168e+0006L,
-   5.083497695595206639433839326338971980149e+0007L,
-   3.036385361800553388049719014005099206516e+0008L,
-   1.067826481452753409910563785161661492137e+0009L,
-   2.145644125557118044720741775125319669272e+0009L,
-   2.324115615959719949363946673491552216799e+0009L,
-   1.223262962112070757966959855619847011146e+0009L,
-   2.569765553318495423738478585947110270709e+0008L,
-   1.354744744299227127897905787732636565504e+0007L,
-};
-static GENERIC qr5[13] = {	/* [1.777.., 2.5] */
-  -1.249999995936639697637680428174576069971e-0001L,
-  -1.260846055371311453485891923426489068315e+0001L,
-  -4.772398467544467480801174330290141578895e+0002L,
-  -8.939852599990298486613760833996490599724e+0003L,
-  -9.184070787149542050979542226446134243197e+0004L,
-  -5.406038945018274458362637897739280435171e+0005L,
-  -1.845896544705190261018653728678171084418e+0006L,
-  -3.613616990680809501878667570653308071547e+0006L,
-  -3.908782978135693252252557720414348623779e+0006L,
-  -2.173711022517323927109138170588442768176e+0006L,
-  -5.431253130679918485836408549007856244495e+0005L,
-  -4.591098546452684510082591587275940765959e+0004L,
-  -5.244711364168207806835520057792229646578e+0002L,
-};
-static GENERIC qs5[13] = {	/* [1.777.., 2.5] */
-   1.0e0L,
-   1.014536210851290878350892750972474861447e+0002L,
-   3.875547510687135314064434160096139681076e+0003L,
-   7.361913122670079814955259281995617732580e+0004L,
-   7.720288944218771126581086539585529314636e+0005L,
-   4.681529554446752496404431433608306558038e+0006L,
-   1.667882621940503925455031252308367745820e+0007L,
-   3.469403153761399881888272620855305156241e+0007L,
-   4.096992047964210711867089384719947863019e+0007L,
-   2.596804755829217449311530735959560630554e+0007L,
-   7.983933774697889238154465064019410763845e+0006L,
-   9.818133816979900819087242425280757938152e+0005L,
-   3.061083930868694396013541535670745443560e+0004L,
-};
-
-static GENERIC qr6[13] = {	/* [1.28, 1.777..] */
-  -1.249999881577289001807137282824929082771e-0001L,
-  -7.998273510053110759610810594119533619282e+0000L,
-  -1.872481955335172543369089617771565632719e+0002L,
-  -2.122116786726300805079874003303799646812e+0003L,
-  -1.293850285839529282503178263484773478457e+0004L,
-  -4.445024742266316181033354192262529356093e+0004L,
-  -8.730161378334357767668344467356505347070e+0004L,
-  -9.706222895172078442801444972505315054736e+0004L,
-  -5.896325518259858270165531513618195321041e+0004L,
-  -1.823172034368108822276420827074668832233e+0004L,
-  -2.509304178635055926638833040337472387175e+0003L,
-  -1.156608965715779237316769828941729964099e+0002L,
-  -7.028005789650731396887346826397785210442e-0001L,
-};
-static GENERIC qs6[13] = {	/* [1.28, 1.777..] */
-   1.0e0L,
-   6.457211085058064845601261321277721075900e+0001L,
-   1.534005216588011210342824555136008682950e+0003L,
-   1.777217999176441782593357660462379097171e+0004L,
-   1.118372652642469468091084810263231199696e+0005L,
-   4.015242433858461813142365748386473605294e+0005L,
-   8.377081045517098645448616514388280497673e+0005L,
-   1.011495020008010352575398009604164287337e+0006L,
-   6.886722075290430568652227875200208955970e+0005L,
-   2.504735189948021472047157148613171956537e+0005L,
-   4.408138920171044846941001844352009817062e+0004L,
-   3.105572178072115145673058722853640854884e+0003L,
-   5.588294821118916113437396504573817033678e+0001L,
+	1.0e0L,
+	2.441498613904962049391000187014945858042e+0002L,
+	2.326188882072370711500164222341514337043e+0004L,
+	1.137138213121231338494977104659239578165e+0006L,
+	3.152918070735662728722998452605364253517e+0007L,
+	5.172877993426507259314270488444013595108e+0008L,
+	5.083086439731669807455961078856470774115e+0009L,
+	2.961842732066434123119325521139476909941e+0010L,
+	9.912185866862440735829781856081353151390e+0010L,
+	1.793560561251622234430564181567297983598e+0011L,
+	1.577090119341228122525265108497940403073e+0011L,
+	5.509910306780166194333889999985463681636e+0010L,
+	4.761691134078874491202320181517936758141e+0009L,
+};
+
+static GENERIC qr4[13] = {		/* [2.5 3.5] */
+	-1.249999999928567734339745043490705340835e-0001L,
+	-1.967201748731419063051601624435565528481e+0001L,
+	-1.186329146714562236407099740615528170707e+0003L,
+	-3.607736959222941810356301491152457934060e+0004L,
+	-6.119200717978104904932828468575194267125e+0005L,
+	-6.037847781158358226670305078652205586384e+0006L,
+	-3.503558153336140359700536720393565984740e+0007L,
+	-1.180196478268225718757218523746787309773e+0008L,
+	-2.221860232085134915841426363505169680528e+0008L,
+	-2.173372505452747585296176761701746236760e+0008L,
+	-9.649364865061237558517730539506568013963e+0007L,
+	-1.465429227847933034546039640094862650385e+0007L,
+	-3.083003197920262085170581866246663380607e+0005L,
+};
+
+static GENERIC qs4[13] = {		/* [2.5 3.5] */
+	1.0e0L,
+	1.579620773732259142752614142139986854055e+0002L,
+	9.581372220329138733203879503753685054968e+0003L,
+	2.939598672379108095776114131010825885308e+0005L,
+	5.052183049314542218630341818692588448168e+0006L,
+	5.083497695595206639433839326338971980149e+0007L,
+	3.036385361800553388049719014005099206516e+0008L,
+	1.067826481452753409910563785161661492137e+0009L,
+	2.145644125557118044720741775125319669272e+0009L,
+	2.324115615959719949363946673491552216799e+0009L,
+	1.223262962112070757966959855619847011146e+0009L,
+	2.569765553318495423738478585947110270709e+0008L,
+	1.354744744299227127897905787732636565504e+0007L,
+};
+
+static GENERIC qr5[13] = {		/* [1.777.., 2.5] */
+	-1.249999995936639697637680428174576069971e-0001L,
+	-1.260846055371311453485891923426489068315e+0001L,
+	-4.772398467544467480801174330290141578895e+0002L,
+	-8.939852599990298486613760833996490599724e+0003L,
+	-9.184070787149542050979542226446134243197e+0004L,
+	-5.406038945018274458362637897739280435171e+0005L,
+	-1.845896544705190261018653728678171084418e+0006L,
+	-3.613616990680809501878667570653308071547e+0006L,
+	-3.908782978135693252252557720414348623779e+0006L,
+	-2.173711022517323927109138170588442768176e+0006L,
+	-5.431253130679918485836408549007856244495e+0005L,
+	-4.591098546452684510082591587275940765959e+0004L,
+	-5.244711364168207806835520057792229646578e+0002L,
+};
+
+static GENERIC qs5[13] = {		/* [1.777.., 2.5] */
+	1.0e0L,
+	1.014536210851290878350892750972474861447e+0002L,
+	3.875547510687135314064434160096139681076e+0003L,
+	7.361913122670079814955259281995617732580e+0004L,
+	7.720288944218771126581086539585529314636e+0005L,
+	4.681529554446752496404431433608306558038e+0006L,
+	1.667882621940503925455031252308367745820e+0007L,
+	3.469403153761399881888272620855305156241e+0007L,
+	4.096992047964210711867089384719947863019e+0007L,
+	2.596804755829217449311530735959560630554e+0007L,
+	7.983933774697889238154465064019410763845e+0006L,
+	9.818133816979900819087242425280757938152e+0005L,
+	3.061083930868694396013541535670745443560e+0004L,
+};
+
+static GENERIC qr6[13] = {		/* [1.28, 1.777..] */
+	-1.249999881577289001807137282824929082771e-0001L,
+	-7.998273510053110759610810594119533619282e+0000L,
+	-1.872481955335172543369089617771565632719e+0002L,
+	-2.122116786726300805079874003303799646812e+0003L,
+	-1.293850285839529282503178263484773478457e+0004L,
+	-4.445024742266316181033354192262529356093e+0004L,
+	-8.730161378334357767668344467356505347070e+0004L,
+	-9.706222895172078442801444972505315054736e+0004L,
+	-5.896325518259858270165531513618195321041e+0004L,
+	-1.823172034368108822276420827074668832233e+0004L,
+	-2.509304178635055926638833040337472387175e+0003L,
+	-1.156608965715779237316769828941729964099e+0002L,
+	-7.028005789650731396887346826397785210442e-0001L,
+};
+
+static GENERIC qs6[13] = {		/* [1.28, 1.777..] */
+	1.0e0L,
+	6.457211085058064845601261321277721075900e+0001L,
+	1.534005216588011210342824555136008682950e+0003L,
+	1.777217999176441782593357660462379097171e+0004L,
+	1.118372652642469468091084810263231199696e+0005L,
+	4.015242433858461813142365748386473605294e+0005L,
+	8.377081045517098645448616514388280497673e+0005L,
+	1.011495020008010352575398009604164287337e+0006L,
+	6.886722075290430568652227875200208955970e+0005L,
+	2.504735189948021472047157148613171956537e+0005L,
+	4.408138920171044846941001844352009817062e+0004L,
+	3.105572178072115145673058722853640854884e+0003L,
+	5.588294821118916113437396504573817033678e+0001L,
 };
-static GENERIC qzero(x)
-GENERIC x;
+
+static GENERIC
+qzero(x)
+    GENERIC x;
 {
 	GENERIC s, r, t, z;
 	int i;
+
 	if (x > huge)
-		return (-0.125L/x);
-	t = one/x; z = t*t;
+		return (-0.125L / x);
+
+	t = one / x;
+	z = t * t;
+
 	if (x > sixteen) {
-	    r = z*qr0[11]+qr0[10]; s = qs0[10];
-	    for (i = 9; i >= 0; i--) {
-		r = z*r + qr0[i];
-		s = z*s + qs0[i];
-	    }
+		r = z * qr0[11] + qr0[10];
+		s = qs0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + qr0[i];
+			s = z * s + qs0[i];
+		}
 	} else if (x > eight) {
-	    r = qr1[11]; s = qs1[11]+z*(qs1[12]+z*qs1[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + qr1[i];
-		s = z*s + qs1[i];
-	    }
-	} else if (x > five) {  /* assume x > 5.0 */
-	    r = qr2[11]; s = qs2[11]+z*(qs2[12]+z*qs2[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + qr2[i];
-		s = z*s + qs2[i];
-	    }
+		r = qr1[11];
+		s = qs1[11] + z * (qs1[12] + z * qs1[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr1[i];
+			s = z * s + qs1[i];
+		}
+	} else if (x > five) {		/* assume x > 5.0 */
+		r = qr2[11];
+		s = qs2[11] + z * (qs2[12] + z * qs2[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr2[i];
+			s = z * s + qs2[i];
+		}
 	} else if (x > 3.5L) {
-	    r = qr3[12]; s = qs3[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + qr3[i];
-		s = z*s + qs3[i];
-	    }
+		r = qr3[12];
+		s = qs3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr3[i];
+			s = z * s + qs3[i];
+		}
 	} else if (x > 2.5L) {
-	    r = qr4[12]; s = qs4[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + qr4[i];
-		s = z*s + qs4[i];
-	    }
-	} else if (x > (1.0L/0.5625L)) {
-	    r = qr5[12]; s = qs5[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + qr5[i];
-		s = z*s + qs5[i];
-	    }
-	} else {	/* assume x > 1.28 */
-	    r = qr6[12]; s = qs6[12];
-	    for (i = 11; i >= 0; i--) {
-		r = z*r + qr6[i];
-		s = z*s + qs6[i];
-	    }
+		r = qr4[12];
+		s = qs4[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr4[i];
+			s = z * s + qs4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = qr5[12];
+		s = qs5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr5[i];
+			s = z * s + qs5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = qr6[12];
+		s = qs6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr6[i];
+			s = z * s + qs6[i];
+		}
 	}
-	return (t*(r/s));
+
+	return (t * (r / s));
 }
--- old/usr/src/lib/libm/common/LD/j1l.c	2019-06-06 20:38:17.939666970 +0000
+++ new/usr/src/lib/libm/common/LD/j1l.c	2019-06-06 20:38:17.957787558 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -46,98 +47,117 @@
 #include <sunmath.h>
 #endif
 
-#define	GENERIC long double
-static GENERIC
-zero    = 0.0L,
-small	= 1.0e-9L,
-tiny 	= 1.0e-38L,
-one	= 1.0L,
-five   	= 5.0L,
-invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
-tpi	= 0.636619772367581343075535053490057448L;
+#define	GENERIC	long double
+
+static GENERIC zero = 0.0L,
+	small = 1.0e-9L,
+	tiny = 1.0e-38L,
+	one = 1.0L,
+	five = 5.0L,
+	invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
+	tpi = 0.636619772367581343075535053490057448L;
 
 static GENERIC pone(), qone();
+
 static GENERIC r0[7] = {
-  -6.249999999999999999999999999999999627320e-0002L,
-   1.940606727194041716205384618494641565464e-0003L,
-  -3.005630423155733701856481469986459043883e-0005L,
-   2.345586219403918667468341047369572169358e-0007L,
-  -9.976809285885253587529010109133336669724e-0010L,
-   2.218743258363623946078958783775107473381e-0012L,
-  -2.071079656218700604767650924103578046280e-0015L,
+	-6.249999999999999999999999999999999627320e-0002L,
+	1.940606727194041716205384618494641565464e-0003L,
+	-3.005630423155733701856481469986459043883e-0005L,
+	2.345586219403918667468341047369572169358e-0007L,
+	-9.976809285885253587529010109133336669724e-0010L,
+	2.218743258363623946078958783775107473381e-0012L,
+	-2.071079656218700604767650924103578046280e-0015L,
 };
+
 static GENERIC s0[7] = {
-   1.0e0L,
-   1.061695903156199920738051277075003059555e-0002L,
-   5.521860513111180371566951179398862692060e-0005L,
-   1.824214367413754193524107877084979441407e-0007L,
-   4.098957778439576834818838198039029353925e-0010L,
-   6.047735079699666389853240090925264056197e-0013L,
-   4.679044728878836197247923279512047035041e-0016L,
+	1.0e0L,
+	1.061695903156199920738051277075003059555e-0002L,
+	5.521860513111180371566951179398862692060e-0005L,
+	1.824214367413754193524107877084979441407e-0007L,
+	4.098957778439576834818838198039029353925e-0010L,
+	6.047735079699666389853240090925264056197e-0013L,
+	4.679044728878836197247923279512047035041e-0016L,
 };
 
 GENERIC
-j1l(x) GENERIC x; {
+j1l(GENERIC x)
+{
 	GENERIC z, d, s, c, ss, cc, r;
 	int i, sgn;
 
 	if (!finitel(x))
-		return (one/x);
+		return (one / x);
+
 	sgn = signbitl(x);
 	x = fabsl(x);
+
 	if (x > 1.28L) {
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
-	 * where x0 = x-3pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
-	 *			=  1/sqrt(2) * (sin(x) - cos(x))
-	 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
-	 *			= -1/sqrt(2) * (cos(x) + sin(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
+		 * where x0 = x-3pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
+		 *			=  1/sqrt(2) * (sin(x) - cos(x))
+		 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
+		 *			= -1/sqrt(2) * (cos(x) + sin(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 1.0e2450L) {	/* x+x may overflow */
-			ss = -s-c;
-			cc =  s-c;
+			ss = -s - c;
+			cc = s - c;
 		} else if (signbitl(s) != signbitl(c)) {
 			cc = s - c;
-			ss = cosl(x+x)/cc;
+			ss = cosl(x + x) / cc;
 		} else {
-			ss = -s-c;
-			cc = cosl(x+x)/ss;
+			ss = -s - c;
+			cc = cosl(x + x) / ss;
 		}
-	/*
-	 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
-	 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
-	 */
-                if (x > 1.0e120L)
-					return (invsqrtpi*cc)/sqrtl(x);
-                d =  invsqrtpi*(pone(x)*cc-qone(x)*ss)/sqrtl(x);
+
+		/*
+		 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
+		 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
+		 */
+		if (x > 1.0e120L)
+			return ((invsqrtpi * cc) / sqrtl(x));
+
+		d = invsqrtpi * (pone(x) * cc - qone(x) * ss) / sqrtl(x);
+
 		if (sgn == 0)
 			return (d);
 		else
 			return (-d);
 	}
+
 	if (x <= small) {
-            if (x <= tiny) d = 0.5L*x;
-            else d =  x*(0.5L-x*x*0.125L);
-	    if (sgn == 0)
+		if (x <= tiny)
+			d = 0.5L * x;
+		else
+			d = x * (0.5L - x * x * 0.125L);
+
+		if (sgn == 0)
 			return (d);
 		else
 			return (-d);
-        }
-	z = x*x;
-	    r = r0[6];
-	    s = s0[6];
-	    for (i = 5; i >= 0; i--) {
-		r = r*z + r0[i];
-		s = s*z + s0[i];
-	    }
-	d = x*0.5L+x*(z*(r/s));
+	}
+
+	z = x * x;
+	r = r0[6];
+	s = s0[6];
+
+	for (i = 5; i >= 0; i--) {
+		r = r * z + r0[i];
+		s = s * z + s0[i];
+	}
+
+	d = x * 0.5L + x * (z * (r / s));
+
 	if (sgn == 0)
 		return (d);
 	else
@@ -145,608 +165,688 @@
 }
 
 static GENERIC u0[7] = {
-  -1.960570906462389484060557273467558703503e-0001L,
-   5.166389353148318460304315890665450006495e-0002L,
-  -2.229699464105910913337190798743451115604e-0003L,
-   3.625437034548863342715657067759078267158e-0005L,
-  -2.689902826993117212255524537353883987171e-0007L,
-   9.304570592456930912969387719010256018466e-0010L,
-  -1.234878126794286643318321347997500346131e-0012L,
+	-1.960570906462389484060557273467558703503e-0001L,
+	5.166389353148318460304315890665450006495e-0002L,
+	-2.229699464105910913337190798743451115604e-0003L,
+	3.625437034548863342715657067759078267158e-0005L,
+	-2.689902826993117212255524537353883987171e-0007L,
+	9.304570592456930912969387719010256018466e-0010L,
+	-1.234878126794286643318321347997500346131e-0012L,
 };
+
 static GENERIC v0[8] = {
-   1.0e0L,
-   1.369394302535807332517110204820556695644e-0002L,
-   9.508438148097659501433367062605935379588e-0005L,
-   4.399007309420092056052714797296467565655e-0007L,
-   1.488083087443756398305819693177715000787e-0009L,
-   3.751609832625793536245746965768587624922e-0012L,
-   6.680926434086257291872903276124244131448e-0015L,
-   6.676602383908906988160099057991121446058e-0018L,
+	1.0e0L,
+	1.369394302535807332517110204820556695644e-0002L,
+	9.508438148097659501433367062605935379588e-0005L,
+	4.399007309420092056052714797296467565655e-0007L,
+	1.488083087443756398305819693177715000787e-0009L,
+	3.751609832625793536245746965768587624922e-0012L,
+	6.680926434086257291872903276124244131448e-0015L,
+	6.676602383908906988160099057991121446058e-0018L,
 };
 
 GENERIC
-y1l(x) GENERIC x; {
+y1l(GENERIC x)
+{
 	GENERIC z, s, c, ss, cc, u, v;
 	int i;
 
 	if (isnanl(x))
-		return (x+x);
+		return (x + x);
+
 	if (x <= zero) {
 		if (x == zero)
-		    return (-one/zero);
+			return (-one / zero);
 		else
-		    return (zero/zero);
+			return (zero / zero);
 	}
+
 	if (x > 1.28L) {
 		if (!finitel(x))
 			return (zero);
+
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
-	 * where x0 = x-3pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
-	 *			=  1/sqrt(2) * (sin(x) - cos(x))
-	 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
-	 *			= -1/sqrt(2) * (cos(x) + sin(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
+		 * where x0 = x-3pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
+		 *			=  1/sqrt(2) * (sin(x) - cos(x))
+		 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
+		 *			= -1/sqrt(2) * (cos(x) + sin(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
 		if (x > 1.0e2450L) {	/* x+x may overflow */
-			ss = -s-c;
-			cc =  s-c;
+			ss = -s - c;
+			cc = s - c;
 		} else if (signbitl(s) != signbitl(c)) {
 			cc = s - c;
-			ss = cosl(x+x)/cc;
+			ss = cosl(x + x) / cc;
 		} else {
-			ss = -s-c;
-			cc = cosl(x+x)/ss;
+			ss = -s - c;
+			cc = cosl(x + x) / ss;
 		}
-	/*
-	 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
-	 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
-	 */
+
+		/*
+		 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
+		 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
+		 */
 		if (x > 1.0e91L)
-			return (invsqrtpi*ss)/sqrtl(x);
-        return (invsqrtpi*(pone(x)*ss+qone(x)*cc)/sqrtl(x));
+			return ((invsqrtpi * ss) / sqrtl(x));
+
+		return (invsqrtpi * (pone(x) * ss + qone(x) * cc) / sqrtl(x));
+	}
+
+	if (x <= tiny)
+		return (-tpi / x);
+
+	z = x * x;
+	u = u0[6];
+	v = v0[6] + z * v0[7];
+
+	for (i = 5; i >= 0; i--) {
+		u = u * z + u0[i];
+		v = v * z + v0[i];
 	}
-        if (x <= tiny) {
-            return (-tpi/x);
-        }
-	z = x*x;
-	    u = u0[6]; v = v0[6]+z*v0[7];
-	    for (i = 5; i >= 0; i--) {
-		u = u*z + u0[i];
-		v = v*z + v0[i];
-	    }
-	return (x*(u/v) + tpi*(j1l(x)*logl(x)-one/x));
+
+	return (x * (u / v) + tpi * (j1l(x) * logl(x) - one / x));
 }
 
 static GENERIC pr0[12] = {
-   1.000000000000000000000000000000000000267e+0000L,
-   1.060717875045891455602180843276758003035e+0003L,
-   4.344347542892127024446687712181105852335e+0005L,
-   8.915680220724007016377924252717410457094e+0007L,
-   9.969502259938406062809873257569171272819e+0009L,
-   6.200290193138613035646510338707386316595e+0011L,
-   2.105978548788015119851815854422247330118e+0013L,
-   3.696635772784601239371730810311998368948e+0014L,
-   3.015913097920694682057958412534134515156e+0015L,
-   9.370298471339353098123277427328592725921e+0015L,
-   7.190349005196335967340799265074029443057e+0015L,
-   2.736097786240689996880391074927552517982e+0014L,
+	1.000000000000000000000000000000000000267e+0000L,
+	1.060717875045891455602180843276758003035e+0003L,
+	4.344347542892127024446687712181105852335e+0005L,
+	8.915680220724007016377924252717410457094e+0007L,
+	9.969502259938406062809873257569171272819e+0009L,
+	6.200290193138613035646510338707386316595e+0011L,
+	2.105978548788015119851815854422247330118e+0013L,
+	3.696635772784601239371730810311998368948e+0014L,
+	3.015913097920694682057958412534134515156e+0015L,
+	9.370298471339353098123277427328592725921e+0015L,
+	7.190349005196335967340799265074029443057e+0015L,
+	2.736097786240689996880391074927552517982e+0014L,
 };
+
 static GENERIC ps0[11] = {
-   1.0e0L,
-   1.060600687545891455602180843276758095107e+0003L,
-   4.343106093416975589147153906505338900961e+0005L,
-   8.910605869002176566582072242244353399059e+0007L,
-   9.959122058635087888690713917622056540190e+0009L,
-   6.188744967234948231792482949171041843894e+0011L,
-   2.098863976953783506401759873801990304907e+0013L,
-   3.672870357018063196746729751479938908450e+0014L,
-   2.975538419246824921049011529574385888420e+0015L,
-   9.063657659995043205018686029284479837091e+0015L,
-   6.401953344314747916729366441508892711691e+0015L,
+	1.0e0L,
+	1.060600687545891455602180843276758095107e+0003L,
+	4.343106093416975589147153906505338900961e+0005L,
+	8.910605869002176566582072242244353399059e+0007L,
+	9.959122058635087888690713917622056540190e+0009L,
+	6.188744967234948231792482949171041843894e+0011L,
+	2.098863976953783506401759873801990304907e+0013L,
+	3.672870357018063196746729751479938908450e+0014L,
+	2.975538419246824921049011529574385888420e+0015L,
+	9.063657659995043205018686029284479837091e+0015L,
+	6.401953344314747916729366441508892711691e+0015L,
 };
+
 static GENERIC pr1[12] = {
-   1.000000000000000000000023667524130660984e+0000L,
-   6.746154419979618754354803488126452971204e+0002L,
-   1.811210781083390154857018330296145970502e+0005L,
-   2.533098390379924268038005329095287842244e+0007L,
-   2.029683619805342145252338570875424600729e+0009L,
-   9.660859662192711465301069401598929980319e+0010L,
-   2.743396238644831519934098967716621316316e+0012L,
-   4.553097354140854377931023170263455246288e+0013L,
-   4.210245069852219757476169864974870720374e+0014L,
-   1.987334056229596485076645967176169801727e+0015L,
-   4.067120052787096893838970455751338930462e+0015L,
-   2.486539606380406398310845264910691398133e+0015L,
+	1.000000000000000000000023667524130660984e+0000L,
+	6.746154419979618754354803488126452971204e+0002L,
+	1.811210781083390154857018330296145970502e+0005L,
+	2.533098390379924268038005329095287842244e+0007L,
+	2.029683619805342145252338570875424600729e+0009L,
+	9.660859662192711465301069401598929980319e+0010L,
+	2.743396238644831519934098967716621316316e+0012L,
+	4.553097354140854377931023170263455246288e+0013L,
+	4.210245069852219757476169864974870720374e+0014L,
+	1.987334056229596485076645967176169801727e+0015L,
+	4.067120052787096893838970455751338930462e+0015L,
+	2.486539606380406398310845264910691398133e+0015L,
 };
+
 static GENERIC ps1[14] = {
-   1.0e0L,
-   6.744982544979618754355808680196859521782e+0002L,
-   1.810421795396966762032155290441364740350e+0005L,
-   2.530986460644310651529583759699988435573e+0007L,
-   2.026743276048023121360249288818290224145e+0009L,
-   9.637461924407405935245269407052641341836e+0010L,
-   2.732378628423766417402292797028314160831e+0012L,
-   4.522345274960527124354844364012184278488e+0013L,
-   4.160650668341743132685335758415469856545e+0014L,
-   1.943730242988858208243492424892435901211e+0015L,
-   3.880228532692127989901131618598067450001e+0015L,
-   2.178020816161154615841000173683302999728e+0015L,
-  -8.994062666842225551554346698171600634173e+0013L,
-   1.368520368508851253495764806934619574990e+0013L,
+	1.0e0L,
+	6.744982544979618754355808680196859521782e+0002L,
+	1.810421795396966762032155290441364740350e+0005L,
+	2.530986460644310651529583759699988435573e+0007L,
+	2.026743276048023121360249288818290224145e+0009L,
+	9.637461924407405935245269407052641341836e+0010L,
+	2.732378628423766417402292797028314160831e+0012L,
+	4.522345274960527124354844364012184278488e+0013L,
+	4.160650668341743132685335758415469856545e+0014L,
+	1.943730242988858208243492424892435901211e+0015L,
+	3.880228532692127989901131618598067450001e+0015L,
+	2.178020816161154615841000173683302999728e+0015L,
+	-8.994062666842225551554346698171600634173e+0013L,
+	1.368520368508851253495764806934619574990e+0013L,
 };
+
 static GENERIC pr2[12] = {
-   1.000000000000000006938651621840396237282e+0000L,
-   3.658416291850404981407101077037948144698e+0002L,
-   5.267073772170356547709794670602812447537e+0004L,
-   3.912012101226837463014925210735894620442e+0006L,
-   1.651295648974103957193874928714180765625e+0008L,
-   4.114901144480797609972484998142146783499e+0009L,
-   6.092524309766036681542980572526335147672e+0010L,
-   5.263913178071282616719249969074134570577e+0011L,
-   2.538408581124324223367341020538081330994e+0012L,
-   6.288607929360291027895126983015365677648e+0012L,
-   6.848330048211148419047055075386525945280e+0012L,
-   2.290309646838867941423178163991423244690e+0012L,
+	1.000000000000000006938651621840396237282e+0000L,
+	3.658416291850404981407101077037948144698e+0002L,
+	5.267073772170356547709794670602812447537e+0004L,
+	3.912012101226837463014925210735894620442e+0006L,
+	1.651295648974103957193874928714180765625e+0008L,
+	4.114901144480797609972484998142146783499e+0009L,
+	6.092524309766036681542980572526335147672e+0010L,
+	5.263913178071282616719249969074134570577e+0011L,
+	2.538408581124324223367341020538081330994e+0012L,
+	6.288607929360291027895126983015365677648e+0012L,
+	6.848330048211148419047055075386525945280e+0012L,
+	2.290309646838867941423178163991423244690e+0012L,
 };
+
 static GENERIC ps2[14] = {
-   1.0e0L,
-   3.657244416850405086459410165762319861856e+0002L,
-   5.262802358425023243992387075861237306312e+0004L,
-   3.905896813959919648136295861661483848364e+0006L,
-   1.646791907791461220742694842108202772763e+0008L,
-   4.096132803064256022224954120208201437344e+0009L,
-   6.046665195915950447544429445730680236759e+0010L,
-   5.198061739781991313414052212328653295168e+0011L,
-   2.484233851814333966401527626421254279796e+0012L,
-   6.047868806925315879339651539434315255940e+0012L,
-   6.333103831254091652501642567294101813354e+0012L,
-   1.875143098754284994467609936924685024968e+0012L,
-  -5.238330920563392692965412762508813601534e+0010L,
-   4.656888609439364725427789198383779259957e+0009L,
+	1.0e0L,
+	3.657244416850405086459410165762319861856e+0002L,
+	5.262802358425023243992387075861237306312e+0004L,
+	3.905896813959919648136295861661483848364e+0006L,
+	1.646791907791461220742694842108202772763e+0008L,
+	4.096132803064256022224954120208201437344e+0009L,
+	6.046665195915950447544429445730680236759e+0010L,
+	5.198061739781991313414052212328653295168e+0011L,
+	2.484233851814333966401527626421254279796e+0012L,
+	6.047868806925315879339651539434315255940e+0012L,
+	6.333103831254091652501642567294101813354e+0012L,
+	1.875143098754284994467609936924685024968e+0012L,
+	-5.238330920563392692965412762508813601534e+0010L,
+	4.656888609439364725427789198383779259957e+0009L,
 };
+
 static GENERIC pr3[13] = {
-   1.000000000000009336887318068056137842897e+0000L,
-   2.242719942728459588488051572002835729183e+0002L,
-   1.955450611382026550266257737331095691092e+0004L,
-   8.707143293993619899395400562409175590739e+0005L,
-   2.186267894487004565948324289010954505316e+0007L,
-   3.224328510541957792360691585667502864688e+0008L,
-   2.821057355151380597331792896882741364897e+0009L,
-   1.445371387295422404365584793796028979840e+0010L,
-   4.181743160669891357783011002656658107864e+0010L,
-   6.387371088767993119325536137794535513922e+0010L,
-   4.575619999412716078064070587767416436396e+0010L,
-   1.228415651211639160620284441690503550842e+0010L,
-   7.242170349875563053436050532153112882072e+0008L,
+	1.000000000000009336887318068056137842897e+0000L,
+	2.242719942728459588488051572002835729183e+0002L,
+	1.955450611382026550266257737331095691092e+0004L,
+	8.707143293993619899395400562409175590739e+0005L,
+	2.186267894487004565948324289010954505316e+0007L,
+	3.224328510541957792360691585667502864688e+0008L,
+	2.821057355151380597331792896882741364897e+0009L,
+	1.445371387295422404365584793796028979840e+0010L,
+	4.181743160669891357783011002656658107864e+0010L,
+	6.387371088767993119325536137794535513922e+0010L,
+	4.575619999412716078064070587767416436396e+0010L,
+	1.228415651211639160620284441690503550842e+0010L,
+	7.242170349875563053436050532153112882072e+0008L,
 };
+
 static GENERIC ps3[13] = {
-   1.0e0L,
-   2.241548067728529551049804610486061401070e+0002L,
-   1.952838216795552145132137932931237181307e+0004L,
-   8.684574926493185744628127341069974575526e+0005L,
-   2.176357771067037962940853412819852189164e+0007L,
-   3.199958682356132977319258783167122100567e+0008L,
-   2.786218931525334687844675219914201872570e+0009L,
-   1.416283776951741549631417572317916039767e+0010L,
-   4.042962659271567948735676834609348842922e+0010L,
-   6.028168462646694510083847222968444402161e+0010L,
-   4.118410226794641413833887606580085281111e+0010L,
-   9.918735736297038430744161253338202230263e+0009L,
-   4.092967198238098023219124487437130332038e+0008L,
+	1.0e0L,
+	2.241548067728529551049804610486061401070e+0002L,
+	1.952838216795552145132137932931237181307e+0004L,
+	8.684574926493185744628127341069974575526e+0005L,
+	2.176357771067037962940853412819852189164e+0007L,
+	3.199958682356132977319258783167122100567e+0008L,
+	2.786218931525334687844675219914201872570e+0009L,
+	1.416283776951741549631417572317916039767e+0010L,
+	4.042962659271567948735676834609348842922e+0010L,
+	6.028168462646694510083847222968444402161e+0010L,
+	4.118410226794641413833887606580085281111e+0010L,
+	9.918735736297038430744161253338202230263e+0009L,
+	4.092967198238098023219124487437130332038e+0008L,
 };
+
 static GENERIC pr4[13] = {
-   1.000000000001509220978157399042059553390e+0000L,
-   1.437551868378147851133499996323782607787e+0002L,
-   7.911335537418177296041518061404505428004e+0003L,
-   2.193710939115317214716518908935756104804e+0005L,
-   3.390662495136730962513489796538274984382e+0006L,
-   3.048655347929348891006070609293884274789e+0007L,
-   1.613781633489496606354045161527450975195e+0008L,
-   4.975089835037230277110156150038482159988e+0008L,
-   8.636047087015115403880904418339566323264e+0008L,
-   7.918202912328366140110671223076949101509e+0008L,
-   3.423294665798984733439650311722794853294e+0008L,
-   5.621904953441963961040503934782662613621e+0007L,
-   2.086303543310240260758670404509484499793e+0006L,
+	1.000000000001509220978157399042059553390e+0000L,
+	1.437551868378147851133499996323782607787e+0002L,
+	7.911335537418177296041518061404505428004e+0003L,
+	2.193710939115317214716518908935756104804e+0005L,
+	3.390662495136730962513489796538274984382e+0006L,
+	3.048655347929348891006070609293884274789e+0007L,
+	1.613781633489496606354045161527450975195e+0008L,
+	4.975089835037230277110156150038482159988e+0008L,
+	8.636047087015115403880904418339566323264e+0008L,
+	7.918202912328366140110671223076949101509e+0008L,
+	3.423294665798984733439650311722794853294e+0008L,
+	5.621904953441963961040503934782662613621e+0007L,
+	2.086303543310240260758670404509484499793e+0006L,
 };
+
 static GENERIC ps4[13] = {
-   1.0e0L,
-   1.436379993384532371670493319591847362304e+0002L,
-   7.894647154785430678061053848847436659499e+0003L,
-   2.184659753392097529008981741550878586174e+0005L,
-   3.366109083305465176803513738147049499361e+0006L,
-   3.011911545968996817697665866587226343186e+0007L,
-   1.582262913779689851316760148459414895301e+0008L,
-   4.819268809494937919217938589530138201770e+0008L,
-   8.201355762990450679702837123432527154830e+0008L,
-   7.268232093982510937417446421282341425212e+0008L,
-   2.950911909015572933262131323934036480462e+0008L,
-   4.242839924305934423010858966540621219396e+0007L,
-   1.064387620445090779182117666330405186866e+0006L,
+	1.0e0L,
+	1.436379993384532371670493319591847362304e+0002L,
+	7.894647154785430678061053848847436659499e+0003L,
+	2.184659753392097529008981741550878586174e+0005L,
+	3.366109083305465176803513738147049499361e+0006L,
+	3.011911545968996817697665866587226343186e+0007L,
+	1.582262913779689851316760148459414895301e+0008L,
+	4.819268809494937919217938589530138201770e+0008L,
+	8.201355762990450679702837123432527154830e+0008L,
+	7.268232093982510937417446421282341425212e+0008L,
+	2.950911909015572933262131323934036480462e+0008L,
+	4.242839924305934423010858966540621219396e+0007L,
+	1.064387620445090779182117666330405186866e+0006L,
 };
+
 static GENERIC pr5[13] = {
-   1.000000000102434805241171427253847353861e+0000L,
-   9.129332257083629259060502249025963234821e+0001L,
-   3.132238483586953037576119377504557191413e+0003L,
-   5.329782528269307971278943122454171107861e+0004L,
-   4.988460157184117790692873002103052944145e+0005L,
-   2.686602071615786816147010334256047469378e+0006L,
-   8.445418526028961197703799808701268301831e+0006L,
-   1.536575358646141157475725889907900827390e+0007L,
-   1.568405818236523821796862770586544811945e+0007L,
-   8.450876239888770102387618667362302173547e+0006L,
-   2.154414900139567328424026827163203446077e+0006L,
-   2.105656926565043898888460254808062352205e+0005L,
-   4.739165011023396507022134303736862812975e+0003L,
+	1.000000000102434805241171427253847353861e+0000L,
+	9.129332257083629259060502249025963234821e+0001L,
+	3.132238483586953037576119377504557191413e+0003L,
+	5.329782528269307971278943122454171107861e+0004L,
+	4.988460157184117790692873002103052944145e+0005L,
+	2.686602071615786816147010334256047469378e+0006L,
+	8.445418526028961197703799808701268301831e+0006L,
+	1.536575358646141157475725889907900827390e+0007L,
+	1.568405818236523821796862770586544811945e+0007L,
+	8.450876239888770102387618667362302173547e+0006L,
+	2.154414900139567328424026827163203446077e+0006L,
+	2.105656926565043898888460254808062352205e+0005L,
+	4.739165011023396507022134303736862812975e+0003L,
 };
+
 static GENERIC ps5[13] = {
-   1.0e0L,
-   9.117613509595327476509152673394703847793e+0001L,
-   3.121697972484015639301279229281770795147e+0003L,
-   5.294447222735893568040911873834576440255e+0004L,
-   4.930368882192772335798256684110887882807e+0005L,
-   2.634854685641165298302167435798357437768e+0006L,
-   8.185462775400326393555896157031818280918e+0006L,
-   1.462417423080215192609668642663030667086e+0007L,
-   1.450624993985851675982860844153954896015e+0007L,
-   7.460467647561995283219086567162006113864e+0006L,
-   1.754210981405612478869227142579056338965e+0006L,
-   1.463286721155271971526264914524746699596e+0005L,
-   2.155894725796702015341211116579827039459e+0003L,
+	1.0e0L,
+	9.117613509595327476509152673394703847793e+0001L,
+	3.121697972484015639301279229281770795147e+0003L,
+	5.294447222735893568040911873834576440255e+0004L,
+	4.930368882192772335798256684110887882807e+0005L,
+	2.634854685641165298302167435798357437768e+0006L,
+	8.185462775400326393555896157031818280918e+0006L,
+	1.462417423080215192609668642663030667086e+0007L,
+	1.450624993985851675982860844153954896015e+0007L,
+	7.460467647561995283219086567162006113864e+0006L,
+	1.754210981405612478869227142579056338965e+0006L,
+	1.463286721155271971526264914524746699596e+0005L,
+	2.155894725796702015341211116579827039459e+0003L,
 };
+
 static GENERIC pr6[13] = {
-   1.000000003564855546741735920315743157129e+0000L,
-   5.734003934862540458119423509909510288366e+0001L,
-   1.209572491935850486086559692291796887976e+0003L,
-   1.243398391422281247933674779163660286838e+0004L,
-   6.930996755181437937258220998601708278787e+0004L,
-   2.198067659532757598646722249966767620099e+0005L,
-   4.033659432712058633933179115820576858455e+0005L,
-   4.257759657219008027016047206574574358678e+0005L,
-   2.511917395876004349480721277445763916389e+0005L,
-   7.813756153070623654178731651381881953552e+0004L,
-   1.152069173381127881385588092905864352891e+0004L,
-   6.548580782804088553777816037551523398082e+0002L,
-   8.668725370116906132327542766127938496880e+0000L,
+	1.000000003564855546741735920315743157129e+0000L,
+	5.734003934862540458119423509909510288366e+0001L,
+	1.209572491935850486086559692291796887976e+0003L,
+	1.243398391422281247933674779163660286838e+0004L,
+	6.930996755181437937258220998601708278787e+0004L,
+	2.198067659532757598646722249966767620099e+0005L,
+	4.033659432712058633933179115820576858455e+0005L,
+	4.257759657219008027016047206574574358678e+0005L,
+	2.511917395876004349480721277445763916389e+0005L,
+	7.813756153070623654178731651381881953552e+0004L,
+	1.152069173381127881385588092905864352891e+0004L,
+	6.548580782804088553777816037551523398082e+0002L,
+	8.668725370116906132327542766127938496880e+0000L,
 };
+
 static GENERIC ps6[13] = {
-   1.0e0L,
-   5.722285236357114566499221525736286205184e+0001L,
-   1.203010842878317935444582950620339570506e+0003L,
-   1.230058335378583550155825502172435371208e+0004L,
-   6.800998550607861288865300438648089894412e+0004L,
-   2.130767829599304262987769347536850885921e+0005L,
-   3.840483466643916681759936972992155310026e+0005L,
-   3.947432373459225542861819148108081160393e+0005L,
-   2.237816239393081111481588434457838526738e+0005L,
-   6.545820495124419723398946273790921540774e+0004L,
-   8.729563630320892741500726213278834737196e+0003L,
-   4.130762660291894753450174794196998813709e+0002L,
-   3.480368898672684645130335786015075595598e+0000L,
+	1.0e0L,
+	5.722285236357114566499221525736286205184e+0001L,
+	1.203010842878317935444582950620339570506e+0003L,
+	1.230058335378583550155825502172435371208e+0004L,
+	6.800998550607861288865300438648089894412e+0004L,
+	2.130767829599304262987769347536850885921e+0005L,
+	3.840483466643916681759936972992155310026e+0005L,
+	3.947432373459225542861819148108081160393e+0005L,
+	2.237816239393081111481588434457838526738e+0005L,
+	6.545820495124419723398946273790921540774e+0004L,
+	8.729563630320892741500726213278834737196e+0003L,
+	4.130762660291894753450174794196998813709e+0002L,
+	3.480368898672684645130335786015075595598e+0000L,
 };
+
 static GENERIC sixteen = 16.0L;
-static GENERIC eight   = 8.0L;
-static GENERIC huge    = 1.0e30L;
+static GENERIC eight = 8.0L;
+static GENERIC huge = 1.0e30L;
 
-static GENERIC pone(x)
-GENERIC x;
+static GENERIC
+pone(x)
+    GENERIC x;
 {
 	GENERIC s, r, t, z;
 	int i;
+
 	if (x > huge)
 		return (one);
-	t = one/x; z = t*t;
+
+	t = one / x;
+	z = t * t;
+
 	if (x > sixteen) {
-	    r = z*pr0[11]+pr0[10]; s = ps0[10];
-	    for (i = 9; i >= 0; i--) {
-		r = z*r + pr0[i];
-		s = z*s + ps0[i];
-	    }
+		r = z * pr0[11] + pr0[10];
+		s = ps0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + pr0[i];
+			s = z * s + ps0[i];
+		}
 	} else if (x > eight) {
-	    r = pr1[11]; s = ps1[11]+z*(ps1[12]+z*ps1[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + pr1[i];
-		s = z*s + ps1[i];
-	    }
+		r = pr1[11];
+		s = ps1[11] + z * (ps1[12] + z * ps1[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr1[i];
+			s = z * s + ps1[i];
+		}
 	} else if (x > five) {
-	    r = pr2[11]; s = ps2[11]+z*(ps2[12]+z*ps2[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + pr2[i];
-		s = z*s + ps2[i];
-	    }
-        } else if (x > 3.5L) {
-            r = pr3[12]; s = ps3[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + pr3[i];
-                s = z*s + ps3[i];
-            }
-        } else if (x > 2.5L) {
-            r = pr4[12]; s = ps4[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + pr4[i];
-                s = z*s + ps4[i];
-            }
-        } else if (x > (1.0L/0.5625L)) {
-            r = pr5[12]; s = ps5[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + pr5[i];
-                s = z*s + ps5[i];
-            }
-        } else {		/* assume x > 1.28 */
-            r = pr6[12]; s = ps6[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + pr6[i];
-                s = z*s + ps6[i];
-            }
-        }
-	return (r/s);
-}
+		r = pr2[11];
+		s = ps2[11] + z * (ps2[12] + z * ps2[13]);
 
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr2[i];
+			s = z * s + ps2[i];
+		}
+	} else if (x > 3.5L) {
+		r = pr3[12];
+		s = ps3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr3[i];
+			s = z * s + ps3[i];
+		}
+	} else if (x > 2.5L) {
+		r = pr4[12];
+		s = ps4[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr4[i];
+			s = z * s + ps4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = pr5[12];
+		s = ps5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr5[i];
+			s = z * s + ps5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = pr6[12];
+		s = ps6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr6[i];
+			s = z * s + ps6[i];
+		}
+	}
 
+	return (r / s);
+}
 static GENERIC qr0[12] = {
-   3.749999999999999999999999999999999971033e-0001L,
-   4.256726035237050601607682277433094262226e+0002L,
-   1.875976490812878489192409978945401066066e+0005L,
-   4.170314268048041914273603680317745592790e+0007L,
-   5.092750132543855817293451118974555746551e+0009L,
-   3.494749676278488654103505795794139483404e+0011L,
-   1.327062148257437316997667817096694173709e+0013L,
-   2.648993138273427226907503742066551150490e+0014L,
-   2.511695665909547412222430494473998127684e+0015L,
-   9.274694506662289043224310499164702306096e+0015L,
-   8.150904170663663829331320302911792892002e+0015L,
-  -5.001918733707662355772037829620388765122e+0014L,
+	3.749999999999999999999999999999999971033e-0001L,
+	4.256726035237050601607682277433094262226e+0002L,
+	1.875976490812878489192409978945401066066e+0005L,
+	4.170314268048041914273603680317745592790e+0007L,
+	5.092750132543855817293451118974555746551e+0009L,
+	3.494749676278488654103505795794139483404e+0011L,
+	1.327062148257437316997667817096694173709e+0013L,
+	2.648993138273427226907503742066551150490e+0014L,
+	2.511695665909547412222430494473998127684e+0015L,
+	9.274694506662289043224310499164702306096e+0015L,
+	8.150904170663663829331320302911792892002e+0015L,
+	-5.001918733707662355772037829620388765122e+0014L,
 };
+
 static GENERIC qs0[11] = {
-   1.0e0L,
-   1.135400380229880160428715273982155760093e+0003L,
-   5.005701183877126164326765545516590744360e+0005L,
-   1.113444200113712167984337603933040102987e+0008L,
-   1.361074819925223062778717565699039471124e+0010L,
-   9.355750985802849484438933905325982809653e+0011L,
-   3.563462786008988825003965543857998084828e+0013L,
-   7.155145113900094163648726863803802910454e+0014L,
-   6.871266835834472758055559013851843654113e+0015L,
-   2.622030899226736712644974988157345234092e+0016L,
-   2.602912729172876330650077021706139707746e+0016L,
+	1.0e0L,
+	1.135400380229880160428715273982155760093e+0003L,
+	5.005701183877126164326765545516590744360e+0005L,
+	1.113444200113712167984337603933040102987e+0008L,
+	1.361074819925223062778717565699039471124e+0010L,
+	9.355750985802849484438933905325982809653e+0011L,
+	3.563462786008988825003965543857998084828e+0013L,
+	7.155145113900094163648726863803802910454e+0014L,
+	6.871266835834472758055559013851843654113e+0015L,
+	2.622030899226736712644974988157345234092e+0016L,
+	2.602912729172876330650077021706139707746e+0016L,
 };
+
 static GENERIC qr1[12] = {
-   3.749999999999999999997762458207284405806e-0001L,
-   2.697883998881706839929255517498189980485e+0002L,
-   7.755195925781028489386938870473834411019e+0004L,
-   1.166777762104017777198211072895528968355e+0007L,
-   1.011504772984321168320010084520261069362e+0009L,
-   5.246007703574156853577754571720205550010e+0010L,
-   1.637692549885592683166116551691266537647e+0012L,
-   3.022303623698185669912990310925039382495e+0013L,
-   3.154769927290655684846107030265909987946e+0014L,
-   1.715819913441554770089730934808123360921e+0015L,
-   4.165044355759732622273534445131736188510e+0015L,
-   3.151381420874174705643100381708086287596e+0015L,
+	3.749999999999999999997762458207284405806e-0001L,
+	2.697883998881706839929255517498189980485e+0002L,
+	7.755195925781028489386938870473834411019e+0004L,
+	1.166777762104017777198211072895528968355e+0007L,
+	1.011504772984321168320010084520261069362e+0009L,
+	5.246007703574156853577754571720205550010e+0010L,
+	1.637692549885592683166116551691266537647e+0012L,
+	3.022303623698185669912990310925039382495e+0013L,
+	3.154769927290655684846107030265909987946e+0014L,
+	1.715819913441554770089730934808123360921e+0015L,
+	4.165044355759732622273534445131736188510e+0015L,
+	3.151381420874174705643100381708086287596e+0015L,
 };
+
 static GENERIC qs1[14] = {
-   1.0e0L,
-   7.197091705351218239785633172408276982828e+0002L,
-   2.070012799599548685544883041297609861055e+0005L,
-   3.117014815317656221871840152778458754516e+0007L,
-   2.705719678902554974863325877025902971727e+0009L,
-   1.406113614727345726925060648750867264098e+0011L,
-   4.403777536067131320363005978631674817359e+0012L,
-   8.170725690209322283061499386703167242894e+0013L,
-   8.609458844975495289227794126964431210566e+0014L,
-   4.766766367015473481257280600694952920204e+0015L,
-   1.202286587943342194863557940888115641650e+0016L,
-   1.012474328306200909525063936061756024120e+0016L,
-   6.183552022678917858273222879615824070703e+0014L,
-  -9.756731548558226997573737400988225722740e+0013L,
+	1.0e0L,
+	7.197091705351218239785633172408276982828e+0002L,
+	2.070012799599548685544883041297609861055e+0005L,
+	3.117014815317656221871840152778458754516e+0007L,
+	2.705719678902554974863325877025902971727e+0009L,
+	1.406113614727345726925060648750867264098e+0011L,
+	4.403777536067131320363005978631674817359e+0012L,
+	8.170725690209322283061499386703167242894e+0013L,
+	8.609458844975495289227794126964431210566e+0014L,
+	4.766766367015473481257280600694952920204e+0015L,
+	1.202286587943342194863557940888115641650e+0016L,
+	1.012474328306200909525063936061756024120e+0016L,
+	6.183552022678917858273222879615824070703e+0014L,
+	-9.756731548558226997573737400988225722740e+0013L,
 };
+
 static GENERIC qr2[12] = {
-   3.749999999999999481245647262226994293189e-0001L,
-   1.471366807289771354491181140167359026735e+0002L,
-   2.279432486768448220142080962843526951250e+0004L,
-   1.828943048523771225163804043356958285893e+0006L,
-   8.379828388647823135832220596417725010837e+0007L,
-   2.279814029335044024585393671278378022053e+0009L,
-   3.711653952257118120832817785271466441420e+0010L,
-   3.557650914518554549916730572553105048068e+0011L,
-   1.924583483146095896259774329498934160650e+0012L,
-   5.424386256063736390759567088291887140278e+0012L,
-   6.839325621241776786206509704671746841737e+0012L,
-   2.702169563144001166291686452305436313971e+0012L,
+	3.749999999999999481245647262226994293189e-0001L,
+	1.471366807289771354491181140167359026735e+0002L,
+	2.279432486768448220142080962843526951250e+0004L,
+	1.828943048523771225163804043356958285893e+0006L,
+	8.379828388647823135832220596417725010837e+0007L,
+	2.279814029335044024585393671278378022053e+0009L,
+	3.711653952257118120832817785271466441420e+0010L,
+	3.557650914518554549916730572553105048068e+0011L,
+	1.924583483146095896259774329498934160650e+0012L,
+	5.424386256063736390759567088291887140278e+0012L,
+	6.839325621241776786206509704671746841737e+0012L,
+	2.702169563144001166291686452305436313971e+0012L,
 };
+
 static GENERIC qs2[14] = {
-   1.0e0L,
-   3.926379194439388135703211933895203191089e+0002L,
-   6.089148804106598297488336063007609312276e+0004L,
-   4.893546162973278583711376356041614150645e+0006L,
-   2.247571119114497845046388801813832219404e+0008L,
-   6.137635663350177751290469334200757872645e+0009L,
-   1.005115019784102856424493519524998953678e+0011L,
-   9.725664462014503832860151384604677240620e+0011L,
-   5.345525100485511116148634192844434636072e+0012L,
-   1.549944007398946691720862738173956994779e+0013L,
-   2.067148441178952625710302124163264760362e+0013L,
-   9.401565402641963611295119487242595462301e+0012L,
-   3.548217088622398274748837287769709374385e+0011L,
-  -2.934470341719047120076509938432417352365e+0010L,
+	1.0e0L,
+	3.926379194439388135703211933895203191089e+0002L,
+	6.089148804106598297488336063007609312276e+0004L,
+	4.893546162973278583711376356041614150645e+0006L,
+	2.247571119114497845046388801813832219404e+0008L,
+	6.137635663350177751290469334200757872645e+0009L,
+	1.005115019784102856424493519524998953678e+0011L,
+	9.725664462014503832860151384604677240620e+0011L,
+	5.345525100485511116148634192844434636072e+0012L,
+	1.549944007398946691720862738173956994779e+0013L,
+	2.067148441178952625710302124163264760362e+0013L,
+	9.401565402641963611295119487242595462301e+0012L,
+	3.548217088622398274748837287769709374385e+0011L,
+	-2.934470341719047120076509938432417352365e+0010L,
 };
+
 static GENERIC qr3[13] = {
-   3.749999999999412724084579833297451472091e-0001L,
-   9.058478580291706212422978492938435582527e+0001L,
-   8.524056033161038750461083666711724381171e+0003L,
-   4.105967158629109427753434569223631014730e+0005L,
-   1.118326603378531348259783091972623333657e+0007L,
-   1.794636683403578918528064904714132329343e+0008L,
-   1.714314157463635959556133236004368896724e+0009L,
-   9.622092032236084846572067257267661456030e+0009L,
-   3.057759524485859159957762858780768355020e+0010L,
-   5.129306780754798531609621454415938890020e+0010L,
-   3.999122002794961070680636194346316041352e+0010L,
-   1.122298454643493485989721564358100345388e+0010L,
-   5.603981987645989709668830968522362582221e+0008L,
+	3.749999999999412724084579833297451472091e-0001L,
+	9.058478580291706212422978492938435582527e+0001L,
+	8.524056033161038750461083666711724381171e+0003L,
+	4.105967158629109427753434569223631014730e+0005L,
+	1.118326603378531348259783091972623333657e+0007L,
+	1.794636683403578918528064904714132329343e+0008L,
+	1.714314157463635959556133236004368896724e+0009L,
+	9.622092032236084846572067257267661456030e+0009L,
+	3.057759524485859159957762858780768355020e+0010L,
+	5.129306780754798531609621454415938890020e+0010L,
+	3.999122002794961070680636194346316041352e+0010L,
+	1.122298454643493485989721564358100345388e+0010L,
+	5.603981987645989709668830968522362582221e+0008L,
 };
+
 static GENERIC qs3[13] = {
-   1.0e0L,
-   2.418328663076578169836155170053634419922e+0002L,
-   2.279620205900121042587523541281272875520e+0004L,
-   1.100984222585729521470129014992217092794e+0006L,
-   3.010743223679247091004262516286654516282e+0007L,
-   4.860925542827367817289619265215599433996e+0008L,
-   4.686668111035348691982715864307839581243e+0009L,
-   2.668701788405102017427214705946730894074e+0010L,
-   8.677395746106802640390580944836650584903e+0010L,
-   1.511936455574951790658498795945106643036e+0011L,
-   1.260845604432623478002018696873608353093e+0011L,
-   4.052692278419853853911440231600864589805e+0010L,
-   2.965516519212226064983267822243329694729e+0009L,
+	1.0e0L,
+	2.418328663076578169836155170053634419922e+0002L,
+	2.279620205900121042587523541281272875520e+0004L,
+	1.100984222585729521470129014992217092794e+0006L,
+	3.010743223679247091004262516286654516282e+0007L,
+	4.860925542827367817289619265215599433996e+0008L,
+	4.686668111035348691982715864307839581243e+0009L,
+	2.668701788405102017427214705946730894074e+0010L,
+	8.677395746106802640390580944836650584903e+0010L,
+	1.511936455574951790658498795945106643036e+0011L,
+	1.260845604432623478002018696873608353093e+0011L,
+	4.052692278419853853911440231600864589805e+0010L,
+	2.965516519212226064983267822243329694729e+0009L,
 };
+
 static GENERIC qr4[13] = {
-   3.749999999919234164154669754440123072618e-0001L,
-   5.844218580776819864791168253485055101858e+0001L,
-   3.489273514092912982675669411371435670220e+0003L,
-   1.050523637774575684509663430018995479594e+0005L,
-   1.764549172059701565500717319792780115289e+0006L,
-   1.725532438844133795028063102681497371154e+0007L,
-   9.938114847359778539965140247590176334874e+0007L,
-   3.331710808184595545396883770200772842314e+0008L,
-   6.271970557641881511609560444872797282698e+0008L,
-   6.188529798677357075020774923903737913285e+0008L,
-   2.821905302742849974509982167877885011629e+0008L,
-   4.615467358646911976773290256984329814896e+0007L,
-   1.348140608731546467396685802693380693275e+0006L,
+	3.749999999919234164154669754440123072618e-0001L,
+	5.844218580776819864791168253485055101858e+0001L,
+	3.489273514092912982675669411371435670220e+0003L,
+	1.050523637774575684509663430018995479594e+0005L,
+	1.764549172059701565500717319792780115289e+0006L,
+	1.725532438844133795028063102681497371154e+0007L,
+	9.938114847359778539965140247590176334874e+0007L,
+	3.331710808184595545396883770200772842314e+0008L,
+	6.271970557641881511609560444872797282698e+0008L,
+	6.188529798677357075020774923903737913285e+0008L,
+	2.821905302742849974509982167877885011629e+0008L,
+	4.615467358646911976773290256984329814896e+0007L,
+	1.348140608731546467396685802693380693275e+0006L,
 };
+
 static GENERIC qs4[13] = {
-   1.0e0L,
-   1.561192663112345185261418296389902133372e+0002L,
-   9.346678031144098270547225423124213083072e+0003L,
-   2.825851246482293547838023847601704751590e+0005L,
-   4.776572711622156091710902891124911556293e+0006L,
-   4.715106953717135402977938048006267859302e+0007L,
-   2.753962350894311316439652227611209035193e+0008L,
-   9.428501434615463207768964787500411575223e+0008L,
-   1.832650858775206787088236896454141572617e+0009L,
-   1.901697378939743226948920874296595242257e+0009L,
-   9.433322226854293780627188599226380812725e+0008L,
-   1.808520540608671608680284520798858587370e+0008L,
-   7.983342331736662753157217446919462398008e+0006L,
+	1.0e0L,
+	1.561192663112345185261418296389902133372e+0002L,
+	9.346678031144098270547225423124213083072e+0003L,
+	2.825851246482293547838023847601704751590e+0005L,
+	4.776572711622156091710902891124911556293e+0006L,
+	4.715106953717135402977938048006267859302e+0007L,
+	2.753962350894311316439652227611209035193e+0008L,
+	9.428501434615463207768964787500411575223e+0008L,
+	1.832650858775206787088236896454141572617e+0009L,
+	1.901697378939743226948920874296595242257e+0009L,
+	9.433322226854293780627188599226380812725e+0008L,
+	1.808520540608671608680284520798858587370e+0008L,
+	7.983342331736662753157217446919462398008e+0006L,
 };
+
 static GENERIC qr5[13] = {
-      3.749999995331364437028988850515190446719e-0001L,
-      3.739356381766559882677514593041627547911e+0001L,
-      1.399562500629413529355265462912819802551e+0003L,
-      2.594154053098947925345332218062210111753e+0004L,
-      2.640149879297408640394163979394594318371e+0005L,
-      1.542471854873199142031889093591449397995e+0006L,
-      5.242272868972053374067572098992335425895e+0006L,
-      1.025834487769410221329633071426044839935e+0007L,
-      1.116553924239448940142230579060124209622e+0007L,
-      6.318076065595910176374916303525884653514e+0006L,
-      1.641218086168640408527639735915512881785e+0006L,
-      1.522369793529178644168813882912134706444e+0005L,
-      2.526530541062297200914180060208669584055e+0003L,
+	3.749999995331364437028988850515190446719e-0001L,
+	3.739356381766559882677514593041627547911e+0001L,
+	1.399562500629413529355265462912819802551e+0003L,
+	2.594154053098947925345332218062210111753e+0004L,
+	2.640149879297408640394163979394594318371e+0005L,
+	1.542471854873199142031889093591449397995e+0006L,
+	5.242272868972053374067572098992335425895e+0006L,
+	1.025834487769410221329633071426044839935e+0007L,
+	1.116553924239448940142230579060124209622e+0007L,
+	6.318076065595910176374916303525884653514e+0006L,
+	1.641218086168640408527639735915512881785e+0006L,
+	1.522369793529178644168813882912134706444e+0005L,
+	2.526530541062297200914180060208669584055e+0003L,
 };
+
 static GENERIC qs5[13] = {
-      1.0e0L,
-      9.998960735935075380397545659016287506660e+0001L,
-      3.758767417842043742686475060540416737562e+0003L,
-      7.013652806952306520121959742519780781653e+0004L,
-      7.208949808818615099246529616211730446850e+0005L,
-      4.272753927109614455417836186072202009252e+0006L,
-      1.482524411356470699336129814111025434703e+0007L,
-      2.988750366665678233425279237627700803473e+0007L,
-      3.396957890261080492694709150553619185065e+0007L,
-      2.050652487738593004111578091156304540386e+0007L,
-      5.900504120811732547616511555946279451316e+0006L,
-      6.563391409260160897024498082273183468347e+0005L,
-      1.692629845012790205348966731477187041419e+0004L,
+	1.0e0L,
+	9.998960735935075380397545659016287506660e+0001L,
+	3.758767417842043742686475060540416737562e+0003L,
+	7.013652806952306520121959742519780781653e+0004L,
+	7.208949808818615099246529616211730446850e+0005L,
+	4.272753927109614455417836186072202009252e+0006L,
+	1.482524411356470699336129814111025434703e+0007L,
+	2.988750366665678233425279237627700803473e+0007L,
+	3.396957890261080492694709150553619185065e+0007L,
+	2.050652487738593004111578091156304540386e+0007L,
+	5.900504120811732547616511555946279451316e+0006L,
+	6.563391409260160897024498082273183468347e+0005L,
+	1.692629845012790205348966731477187041419e+0004L,
 };
+
 static GENERIC qr6[13] = {
-    3.749999861516664133157566870858975421296e-0001L,
-    2.367863756747764863120797431599473468918e+0001L,
-    5.476715802114976248882067325630793143777e+0002L,
-    6.143190357869842894025012945444096170251e+0003L,
-    3.716250534677997850513733595140463851730e+0004L,
-    1.270883463823876752138326905022875657430e+0005L,
-    2.495301449636814481646371665429083801388e+0005L,
-    2.789578988212952248340486296254398601942e+0005L,
-    1.718247946911109055931819087137397324634e+0005L,
-    5.458973214011665714330326732204106364229e+0004L,
-    7.912102686687948786048943339759596652813e+0003L,
-    4.077961006160866935722030715149087938091e+0002L,
-    3.765206972770245085551057237882528510428e+0000L,
+	3.749999861516664133157566870858975421296e-0001L,
+	2.367863756747764863120797431599473468918e+0001L,
+	5.476715802114976248882067325630793143777e+0002L,
+	6.143190357869842894025012945444096170251e+0003L,
+	3.716250534677997850513733595140463851730e+0004L,
+	1.270883463823876752138326905022875657430e+0005L,
+	2.495301449636814481646371665429083801388e+0005L,
+	2.789578988212952248340486296254398601942e+0005L,
+	1.718247946911109055931819087137397324634e+0005L,
+	5.458973214011665714330326732204106364229e+0004L,
+	7.912102686687948786048943339759596652813e+0003L,
+	4.077961006160866935722030715149087938091e+0002L,
+	3.765206972770245085551057237882528510428e+0000L,
 };
+
 static GENERIC qs6[13] = {
-    1.0e0L,
-    6.341646532940517305641893852673926809601e+0001L,
-    1.477058277414040790932597537920671025359e+0003L,
-    1.674406564031044491436044253393536487604e+0004L,
-    1.028516501369755949895050806908994650768e+0005L,
-    3.593620042532885295087463507733285434207e+0005L,
-    7.267924991381020915185873399453724799625e+0005L,
-    8.462277510768818399961191426205006083088e+0005L,
-    5.514399892230892163373611895645500250514e+0005L,
-    1.898084241009259353540620272932188102299e+0005L,
-    3.102941242117739015721984123081026253068e+0004L,
-    1.958971184431466907681440650181421086143e+0003L,
-    2.878853357310495087181721613889455121867e+0001L,
+	1.0e0L,
+	6.341646532940517305641893852673926809601e+0001L,
+	1.477058277414040790932597537920671025359e+0003L,
+	1.674406564031044491436044253393536487604e+0004L,
+	1.028516501369755949895050806908994650768e+0005L,
+	3.593620042532885295087463507733285434207e+0005L,
+	7.267924991381020915185873399453724799625e+0005L,
+	8.462277510768818399961191426205006083088e+0005L,
+	5.514399892230892163373611895645500250514e+0005L,
+	1.898084241009259353540620272932188102299e+0005L,
+	3.102941242117739015721984123081026253068e+0004L,
+	1.958971184431466907681440650181421086143e+0003L,
+	2.878853357310495087181721613889455121867e+0001L,
 };
-static GENERIC qone(x)
-GENERIC x;
+
+static GENERIC
+qone(x)
+    GENERIC x;
 {
 	GENERIC s, r, t, z;
 	int i;
+
 	if (x > huge)
-		return (0.375L/x);
-	t = one/x; z = t*t;
+		return (0.375L / x);
+
+	t = one / x;
+	z = t * t;
+
 	if (x > sixteen) {
-	    r = z*qr0[11]+qr0[10]; s = qs0[10];
-	    for (i = 9; i >= 0; i--) {
-		r = z*r + qr0[i];
-		s = z*s + qs0[i];
-	    }
+		r = z * qr0[11] + qr0[10];
+		s = qs0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + qr0[i];
+			s = z * s + qs0[i];
+		}
 	} else if (x > eight) {
-	    r = qr1[11]; s = qs1[11]+z*(qs1[12]+z*qs1[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + qr1[i];
-		s = z*s + qs1[i];
-	    }
-	} else if (x > five) {	/* x > 5.0 */
-	    r = qr2[11]; s = qs2[11]+z*(qs2[12]+z*qs2[13]);
-	    for (i = 10; i >= 0; i--) {
-		r = z*r + qr2[i];
-		s = z*s + qs2[i];
-	    }
-        } else if (x > 3.5L) {
-            r = qr3[12]; s = qs3[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + qr3[i];
-                s = z*s + qs3[i];
-            }
-        } else if (x > 2.5L) {
-            r = qr4[12]; s = qs4[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + qr4[i];
-                s = z*s + qs4[i];
-            }
-        } else if (x > (1.0L/0.5625L)) {
-            r = qr5[12]; s = qs5[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + qr5[i];
-                s = z*s + qs5[i];
-            }
-        } else {		/* assume x > 1.28 */
-            r = qr6[12]; s = qs6[12];
-            for (i = 11; i >= 0; i--) {
-                r = z*r + qr6[i];
-                s = z*s + qs6[i];
-            }
-        }
-	return (t*(r/s));
+		r = qr1[11];
+		s = qs1[11] + z * (qs1[12] + z * qs1[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr1[i];
+			s = z * s + qs1[i];
+		}
+	} else if (x > five) {		/* x > 5.0 */
+		r = qr2[11];
+		s = qs2[11] + z * (qs2[12] + z * qs2[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr2[i];
+			s = z * s + qs2[i];
+		}
+	} else if (x > 3.5L) {
+		r = qr3[12];
+		s = qs3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr3[i];
+			s = z * s + qs3[i];
+		}
+	} else if (x > 2.5L) {
+		r = qr4[12];
+		s = qs4[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr4[i];
+			s = z * s + qs4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = qr5[12];
+		s = qs5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr5[i];
+			s = z * s + qs5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = qr6[12];
+		s = qs6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr6[i];
+			s = z * s + qs6[i];
+		}
+	}
+
+	return (t * (r / s));
 }
--- old/usr/src/lib/libm/common/LD/jnl.c	2019-06-06 20:38:18.498850545 +0000
+++ new/usr/src/lib/libm/common/LD/jnl.c	2019-06-06 20:38:18.515496672 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -57,15 +58,15 @@
 
 #include "libm.h"
 #include "longdouble.h"
-#include <float.h>	/* LDBL_MAX */
+#include <float.h>			/* LDBL_MAX */
 
-#define	GENERIC long double
+#define	GENERIC	long double
 
 static const GENERIC
 invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
-two  = 2.0L,
-zero = 0.0L,
-one  = 1.0L;
+	two = 2.0L,
+	zero = 0.0L,
+	one = 1.0L;
 
 GENERIC
 jnl(int n, GENERIC x)
@@ -81,73 +82,85 @@
 		n = -n;
 		x = -x;
 	}
+
 	if (n == 0)
 		return (j0l(x));
+
 	if (n == 1)
 		return (j1l(x));
+
 	if (x != x)
-		return (x+x);
-	if ((n&1) == 0)
-		sgn = 0;			/* even n */
+		return (x + x);
+
+	if ((n & 1) == 0)
+		sgn = 0;		/* even n */
 	else
 		sgn = signbitl(x);	/* old n  */
+
 	x = fabsl(x);
-	if (x == zero || !finitel(x)) b = zero;
-	else if ((GENERIC)n <= x) {
+
+	if (x == zero || !finitel(x)) {
+		b = zero;
+	} else if ((GENERIC)n <= x) {
+		/*
+		 * Safe to use
+		 * J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
+		 */
+		if (x > 1.0e91L) {
 			/*
-			 * Safe to use
-			 * J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
+			 * x >> n**2
+			 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+			 *  Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+			 *  Let s=sin(x), c=cos(x),
+			 *  xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
+			 *
+			 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
+			 *	----------------------------------
+			 *	   0	 s-c		 c+s
+			 *	   1	-s-c		-c+s
+			 *	   2	-s+c		-c-s
+			 *	   3	 s+c		 c-s
 			 */
-		if (x > 1.0e91L) {
-				/*
-				 * x >> n**2
-				 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *  Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *  Let s=sin(x), c=cos(x),
-				 *  xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
-				 *
-				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
-				 *	----------------------------------
-				 *	   0	 s-c		 c+s
-				 *	   1	-s-c		-c+s
-				 *	   2	-s+c		-c-s
-				 *	   3	 s+c		 c-s
-				 */
-			switch (n&3) {
+			switch (n & 3) {
 			case 0:
-				temp =  cosl(x)+sinl(x);
+				temp = cosl(x) + sinl(x);
 				break;
 			case 1:
-				temp = -cosl(x)+sinl(x);
+				temp = -cosl(x) + sinl(x);
 				break;
 			case 2:
-				temp = -cosl(x)-sinl(x);
+				temp = -cosl(x) - sinl(x);
 				break;
 			case 3:
-				temp =  cosl(x)-sinl(x);
+				temp = cosl(x) - sinl(x);
 				break;
 			}
-			b = invsqrtpi*temp/sqrtl(x);
+
+			b = invsqrtpi * temp / sqrtl(x);
 		} else {
 			a = j0l(x);
 			b = j1l(x);
+
 			for (i = 1; i < n; i++) {
 				temp = b;
 				/* avoid underflow */
-				b = b*((GENERIC)(i+i)/x) - a;
+				b = b * ((GENERIC)(i + i) / x) - a;
 				a = temp;
 			}
 		}
 	} else {
 		if (x < 1e-17L) {	/* use J(n,x) = 1/n!*(x/2)^n */
-			b = powl(0.5L*x, (GENERIC)n);
+			b = powl(0.5L * x, (GENERIC)n);
+
 			if (b != zero) {
 				for (a = one, i = 1; i <= n; i++)
 					a *= (GENERIC)i;
-				b = b/a;
+
+				b = b / a;
 			}
 		} else {
 			/* BEGIN CSTYLED */
+
 			/*
 			 * use backward recurrence
 			 *			x      x^2	x^2
@@ -177,29 +190,38 @@
 			 * When Q(k) > 1e9	good for double
 			 * When Q(k) > 1e17	good for quaduple
 			 */
-			/* END CSTYLED */
-			/* determine k */
+
+			/*
+			 * END CSTYLED
+			 * determine k
+			 */
 			GENERIC t, v;
 			double q0, q1, h, tmp;
 			int k, m;
-			w  = (n+n)/(double)x;
-			h = 2.0/(double)x;
+
+			w = (n + n) / (double)x;
+			h = 2.0 / (double)x;
 			q0 = w;
-			z = w+h;
-			q1 = w*z - 1.0;
+			z = w + h;
+			q1 = w * z - 1.0;
 			k = 1;
+
 			while (q1 < 1.0e17) {
 				k += 1;
 				z += h;
-				tmp = z*q1 - q0;
+				tmp = z * q1 - q0;
 				q0 = q1;
 				q1 = tmp;
 			}
-			m = n+n;
-			for (t = zero, i = 2*(n+k); i >= m; i -= 2)
-				t = one/(i/x-t);
+
+			m = n + n;
+
+			for (t = zero, i = 2 * (n + k); i >= m; i -= 2)
+				t = one / (i / x - t);
+
 			a = t;
 			b = one;
+
 			/*
 			 * Estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
 			 * hence, if n*(log(2n/x)) > ...
@@ -213,29 +235,33 @@
 			 * likely underflow to zero.
 			 */
 			tmp = n;
-			v = two/x;
-			tmp = tmp*logl(fabsl(v*tmp));
+			v = two / x;
+			tmp = tmp * logl(fabsl(v * tmp));
+
 			if (tmp < 1.1356523406294143949491931077970765e+04L) {
-				for (i = n-1; i > 0; i--) {
+				for (i = n - 1; i > 0; i--) {
 					temp = b;
-					b = ((i+i)/x)*b - a;
+					b = ((i + i) / x) * b - a;
 					a = temp;
 				}
 			} else {
-				for (i = n-1; i > 0; i--) {
+				for (i = n - 1; i > 0; i--) {
 					temp = b;
-					b = ((i+i)/x)*b - a;
+					b = ((i + i) / x) * b - a;
 					a = temp;
+
 					if (b > 1e1000L) {
 						a /= b;
 						t /= b;
-						b  = 1.0;
+						b = 1.0;
 					}
 				}
 			}
-			b = (t*j0l(x)/b);
+
+			b = (t * j0l(x) / b);
 		}
 	}
+
 	if (sgn != 0)
 		return (-b);
 	else
@@ -250,71 +276,83 @@
 	GENERIC a, b, temp = 0;
 
 	if (x != x)
-		return (x+x);
+		return (x + x);
+
 	if (x <= zero) {
 		if (x == zero)
-			return (-one/zero);
+			return (-one / zero);
 		else
-			return (zero/zero);
+			return (zero / zero);
 	}
+
 	sign = 1;
+
 	if (n < 0) {
 		n = -n;
-		if ((n&1) == 1)
+
+		if ((n & 1) == 1)
 			sign = -1;
 	}
+
 	if (n == 0)
 		return (y0l(x));
+
 	if (n == 1)
-		return (sign*y1l(x));
+		return (sign * y1l(x));
+
 	if (!finitel(x))
 		return (zero);
 
 	if (x > 1.0e91L) {
-				/*
-				 * x >> n**2
-				 * Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *   Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *   Let s=sin(x), c=cos(x),
-				 * xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
-				 *
-				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
-				 *	----------------------------------
-				 *	   0	 s-c		 c+s
-				 *	   1	-s-c		-c+s
-				 *	   2	-s+c		-c-s
-				 *	   3	 s+c		 c-s
-				 */
-		switch (n&3) {
+		/*
+		 * x >> n**2
+		 * Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+		 *   Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+		 *   Let s=sin(x), c=cos(x),
+		 * xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
+		 *
+		 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
+		 *	----------------------------------
+		 *	   0	 s-c		 c+s
+		 *	   1	-s-c		-c+s
+		 *	   2	-s+c		-c-s
+		 *	   3	 s+c		 c-s
+		 */
+		switch (n & 3) {
 		case 0:
-			temp =  sinl(x)-cosl(x);
+			temp = sinl(x) - cosl(x);
 			break;
 		case 1:
-			temp = -sinl(x)-cosl(x);
+			temp = -sinl(x) - cosl(x);
 			break;
 		case 2:
-			temp = -sinl(x)+cosl(x);
+			temp = -sinl(x) + cosl(x);
 			break;
 		case 3:
-			temp =  sinl(x)+cosl(x);
+			temp = sinl(x) + cosl(x);
 			break;
 		}
-		b = invsqrtpi*temp/sqrtl(x);
+
+		b = invsqrtpi * temp / sqrtl(x);
 	} else {
 		a = y0l(x);
 		b = y1l(x);
+
 		/*
 		 * fix 1262058 and take care of non-default rounding
 		 */
 		for (i = 1; i < n; i++) {
 			temp = b;
-			b *= (GENERIC) (i + i) / x;
+			b *= (GENERIC)(i + i) / x;
+
 			if (b <= -LDBL_MAX)
 				break;
+
 			b -= a;
 			a = temp;
 		}
 	}
+
 	if (sign > 0)
 		return (b);
 	else
--- old/usr/src/lib/libm/common/LD/lgammal.c	2019-06-06 20:38:18.991428065 +0000
+++ new/usr/src/lib/libm/common/LD/lgammal.c	2019-06-06 20:38:19.008836951 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,11 +39,11 @@
 
 extern int signgam;
 extern int signgaml;
-
 long double
-lgammal(long double x) {
+lgammal(long double x)
+{
 	long double y = __k_lgammal(x, &signgaml);
 
 	signgam = signgaml;	/* SUSv3 requires the setting of signgam */
-	return y;
+	return (y);
 }
--- old/usr/src/lib/libm/common/LD/lgammal_r.c	2019-06-06 20:38:19.531398182 +0000
+++ new/usr/src/lib/libm/common/LD/lgammal_r.c	2019-06-06 20:38:19.550630397 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,6 +38,7 @@
 #include "longdouble.h"
 
 long double
-lgammal_r(long double x, int *signgamlp) {
-	return __k_lgammal(x, signgamlp);
+lgammal_r(long double x, int *signgamlp)
+{
+	return (__k_lgammal(x, signgamlp));
 }
--- old/usr/src/lib/libm/common/LD/log1pl.c	2019-06-06 20:38:20.035181339 +0000
+++ new/usr/src/lib/libm/common/LD/log1pl.c	2019-06-06 20:38:20.055353678 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,26 +40,33 @@
 #if defined(__x86)
 #define	__swapRD	__swap87RD
 #endif
+
 extern enum fp_direction_type __swapRD(enum fp_direction_type);
 
 long double
-log1pl(long double x) {
+log1pl(long double x)
+{
 	long double y;
 	enum fp_direction_type rd;
 
 	if (x != x)
 		return (x + x);
+
 	if (x < -1.L)
 		return (logl(x));
+
 	rd = __swapRD(fp_nearest);
 	y = 1.L + x;
+
 	if (y != 1.L) {
 		if (y == x)
 			x = logl(x);
 		else
 			x *= logl(y) / (y - 1.L);
 	}
+
 	if (rd != fp_nearest)
 		(void) __swapRD(rd);
+
 	return (x);
 }
--- old/usr/src/lib/libm/common/LD/logbl.c	2019-06-06 20:38:20.490228516 +0000
+++ new/usr/src/lib/libm/common/LD/logbl.c	2019-06-06 20:38:20.506724141 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,52 +31,63 @@
 #pragma weak __logbl = logbl
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
-#define	_C99SUSv3_logb	_C99SUSv3_logb_subnormal_is_like_ilogb
+#include "xpg6.h"			/* __xpg6 */
+#define	_C99SUSv3_logb		_C99SUSv3_logb_subnormal_is_like_ilogb
 
 #if defined(__sparc)
-#define	ISNORMALL(k, x)	(k != 0x7fff)			/* assuming k != 0 */
+#define	ISNORMALL(k, x)		(k != 0x7fff)	/* assuming k != 0 */
 #define	X86PDNRM(k, x)
-#define	XSCALE_OFFSET	0x406f				/* 0x3fff + 112 */
+#define	XSCALE_OFFSET		0x406f		/* 0x3fff + 112 */
+
 static const long double xscale = 5192296858534827628530496329220096.0L;
-								/* 2^112 */
+
+/* 2^112 */
 #elif defined(__x86)
 /*
  * if pseudo-denormal, replace by the equivalent normal
  */
-#define	X86PDNRM(k, x)	if (k == 0 && (((int *) &x)[1] & 0x80000000) != 0) \
-				((int *) &x)[2] |= k = 1
-#if defined(HANDLE_UNSUPPORTED)				/* assuming k != 0 */
-#define	ISNORMALL(k, x)	(k != 0x7fff && (((int *) &x)[1] & 0x80000000) != 0)
+#define	X86PDNRM(k, x)		if (k == 0 && (((int *)&x)[1] & 0x80000000) != \
+	    0) \
+		((int *)&x)[2] |= k = 1
+#if defined(HANDLE_UNSUPPORTED)		/* assuming k != 0 */
+#define	ISNORMALL(k, x)		(k != 0x7fff && \
+	(((int *)&x)[1] & 0x80000000) != 0)
 #else
-#define	ISNORMALL(k, x)	(k != 0x7fff)
+#define	ISNORMALL(k, x)		(k != 0x7fff)
 #endif
-#define	XSCALE_OFFSET	0x403e				/* 0x3fff + 63 */
+#define	XSCALE_OFFSET		0x403e			  /* 0x3fff + 63 */
 static const long double xscale = 9223372036854775808.0L;	/* 2^63 */
 #endif
 
 static long double
-raise_division(long double v) {
+raise_division(long double v)
+{
 #pragma STDC FENV_ACCESS ON
+
 	static const long double zero = 0.0L;
+
 	return (v / zero);
 }
 
 long double
-logbl(long double x) {
+logbl(long double x)
+{
 	int k = XBIASED_EXP(x);
 
 	X86PDNRM(k, x);
+
 	if (k == 0) {
-		if (ISZEROL(x))
+		if (ISZEROL(x)) {
 			return (raise_division(-1.0L));
-		else if ((__xpg6 & _C99SUSv3_logb) != 0) {
-			x *= xscale;		/* scale up by 2^112 or 2^63 */
-			return (long double) (XBIASED_EXP(x) - XSCALE_OFFSET);
-		} else
-			return ((long double) (-16382));
-	} else if (ISNORMALL(k, x))
-		return ((long double) (k - 0x3fff));
-	else
+		} else if ((__xpg6 & _C99SUSv3_logb) != 0) {
+			x *= xscale;	/* scale up by 2^112 or 2^63 */
+			return ((long double)(XBIASED_EXP(x) - XSCALE_OFFSET));
+		} else {
+			return ((long double)(-16382));
+		}
+	} else if (ISNORMALL(k, x)) {
+		return ((long double)(k - 0x3fff));
+	} else {
 		return (x * x);
+	}
 }
--- old/usr/src/lib/libm/common/LD/longdouble.h	2019-06-06 20:38:20.973516986 +0000
+++ new/usr/src/lib/libm/common/LD/longdouble.h	2019-06-06 20:38:20.993123005 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-#ifndef	_LD_LONGDOUBLE_H
+#ifndef _LD_LONGDOUBLE_H
 #define	_LD_LONGDOUBLE_H
 #include <sys/ieeefp.h>
 
@@ -38,7 +39,6 @@
 extern long double __k_tanl(long double, long double, int);
 extern long double __poly_libmq(long double, int, long double *);
 extern int __rem_pio2l(long double, long double *);
-
 extern long double acosdl(long double);
 extern long double acoshl(long double);
 extern long double acosl(long double);
@@ -133,7 +133,6 @@
 extern long double y0l(long double);
 extern long double y1l(long double);
 extern long double ynl(int, long double);
-
 extern long double q_copysign_(long double *, long double *);
 extern long double q_fabs_(long double *);
 extern int iq_finite_(long double *);
@@ -156,5 +155,4 @@
 extern long double q_scalbn_(long double *, int *);
 extern long double q_signaling_nan_(long *);
 extern int iq_signbit_(long double *);
-
-#endif	/* _LD_LONGDOUBLE_H */
+#endif /* _LD_LONGDOUBLE_H */
--- old/usr/src/lib/libm/common/LD/nextafterl.c	2019-06-06 20:38:21.481289632 +0000
+++ new/usr/src/lib/libm/common/LD/nextafterl.c	2019-06-06 20:38:21.498196777 +0000
@@ -51,16 +51,16 @@
 						--px[n0]; \
 		}
 #elif defined(__x86)
-#define	n0	2
-#define	n1	1
-#define	n2	0
-#define	n3	0
+#define		n0	2
+#define		n1	1
+#define		n2	0
+#define		n3	0
 /*
  * if pseudo-denormal, replace by the equivalent normal
  */
-#define	X86PDNRM1(x)	if (XBIASED_EXP(x) == 0 && (((int *) &x)[1] & \
+#define	X86PDNRM1(x)	if (XBIASED_EXP(x) == 0 && (((int *)&x)[1] & \
 				0x80000000) != 0) \
-				((int *) &x)[2] |= 1
+				((int *)&x)[2] |= 1
 #define	INC(px)	{ \
 			if (++px[n2] == 0) \
 				if ((++px[n1] & ~0x80000000) == 0) \
@@ -75,9 +75,10 @@
 #endif
 
 long double
-nextafterl(long double x, long double y) {
-	int *px = (int *) &x;
-	int *py = (int *) &y;
+nextafterl(long double x, long double y)
+{
+	int *px = (int *)&x;
+	int *py = (int *)&y;
 
 	if (x == y)
 		return (y);		/* C99 requirement */
--- old/usr/src/lib/libm/common/LD/scalbl.c	2019-06-06 20:38:21.977835651 +0000
+++ new/usr/src/lib/libm/common/LD/scalbl.c	2019-06-06 20:38:21.994399899 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,12 +40,13 @@
 #include <sys/isa_defs.h>
 
 long double
-scalbl(long double x, long double fn) {
-	int *py = (int *) &fn, n;
+scalbl(long double x, long double fn)
+{
+	int *py = (int *)&fn, n;
 	long double z;
 
 	if (isnanl(x) || isnanl(fn))
-		return x * fn;
+		return (x * fn);
 
 	/* fn is +/-Inf */
 #if defined(_BIG_ENDIAN)
@@ -54,19 +56,22 @@
 	if ((py[2] & 0x7fff) == 0x7fff) {
 		if ((py[2] & 0x8000) != 0)
 #endif
-			return x / (-fn);
+			return (x / (-fn));
 		else
-			return x * fn;
+			return (x * fn);
 	}
+
 	if (rintl(fn) != fn)
-		return (fn - fn) / (fn - fn);
-	if (fn > 65000.0L)
+		return ((fn - fn) / (fn - fn));
+
+	if (fn > 65000.0L) {
 		z = scalbnl(x, 65000);
-	else if (-fn > 65000.0L)
+	} else if (-fn > 65000.0L) {
 		z = scalbnl(x, -65000);
-	else {
-		n = (int) fn;
+	} else {
+		n = (int)fn;
 		z = scalbnl(x, n);
 	}
-	return z;
+
+	return (z);
 }
--- old/usr/src/lib/libm/common/LD/signgaml.c	2019-06-06 20:38:22.445785850 +0000
+++ new/usr/src/lib/libm/common/LD/signgaml.c	2019-06-06 20:38:22.461831003 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/LD/significandl.c	2019-06-06 20:38:22.902715544 +0000
+++ new/usr/src/lib/libm/common/LD/significandl.c	2019-06-06 20:38:22.919108811 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,7 +33,8 @@
 #include "libm.h"
 
 long double
-significandl(long double x) {
+significandl(long double x)
+{
 	if (ISZEROL(x) || XBIASED_EXP(x) == 0x7fff)	/* 0/+-Inf/NaN */
 		return (x + x);
 	else
--- old/usr/src/lib/libm/common/LD/sincosl.c	2019-06-06 20:38:23.354523377 +0000
+++ new/usr/src/lib/libm/common/LD/sincosl.c	2019-06-06 20:38:23.372005803 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,8 +30,9 @@
 
 #pragma weak __sincosl = sincosl
 
-/* INDENT OFF */
-/* cosl(x)
+/* BEGIN CSTYLED */
+/*
+ * cosl(x)
  * Table look-up algorithm by K.C. Ng, November, 1989.
  *
  * kernel function:
@@ -59,7 +61,7 @@
  * Accuracy:
  *	computer TRIG(x) returns trig(x) nearly rounded.
  */
-/* INDENT ON */
+/* END CSTYLED */
 
 #include "libm.h"
 #include "longdouble.h"
@@ -67,11 +69,13 @@
 #include <sys/isa_defs.h>
 
 void
-sincosl(long double x, long double *s, long double *c) {
+sincosl(long double x, long double *s, long double *c)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
+
 #if defined(__i386) || defined(__amd64)
-	int *px = (int *) &x;
+	int *px = (int *)&x;
 #endif
 
 	/* trig(Inf or NaN) is NaN */
@@ -84,17 +88,19 @@
 #if defined(__i386) || defined(__amd64)
 	XTOI(px, ix);
 #else
-	ix = *(int *) &x;
+	ix = *(int *)&x;
 #endif
 
 	/* |x| ~< pi/4 */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)
-		*s = __k_sincosl(x, z, c);
 
+	if (ix <= 0x3ffe9220) {
+		*s = __k_sincosl(x, z, c);
+	}
 	/* argument reduction needed */
 	else {
 		n = __rem_pio2l(x, y);
+
 		switch (n & 3) {
 		case 0:
 			*s = __k_sincosl(y[0], y[1], c);
--- old/usr/src/lib/libm/common/LD/sincospil.c	2019-06-06 20:38:23.800054836 +0000
+++ new/usr/src/lib/libm/common/LD/sincospil.c	2019-06-06 20:38:23.817344505 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -73,34 +74,38 @@
 
 #include <sys/isa_defs.h>
 
-#define I(q, m)	((int *) &(q))[m]
-#define U(q, m)	((unsigned *) &(q))[m]
+#define	I(q, m)				((int *)&(q))[m]
+#define	U(q, m)				((unsigned *)&(q))[m]
 #if defined(__i386) || defined(__amd64)
-#define LDBL_MOST_SIGNIF_I(ld)	((I(ld, 2) << 16) | (0xffff & (I(ld, 1) >> 15)))
-#define LDBL_LEAST_SIGNIF_U(ld)	U(ld, 0)
-#define PREC	64
-#define PRECM1	63
-#define PRECM2	62
+#define	LDBL_MOST_SIGNIF_I(ld)		((I(ld, 2) << 16) | (0xffff & (I(ld, \
+	1) >> 15)))
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, 0)
+#define	PREC				64
+#define	PRECM1				63
+#define	PRECM2				62
+
 static const long double twoPRECM2 = 9.223372036854775808000000000000000e+18L;
 #else
-#define LDBL_MOST_SIGNIF_I(ld)	I(ld, 0)
-#define LDBL_LEAST_SIGNIF_U(ld)	U(ld, sizeof(long double) / sizeof(int) - 1)
-#define PREC	113
-#define PRECM1	112
-#define PRECM2	111
+#define	LDBL_MOST_SIGNIF_I(ld)		I(ld, 0)
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, sizeof (long double) / \
+	sizeof (int) - 1)
+#define	PREC				113
+#define	PRECM1				112
+#define	PRECM2				111
+
 static const long double twoPRECM2 = 5.192296858534827628530496329220096e+33L;
 #endif
 
-static const long double
-zero	= 0.0L,
-quater	= 0.25L,
-one	= 1.0L,
-pi	= 3.141592653589793238462643383279502884197e+0000L,
-sqrth	= 0.707106781186547524400844362104849039284835937688474,
-tiny	= 1.0e-100;
+static const long double zero = 0.0L,
+	quater = 0.25L,
+	one = 1.0L,
+	pi = 3.141592653589793238462643383279502884197e+0000L,
+	sqrth = 0.707106781186547524400844362104849039284835937688474,
+	tiny = 1.0e-100;
 
 void
-sincospil(long double x, long double *s, long double *c) {
+sincospil(long double x, long double *s, long double *c)
+{
 	long double y, z, t;
 	int hx, n, k;
 	unsigned lx;
@@ -108,97 +113,99 @@
 	hx = LDBL_MOST_SIGNIF_I(x);
 	lx = LDBL_LEAST_SIGNIF_U(x);
 	k = ((hx & 0x7fff0000) >> 16) - 0x3fff;
+
 	if (k >= PRECM2) {		/* |x| >= 2**(Prec-2) */
 		if (k >= 16384) {
 			*s = *c = x - x;
-		}
-		else {
+		} else {
 			if (k >= PREC) {
 				*s = zero;
 				*c = one;
-			}
-			else if (k == PRECM1) {
+			} else if (k == PRECM1) {
 				if ((lx & 1) == 0) {
 					*s = zero;
 					*c = one;
-				}
-				else {
+				} else {
 					*s = -zero;
 					*c = -one;
 				}
-			}
-			else {	/* k = Prec - 2 */
+			} else { /* k = Prec - 2 */
 				if ((lx & 1) == 0) {
 					*s = zero;
 					*c = one;
-				}
-				else {
+				} else {
 					*s = one;
 					*c = zero;
 				}
+
 				if ((lx & 2) != 0) {
 					*s = -*s;
 					*c = -*c;
 				}
 			}
 		}
-	}
-	else if (k < -2) 	/* |x| < 0.25 */
+	} else if (k < -2) {		/* |x| < 0.25 */
 		*s = __k_sincosl(pi * fabsl(x), zero, c);
-	else {
+	} else {
 		/* y = |4x|, z = floor(y), and n = (int)(z mod 8.0) */
 		y = 4.0L * fabsl(x);
+
 		if (k < PRECM2) {
 			z = y + twoPRECM2;
 			n = LDBL_LEAST_SIGNIF_U(z) & 7;	/* 3 LSb of z */
 			t = z - twoPRECM2;
 			k = 0;
-			if (t == y)
+
+			if (t == y) {
 				k = 1;
-			else if (t > y) {
+			} else if (t > y) {
 				n -= 1;
 				t = quater + (y - t) * quater;
-			}
-			else
+			} else {
 				t = (y - t) * quater;
-		}
-		else { 	/* k = Prec-3 */
+			}
+		} else { /* k = Prec-3 */
 			n = LDBL_LEAST_SIGNIF_U(y) & 7;	/* 3 LSb of z */
 			k = 1;
 		}
-		if (k) {	/* x = N/4 */
-			if ((n & 1) != 0)
+
+		if (k) {		/* x = N/4 */
+			if ((n & 1) != 0) {
 				*s = *c = sqrth + tiny;
-			else
-				if ((n & 2) == 0) {
-					*s = zero;
-					*c = one;
-				}
-				else {
-					*s = one;
-					*c = zero;
-				}
+			} else if ((n & 2) == 0) {
+				*s = zero;
+				*c = one;
+			} else {
+				*s = one;
+				*c = zero;
+			}
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 1) & 4) != 0)
 				*c = -*c;
-		}
-		else {
+		} else {
 			if ((n & 1) != 0)
 				t = quater - t;
+
 			if (((n + (n & 1)) & 2) == 0)
 				*s = __k_sincosl(pi * t, zero, c);
 			else
 				*c = __k_sincosl(pi * t, zero, s);
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 2) & 4) != 0)
 				*c = -*c;
 		}
 	}
+
 	if (hx < 0)
 		*s = -*s;
 }
+
 #undef U
 #undef LDBL_LEAST_SIGNIF_U
 #undef I
--- old/usr/src/lib/libm/common/LD/sinhl.c	2019-06-06 20:38:24.291143466 +0000
+++ new/usr/src/lib/libm/common/LD/sinhl.c	2019-06-06 20:38:24.309018875 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,7 +33,9 @@
 #include "libm.h"
 #include "longdouble.h"
 
-/* SINH(X)
+/* BEGIN CSTYLED */
+/*
+ * SINH(X)
  * RETURN THE HYPERBOLIC SINE OF X
  *
  * Method :
@@ -41,7 +44,7 @@
  *
  *	                                      EXPM1(x) + EXPM1(x)/(EXPM1(x)+1)
  *	    0 <= x <= lnovft     : SINH(x) := --------------------------------
- *			       		                      2
+ *			                                      2
  *
  *     lnovft <= x <  INF	 : SINH(x) := EXP(x-MEP1*ln2)*2**ME
  *
@@ -56,6 +59,7 @@
  *	only SINH(0)=0 is exact for finite argument.
  *
  */
+/* END CSTYLED */
 
 static const long double C[] = {
 	0.5L,
@@ -64,19 +68,21 @@
 	7.004447686242549087858985e-16L
 };
 
-#define	half	C[0]
-#define	one	C[1]
-#define	lnovft	C[2]
-#define	lnovlo	C[3]
+#define	half		C[0]
+#define	one		C[1]
+#define	lnovft		C[2]
+#define	lnovlo		C[3]
 
 long double
 sinhl(long double x)
 {
-	long double	r, t;
+	long double r, t;
 
 	if (!finitel(x))
-		return (x + x);	/* x is INF or NaN */
+		return (x + x);		/* x is INF or NaN */
+
 	r = fabsl(x);
+
 	if (r < lnovft) {
 		t = expm1l(r);
 		r = copysignl((t + t / (one + t)) * half, x);
@@ -84,5 +90,6 @@
 		r = copysignl(expl((r - lnovft) - lnovlo), x);
 		r = scalbnl(r, 16383);
 	}
+
 	return (r);
 }
--- old/usr/src/lib/libm/common/LD/sinl.c	2019-06-06 20:38:24.799300084 +0000
+++ new/usr/src/lib/libm/common/LD/sinl.c	2019-06-06 20:38:24.816938841 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,8 +30,9 @@
 
 #pragma weak __sinl = sinl
 
-/* INDENT OFF */
-/* sinl(x)
+/* BEGIN CSTYLED */
+/*
+ * sinl(x)
  * Table look-up algorithm by K.C. Ng, November, 1989.
  *
  * kernel function:
@@ -60,7 +62,7 @@
  * Accuracy:
  *	computer TRIG(x) returns trig(x) nearly rounded.
  */
-/* INDENT ON */
+/* END CSTYLED */
 
 #include "libm.h"
 #include "longdouble.h"
@@ -68,42 +70,47 @@
 #include <sys/isa_defs.h>
 
 long double
-sinl(long double x) {
+sinl(long double x)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
+
 #if defined(__i386) || defined(__amd64)
-	int *px = (int *) &x;
+	int *px = (int *)&x;
 #endif
 
 	/* sin(Inf or NaN) is NaN */
 	if (!finitel(x))
-		return x - x;
+		return (x - x);
 
 	/* High word of x. */
 #if defined(__i386) || defined(__amd64)
 	XTOI(px, ix);
 #else
-	ix = *(int *) &x;
+	ix = *(int *)&x;
 #endif
 	/* |x| ~< pi/4 */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)
-		return __k_sinl(x, z);
 
+	if (ix <= 0x3ffe9220) {
+		return (__k_sinl(x, z));
+	}
 	/* argument reduction needed */
 	else {
 		n = __rem_pio2l(x, y);
+
 		switch (n & 3) {
 		case 0:
-			return __k_sinl(y[0], y[1]);
+			return (__k_sinl(y[0], y[1]));
 		case 1:
-			return __k_cosl(y[0], y[1]);
+			return (__k_cosl(y[0], y[1]));
 		case 2:
-			return -__k_sinl(y[0], y[1]);
+			return (-__k_sinl(y[0], y[1]));
 		case 3:
-			return -__k_cosl(y[0], y[1]);
-		/* NOTREACHED */
+			return (-__k_cosl(y[0], y[1]));
+			/* NOTREACHED */
 		}
 	}
-	return 0.0L;
+
+	return (0.0L);
 }
--- old/usr/src/lib/libm/common/LD/sinpil.c	2019-06-06 20:38:25.304254425 +0000
+++ new/usr/src/lib/libm/common/LD/sinpil.c	2019-06-06 20:38:25.322484105 +0000
@@ -22,12 +22,15 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* long double sinpil(long double x),
+/* BEGIN CSTYLED */
+/*
+ * long double sinpil(long double x),
  * return long double precision sinl(pi*x).
  *
  * Algorithm, 10/17/2002, K.C. Ng
@@ -66,40 +69,45 @@
  * high (tpi_h) and low (tpi_l) parts and call __k_sin/cos(tip_h, tip_lo)
  * instead.
  */
+/* END CSTYLED */
 
 #include "libm.h"
 #include "longdouble.h"
 
 #include <sys/isa_defs.h>
 
-#define I(q, m)	((int *) &(q))[m]
-#define U(q, m)	((unsigned *) &(q))[m]
+#define	I(q, m)				((int *)&(q))[m]
+#define	U(q, m)				((unsigned *)&(q))[m]
 #if defined(__i386) || defined(__amd64)
-#define LDBL_MOST_SIGNIF_I(ld)	((I(ld, 2) << 16) | (0xffff & (I(ld, 1) >> 15)))
-#define LDBL_LEAST_SIGNIF_U(ld)	U(ld, 0)
-#define PREC	64
-#define PRECM1	63
-#define PRECM2	62
+#define	LDBL_MOST_SIGNIF_I(ld)		((I(ld, 2) << 16) | (0xffff & (I(ld, \
+	1) >> 15)))
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, 0)
+#define	PREC				64
+#define	PRECM1				63
+#define	PRECM2				62
+
 static const long double twoPRECM2 = 9.223372036854775808000000000000000e+18L;
 #else
-#define LDBL_MOST_SIGNIF_I(ld)	I(ld, 0)
-#define LDBL_LEAST_SIGNIF_U(ld)	U(ld, sizeof(long double) / sizeof(int) - 1)
-#define PREC	113
-#define PRECM1	112
-#define PRECM2	111
+#define	LDBL_MOST_SIGNIF_I(ld)		I(ld, 0)
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, sizeof (long double) / \
+	sizeof (int) - 1)
+#define	PREC				113
+#define	PRECM1				112
+#define	PRECM2				111
+
 static const long double twoPRECM2 = 5.192296858534827628530496329220096e+33L;
 #endif
 
-static const long double
-zero	= 0.0L,
-quater	= 0.25L,
-one	= 1.0L,
-pi	= 3.141592653589793238462643383279502884197e+0000L,
-sqrth   = 0.707106781186547524400844362104849039284835937688474,
-tiny    = 1.0e-100;
+static const long double zero = 0.0L,
+	quater = 0.25L,
+	one = 1.0L,
+	pi = 3.141592653589793238462643383279502884197e+0000L,
+	sqrth = 0.707106781186547524400844362104849039284835937688474,
+	tiny = 1.0e-100;
 
 long double
-sinpil(long double x) {
+sinpil(long double x)
+{
 	long double y, z, t;
 	int hx, n, k;
 	unsigned lx;
@@ -107,65 +115,72 @@
 	hx = LDBL_MOST_SIGNIF_I(x);
 	lx = LDBL_LEAST_SIGNIF_U(x);
 	k = ((hx & 0x7fff0000) >> 16) - 0x3fff;
+
 	if (k >= PRECM2) {		/* |x| >= 2**(Prec-2) */
-		if (k >= 16384)
+		if (k >= 16384) {
 			y = x - x;
-		else {
-			if (k >= PREC)
+		} else {
+			if (k >= PREC) {
 				y = zero;
-			else if (k == PRECM1)
-				y = (lx & 1) == 0 ? zero: -zero;
-			else {	/* k = Prec - 2 */
+			} else if (k == PRECM1) {
+				y = (lx & 1) == 0 ? zero : -zero;
+			} else { /* k = Prec - 2 */
 				y = (lx & 1) == 0 ? zero : one;
+
 				if ((lx & 2) != 0)
 					y = -y;
 			}
 		}
-	}
-	else if (k < -2) 	/* |x| < 0.25 */
+	} else if (k < -2) {		/* |x| < 0.25 */
 		y = __k_sinl(pi * fabsl(x), zero);
-	else {
+	} else {
 		/* y = |4x|, z = floor(y), and n = (int)(z mod 8.0) */
 		y = 4.0L * fabsl(x);
+
 		if (k < PRECM2) {
 			z = y + twoPRECM2;
 			n = LDBL_LEAST_SIGNIF_U(z) & 7;	/* 3 LSb of z */
 			t = z - twoPRECM2;
 			k = 0;
-			if (t == y)
+
+			if (t == y) {
 				k = 1;
-			else if (t > y) {
+			} else if (t > y) {
 				n -= 1;
 				t = quater + (y - t) * quater;
-			}
-			else
+			} else {
 				t = (y - t) * quater;
-		}
-		else { 	/* k = Prec-3 */
+			}
+		} else { /* k = Prec-3 */
 			n = LDBL_LEAST_SIGNIF_U(y) & 7;	/* 3 LSb of z */
 			k = 1;
 		}
-		if (k) {	/* x = N/4 */
+
+		if (k) {		/* x = N/4 */
 			if ((n & 1) != 0)
 				y = sqrth + tiny;
 			else
 				y = (n & 2) == 0 ? zero : one;
+
 			if ((n & 4) != 0)
 				y = -y;
-		}
-		else {
+		} else {
 			if ((n & 1) != 0)
 				t = quater - t;
+
 			if (((n + (n & 1)) & 2) == 0)
 				y = __k_sinl(pi * t, zero);
 			else
 				y = __k_cosl(pi * t, zero);
+
 			if ((n & 4) != 0)
 				y = -y;
 		}
 	}
-	return hx >= 0 ? y : -y;
+
+	return (hx >= 0 ? y : -y);
 }
+
 #undef U
 #undef LDBL_LEAST_SIGNIF_U
 #undef I
--- old/usr/src/lib/libm/common/LD/tanhl.c	2019-06-06 20:38:25.810694489 +0000
+++ new/usr/src/lib/libm/common/LD/tanhl.c	2019-06-06 20:38:25.830027416 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -45,9 +46,9 @@
  *     threshold <  x <= INF       :  tanhl(x) := 1.
  *
  * where
- *	single : 	small = 1.e-5		threshold = 11.0
- *	double : 	small = 1.e-10		threshold = 22.0
- *	quad   : 	small = 1.e-20		threshold = 45.0
+ *	single :        small = 1.e-5		threshold = 11.0
+ *	double :        small = 1.e-10		threshold = 22.0
+ *	quad   :        small = 1.e-20		threshold = 45.0
  *
  * Note: threshold was chosen so that
  *		fl(1.0+2/(expm1(2*threshold)+2)) == 1.
@@ -60,41 +61,49 @@
 #include "libm.h"
 #include "longdouble.h"
 
-static const long double small = 1.0e-20L, one = 1.0, two = 2.0,
+static const long double small = 1.0e-20L,
+	one = 1.0,
+	two = 2.0,
 #ifndef lint
 	big = 1.0e+20L,
 #endif
 	threshold = 45.0L;
 
 long double
-tanhl(long double x) {
+tanhl(long double x)
+{
 	long double t, y, z;
 	int signx;
+
 #ifndef lint
 	volatile long double dummy __unused;
 #endif
 
 	if (isnanl(x))
 		return (x + x);		/* x is NaN */
+
 	signx = signbitl(x);
 	t = fabsl(x);
 	z = one;
+
 	if (t <= threshold) {
-		if (t > one)
+		if (t > one) {
 			z = one - two / (expm1l(t + t) + two);
-		else if (t > small) {
+		} else if (t > small) {
 			y = expm1l(-t - t);
 			z = -y / (y + two);
 		} else {
 #ifndef lint
 			dummy = t + big;
-							/* inexact if t != 0 */
+			/* inexact if t != 0 */
 #endif
 			return (x);
 		}
-	} else if (!finitel(t))
+	} else if (!finitel(t)) {
 		return (copysignl(one, x));
-	else
+	} else {
 		return (signx ? -z + small * small : z - small * small);
+	}
+
 	return (signx ? -z : z);
 }
--- old/usr/src/lib/libm/common/LD/tanl.c	2019-06-06 20:38:26.318831204 +0000
+++ new/usr/src/lib/libm/common/LD/tanl.c	2019-06-06 20:38:26.336809644 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,8 +30,9 @@
 
 #pragma weak __tanl = tanl
 
-/* INDENT OFF */
-/* cosl(x)
+/* BEGIN CSTYLED */
+/*
+ * cosl(x)
  * Table look-up algorithm by K.C. Ng, November, 1989.
  *
  * kernel function:
@@ -59,7 +61,7 @@
  * Accuracy:
  *	computer TRIG(x) returns trig(x) nearly rounded.
  */
-/* INDENT ON */
+/* END CSTYLED */
 
 #include "libm.h"
 #include "longdouble.h"
@@ -67,32 +69,35 @@
 #include <sys/isa_defs.h>
 
 long double
-tanl(long double x) {
+tanl(long double x)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
+
 #if defined(__i386) || defined(__amd64)
-	int *px = (int *) &x;
+	int *px = (int *)&x;
 #endif
 
 	/* trig(Inf or NaN) is NaN */
 	if (!finitel(x))
-		return x - x;
+		return (x - x);
 
 	/* High word of x. */
 #if defined(__i386) || defined(__amd64)
 	XTOI(px, ix);
 #else
-	ix = *(int *) &x;
+	ix = *(int *)&x;
 #endif
 
 	/* |x| ~< pi/4 */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)
-		return __k_tanl(x, z, 0);
 
+	if (ix <= 0x3ffe9220) {
+		return (__k_tanl(x, z, 0));
+	}
 	/* argument reduction needed */
 	else {
 		n = __rem_pio2l(x, y);
-		return __k_tanl(y[0], y[1], n & 1);
+		return (__k_tanl(y[0], y[1], n & 1));
 	}
 }
--- old/usr/src/lib/libm/common/Q/_TBL_atanl.c	2019-06-06 20:38:26.826604470 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_atanl.c	2019-06-06 20:38:26.844099723 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/Q/_TBL_cosl.c	2019-06-06 20:38:27.315194761 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_cosl.c	2019-06-06 20:38:27.334525984 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/Q/_TBL_expl.c	2019-06-06 20:38:27.768034396 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_expl.c	2019-06-06 20:38:27.784385841 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/Q/_TBL_expm1l.c	2019-06-06 20:38:28.238293862 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_expm1l.c	2019-06-06 20:38:28.255012941 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -200,6 +201,7 @@
 	-1.2578125000000000000000000000000036593e+00L,
 	-1.2734375000000000000000000000000005778e+00L,
 };
+
 const long double _TBL_expm1l[] = {
 	+7.8430972064479776934535597601230757455e-03L,
 	+2.3714316602357916968850532165767719684e-02L,
--- old/usr/src/lib/libm/common/Q/_TBL_ipio2l.c	2019-06-06 20:38:28.755606327 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_ipio2l.c	2019-06-06 20:38:28.773725324 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,7 +35,7 @@
 
 #include "libm.h"
 
-const int _TBL_ipio2l_inf[] = { /* by DHBailey MP package */
+const int _TBL_ipio2l_inf[] = {		/* by DHBailey MP package */
 	0xA2F983, 0x6E4E44, 0x1529FC, 0x2757D1, 0xF534DD, 0xC0DB62,
 	0x95993C, 0x439041, 0xFE5163, 0xABDEBB, 0xC561B7, 0x246E3A,
 	0x424DD2, 0xE00649, 0x2EEA09, 0xD1921C, 0xFE1DEB, 0x1CB129,
@@ -346,6 +347,7 @@
 	0xF129DE, 0x49C2D6, 0x9641D2, 0xC4747C, 0x220804, 0x503F05,
 	0x7E274F, 0xCA83D9, 0x9D6495, 0x0E5039,
 };
+
 const int _TBL_ipio2l_53[] = {
 	0xA2F983, 0x6E4E44, 0x16F3C4, 0xEA69B5, 0xD3E131, 0x60E1D2,
 	0xD7982A, 0xC031F5, 0xD67BCC, 0xFD1375, 0x60919B, 0x3FA0BB,
--- old/usr/src/lib/libm/common/Q/_TBL_logl.c	2019-06-06 20:38:29.290877851 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_logl.c	2019-06-06 20:38:29.308392326 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/Q/_TBL_sinl.c	2019-06-06 20:38:29.806146569 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_sinl.c	2019-06-06 20:38:29.824676801 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/Q/_TBL_tanl.c	2019-06-06 20:38:30.334661508 +0000
+++ new/usr/src/lib/libm/common/Q/_TBL_tanl.c	2019-06-06 20:38:30.356124562 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/Q/__cosl.c	2019-06-06 20:38:30.870794826 +0000
+++ new/usr/src/lib/libm/common/Q/__cosl.c	2019-06-06 20:38:30.891022573 +0000
@@ -22,11 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
+/* BEGIN CSTYLED */
 /*
  * __k_cosl(long double x, long double y)
  * kernel cos function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -46,7 +48,7 @@
  *		ht = (hx + 0x400)&0x7ffff800	(round x to a break point t)
  *		lt = 0
  *		i  = (hy-0x3ffc4000)>>11;	(i<=64)
- *		x' = (x - t)+y 			(|x'| ~<= 2^-7
+ *		x' = (x - t)+y                  (|x'| ~<= 2^-7
  *	   By
  *		cos(t+x')
  *		  = cos(t)cos(x')-sin(t)sin(x')
@@ -60,75 +62,88 @@
  *		z = x*x;
  *		cos(t+x) = a+(b+ (-c*x*(1+z*(pp1+z*pp2))+a*(z*(qq1+z*qq2)))
  */
+/* END CSTYLED */
 
 #include "libm.h"
 
 extern const long double _TBL_cosl_hi[], _TBL_cosl_lo[], _TBL_sinl_hi[];
-static const long double
-	one	= 1.0L,
+static const long double one = 1.0L;
+
 /*
  *                   3           11       -122.32
  * |sin(x) - (x+pp1*x +...+ pp5*x  )| <= 2        for |x|<1/64
  */
-	pp1	= -1.666666666666666666666666666586782940810e-0001L,
-	pp2	= +8.333333333333333333333003723660929317540e-0003L,
-	pp3	= -1.984126984126984076045903483778337804470e-0004L,
-	pp4	= +2.755731922361906641319723106210900949413e-0006L,
-	pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = +8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = +2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  *		    2	         16       -117.11
  * |cos(x) - (1+q1*x + ... + q8*x  )| <= 2        for |x|<= 0.15625
  */
-	q1	= -4.999999999999999999999999999999756416975e-0001L,
-	q2	= +4.166666666666666666666666664006066577258e-0002L,
-	q3	= -1.388888888888888888888877700363937169637e-0003L,
-	q4	= +2.480158730158730158494468463031814083559e-0005L,
-	q5	= -2.755731922398586276322819250356005542871e-0007L,
-	q6	= +2.087675698767424261441959760729854017855e-0009L,
-	q7	= -1.147074481239662089072452129010790774761e-0011L,
-	q8	= +4.777761647399651599730663422263531034782e-0014L,
+static const long double
+	q1 = -4.999999999999999999999999999999756416975e-0001L,
+	q2 = +4.166666666666666666666666664006066577258e-0002L,
+	q3 = -1.388888888888888888888877700363937169637e-0003L,
+	q4 = +2.480158730158730158494468463031814083559e-0005L,
+	q5 = -2.755731922398586276322819250356005542871e-0007L,
+	q6 = +2.087675698767424261441959760729854017855e-0009L,
+	q7 = -1.147074481239662089072452129010790774761e-0011L,
+	q8 = +4.777761647399651599730663422263531034782e-0014L;
+
 /*
  *		     2	         10       -123.84
  * |cos(x) - (1+qq1*x +...+ qq5*x  )| <= 2        for |x|<=1/128
  */
-	qq1	= -4.999999999999999999999999999999378373641e-0001L,
-	qq2	= +4.166666666666666666666665478399327703130e-0002L,
-	qq3	= -1.388888888888888888058211230618051613494e-0003L,
-	qq4	= +2.480158730156105377771585658905303111866e-0005L,
-	qq5	= -2.755728099762526325736488376695157008736e-0007L;
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = +4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = +2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
 
 #define	i0	0
 
 long double
-__k_cosl(long double x, long double y) {
+__k_cosl(long double x, long double y)
+{
 	long double a, t, z, w;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0L;
 	hx = px[i0];
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc4000) {
 		if (ix < 0x3fc60000)
-			if ((i = (int) x) == 0)
-				return (one);	/* generate inexact */
+			if ((i = (int)x) == 0)
+				return (one);
+
+		/* generate inexact */
 		z = x * x;
 
-		if (ix < 0x3ff80000)	/* 0.0078125 */
-			return one + z * (qq1 + z * (qq2 + z * (qq3 +
-				z * (qq4 + z * qq5))));
-		else
-			return one + z * (q1 + z * (q2 + z * (q3 +
-				z * (q4 + z * (q5 + z * (q6 + z * (q7 +
-				z * q8)))))));
+		if (ix < 0x3ff80000) {	/* 0.0078125 */
+			return (one + z * (qq1 + z * (qq2 + z * (qq3 + z *
+			    (qq4 + z * qq5)))));
+		} else {
+			return (one + z * (q1 + z * (q2 + z * (q3 + z * (q4 +
+			    z * (q5 + z * (q6 + z * (q7 + z * q8))))))));
+		}
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 	pt[i0] = j;
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a = _TBL_cosl_hi[i];
 	z = x * x;
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
--- old/usr/src/lib/libm/common/Q/__lgammal.c	2019-06-06 20:38:31.405870103 +0000
+++ new/usr/src/lib/libm/common/Q/__lgammal.c	2019-06-06 20:38:31.423938054 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -41,8 +42,8 @@
  *
  *
  * Note 1. Since gamma(1+s)=s*gamma(s), hence
- *	   	lgamma(1+s) = log(s) + lgamma(s), or
- *	   	lgamma(s) = lgamma(1+s) - log(s).
+ *	        lgamma(1+s) = log(s) + lgamma(s), or
+ *	        lgamma(s) = lgamma(1+s) - log(s).
  *	   When s is really tiny (like roundoff), lgamma(1+s) ~ s(1-enler)
  *	   Hence lgamma(s) ~ -log(s) for tiny s
  *
@@ -56,342 +57,383 @@
 static long double polytail(long double);
 static long double primary(long double);
 
-static const long double
-c0 =	 0.0L,
-ch = 	 0.5L,
-c1 =	 1.0L,
-c2 =	 2.0L,
-c3 =	 3.0L,
-c4 =	 4.0L,
-c5 =	 5.0L,
-c6 =	 6.0L,
-pi =	 3.1415926535897932384626433832795028841971L,
-tiny =   1.0e-40L;
+static const long double c0 = 0.0L,
+	ch = 0.5L,
+	c1 = 1.0L,
+	c2 = 2.0L,
+	c3 = 3.0L,
+	c4 = 4.0L,
+	c5 = 5.0L,
+	c6 = 6.0L,
+	pi = 3.1415926535897932384626433832795028841971L,
+	tiny = 1.0e-40L;
 
 long double
-__k_lgammal(long double x, int *signgamlp) {
-	long double t,y;
+__k_lgammal(long double x, int *signgamlp)
+{
+	long double t, y;
 	int i;
 
-    /* purge off +-inf, NaN and negative arguments */
-	if (!finitel(x)) return x*x;
+	/* purge off +-inf, NaN and negative arguments */
+	if (!finitel(x))
+		return (x * x);
+
 	*signgamlp = 1;
-	if (signbitl(x)) return (neg(x,signgamlp));
 
-    /* for x < 8.0 */
-	if (x<8.0L) {
-	    y = anintl(x);
-	    i = (int) y;
-	    switch(i) {
-	    case 0:
-		if (x<1.0e-40L) return -logl(x); else
-		return (primary(x)-log1pl(x))-logl(x);
-	    case 1:
-		return primary(x-y)-logl(x);
-	    case 2:
-		return primary(x-y);
-	    case 3:
-		return primary(x-y)+logl(x-c1);
-	    case 4:
-		return primary(x-y)+logl((x-c1)*(x-c2));
-	    case 5:
-		return primary(x-y)+logl((x-c1)*(x-c2)*(x-c3));
-	    case 6:
-		return primary(x-y)+logl((x-c1)*(x-c2)*(x-c3)*(x-c4));
-	    case 7:
-		return primary(x-y)+logl((x-c1)*(x-c2)*(x-c3)*(x-c4)*(x-c5));
-	    case 8:
-		return primary(x-y)+
-			logl((x-c1)*(x-c2)*(x-c3)*(x-c4)*(x-c5)*(x-c6));
-	    }
+	if (signbitl(x))
+		return (neg(x, signgamlp));
+
+	/* for x < 8.0 */
+	if (x < 8.0L) {
+		y = anintl(x);
+		i = (int)y;
+
+		switch (i) {
+		case 0:
+
+			if (x < 1.0e-40L)
+				return (-logl(x));
+			else
+				return ((primary(x) - log1pl(x)) - logl(x));
+
+		case 1:
+			return (primary(x - y) - logl(x));
+		case 2:
+			return (primary(x - y));
+		case 3:
+			return (primary(x - y) + logl(x - c1));
+		case 4:
+			return (primary(x - y) + logl((x - c1) * (x - c2)));
+		case 5:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3)));
+		case 6:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3) * (x - c4)));
+		case 7:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3) * (x - c4) * (x - c5)));
+		case 8:
+			return (primary(x - y) + logl((x - c1) * (x - c2) * (x -
+			    c3) * (x - c4) * (x - c5) * (x - c6)));
+		}
 	}
 
-    /* 8.0 <= x < 1.0e40 */
+	/* 8.0 <= x < 1.0e40 */
 	if (x < 1.0e40L) {
-	    t = logl(x);
-	    return x*(t-c1)-(ch*t-polytail(c1/x));
+		t = logl(x);
+		return (x * (t - c1) - (ch * t - polytail(c1 / x)));
 	}
 
-    /* 1.0e40 <= x <= inf */
-	return x*(logl(x)-c1);
+	/* 1.0e40 <= x <= inf */
+	return (x * (logl(x) - c1));
 }
 
-static const long double an1[] = {		/* 20 terms */
-  -0.0772156649015328606065120900824024309741L,
-   3.224670334241132182362075833230130289059e-0001L,
-  -6.735230105319809513324605383668929964120e-0002L,
-   2.058080842778454787900092432928910226297e-0002L,
-  -7.385551028673985266273054086081102125704e-0003L,
-   2.890510330741523285758867304409628648727e-0003L,
-  -1.192753911703260976581414338096267498555e-0003L,
-   5.096695247430424562831956662855697824035e-0004L,
-  -2.231547584535777978926798502084300123638e-0004L,
-   9.945751278186384670278268034322157947635e-0005L,
-  -4.492623673665547726647838474125147631082e-0005L,
-   2.050721280617796810096993154281561168706e-0005L,
-  -9.439487785617396552092393234044767313568e-0006L,
-   4.374872903516051510689234173139793159340e-0006L,
-  -2.039156676413643091040459825776029327487e-0006L,
-   9.555777181318621470466563543806211523634e-0007L,
-  -4.468344919709630637558538313482398989638e-0007L,
-   2.216738086090045781773004477831059444178e-0007L,
-  -7.472783403418388455860445842543843485916e-0008L,
-   8.777317930927149922056782132706238921648e-0008L,
+static const long double an1[] = {	/* 20 terms */
+	-0.0772156649015328606065120900824024309741L,
+	3.224670334241132182362075833230130289059e-0001L,
+	-6.735230105319809513324605383668929964120e-0002L,
+	2.058080842778454787900092432928910226297e-0002L,
+	-7.385551028673985266273054086081102125704e-0003L,
+	2.890510330741523285758867304409628648727e-0003L,
+	-1.192753911703260976581414338096267498555e-0003L,
+	5.096695247430424562831956662855697824035e-0004L,
+	-2.231547584535777978926798502084300123638e-0004L,
+	9.945751278186384670278268034322157947635e-0005L,
+	-4.492623673665547726647838474125147631082e-0005L,
+	2.050721280617796810096993154281561168706e-0005L,
+	-9.439487785617396552092393234044767313568e-0006L,
+	4.374872903516051510689234173139793159340e-0006L,
+	-2.039156676413643091040459825776029327487e-0006L,
+	9.555777181318621470466563543806211523634e-0007L,
+	-4.468344919709630637558538313482398989638e-0007L,
+	2.216738086090045781773004477831059444178e-0007L,
+	-7.472783403418388455860445842543843485916e-0008L,
+	8.777317930927149922056782132706238921648e-0008L,
 };
 
-static const long double an2[] = {		/* 20 terms */
-  -.0772156649015328606062692723698127607018L,
-   3.224670334241132182635552349060279118047e-0001L,
-  -6.735230105319809367555642883133994818325e-0002L,
-   2.058080842778459676880822202762143671813e-0002L,
-  -7.385551028672828216011343150077846918930e-0003L,
-   2.890510330762060607399561536905727853178e-0003L,
-  -1.192753911419623262328187532759756368041e-0003L,
-   5.096695278636456678258091134532258618614e-0004L,
-  -2.231547306817535743052975194022893369135e-0004L,
-   9.945771461633313282744264853986643877087e-0005L,
-  -4.492503279458972037926876061257489481619e-0005L,
-   2.051311416812082875492678651369394595613e-0005L,
-  -9.415778282365955203915850761537462941165e-0006L,
-   4.452428829045147098722932981088650055919e-0006L,
-  -1.835024727987632579886951760650722695781e-0006L,
-   1.379783080658545009579060714946381462565e-0006L,
-   2.282637532109775156769736768748402175238e-0007L,
-   1.002577375515900191362119718128149880168e-0006L,
-   5.177028794262638311939991106423220002463e-0007L,
-   3.127947245174847104122426445937830555755e-0007L,
+static const long double an2[] = {	/* 20 terms */
+	-.0772156649015328606062692723698127607018L,
+	3.224670334241132182635552349060279118047e-0001L,
+	-6.735230105319809367555642883133994818325e-0002L,
+	2.058080842778459676880822202762143671813e-0002L,
+	-7.385551028672828216011343150077846918930e-0003L,
+	2.890510330762060607399561536905727853178e-0003L,
+	-1.192753911419623262328187532759756368041e-0003L,
+	5.096695278636456678258091134532258618614e-0004L,
+	-2.231547306817535743052975194022893369135e-0004L,
+	9.945771461633313282744264853986643877087e-0005L,
+	-4.492503279458972037926876061257489481619e-0005L,
+	2.051311416812082875492678651369394595613e-0005L,
+	-9.415778282365955203915850761537462941165e-0006L,
+	4.452428829045147098722932981088650055919e-0006L,
+	-1.835024727987632579886951760650722695781e-0006L,
+	1.379783080658545009579060714946381462565e-0006L,
+	2.282637532109775156769736768748402175238e-0007L,
+	1.002577375515900191362119718128149880168e-0006L,
+	5.177028794262638311939991106423220002463e-0007L,
+	3.127947245174847104122426445937830555755e-0007L,
 };
 
-static const long double an3[] = {		/* 20 terms */
-  -.0772156649015328227870646417729220690875L,
-   3.224670334241156699881788955959915250365e-0001L,
-  -6.735230105312273571375431059744975563170e-0002L,
-   2.058080842924464587662846071337083809005e-0002L,
-  -7.385551008677271654723604653956131791619e-0003L,
-   2.890510536479782086197110272583833176602e-0003L,
-  -1.192752262076857692740571567808259138697e-0003L,
-   5.096800771149805289371135155128380707889e-0004L,
-  -2.231000836682831335505058492409860123647e-0004L,
-   9.968912171073936803871803966360595275047e-0005L,
-  -4.412020779327746243544387946167256187258e-0005L,
-   2.281374113541454151067016632998630209049e-0005L,
-  -4.028361291428629491824694655287954266830e-0006L,
-   1.470694920619518924598956849226530750139e-0005L,
-   1.381686137617987197975289545582377713772e-0005L,
-   2.012493539265777728944759982054970441601e-0005L,
-   1.723917864208965490251560644681933675799e-0005L,
-   1.202954035243788300138608765425123713395e-0005L,
-   5.079851887558623092776296577030850938146e-0006L,
-   1.220657945824153751555138592006604026282e-0006L,
+static const long double an3[] = {	/* 20 terms */
+	-.0772156649015328227870646417729220690875L,
+	3.224670334241156699881788955959915250365e-0001L,
+	-6.735230105312273571375431059744975563170e-0002L,
+	2.058080842924464587662846071337083809005e-0002L,
+	-7.385551008677271654723604653956131791619e-0003L,
+	2.890510536479782086197110272583833176602e-0003L,
+	-1.192752262076857692740571567808259138697e-0003L,
+	5.096800771149805289371135155128380707889e-0004L,
+	-2.231000836682831335505058492409860123647e-0004L,
+	9.968912171073936803871803966360595275047e-0005L,
+	-4.412020779327746243544387946167256187258e-0005L,
+	2.281374113541454151067016632998630209049e-0005L,
+	-4.028361291428629491824694655287954266830e-0006L,
+	1.470694920619518924598956849226530750139e-0005L,
+	1.381686137617987197975289545582377713772e-0005L,
+	2.012493539265777728944759982054970441601e-0005L,
+	1.723917864208965490251560644681933675799e-0005L,
+	1.202954035243788300138608765425123713395e-0005L,
+	5.079851887558623092776296577030850938146e-0006L,
+	1.220657945824153751555138592006604026282e-0006L,
 };
 
-static const long double an4[] = {		/* 21 terms */
-  -.0772156649015732285350261816697540392371L,
-   3.224670334221752060691751340365212226097e-0001L,
-  -6.735230109744009693977755991488196368279e-0002L,
-   2.058080778913037626909954141611580783216e-0002L,
-  -7.385557567931505621170483708950557506819e-0003L,
-   2.890459838416254326340844289785254883436e-0003L,
-  -1.193059036207136762877351596966718455737e-0003L,
-   5.081914708100372836613371356529568937869e-0004L,
-  -2.289855016133600313131553005982542045338e-0004L,
-   8.053454537980585879620331053833498511491e-0005L,
-  -9.574620532104845821243493405855672438998e-0005L,
-  -9.269085628207107155601445001196317715686e-0005L,
-  -2.183276779859490461716196344776208220180e-0004L,
-  -3.134834305597571096452454999737269668868e-0004L,
-  -3.973878894951937437018305986901392888619e-0004L,
-  -3.953352414899222799161275564386488057119e-0004L,
-  -3.136740932204038779362660900621212816511e-0004L,
-  -1.884502253819634073946130825196078627664e-0004L,
-  -8.192655799958926853585332542123631379301e-0005L,
-  -2.292183750010571062891605074281744854436e-0005L,
-  -3.223980628729716864927724265781406614294e-0006L,
+static const long double an4[] = {	/* 21 terms */
+	-.0772156649015732285350261816697540392371L,
+	3.224670334221752060691751340365212226097e-0001L,
+	-6.735230109744009693977755991488196368279e-0002L,
+	2.058080778913037626909954141611580783216e-0002L,
+	-7.385557567931505621170483708950557506819e-0003L,
+	2.890459838416254326340844289785254883436e-0003L,
+	-1.193059036207136762877351596966718455737e-0003L,
+	5.081914708100372836613371356529568937869e-0004L,
+	-2.289855016133600313131553005982542045338e-0004L,
+	8.053454537980585879620331053833498511491e-0005L,
+	-9.574620532104845821243493405855672438998e-0005L,
+	-9.269085628207107155601445001196317715686e-0005L,
+	-2.183276779859490461716196344776208220180e-0004L,
+	-3.134834305597571096452454999737269668868e-0004L,
+	-3.973878894951937437018305986901392888619e-0004L,
+	-3.953352414899222799161275564386488057119e-0004L,
+	-3.136740932204038779362660900621212816511e-0004L,
+	-1.884502253819634073946130825196078627664e-0004L,
+	-8.192655799958926853585332542123631379301e-0005L,
+	-2.292183750010571062891605074281744854436e-0005L,
+	-3.223980628729716864927724265781406614294e-0006L,
 };
 
-static const long double ap1[] = {			/* 19 terms */
-  -0.0772156649015328606065120900824024296961L,
-   3.224670334241132182362075833230047956465e-0001L,
-  -6.735230105319809513324605382963943777301e-0002L,
-   2.058080842778454787900092126606252375465e-0002L,
-  -7.385551028673985266272518231365020063941e-0003L,
-   2.890510330741523285681704570797770736423e-0003L,
-  -1.192753911703260971285304221165990244515e-0003L,
-   5.096695247430420878696018188830886972245e-0004L,
-  -2.231547584535654004647639737841526025095e-0004L,
-   9.945751278137201960636098805852315982919e-0005L,
-  -4.492623672777606053587919463929044226280e-0005L,
-   2.050721258703289487603702670753053765201e-0005L,
-  -9.439485626565616989352750672499008021041e-0006L,
-   4.374838162403994645138200419356844574219e-0006L,
-  -2.038979492862555348577006944451002161496e-0006L,
-   9.536763152382263548086981191378885102802e-0007L,
-  -4.426111214332434049863595231916564014913e-0007L,
-   1.911148847512947464234633846270287546882e-0007L,
-  -5.788673944861923038157839080272303519671e-0008L,
+static const long double ap1[] = {	/* 19 terms */
+	-0.0772156649015328606065120900824024296961L,
+	3.224670334241132182362075833230047956465e-0001L,
+	-6.735230105319809513324605382963943777301e-0002L,
+	2.058080842778454787900092126606252375465e-0002L,
+	-7.385551028673985266272518231365020063941e-0003L,
+	2.890510330741523285681704570797770736423e-0003L,
+	-1.192753911703260971285304221165990244515e-0003L,
+	5.096695247430420878696018188830886972245e-0004L,
+	-2.231547584535654004647639737841526025095e-0004L,
+	9.945751278137201960636098805852315982919e-0005L,
+	-4.492623672777606053587919463929044226280e-0005L,
+	2.050721258703289487603702670753053765201e-0005L,
+	-9.439485626565616989352750672499008021041e-0006L,
+	4.374838162403994645138200419356844574219e-0006L,
+	-2.038979492862555348577006944451002161496e-0006L,
+	9.536763152382263548086981191378885102802e-0007L,
+	-4.426111214332434049863595231916564014913e-0007L,
+	1.911148847512947464234633846270287546882e-0007L,
+	-5.788673944861923038157839080272303519671e-0008L,
 };
 
-static const long double ap2[] = {			/* 19 terms */
-  -0.077215664901532860606428624449354836087L,
-   3.224670334241132182271948744265855440139e-0001L,
-  -6.735230105319809467356126599005051676203e-0002L,
-   2.058080842778453315716389815213496002588e-0002L,
-  -7.385551028673653323064118422580096222959e-0003L,
-   2.890510330735923572088003424849289006039e-0003L,
-  -1.192753911629952368606185543945790688144e-0003L,
-   5.096695239806718875364547587043220998766e-0004L,
-  -2.231547520600616108991867127392089144886e-0004L,
-   9.945746913898151120612322833059416008973e-0005L,
-  -4.492599307461977003570224943054585729684e-0005L,
-   2.050609891889165453592046505651759999090e-0005L,
-  -9.435329866734193796540515247917165988579e-0006L,
-   4.362267138522223236241016136585565144581e-0006L,
-  -2.008556356653246579300491601497510230557e-0006L,
-   8.961498103387207161105347118042844354395e-0007L,
-  -3.614187228330216282235692806488341157741e-0007L,
-   1.136978988247816860500420915014777753153e-0007L,
-  -2.000532786387196664019286514899782691776e-0008L,
+static const long double ap2[] = {	/* 19 terms */
+	-0.077215664901532860606428624449354836087L,
+	3.224670334241132182271948744265855440139e-0001L,
+	-6.735230105319809467356126599005051676203e-0002L,
+	2.058080842778453315716389815213496002588e-0002L,
+	-7.385551028673653323064118422580096222959e-0003L,
+	2.890510330735923572088003424849289006039e-0003L,
+	-1.192753911629952368606185543945790688144e-0003L,
+	5.096695239806718875364547587043220998766e-0004L,
+	-2.231547520600616108991867127392089144886e-0004L,
+	9.945746913898151120612322833059416008973e-0005L,
+	-4.492599307461977003570224943054585729684e-0005L,
+	2.050609891889165453592046505651759999090e-0005L,
+	-9.435329866734193796540515247917165988579e-0006L,
+	4.362267138522223236241016136585565144581e-0006L,
+	-2.008556356653246579300491601497510230557e-0006L,
+	8.961498103387207161105347118042844354395e-0007L,
+	-3.614187228330216282235692806488341157741e-0007L,
+	1.136978988247816860500420915014777753153e-0007L,
+	-2.000532786387196664019286514899782691776e-0008L,
 };
 
-static const long double ap3[] = {			/* 19 terms */
-  -0.077215664901532859888521470795348856446L,
-   3.224670334241131733364048614484228443077e-0001L,
-  -6.735230105319676541660495145259038151576e-0002L,
-   2.058080842775975461837768839015444273830e-0002L,
-  -7.385551028347615729728618066663566606906e-0003L,
-   2.890510327517954083379032008643080256676e-0003L,
-  -1.192753886919470728001821137439430882603e-0003L,
-   5.096693728898932234814903769146577482912e-0004L,
-  -2.231540055048827662528594010961874258037e-0004L,
-   9.945446210018649311491619999438833843723e-0005L,
-  -4.491608206598064519190236245753867697750e-0005L,
-   2.047939071322271016498065052853746466669e-0005L,
-  -9.376824046522786006677541036631536790762e-0006L,
-   4.259329829498149111582277209189150127347e-0006L,
-  -1.866064770421594266702176289764212873428e-0006L,
-   7.462066721137579592928128104534957135669e-0007L,
-  -2.483546217529077735074007138457678727371e-0007L,
-   5.915166576378161473299324673649144297574e-0008L,
-  -7.334139641706988966966252333759604701905e-0009L,
+static const long double ap3[] = {	/* 19 terms */
+	-0.077215664901532859888521470795348856446L,
+	3.224670334241131733364048614484228443077e-0001L,
+	-6.735230105319676541660495145259038151576e-0002L,
+	2.058080842775975461837768839015444273830e-0002L,
+	-7.385551028347615729728618066663566606906e-0003L,
+	2.890510327517954083379032008643080256676e-0003L,
+	-1.192753886919470728001821137439430882603e-0003L,
+	5.096693728898932234814903769146577482912e-0004L,
+	-2.231540055048827662528594010961874258037e-0004L,
+	9.945446210018649311491619999438833843723e-0005L,
+	-4.491608206598064519190236245753867697750e-0005L,
+	2.047939071322271016498065052853746466669e-0005L,
+	-9.376824046522786006677541036631536790762e-0006L,
+	4.259329829498149111582277209189150127347e-0006L,
+	-1.866064770421594266702176289764212873428e-0006L,
+	7.462066721137579592928128104534957135669e-0007L,
+	-2.483546217529077735074007138457678727371e-0007L,
+	5.915166576378161473299324673649144297574e-0008L,
+	-7.334139641706988966966252333759604701905e-0009L,
 };
 
-static const long double ap4[] = {			/* 19 terms */
-  -0.0772156649015326785569313252637238673675L,
-   3.224670334241051435008842685722468344822e-0001L,
-  -6.735230105302832007479431772160948499254e-0002L,
-   2.058080842553481183648529360967441889912e-0002L,
-  -7.385551007602909242024706804659879199244e-0003L,
-   2.890510182473907253939821312248303471206e-0003L,
-  -1.192753098427856770847894497586825614450e-0003L,
-   5.096659636418811568063339214203693550804e-0004L,
-  -2.231421144004355691166194259675004483639e-0004L,
-   9.942073842343832132754332881883387625136e-0005L,
-  -4.483809261973204531263252655050701205397e-0005L,
-   2.033260142610284888319116654931994447173e-0005L,
-  -9.153539544026646699870528191410440585796e-0006L,
-   3.988460469925482725894144688699584997971e-0006L,
-  -1.609692980087029172567957221850825977621e-0006L,
-   5.634916377249975825399706694496688803488e-0007L,
-  -1.560065465929518563549083208482591437696e-0007L,
-   2.961350193868935325526962209019387821584e-0008L,
-  -2.834602215195368130104649234505033159842e-0009L,
+static const long double ap4[] = {	/* 19 terms */
+	-0.0772156649015326785569313252637238673675L,
+	3.224670334241051435008842685722468344822e-0001L,
+	-6.735230105302832007479431772160948499254e-0002L,
+	2.058080842553481183648529360967441889912e-0002L,
+	-7.385551007602909242024706804659879199244e-0003L,
+	2.890510182473907253939821312248303471206e-0003L,
+	-1.192753098427856770847894497586825614450e-0003L,
+	5.096659636418811568063339214203693550804e-0004L,
+	-2.231421144004355691166194259675004483639e-0004L,
+	9.942073842343832132754332881883387625136e-0005L,
+	-4.483809261973204531263252655050701205397e-0005L,
+	2.033260142610284888319116654931994447173e-0005L,
+	-9.153539544026646699870528191410440585796e-0006L,
+	3.988460469925482725894144688699584997971e-0006L,
+	-1.609692980087029172567957221850825977621e-0006L,
+	5.634916377249975825399706694496688803488e-0007L,
+	-1.560065465929518563549083208482591437696e-0007L,
+	2.961350193868935325526962209019387821584e-0008L,
+	-2.834602215195368130104649234505033159842e-0009L,
 };
 
 static long double
-primary(long double s) {	/* assume |s|<=0.5 */
+primary(long double s)			/* assume |s|<=0.5 */
+{
 	int i;
 
-	i = (int) (8.0L * (s + 0.5L));
-	switch(i) {
-	case 0:	return ch*s+s*poly(s,an4,21);
-	case 1:	return ch*s+s*poly(s,an3,20);
-	case 2:	return ch*s+s*poly(s,an2,20);
-	case 3:	return ch*s+s*poly(s,an1,20);
-	case 4:	return ch*s+s*poly(s,ap1,19);
-	case 5:	return ch*s+s*poly(s,ap2,19);
-	case 6:	return ch*s+s*poly(s,ap3,19);
-	case 7:	return ch*s+s*poly(s,ap4,19);
+	i = (int)(8.0L * (s + 0.5L));
+
+	switch (i) {
+	case 0:
+		return (ch * s + s * poly(s, an4, 21));
+	case 1:
+		return (ch * s + s * poly(s, an3, 20));
+	case 2:
+		return (ch * s + s * poly(s, an2, 20));
+	case 3:
+		return (ch * s + s * poly(s, an1, 20));
+	case 4:
+		return (ch * s + s * poly(s, ap1, 19));
+	case 5:
+		return (ch * s + s * poly(s, ap2, 19));
+	case 6:
+		return (ch * s + s * poly(s, ap3, 19));
+	case 7:
+		return (ch * s + s * poly(s, ap4, 19));
 	}
+
 	/* NOTREACHED */
-    return 0.0L;
+	return (0.0L);
 }
 
 static long double
-poly(long double s, const long double *p, int n) {
+poly(long double s, const long double *p, int n)
+{
 	long double y;
 	int i;
-	y = p[n-1];
-	for (i=n-2;i>=0;i--) y = p[i]+s*y;
-	return y;
+
+	y = p[n - 1];
+
+	for (i = n - 2; i >= 0; i--)
+		y = p[i] + s * y;
+
+	return (y);
 }
 
 static const long double pt[] = {
-   9.189385332046727417803297364056176804663e-0001L,
-   8.333333333333333333333333333331286969123e-0002L,
-  -2.777777777777777777777777553194796036402e-0003L,
-   7.936507936507936507927283071433584248176e-0004L,
-  -5.952380952380952362351042163192634108297e-0004L,
-   8.417508417508395661774286645578379460131e-0004L,
-  -1.917526917525263651186066417934685675649e-0003L,
-   6.410256409395203164659292973142293199083e-0003L,
-  -2.955065327248303301763594514012418438188e-0002L,
-   1.796442830099067542945998615411893822886e-0001L,
-  -1.392413465829723742489974310411118662919e+0000L,
-   1.339984238037267658352656597960492029261e+0001L,
-  -1.564707657605373662425785904278645727813e+0002L,
-   2.156323807499211356127813962223067079300e+0003L,
-  -3.330486427626223184647299834137041307569e+0004L,
-   5.235535072011889213611369254140123518699e+0005L,
-  -7.258160984602220710491988573430212593080e+0006L,
-   7.316526934569686459641438882340322673357e+0007L,
-  -3.806450279064900548836571789284896711473e+0008L,
+	9.189385332046727417803297364056176804663e-0001L,
+	8.333333333333333333333333333331286969123e-0002L,
+	-2.777777777777777777777777553194796036402e-0003L,
+	7.936507936507936507927283071433584248176e-0004L,
+	-5.952380952380952362351042163192634108297e-0004L,
+	8.417508417508395661774286645578379460131e-0004L,
+	-1.917526917525263651186066417934685675649e-0003L,
+	6.410256409395203164659292973142293199083e-0003L,
+	-2.955065327248303301763594514012418438188e-0002L,
+	1.796442830099067542945998615411893822886e-0001L,
+	-1.392413465829723742489974310411118662919e+0000L,
+	1.339984238037267658352656597960492029261e+0001L,
+	-1.564707657605373662425785904278645727813e+0002L,
+	2.156323807499211356127813962223067079300e+0003L,
+	-3.330486427626223184647299834137041307569e+0004L,
+	5.235535072011889213611369254140123518699e+0005L,
+	-7.258160984602220710491988573430212593080e+0006L,
+	7.316526934569686459641438882340322673357e+0007L,
+	-3.806450279064900548836571789284896711473e+0008L,
 };
 
 static long double
-polytail(long double s) {
-	long double t,z;
+polytail(long double s)
+{
+	long double t, z;
 	int i;
-	z = s*s;
+
+	z = s * s;
 	t = pt[18];
-	for (i=17;i>=1;i--) t = pt[i]+z*t;
-	return pt[0]+s*t;
+
+	for (i = 17; i >= 1; i--)
+		t = pt[i] + z * t;
+
+	return (pt[0] + s * t);
 }
 
 static long double
-neg(long double z, int *signgamlp) {
-	long double t,p;
-
-     /*
-      * written by K.C. Ng,  Feb 2, 1989.
-      *
-      * Since
-      *		-z*G(-z)*G(z) = pi/sin(pi*z),
-      * we have
-      * 	G(-z) = -pi/(sin(pi*z)*G(z)*z)
-      * 	      =  pi/(sin(pi*(-z))*G(z)*z)
-      * Algorithm
-      *		z = |z|
-      *		t = sinpi(z); ...note that when z>2**112, z is an int
-      *		and hence t=0.
-      *
-      *		if (t == 0.0) return 1.0/0.0;
-      *		if (t< 0.0) *signgamlp = -1; else t= -t;
-      *		if (z<1.0e-40)	...tiny z
-      *		    return -log(z);
-      *		else
-      *		    return log(pi/(t*z))-lgamma(z);
-      *
-      */
+neg(long double z, int *signgamlp)
+{
+	long double t, p;
+
+	/* BEGIN CSTYLED */
+	/*
+	 * written by K.C. Ng,  Feb 2, 1989.
+	 *
+	 * Since
+	 *		-z*G(-z)*G(z) = pi/sin(pi*z),
+	 * we have
+	 *      G(-z) = -pi/(sin(pi*z)*G(z)*z)
+	 *            =  pi/(sin(pi*(-z))*G(z)*z)
+	 * Algorithm
+	 *		z = |z|
+	 *		t = sinpi(z); ...note that when z>2**112, z is an int
+	 *		and hence t=0.
+	 *
+	 *		if (t == 0.0) return 1.0/0.0;
+	 *		if (t< 0.0) *signgamlp = -1; else t= -t;
+	 *		if (z<1.0e-40)	...tiny z
+	 *		    return -log(z);
+	 *		else
+	 *		    return log(pi/(t*z))-lgamma(z);
+	 *
+	 */
+	/* END CSTYLED */
 
 	t = sinpil(z);			/* t := sin(pi*z) */
-	if (t == c0)  			/* return   1.0/0.0 =  +INF */
-	    return c1/c0;
+
+	if (t == c0)			/* return   1.0/0.0 =  +INF */
+		return (c1 / c0);
 
 	z = -z;
-	if (z<=tiny)
-	    p = -logl(z);
+
+	if (z <= tiny)
+		p = -logl(z);
 	else
-      	    p = logl(pi/(fabsl(t)*z))-__k_lgammal(z,signgamlp);
-	if (t<c0) *signgamlp = -1;
-	return p;
+		p = logl(pi / (fabsl(t) * z)) - __k_lgammal(z, signgamlp);
+
+	if (t < c0)
+		*signgamlp = -1;
+
+	return (p);
 }
--- old/usr/src/lib/libm/common/Q/__poly_libmq.c	2019-06-06 20:38:31.936771157 +0000
+++ new/usr/src/lib/libm/common/Q/__poly_libmq.c	2019-06-06 20:38:31.955001101 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,12 +31,15 @@
 #include "libm.h"
 
 long double
-__poly_libmq(long double x, int n, const long double p[]) {
+__poly_libmq(long double x, int n, const long double p[])
+{
 	long double t;
 	int i;
 
 	t = p[n - 1];
+
 	for (i = n - 2; i >= 0; i--)
 		t = p[i] + x * t;
+
 	return (t);
 }
--- old/usr/src/lib/libm/common/Q/__rem_pio2l.c	2019-06-06 20:38:32.442687196 +0000
+++ new/usr/src/lib/libm/common/Q/__rem_pio2l.c	2019-06-06 20:38:32.460058560 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,19 +36,18 @@
 
 #ifndef FDLIBM_BASED
 #include "libm.h"
+
 extern int __rem_pio2m(double *, double *, int, int, int, const int *);
-#else				/* FDLIBM_BASED */
+#else /* FDLIBM_BASED */
 #include "fdlibm.h"
 #define	__rem_pio2m	__kernel_rem_pio2
-#endif				/* FDLIBM_BASED */
+#endif /* FDLIBM_BASED */
 
 #include "longdouble.h"
 
 extern const int _TBL_ipio2l_inf[];
-
-static const long double
-	two24l = 16777216.0L,
-	pio4   = 0.7853981633974483096156608458198757210495L;
+static const long double two24l = 16777216.0L,
+	pio4 = 0.7853981633974483096156608458198757210495L;
 
 int
 __rem_pio2l(long double x, long double *y)
@@ -59,30 +59,38 @@
 
 	sign = signbitl(x);
 	z = fabsl(x);
+
 	if (z <= pio4) {
 		y[0] = x;
 		y[1] = 0;
 		return (0);
 	}
+
 	e0 = ilogbl(z) - 23;
 	z = scalbnl(z, -e0);
+
 	for (i = 0; i < 5; i++) {
 		t[i] = (double)((int)(z));
 		z = (z - (long double)t[i]) * two24l;
 	}
+
 	nx = 5;
+
 	while (t[nx - 1] == 0.0)
-		nx--;		/* skip zero term */
+		nx--;			/* skip zero term */
+
 	ipio2 = _TBL_ipio2l_inf;
 	n = __rem_pio2m(t, v, e0, nx, 3, (const int *)ipio2);
 	z = (long double)v[2] + (long double)v[1];
 	w = (long double)v[0];
 	y[0] = z + w;
 	y[1] = z - (y[0] - w);
+
 	if (sign != 0) {
 		y[0] = -y[0];
 		y[1] = -y[1];
 		return (-n);
 	}
+
 	return (n);
 }
--- old/usr/src/lib/libm/common/Q/__sincosl.c	2019-06-06 20:38:32.926195165 +0000
+++ new/usr/src/lib/libm/common/Q/__sincosl.c	2019-06-06 20:38:32.944259820 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -40,95 +41,109 @@
 
 #include "libm.h"
 
-extern const long double _TBL_sinl_hi[], _TBL_sinl_lo[],
-	_TBL_cosl_hi[], _TBL_cosl_lo[];
-static const long double
-	one	= 1.0L,
+extern const long double _TBL_sinl_hi[], _TBL_sinl_lo[], _TBL_cosl_hi[],
+	_TBL_cosl_lo[];
+static const long double one = 1.0L;
+
 /*
  *                   3           11       -122.32
  * |sin(x) - (x+pp1*x +...+ pp5*x  )| <= 2        for |x|<1/64
  */
-	pp1	= -1.666666666666666666666666666586782940810e-0001L,
-	pp2	= +8.333333333333333333333003723660929317540e-0003L,
-	pp3	= -1.984126984126984076045903483778337804470e-0004L,
-	pp4	= +2.755731922361906641319723106210900949413e-0006L,
-	pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = +8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = +2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p8*x^17)|
  * |------------------------------- | <= 2^-116.17 for |x|<0.1953125
  * |                 x              |
  */
-	p1	= -1.666666666666666666666666666666211262297e-0001L,
-	p2	= +8.333333333333333333333333301497876908541e-0003L,
-	p3	= -1.984126984126984126984041302881180621922e-0004L,
-	p4	= +2.755731922398589064100587351307269621093e-0006L,
-	p5	= -2.505210838544163129378906953765595393873e-0008L,
-	p6	= +1.605904383643244375050998243778534074273e-0010L,
-	p7	= -7.647162722800685516901456114270824622699e-0013L,
-	p8	= +2.810046428661902961725428841068844462603e-0015L,
+static const long double
+	p1 = -1.666666666666666666666666666666211262297e-0001L,
+	p2 = +8.333333333333333333333333301497876908541e-0003L,
+	p3 = -1.984126984126984126984041302881180621922e-0004L,
+	p4 = +2.755731922398589064100587351307269621093e-0006L,
+	p5 = -2.505210838544163129378906953765595393873e-0008L,
+	p6 = +1.605904383643244375050998243778534074273e-0010L,
+	p7 = -7.647162722800685516901456114270824622699e-0013L,
+	p8 = +2.810046428661902961725428841068844462603e-0015L;
+
 /*
  *                   2           10       -123.84
  * |cos(x) - (1+qq1*x +...+ qq5*x  )| <= 2        for |x|<=1/128
  */
-	qq1	= -4.999999999999999999999999999999378373641e-0001L,
-	qq2	= +4.166666666666666666666665478399327703130e-0002L,
-	qq3	= -1.388888888888888888058211230618051613494e-0003L,
-	qq4	= +2.480158730156105377771585658905303111866e-0005L,
-	qq5	= -2.755728099762526325736488376695157008736e-0007L,
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = +4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = +2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
+
 /*
  *                  2            16       -117.11
  * |cos(x) - (1+q1*x + ... + q8*x  )| <= 2        for |x|<= 0.15625
  */
-	q1	= -4.999999999999999999999999999999756416975e-0001L,
-	q2	= +4.166666666666666666666666664006066577258e-0002L,
-	q3	= -1.388888888888888888888877700363937169637e-0003L,
-	q4	= +2.480158730158730158494468463031814083559e-0005L,
-	q5	= -2.755731922398586276322819250356005542871e-0007L,
-	q6	= +2.087675698767424261441959760729854017855e-0009L,
-	q7	= -1.147074481239662089072452129010790774761e-0011L,
-	q8	= +4.777761647399651599730663422263531034782e-0014L;
+static const long double
+	q1 = -4.999999999999999999999999999999756416975e-0001L,
+	q2 = +4.166666666666666666666666664006066577258e-0002L,
+	q3 = -1.388888888888888888888877700363937169637e-0003L,
+	q4 = +2.480158730158730158494468463031814083559e-0005L,
+	q5 = -2.755731922398586276322819250356005542871e-0007L,
+	q6 = +2.087675698767424261441959760729854017855e-0009L,
+	q7 = -1.147074481239662089072452129010790774761e-0011L,
+	q8 = +4.777761647399651599730663422263531034782e-0014L;
 
 #define	i0	0
 
 long double
-__k_sincosl(long double x, long double y, long double *c) {
+__k_sincosl(long double x, long double y, long double *c)
+{
 	long double a1, a2, t, t1, t2, z, w;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0L;
 	hx = px[i0];
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc4000) {
-		if (ix < 0x3fc60000)
-			if (((int) x) == 0) {
+		if (ix < 0x3fc60000) {
+			if (((int)x) == 0) {
 				*c = one;
 				return (x);
-			}	/* generate inexact */
+			}		/* generate inexact */
+		}
+
 		z = x * x;
 
 		if (ix < 0x3ff80000) {
-			*c = one + z * (qq1 + z * (qq2 + z * (qq3 +
-				z * (qq4 + z * qq5))));
-			t = z * (p1 + z * (p2 + z * (p3 + z * (p4 +
-				z * (p5 + z * p6)))));
+			*c = one + z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 +
+			    z * qq5))));
+			t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 +
+			    z * p6)))));
 		} else {
-			*c = one + z * (q1 + z * (q2 + z * (q3 + z * (q4 +
-				z * (q5 + z * (q6 + z * (q7 + z * q8)))))));
+			*c = one + z * (q1 + z * (q2 + z * (q3 + z * (q4 + z *
+			    (q5 + z * (q6 + z * (q7 + z * q8)))))));
 			t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 +
-				z * (p6 + z * (p7 + z * p8)))))));
+			    z * (p6 + z * (p7 + z * p8)))))));
 		}
 
 		t = y + x * t;
 		return (x + t);
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 	pt[i0] = j;
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a1 = _TBL_sinl_hi[i];
 	z = x * x;
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
@@ -138,6 +153,7 @@
 	*c = a2 + t2;
 	t1 = a2 * w + a1 * t;
 	t1 += _TBL_sinl_lo[i];
+
 	if (hx < 0)
 		return (-a1 - t1);
 	else
--- old/usr/src/lib/libm/common/Q/__sinl.c	2019-06-06 20:38:33.437683529 +0000
+++ new/usr/src/lib/libm/common/Q/__sinl.c	2019-06-06 20:38:33.455818586 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -46,7 +47,7 @@
  *		ht = (hx + 0x400)&0x7ffff800	(round x to a break point t)
  *		lt = 0
  *		i  = (hy-0x3ffc4000)>>11;	(i<=64)
- *		x' = (x - t)+y 			(|x'| ~<= 2^-7
+ *		x' = (x - t)+y                  (|x'| ~<= 2^-7
  *	   By
  *		sin(t+x')
  *		  = sin(t)cos(x')+cos(t)sin(x')
@@ -64,78 +65,92 @@
 #include "libm.h"
 
 extern const long double _TBL_sinl_hi[], _TBL_sinl_lo[], _TBL_cosl_hi[];
-static const long double
-one	= 1.0L,
+static const long double one = 1.0L;
+
 /*
  *		     3	         11       -122.32
  * |sin(x) - (x+pp1*x +...+ pp5*x  )| <= 2        for |x|<1/64
  */
-	pp1	= -1.666666666666666666666666666586782940810e-0001L,
-	pp2	= +8.333333333333333333333003723660929317540e-0003L,
-	pp3	= -1.984126984126984076045903483778337804470e-0004L,
-	pp4	= +2.755731922361906641319723106210900949413e-0006L,
-	pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = +8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = +2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  * |(sin(x) - (x+p1*x^3+...+p8*x^17)|
  * |------------------------------- | <= 2^-116.17 for |x|<0.1953125
  * |                 x              |
  */
-	p1	= -1.666666666666666666666666666666211262297e-0001L,
-	p2	= +8.333333333333333333333333301497876908541e-0003L,
-	p3	= -1.984126984126984126984041302881180621922e-0004L,
-	p4	= +2.755731922398589064100587351307269621093e-0006L,
-	p5	= -2.505210838544163129378906953765595393873e-0008L,
-	p6	= +1.605904383643244375050998243778534074273e-0010L,
-	p7	= -7.647162722800685516901456114270824622699e-0013L,
-	p8	= +2.810046428661902961725428841068844462603e-0015L,
+static const long double
+	p1 = -1.666666666666666666666666666666211262297e-0001L,
+	p2 = +8.333333333333333333333333301497876908541e-0003L,
+	p3 = -1.984126984126984126984041302881180621922e-0004L,
+	p4 = +2.755731922398589064100587351307269621093e-0006L,
+	p5 = -2.505210838544163129378906953765595393873e-0008L,
+	p6 = +1.605904383643244375050998243778534074273e-0010L,
+	p7 = -7.647162722800685516901456114270824622699e-0013L,
+	p8 = +2.810046428661902961725428841068844462603e-0015L;
+
 /*
  *		     2	         10        -123.84
  * |cos(x) - (1+qq1*x +...+ qq5*x  )| <= 2        for |x|<=1/128
  */
-	qq1	= -4.999999999999999999999999999999378373641e-0001L,
-	qq2	= +4.166666666666666666666665478399327703130e-0002L,
-	qq3	= -1.388888888888888888058211230618051613494e-0003L,
-	qq4	= +2.480158730156105377771585658905303111866e-0005L,
-	qq5	= -2.755728099762526325736488376695157008736e-0007L;
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = +4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = +2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
 
 #define	i0	0
 
 long double
-__k_sinl(long double x, long double y) {
+__k_sinl(long double x, long double y)
+{
 	long double a, t, z, w;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0L;
 	hx = px[i0];
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc9000) {
-		*(3 - i0 + (int *) &t) = -1;	/* one-ulp */
-		*(2 + (int *) &t) = -1;	/* one-ulp */
-		*(1 + (int *) &t) = -1;	/* one-ulp */
-		*(i0 + (int *) &t) -= 1;	/* one-ulp */
+		*(3 - i0 + (int *)&t) = -1;	/* one-ulp */
+		*(2 + (int *)&t) = -1;		/* one-ulp */
+		*(1 + (int *)&t) = -1;		/* one-ulp */
+		*(i0 + (int *)&t) -= 1;		/* one-ulp */
+
 		if (ix < 0x3fc60000)
-			if (((int) (x * t)) < 1)
-				return (x);	/* inexact and underflow */
+			if (((int)(x * t)) < 1)
+				return (x);
+
+		/* inexact and underflow */
 		z = x * x;
-		t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 +
-			z * (p6 + z * (p7 + z * p8)))))));
+		t = z * (p1 + z * (p2 + z * (p3 + z * (p4 + z * (p5 + z * (p6 +
+		    z * (p7 + z * p8)))))));
 		t = y + x * t;
 		return (x + t);
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 	pt[i0] = j;
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a = _TBL_sinl_hi[i];
 	z = x * x;
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
 	w = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z * pp5)))));
 	t = _TBL_cosl_hi[i] * w + a * t;
 	t += _TBL_sinl_lo[i];
+
 	if (hx < 0)
 		return (-a - t);
 	else
--- old/usr/src/lib/libm/common/Q/__tanl.c	2019-06-06 20:38:33.959192980 +0000
+++ new/usr/src/lib/libm/common/Q/__tanl.c	2019-06-06 20:38:33.979404290 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -46,7 +47,7 @@
  *		ht = (hx + 0x400)&0x7ffff800	(round x to a break point t)
  *		lt = 0
  *		i  = (hy-0x3ffc4000)>>11;	(i<=64)
- *		x' = (x - t)+y 			(|x'| ~<= 2^-7)
+ *		x' = (x - t)+y                  (|x'| ~<= 2^-7)
  *	   By
  *		tan(t+x')
  *		  = (tan(t)+tan(x'))/(1-tan(x')tan(t))
@@ -60,7 +61,7 @@
  *		       tan(t) + tan(t)*(cos(x')-1) + sin(x')
  *
  *
- *	   where 	tan(t) is from the table,
+ *	   where        tan(t) is from the table,
  *			sin(x') = x + pp1*x^3 + ...+ pp5*x^11
  *			cos(x') = 1 + qq1*x^2 + ...+ qq5*x^10
  */
@@ -68,88 +69,104 @@
 #include "libm.h"
 
 extern const long double _TBL_tanl_hi[], _TBL_tanl_lo[];
-static const long double
-	one	= 1.0L,
+static const long double one = 1.0L;
+
 /*
  *                   3           11       -122.32
  * |sin(x) - (x+pp1*x +...+ pp5*x  )| <= 2        for |x|<1/64
  */
-	pp1	= -1.666666666666666666666666666586782940810e-0001L,
-	pp2	= +8.333333333333333333333003723660929317540e-0003L,
-	pp3	= -1.984126984126984076045903483778337804470e-0004L,
-	pp4	= +2.755731922361906641319723106210900949413e-0006L,
-	pp5	= -2.505198398570947019093998469135012057673e-0008L,
+static const long double
+	pp1 = -1.666666666666666666666666666586782940810e-0001L,
+	pp2 = +8.333333333333333333333003723660929317540e-0003L,
+	pp3 = -1.984126984126984076045903483778337804470e-0004L,
+	pp4 = +2.755731922361906641319723106210900949413e-0006L,
+	pp5 = -2.505198398570947019093998469135012057673e-0008L;
+
 /*
  *                   2           10        -123.84
  * |cos(x) - (1+qq1*x +...+ qq5*x  )| <= 2        for |x|<=1/128
  */
-	qq1	= -4.999999999999999999999999999999378373641e-0001L,
-	qq2	= +4.166666666666666666666665478399327703130e-0002L,
-	qq3	= -1.388888888888888888058211230618051613494e-0003L,
-	qq4	= +2.480158730156105377771585658905303111866e-0005L,
-	qq5	= -2.755728099762526325736488376695157008736e-0007L,
+static const long double
+	qq1 = -4.999999999999999999999999999999378373641e-0001L,
+	qq2 = +4.166666666666666666666665478399327703130e-0002L,
+	qq3 = -1.388888888888888888058211230618051613494e-0003L,
+	qq4 = +2.480158730156105377771585658905303111866e-0005L,
+	qq5 = -2.755728099762526325736488376695157008736e-0007L;
+
 /*
  * |tan(x) - (x+t1*x^3+...+t6*x^13)|
  * |------------------------------ | <= 2^-59.73 for |x|<0.15625
  * |                x              |
  */
-	t1	= +3.333333333333333333333333333333423342490e-0001L,
-	t2	= +1.333333333333333333333333333093838744537e-0001L,
-	t3	= +5.396825396825396825396827906318682662250e-0002L,
-	t4	= +2.186948853615520282185576976994418486911e-0002L,
-	t5	= +8.863235529902196573354554519991152936246e-0003L,
-	t6	= +3.592128036572480064652191427543994878790e-0003L,
-	t7	= +1.455834387051455257856833807581901305474e-0003L,
-	t8	= +5.900274409318599857829983256201725587477e-0004L,
-	t9	= +2.391291152117265181501116961901122362937e-0004L,
-	t10	= +9.691533169382729742394024173194981882375e-0005L,
-	t11	= +3.927994733186415603228178184225780859951e-0005L,
-	t12	= +1.588300018848323824227640064883334101288e-0005L,
-	t13	= +6.916271223396808311166202285131722231723e-0006L;
+static const long double
+	t1 = +3.333333333333333333333333333333423342490e-0001L,
+	t2 = +1.333333333333333333333333333093838744537e-0001L,
+	t3 = +5.396825396825396825396827906318682662250e-0002L,
+	t4 = +2.186948853615520282185576976994418486911e-0002L,
+	t5 = +8.863235529902196573354554519991152936246e-0003L,
+	t6 = +3.592128036572480064652191427543994878790e-0003L,
+	t7 = +1.455834387051455257856833807581901305474e-0003L,
+	t8 = +5.900274409318599857829983256201725587477e-0004L,
+	t9 = +2.391291152117265181501116961901122362937e-0004L,
+	t10 = +9.691533169382729742394024173194981882375e-0005L,
+	t11 = +3.927994733186415603228178184225780859951e-0005L,
+	t12 = +1.588300018848323824227640064883334101288e-0005L,
+	t13 = +6.916271223396808311166202285131722231723e-0006L;
 
 #define	i0	0
 
 long double
-__k_tanl(long double x, long double y, int k) {
+__k_tanl(long double x, long double y, int k)
+{
 	long double a, t, z, w = 0, s, c;
-	int *pt = (int *) &t, *px = (int *) &x;
+	int *pt = (int *)&t, *px = (int *)&x;
 	int i, j, hx, ix;
 
 	t = 1.0L;
 	hx = px[i0];
 	ix = hx & 0x7fffffff;
+
 	if (ix < 0x3ffc4000) {
-		*(3 - i0 + (int *) &t) = 1;	/* make t = one+ulp */
+		*(3 - i0 + (int *)&t) = 1;	/* make t = one+ulp */
+
 		if (ix < 0x3fc60000) {
-			if (((int) (x * t)) < 1)	/* generate inexact */
-				w = x;	/* generate underflow if subnormal */
+			if (((int)(x * t)) < 1)	/* generate inexact */
+				w = x; /* generate underflow if subnormal */
 		} else {
 			z = x * x;
-			if (ix < 0x3ff30000)	/* 2**-12 */
+
+			if (ix < 0x3ff30000) {	/* 2**-12 */
 				t = z * (t1 + z * (t2 + z * (t3 + z * t4)));
-			else
-				t = z * (t1 + z * (t2 + z * (t3 + z * (t4 +
-					z * (t5 + z * (t6 + z * (t7 + z * (t8 +
-					z * (t9 + z * (t10 + z * (t11 +
-					z * (t12 + z * t13))))))))))));
+			} else {
+				t = z * (t1 + z * (t2 + z * (t3 + z * (t4 + z *
+				    (t5 + z * (t6 + z * (t7 + z * (t8 + z *
+				    (t9 + z * (t10 + z * (t11 + z * (t12 + z *
+				    t13))))))))))));
+			}
+
 			t = y + x * t;
 			w = x + t;
 		}
+
 		return (k == 0 ? w : -one / w);
 	}
+
 	j = (ix + 0x400) & 0x7ffff800;
 	i = (j - 0x3ffc4000) >> 11;
 	pt[i0] = j;
+
 	if (hx > 0)
 		x = y - (t - x);
 	else
 		x = (-y) - (t + x);
+
 	a = _TBL_tanl_hi[i];
 	z = x * x;
 	/* cos(x)-1 */
 	t = z * (qq1 + z * (qq2 + z * (qq3 + z * (qq4 + z * qq5))));
 	/* sin(x) */
 	s = x * (one + z * (pp1 + z * (pp2 + z * (pp3 + z * (pp4 + z * pp5)))));
+
 	if (k == 0) {
 		w = a * s;
 		t = _TBL_tanl_lo[i] + (s + a * w) / (one - (w - t));
--- old/usr/src/lib/libm/common/Q/acoshl.c	2019-06-06 20:38:34.463088386 +0000
+++ new/usr/src/lib/libm/common/Q/acoshl.c	2019-06-06 20:38:34.481678160 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,25 +32,26 @@
 
 #include "libm.h"
 
-static const long double
-	zero	= 0.0L,
-	ln2	= 6.931471805599453094172321214581765680755e-0001L,
-	one	= 1.0L,
-	big	= 1.e+20L;
+static const long double zero = 0.0L,
+	ln2 = 6.931471805599453094172321214581765680755e-0001L,
+	one = 1.0L,
+	big = 1.e+20L;
 
 long double
-acoshl(long double x) {
+acoshl(long double x)
+{
 	long double t;
 
-	if (isnanl(x))
+	if (isnanl(x)) {
 		return (x + x);
-	else if (x > big)
+	} else if (x > big) {
 		return (logl(x) + ln2);
-	else if (x > one) {
+	} else if (x > one) {
 		t = sqrtl(x - one);
 		return (log1pl(t * (t + sqrtl(x + one))));
-	} else if (x == one)
+	} else if (x == one) {
 		return (zero);
-	else
+	} else {
 		return ((x - x) / (x - x));
+	}
 }
--- old/usr/src/lib/libm/common/Q/acosl.c	2019-06-06 20:38:34.910716819 +0000
+++ new/usr/src/lib/libm/common/Q/acosl.c	2019-06-06 20:38:34.926636428 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -49,9 +50,9 @@
 #include "libm.h"
 
 static const long double zero = 0.0L, one = 1.0L;
-
 long double
-acosl(long double x) {
+acosl(long double x)
+{
 	if (isnanl(x))
 		return (x + x);
 	else if (fabsl(x) < one)
@@ -60,8 +61,8 @@
 		x = atan2l(one, zero);	/* x <- PI */
 	else if (x == one)
 		x = zero;
-	else {		/* |x| > 1  create invalid signal */
+	else				/* |x| > 1  create invalid signal */
 		return (zero / zero);
-	}
+
 	return (x + x);
 }
--- old/usr/src/lib/libm/common/Q/asinhl.c	2019-06-06 20:38:35.390559838 +0000
+++ new/usr/src/lib/libm/common/Q/asinhl.c	2019-06-06 20:38:35.407347945 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,29 +33,34 @@
 #include "libm.h"
 
 static const long double
-	ln2	= 6.931471805599453094172321214581765680755e-0001L,
-	one	= 1.0L,
-	big	= 1.0e+20L,
-	tiny	= 1.0e-20L;
+	ln2 = 6.931471805599453094172321214581765680755e-0001L,
+	one = 1.0L,
+	big = 1.0e+20L,
+	tiny = 1.0e-20L;
 
 long double
-asinhl(long double x) {
+asinhl(long double x)
+{
 	long double t, w;
+
 #ifndef lint
 	volatile long double dummy;
 #endif
 
 	w = fabsl(x);
+
 	if (isnanl(x))
-		return (x + x);	/* x is NaN */
+		return (x + x);		/* x is NaN */
+
 	if (w < tiny) {
 #ifndef lint
 		dummy = x + big;	/* inexact if x != 0 */
 #endif
-		return (x);	/* tiny x */
+		return (x);		/* tiny x */
 	} else if (w < big) {
 		t = one / w;
 		return (copysignl(log1pl(w + w / (t + sqrtl(one + t * t))), x));
-	} else
+	} else {
 		return (copysignl(logl(w) + ln2, x));
+	}
 }
--- old/usr/src/lib/libm/common/Q/asinl.c	2019-06-06 20:38:35.846427008 +0000
+++ new/usr/src/lib/libm/common/Q/asinl.c	2019-06-06 20:38:35.863570752 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,35 +45,41 @@
 #include "libm.h"
 
 static const long double zero = 0.0L, small = 1.0e-20L, half = 0.5L, one = 1.0L;
+
 #ifndef lint
 static const long double big = 1.0e+20L;
 #endif
 
 long double
-asinl(long double x) {
+asinl(long double x)
+{
 	long double t, w;
+
 #ifndef lint
 	volatile long double dummy;
 #endif
 
 	w = fabsl(x);
-	if (isnanl(x))
+
+	if (isnanl(x)) {
 		return (x + x);
-	else if (w <= half) {
+	} else if (w <= half) {
 		if (w < small) {
 #ifndef lint
 			dummy = w + big;
-							/* inexact if w != 0 */
+			/* inexact if w != 0 */
 #endif
 			return (x);
-		} else
+		} else {
 			return (atanl(x / sqrtl(one - x * x)));
+		}
 	} else if (w < one) {
 		t = one - w;
 		w = t + t;
 		return (atanl(x / sqrtl(w - t * t)));
-	} else if (w == one)
+	} else if (w == one) {
 		return (atan2l(x, zero));	/* asin(+-1) =  +- PI/2 */
-	else
+	} else {
 		return (zero / zero);		/* |x| > 1: invalid */
+	}
 }
--- old/usr/src/lib/libm/common/Q/atan2l.c	2019-06-06 20:38:36.335314213 +0000
+++ new/usr/src/lib/libm/common/Q/atan2l.c	2019-06-06 20:38:36.354088313 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -61,16 +62,15 @@
 #include "libm.h"
 #include "longdouble.h"
 
-static const long double
-	zero	=  0.0L,
-	tiny	=  1.0e-40L,
-	one	=  1.0L,
-	half	=  0.5L,
-	PI3o4	=  2.356194490192344928846982537459627163148L,
-	PIo4	=  0.785398163397448309615660845819875721049L,
-	PIo2	=  1.570796326794896619231321691639751442099L,
-	PI	=  3.141592653589793238462643383279502884197L,
-	PI_lo	=  8.671810130123781024797044026043351968762e-35L;
+static const long double zero = 0.0L,
+	tiny = 1.0e-40L,
+	one = 1.0L,
+	half = 0.5L,
+	PI3o4 = 2.356194490192344928846982537459627163148L,
+	PIo4 = 0.785398163397448309615660845819875721049L,
+	PIo2 = 1.570796326794896619231321691639751442099L,
+	PI = 3.141592653589793238462643383279502884197L,
+	PI_lo = 8.671810130123781024797044026043351968762e-35L;
 
 long double
 atan2l(long double y, long double x)
@@ -79,26 +79,30 @@
 	int k, m, signy, signx;
 
 	if (x != x || y != y)
-		return (x + y);	/* return NaN if x or y is NAN */
+		return (x + y);		/* return NaN if x or y is NAN */
+
 	signy = signbitl(y);
 	signx = signbitl(x);
+
 	if (x == one)
 		return (atanl(y));
+
 	/* Ensure sign indicators are boolean */
 	m = (signy != 0) + (signx != 0) + (signx != 0);
 
 	/* when y = 0 */
-	if (y == zero)
+	if (y == zero) {
 		switch (m) {
 		case 0:
-			return (y);	/* atan(+0,+anything) */
+			return (y);		/* atan(+0,+anything) */
 		case 1:
-			return (y);	/* atan(-0,+anything) */
+			return (y);		/* atan(-0,+anything) */
 		case 2:
 			return (PI + tiny);	/* atan(+0,-anything) */
 		case 3:
 			return (-PI - tiny);	/* atan(-0,-anything) */
 		}
+	}
 
 	/* when x = 0 */
 	if (x == zero)
@@ -120,9 +124,9 @@
 		} else {
 			switch (m) {
 			case 0:
-				return (zero);	/* atan(+...,+INF) */
+				return (zero);		/* atan(+...,+INF) */
 			case 1:
-				return (-zero);	/* atan(-...,+INF) */
+				return (-zero);		/* atan(-...,+INF) */
 			case 2:
 				return (PI + tiny);	/* atan(+...,-INF) */
 			case 3:
@@ -130,6 +134,7 @@
 			}
 		}
 	}
+
 	/* when y is INF */
 	if (!finitel(y))
 		return (signy != 0 ? -PIo2 - tiny : PIo2 + tiny);
@@ -149,14 +154,15 @@
 
 	switch (m) {
 	case 0:
-		return (z);	/* atan(+,+) */
+		return (z);		/* atan(+,+) */
 	case 1:
-		return (-z);	/* atan(-,+) */
+		return (-z);		/* atan(-,+) */
 	case 2:
 		return (PI - (z - t));	/* atan(+,-) */
 	case 3:
 		return ((z - t) - PI);	/* atan(-,-) */
 	}
+
 	/* NOTREACHED */
 	return (0.0L);
 }
--- old/usr/src/lib/libm/common/Q/atan2pil.c	2019-06-06 20:38:36.833005254 +0000
+++ new/usr/src/lib/libm/common/Q/atan2pil.c	2019-06-06 20:38:36.849946126 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,8 +35,8 @@
  */
 
 static const long double invpi = 3.183098861837906715377675267450287240689e-1L;
-
 long double
-atan2pil(long double y, long double x) {
+atan2pil(long double y, long double x)
+{
 	return (atan2l(y, x) * invpi);
 }
--- old/usr/src/lib/libm/common/Q/atanhl.c	2019-06-06 20:38:37.264097605 +0000
+++ new/usr/src/lib/libm/common/Q/atanhl.c	2019-06-06 20:38:37.279942950 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -48,14 +49,16 @@
  */
 
 static const long double zero = 0.0L, half = 0.5L, one = 1.0L;
-
 long double
-atanhl(long double x) {
+atanhl(long double x)
+{
 	long double t;
 
 	t = fabsl(x);
+
 	if (t == one)
 		return (x / zero);
+
 	t = t / (one - t);
 	return (copysignl(half, x) * log1pl(t + t));
 }
--- old/usr/src/lib/libm/common/Q/atanl.c	2019-06-06 20:38:37.694411967 +0000
+++ new/usr/src/lib/libm/common/Q/atanl.c	2019-06-06 20:38:37.711717887 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,9 +40,9 @@
  * The algorithm is based on atan(x)=atan(y)+atan((x-y)/(1+x*y)).
  * We use poly1(x) to approximate atan(x) for x in [0,1/8] with
  * error (relative)
- * 	|(atan(x)-poly1(x))/x|<= 2^-115.94 	long double
- * 	|(atan(x)-poly1(x))/x|<= 2^-58.85	double
- * 	|(atan(x)-poly1(x))/x|<= 2^-25.53 	float
+ *      |(atan(x)-poly1(x))/x|<= 2^-115.94      long double
+ *      |(atan(x)-poly1(x))/x|<= 2^-58.85	double
+ *      |(atan(x)-poly1(x))/x|<= 2^-25.53       float
  * and use poly2(x) to approximate atan(x) for x in [0,1/65] with
  * error (absolute)
  *	|atan(x)-poly2(x)|<= 2^-122.15		long double
@@ -80,38 +81,38 @@
 #include "libm.h"
 
 extern const long double _TBL_atanl_hi[], _TBL_atanl_lo[];
-static const long double
-	one	=   1.0L,
-	p1  	=  -3.333333333333333333333333333331344526118e-0001L,
-	p2  	=   1.999999999999999999999999989931277668570e-0001L,
-	p3  	=  -1.428571428571428571428553606221309530901e-0001L,
-	p4  	=   1.111111111111111111095219842737139747418e-0001L,
-	p5  	=  -9.090909090909090825503603835248061123323e-0002L,
-	p6  	=   7.692307692307664052130743214708925258904e-0002L,
-	p7  	=  -6.666666666660213835187713228363717388266e-0002L,
-	p8  	=   5.882352940152439399097283359608661949504e-0002L,
-	p9  	=  -5.263157780447533993046614040509529668487e-0002L,
-	p10 	=   4.761895816878184933175855990886788439447e-0002L,
-	p11 	=  -4.347345005832274022681019724553538135922e-0002L,
-	p12 	=   3.983031914579635037502589204647752042736e-0002L,
-	p13 	=  -3.348206704469830575196657749413894897554e-0002L,
-	q1  	=  -3.333333333333333333333333333195273650186e-0001L,
-	q2  	=   1.999999999999999999999988146114392615808e-0001L,
-	q3  	=  -1.428571428571428571057630319435467111253e-0001L,
-	q4  	=   1.111111111111105373263048208994541544098e-0001L,
-	q5  	=  -9.090909090421834209167373258681021816441e-0002L,
-	q6  	=   7.692305377813692706850171767150701644539e-0002L,
-	q7  	=  -6.660896644393861499914731734305717901330e-0002L,
-	pio2hi	=   1.570796326794896619231321691639751398740e+0000L,
-	pio2lo	=   4.335905065061890512398522013021675984381e-0035L;
+static const long double one = 1.0L,
+	p1 = -3.333333333333333333333333333331344526118e-0001L,
+	p2 = 1.999999999999999999999999989931277668570e-0001L,
+	p3 = -1.428571428571428571428553606221309530901e-0001L,
+	p4 = 1.111111111111111111095219842737139747418e-0001L,
+	p5 = -9.090909090909090825503603835248061123323e-0002L,
+	p6 = 7.692307692307664052130743214708925258904e-0002L,
+	p7 = -6.666666666660213835187713228363717388266e-0002L,
+	p8 = 5.882352940152439399097283359608661949504e-0002L,
+	p9 = -5.263157780447533993046614040509529668487e-0002L,
+	p10 = 4.761895816878184933175855990886788439447e-0002L,
+	p11 = -4.347345005832274022681019724553538135922e-0002L,
+	p12 = 3.983031914579635037502589204647752042736e-0002L,
+	p13 = -3.348206704469830575196657749413894897554e-0002L,
+	q1 = -3.333333333333333333333333333195273650186e-0001L,
+	q2 = 1.999999999999999999999988146114392615808e-0001L,
+	q3 = -1.428571428571428571057630319435467111253e-0001L,
+	q4 = 1.111111111111105373263048208994541544098e-0001L,
+	q5 = -9.090909090421834209167373258681021816441e-0002L,
+	q6 = 7.692305377813692706850171767150701644539e-0002L,
+	q7 = -6.660896644393861499914731734305717901330e-0002L,
+	pio2hi = 1.570796326794896619231321691639751398740e+0000L,
+	pio2lo = 4.335905065061890512398522013021675984381e-0035L;
 
 #define	i0	0
 #define	i1	3
 
 long double
-atanl(long double x) {
+atanl(long double x)
+{
 	long double y, z, r, p, s;
-	int *px = (int *) &x, *py = (int *) &y;
+	int *px = (int *)&x, *py = (int *)&y;
 	int ix, iy, sign, j;
 
 	ix = px[i0];
@@ -120,59 +121,66 @@
 
 	/* for |x| < 1/8 */
 	if (ix < 0x3ffc0000) {
-		if (ix < 0x3feb0000) {	/* when |x| < 2**(-prec/6-2) */
+		if (ix < 0x3feb0000) {		/* when |x| < 2**(-prec/6-2) */
 			if (ix < 0x3fc50000) {	/* if |x| < 2**(-prec/2-2) */
 				s = one;
-				*(3 - i0 + (int *) &s) = -1;	/* s = 1-ulp */
-				*(1 + (int *) &s) = -1;
-				*(2 + (int *) &s) = -1;
-				*(i0 + (int *) &s) -= 1;
-				if ((int) (s * x) < 1)
+				*(3 - i0 + (int *)&s) = -1;	/* s = 1-ulp */
+				*(1 + (int *)&s) = -1;
+				*(2 + (int *)&s) = -1;
+				*(i0 + (int *)&s) -= 1;
+
+				if ((int)(s * x) < 1)
 					return (x);	/* raise inexact */
 			}
+
 			z = x * x;
-			if (ix < 0x3fe20000) {	/* if |x| < 2**(-prec/4-1) */
+
+			if (ix < 0x3fe20000)	/* if |x| < 2**(-prec/4-1) */
 				return (x + (x * z) * p1);
-			} else {	/* if |x| < 2**(-prec/6-2) */
+			else			/* if |x| < 2**(-prec/6-2) */
 				return (x + (x * z) * (p1 + z * p2));
-			}
 		}
+
 		z = x * x;
-		return (x + (x * z) * (p1 + z * (p2 + z * (p3 + z * (p4 +
-			z * (p5 + z * (p6 + z * (p7 + z * (p8 + z * (p9 +
-			z * (p10 + z * (p11 + z * (p12 + z * p13)))))))))))));
+		return (x + (x * z) * (p1 + z * (p2 + z * (p3 + z * (p4 + z *
+		    (p5 + z * (p6 + z * (p7 + z * (p8 + z * (p9 + z *
+		    (p10 + z * (p11 + z * (p12 + z * p13)))))))))))));
 	}
 
 	/* for |x| >= 8.0 */
 	if (ix >= 0x40020000) {
 		px[i0] = ix;
+
 		if (ix < 0x40050400) {	/* x <  65 */
 			r = one / x;
 			z = r * r;
+
 			/*
 			 * poly1
 			 */
-			y = r * (one + z * (p1 + z * (p2 + z * (p3 +
-				z * (p4 + z * (p5 + z * (p6 + z * (p7 +
-				z * (p8 + z * (p9 + z * (p10 + z * (p11 +
-				z * (p12 + z * p13)))))))))))));
+			y = r * (one + z * (p1 + z * (p2 + z * (p3 + z * (p4 +
+			    z * (p5 + z * (p6 + z * (p7 + z * (p8 + z * (p9 +
+			    z * (p10 + z * (p11 + z * (p12 + z *
+			    p13)))))))))))));
 			y -= pio2lo;
 		} else if (ix < 0x40260000) {	/* x <  2**(prec/3+2) */
 			r = one / x;
 			z = r * r;
+
 			/*
 			 * poly2
 			 */
 			y = r * (one + z * (q1 + z * (q2 + z * (q3 + z * (q4 +
-				z * (q5 + z * (q6 + z * q7)))))));
+			    z * (q5 + z * (q6 + z * q7)))))));
 			y -= pio2lo;
 		} else if (ix < 0x40720000) {	/* x <  2**(prec+2) */
 			y = one / x - pio2lo;
 		} else if (ix < 0x7fff0000) {	/* x <  inf */
 			y = -pio2lo;
-		} else {		/* x is inf or NaN */
+		} else {			/* x is inf or NaN */
 			if (((ix - 0x7fff0000) | px[1] | px[2] | px[i1]) != 0)
 				return (x - x);
+
 			y = -pio2lo;
 		}
 
@@ -193,12 +201,15 @@
 		s = (x - y) / (one + x * y);
 	else
 		s = (y - x) / (one + x * y);
+
 	z = s * s;
+
 	if (ix == iy)
 		p = s * (one + z * (q1 + z * (q2 + z * (q3 + z * q4))));
 	else
-		p = s * (one + z * (q1 + z * (q2 + z * (q3 + z * (q4 +
-			z * (q5 + z * (q6 + z * q7)))))));
+		p = s * (one + z * (q1 + z * (q2 + z * (q3 + z * (q4 + z * (q5 +
+		    z * (q6 + z * q7)))))));
+
 	if (sign == 0) {
 		r = p + _TBL_atanl_lo[j];
 		return (r + _TBL_atanl_hi[j]);
--- old/usr/src/lib/libm/common/Q/cbrtl.c	2019-06-06 20:38:38.193420594 +0000
+++ new/usr/src/lib/libm/common/Q/cbrtl.c	2019-06-06 20:38:38.210898722 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,30 +36,34 @@
 #define	n0	0
 
 long double
-cbrtl(long double x) {
+cbrtl(long double x)
+{
 	long double s, t, r, w, y;
 	double dx, dy;
-	int *py = (int *) &dy;
+	int *py = (int *)&dy;
 	int n, m, m3, sx;
 
 	if (!finitel(x))
 		return (x + x);
+
 	if (iszerol(x))
 		return (x);
+
 	sx = signbitl(x);
 	x = fabsl(x);
 	n = ilogbl(x);
 	m = n / 3;
 	m3 = m + m + m;
 	y = scalbnl(x, -m3);
-	dx = (double) y;
+	dx = (double)y;
 	dy = cbrt(dx);
 	py[1 - n0] += 2;
+
 	if (py[1 - n0] == 0)
 		py[n0] += 1;
 
 	/* one step newton iteration to 113 bits with error < 0.667ulps */
-	t = (long double) dy;
+	t = (long double)dy;
 	t = scalbnl(t, m);
 	s = t * t;
 	r = x / s;
--- old/usr/src/lib/libm/common/Q/copysignl.c	2019-06-06 20:38:38.680829207 +0000
+++ new/usr/src/lib/libm/common/Q/copysignl.c	2019-06-06 20:38:38.697537926 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,9 +33,10 @@
 #include "libm.h"
 
 long double
-copysignl(long double x, long double y) {
-	int *px = (int *) &x;
-	int *py = (int *) &y;
+copysignl(long double x, long double y)
+{
+	int *px = (int *)&x;
+	int *py = (int *)&y;
 
 	px[HIXWORD] = (px[HIXWORD] & ~XSGNMSK) | (py[HIXWORD] & XSGNMSK);
 	return (x);
--- old/usr/src/lib/libm/common/Q/coshl.c	2019-06-06 20:38:39.162591355 +0000
+++ new/usr/src/lib/libm/common/Q/coshl.c	2019-06-06 20:38:39.180407346 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,7 +33,6 @@
 #include "libm.h"
 #include "longdouble.h"
 
-
 /*
  * coshl(X)
  * RETURN THE HYPERBOLIC COSINE OF X
@@ -64,44 +64,48 @@
  *	only coshl(0)=1 is exact for finite x.
  */
 
-#define	ME	16383
-#define	MEP1	16384
-#define	LNOVFT	1.135652340629414394949193107797076342845e+4L
-		/* last 32 bits of LN2HI is zero */
-#define	LN2HI   6.931471805599453094172319547495844850203e-0001L
-#define	LN2LO   1.667085920830552208890449330400379754169e-0025L
-#define	THR1	0.3465L
-#define	THR2	45.L
-
-static const long double
-	half 	= 0.5L,
-	tinyl	= 7.5e-37L,
-	one	= 1.0L,
-	ln2hi   = LN2HI,
-	ln2lo   = LN2LO,
-	lnovftL	= LNOVFT,
-	thr1	= THR1,
-	thr2	= THR2;
+#define	ME		16383
+#define	MEP1		16384
+#define	LNOVFT		1.135652340629414394949193107797076342845e+4L
+/* last 32 bits of LN2HI is zero */
+#define	LN2HI		6.931471805599453094172319547495844850203e-0001L
+#define	LN2LO		1.667085920830552208890449330400379754169e-0025L
+#define	THR1		0.3465L
+#define	THR2		45.L
+
+static const long double half = 0.5L,
+	tinyl = 7.5e-37L,
+	one = 1.0L,
+	ln2hi = LN2HI,
+	ln2lo = LN2LO,
+	lnovftL = LNOVFT,
+	thr1 = THR1,
+	thr2 = THR2;
 
 long double
-coshl(long double x) {
+coshl(long double x)
+{
 	long double t, w;
 
 	w = fabsl(x);
+
 	if (!finitel(w))
 		return (w + w);		/* x is INF or NaN */
+
 	if (w < thr1) {
 		t = w < tinyl ? w : expm1l(w);
 		w = one + t;
+
 		if (w != one)
 			w = one + (t * t) / (w + w);
+
 		return (w);
 	} else if (w < thr2) {
 		t = expl(w);
 		return (half * (t + one / t));
-	} else if (w <= lnovftL)
+	} else if (w <= lnovftL) {
 		return (half * expl(w));
-	else {
+	} else {
 		return (scalbnl(expl((w - MEP1 * ln2hi) - MEP1 * ln2lo), ME));
 	}
 }
--- old/usr/src/lib/libm/common/Q/cosl.c	2019-06-06 20:38:39.629241405 +0000
+++ new/usr/src/lib/libm/common/Q/cosl.c	2019-06-06 20:38:39.645358282 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -65,19 +66,22 @@
 #include "longdouble.h"
 
 long double
-cosl(long double x) {
+cosl(long double x)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
 
-	ix = *(int *) &x;			/* High word of x */
+	ix = *(int *)&x;		/* High word of x */
 
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)			/* |x| ~< pi/4 */
+
+	if (ix <= 0x3ffe9220) {		/* |x| ~< pi/4 */
 		return (__k_cosl(x, z));
-	else if (ix >= 0x7fff0000)		/* trig(Inf or NaN) is NaN */
+	} else if (ix >= 0x7fff0000) {	/* trig(Inf or NaN) is NaN */
 		return (x - x);
-	else {					/* argument reduction needed */
+	} else {			/* argument reduction needed */
 		n = __rem_pio2l(x, y);
+
 		switch (n & 3) {
 		case 0:
 			return (__k_cosl(y[0], y[1]));
@@ -89,6 +93,7 @@
 			return (__k_sinl(y[0], y[1]));
 		}
 	}
+
 	/* NOTREACHED */
-    return 0.0L;
+	return (0.0L);
 }
--- old/usr/src/lib/libm/common/Q/erfl.c	2019-06-06 20:38:40.079381287 +0000
+++ new/usr/src/lib/libm/common/Q/erfl.c	2019-06-06 20:38:40.097147219 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,18 +34,18 @@
  *			     x
  *		      2      |\
  *     erf(x)  =  ---------  | exp(-t*t)dt
- *	 	   sqrt(pi) \|
+ *	           sqrt(pi) \|
  *			     0
  *
  *     erfc(x) =  1-erf(x)
  *
  * method:
- * 	Since erf(-x) = -erf(x), we assume x>=0.
+ *      Since erf(-x) = -erf(x), we assume x>=0.
  *	For x near 0, we have the expansion
  *
- *     	    erf(x) = (2/sqrt(pi))*(x - x^3/3 + x^5/10 - x^7/42 + ....).
+ *          erf(x) = (2/sqrt(pi))*(x - x^3/3 + x^5/10 - x^7/42 + ....).
  *
- * 	Since 2/sqrt(pi) = 1.128379167095512573896158903121545171688,
+ *      Since 2/sqrt(pi) = 1.128379167095512573896158903121545171688,
  *	we use x + x*P(x^2) to approximate erf(x). This formula will
  *	guarantee the error less than one ulp where x is not too far
  *	away from 0. We note that erf(x)=x at x = 0.6174...... After
@@ -53,10 +54,10 @@
  *
  *	For x in [0,0.84375]
  *		   2		    2        4		     40
- *	   P = 	P(x ) = (p0 + p1 * x + p2 * x + ... + p20 * x  )
+ *	   P =  P(x ) = (p0 + p1 * x + p2 * x + ... + p20 * x  )
  *
  *	   erf(x)  = x + x*P
- *	   erfc(x) = 1 - erf(x) 	  if x<=0.25
+ *	   erfc(x) = 1 - erf(x)           if x<=0.25
  *		   = 0.5 + ((0.5-x)-x*P)  if x in [0.25,0.84375]
  *	precision: |P(x^2)-(erf(x)-x)/x| <= 2**-122.50
  *
@@ -99,247 +100,279 @@
 #include "libm.h"
 #include "longdouble.h"
 
-static const long double
-	tiny	    = 1e-40L,
-	nearunfl    = 1e-4000L,
-	half	    = 0.5L,
-	one	    = 1.0L,
-	onehalf	    = 1.5L,
-	L16_3	    = 16.0L/3.0L;
+static const long double tiny = 1e-40L,
+	nearunfl = 1e-4000L,
+	half = 0.5L,
+	one = 1.0L,
+	onehalf = 1.5L,
+	L16_3 = 16.0L / 3.0L;
+
 /*
  * Coefficients for even polynomial P for erf(x)=x+x*P(x^2) on [0,0.84375]
  */
-static const long double P[] = { 	/* 21 coeffs */
-   1.283791670955125738961589031215451715556e-0001L,
-  -3.761263890318375246320529677071815594603e-0001L,
-   1.128379167095512573896158903121205899135e-0001L,
-  -2.686617064513125175943235483344625046092e-0002L,
-   5.223977625442187842111846652980454568389e-0003L,
-  -8.548327023450852832546626271083862724358e-0004L,
-   1.205533298178966425102164715902231976672e-0004L,
-  -1.492565035840625097674944905027897838996e-0005L,
-   1.646211436588924733604648849172936692024e-0006L,
-  -1.636584469123491976815834704799733514987e-0007L,
-   1.480719281587897445302529007144770739305e-0008L,
-  -1.229055530170782843046467986464722047175e-0009L,
-   9.422759064320307357553954945760654341633e-0011L,
-  -6.711366846653439036162105104991433380926e-0012L,
-   4.463224090341893165100275380693843116240e-0013L,
-  -2.783513452582658245422635662559779162312e-0014L,
-   1.634227412586960195251346878863754661546e-0015L,
-  -9.060782672889577722765711455623117802795e-0017L,
-   4.741341801266246873412159213893613602354e-0018L,
-  -2.272417596497826188374846636534317381203e-0019L,
-   8.069088733716068462496835658928566920933e-0021L,
+static const long double P[] = {	/* 21 coeffs */
+	1.283791670955125738961589031215451715556e-0001L,
+	-3.761263890318375246320529677071815594603e-0001L,
+	1.128379167095512573896158903121205899135e-0001L,
+	-2.686617064513125175943235483344625046092e-0002L,
+	5.223977625442187842111846652980454568389e-0003L,
+	-8.548327023450852832546626271083862724358e-0004L,
+	1.205533298178966425102164715902231976672e-0004L,
+	-1.492565035840625097674944905027897838996e-0005L,
+	1.646211436588924733604648849172936692024e-0006L,
+	-1.636584469123491976815834704799733514987e-0007L,
+	1.480719281587897445302529007144770739305e-0008L,
+	-1.229055530170782843046467986464722047175e-0009L,
+	9.422759064320307357553954945760654341633e-0011L,
+	-6.711366846653439036162105104991433380926e-0012L,
+	4.463224090341893165100275380693843116240e-0013L,
+	-2.783513452582658245422635662559779162312e-0014L,
+	1.634227412586960195251346878863754661546e-0015L,
+	-9.060782672889577722765711455623117802795e-0017L,
+	4.741341801266246873412159213893613602354e-0018L,
+	-2.272417596497826188374846636534317381203e-0019L,
+	8.069088733716068462496835658928566920933e-0021L,
 };
 
 /*
  * Rational erf(x) = ((float)0.84506291151) + P1(x-1)/Q1(x-1) on [0.84375,1.25]
  */
-static const long double C1   = (long double)((float)0.84506291151);
-static const long double P1[] = { 	/*  12 top coeffs */
-  -2.362118560752659955654364917390741930316e-0003L,
-   4.129623379624420034078926610650759979146e-0001L,
-  -3.973857505403547283109417923182669976904e-0002L,
-   4.357503184084022439763567513078036755183e-0002L,
-   8.015593623388421371247676683754171456950e-0002L,
-  -1.034459310403352486685467221776778474602e-0002L,
-   5.671850295381046679675355719017720821383e-0003L,
-   1.219262563232763998351452194968781174318e-0003L,
-   5.390833481581033423020320734201065475098e-0004L,
-  -1.978853912815115495053119023517805528300e-0004L,
-   6.184234513953600118335017885706420552487e-0005L,
-  -5.331802711697810861017518515816271808286e-0006L,
+static const long double C1 = (long double)((float)0.84506291151);
+static const long double P1[] = {	/*  12 top coeffs */
+	-2.362118560752659955654364917390741930316e-0003L,
+	4.129623379624420034078926610650759979146e-0001L,
+	-3.973857505403547283109417923182669976904e-0002L,
+	4.357503184084022439763567513078036755183e-0002L,
+	8.015593623388421371247676683754171456950e-0002L,
+	-1.034459310403352486685467221776778474602e-0002L,
+	5.671850295381046679675355719017720821383e-0003L,
+	1.219262563232763998351452194968781174318e-0003L,
+	5.390833481581033423020320734201065475098e-0004L,
+	-1.978853912815115495053119023517805528300e-0004L,
+	6.184234513953600118335017885706420552487e-0005L,
+	-5.331802711697810861017518515816271808286e-0006L,
 };
-static const long double Q1[] = { 	/*  12 bottom coeffs with leading 1.0 hidden */
-   9.081506296064882195280178373107623196655e-0001L,
-   6.821049531968204097604392183650687642520e-0001L,
-   4.067869178233539502315055970743271822838e-0001L,
-   1.702332233546316765818144723063881095577e-0001L,
-   7.498098377690553934266423088708614219356e-0002L,
-   2.050154396918178697056927234366372760310e-0002L,
-   7.012988534031999899054782333851905939379e-0003L,
-   1.149904787014400354649843451234570731076e-0003L,
-   3.185620255011299476196039491205159718620e-0004L,
-   1.273405072153008775426376193374105840517e-0005L,
-   4.753866999959432971956781228148402971454e-0006L,
-  -1.002287602111660026053981728549540200683e-0006L,
+
+static const long double Q1[] = { /* 12 bottom coeffs with leading 1.0 hidden */
+	9.081506296064882195280178373107623196655e-0001L,
+	6.821049531968204097604392183650687642520e-0001L,
+	4.067869178233539502315055970743271822838e-0001L,
+	1.702332233546316765818144723063881095577e-0001L,
+	7.498098377690553934266423088708614219356e-0002L,
+	2.050154396918178697056927234366372760310e-0002L,
+	7.012988534031999899054782333851905939379e-0003L,
+	1.149904787014400354649843451234570731076e-0003L,
+	3.185620255011299476196039491205159718620e-0004L,
+	1.273405072153008775426376193374105840517e-0005L,
+	4.753866999959432971956781228148402971454e-0006L,
+	-1.002287602111660026053981728549540200683e-0006L,
 };
+
 /*
  * Rational erf(x) = ((float)0.95478588343) + P2(x-1.5)/Q2(x-1.5)
  * on [1.25,1.75]
  */
-static const long double C2   = (long double)((float)0.95478588343);
-static const long double P2[] = { 	/*  12 top coeffs */
-   1.131926304864446730135126164594785863512e-0002L,
-   1.273617996967754151544330055186210322832e-0001L,
-  -8.169980734667512519897816907190281143423e-0002L,
-   9.512267486090321197833634271787944271746e-0002L,
-  -2.394251569804872160005274999735914368170e-0002L,
-   1.108768660227528667525252333184520222905e-0002L,
-   3.527435492933902414662043314373277494221e-0004L,
-   4.946116273341953463584319006669474625971e-0004L,
-  -4.289851942513144714600285769022420962418e-0005L,
-   8.304719841341952705874781636002085119978e-0005L,
-  -1.040460226177309338781902252282849903189e-0005L,
-   2.122913331584921470381327583672044434087e-0006L,
+static const long double C2 = (long double)((float)0.95478588343);
+static const long double P2[] = {	/*  12 top coeffs */
+	1.131926304864446730135126164594785863512e-0002L,
+	1.273617996967754151544330055186210322832e-0001L,
+	-8.169980734667512519897816907190281143423e-0002L,
+	9.512267486090321197833634271787944271746e-0002L,
+	-2.394251569804872160005274999735914368170e-0002L,
+	1.108768660227528667525252333184520222905e-0002L,
+	3.527435492933902414662043314373277494221e-0004L,
+	4.946116273341953463584319006669474625971e-0004L,
+	-4.289851942513144714600285769022420962418e-0005L,
+	8.304719841341952705874781636002085119978e-0005L,
+	-1.040460226177309338781902252282849903189e-0005L,
+	2.122913331584921470381327583672044434087e-0006L,
 };
-static const long double Q2[] = { 	/*  13 bottom coeffs with leading 1.0 hidden */
-   7.448815737306992749168727691042003832150e-0001L,
-   7.161813850236008294484744312430122188043e-0001L,
-   3.603134756584225766144922727405641236121e-0001L,
-   1.955811609133766478080550795194535852653e-0001L,
-   7.253059963716225972479693813787810711233e-0002L,
-   2.752391253757421424212770221541238324978e-0002L,
-   7.677654852085240257439050673446546828005e-0003L,
-   2.141102244555509687346497060326630061069e-0003L,
-   4.342123013830957093949563339130674364271e-0004L,
-   8.664587895570043348530991997272212150316e-0005L,
-   1.109201582511752087060167429397033701988e-0005L,
-   1.357834375781831062713347000030984364311e-0006L,
-   4.957746280594384997273090385060680016451e-0008L,
+
+static const long double Q2[] = { /* 13 bottom coeffs with leading 1.0 hidden */
+	7.448815737306992749168727691042003832150e-0001L,
+	7.161813850236008294484744312430122188043e-0001L,
+	3.603134756584225766144922727405641236121e-0001L,
+	1.955811609133766478080550795194535852653e-0001L,
+	7.253059963716225972479693813787810711233e-0002L,
+	2.752391253757421424212770221541238324978e-0002L,
+	7.677654852085240257439050673446546828005e-0003L,
+	2.141102244555509687346497060326630061069e-0003L,
+	4.342123013830957093949563339130674364271e-0004L,
+	8.664587895570043348530991997272212150316e-0005L,
+	1.109201582511752087060167429397033701988e-0005L,
+	1.357834375781831062713347000030984364311e-0006L,
+	4.957746280594384997273090385060680016451e-0008L,
 };
+
 /*
  * erfc(x) = exp(-x*x)/x * R1(1/x)/S1(1/x) on [1.75, 16/3]
  */
-static const long double R1[] = { 	/*  14 top coeffs */
-   4.630195122654315016370705767621550602948e+0006L,
-   1.257949521746494830700654204488675713628e+0007L,
-   1.704153822720260272814743497376181625707e+0007L,
-   1.502600568706061872381577539537315739943e+0007L,
-   9.543710793431995284827024445387333922861e+0006L,
-   4.589344808584091011652238164935949522427e+0006L,
-   1.714660662941745791190907071920671844289e+0006L,
-   5.034802147768798894307672256192466283867e+0005L,
-   1.162286400443554670553152110447126850725e+0005L,
-   2.086643834548901681362757308058660399137e+0004L,
-   2.839793161868140305907004392890348777338e+0003L,
-   2.786687241658423601778258694498655680778e+0002L,
-   1.779177837102695602425897452623985786464e+0001L,
-   5.641895835477470769043614623819144434731e-0001L,
+static const long double R1[] = {	/*  14 top coeffs */
+	4.630195122654315016370705767621550602948e+0006L,
+	1.257949521746494830700654204488675713628e+0007L,
+	1.704153822720260272814743497376181625707e+0007L,
+	1.502600568706061872381577539537315739943e+0007L,
+	9.543710793431995284827024445387333922861e+0006L,
+	4.589344808584091011652238164935949522427e+0006L,
+	1.714660662941745791190907071920671844289e+0006L,
+	5.034802147768798894307672256192466283867e+0005L,
+	1.162286400443554670553152110447126850725e+0005L,
+	2.086643834548901681362757308058660399137e+0004L,
+	2.839793161868140305907004392890348777338e+0003L,
+	2.786687241658423601778258694498655680778e+0002L,
+	1.779177837102695602425897452623985786464e+0001L,
+	5.641895835477470769043614623819144434731e-0001L,
 };
-static const long double S1[] = { 	/* 15 bottom coeffs with leading 1.0 hidden */
-   4.630195122654331529595606896287596843110e+0006L,
-   1.780411093345512024324781084220509055058e+0007L,
-   3.250113097051800703707108623715776848283e+0007L,
-   3.737857099176755050912193712123489115755e+0007L,
-   3.029787497516578821459174055870781168593e+0007L,
-   1.833850619965384765005769632103205777227e+0007L,
-   8.562719999736915722210391222639186586498e+0006L,
-   3.139684562074658971315545539760008136973e+0006L,
-   9.106421313731384880027703627454366930945e+0005L,
-   2.085108342384266508613267136003194920001e+0005L,
-   3.723126272693120340730491416449539290600e+0004L,
-   5.049169878567344046145695360784436929802e+0003L,
-   4.944274532748010767670150730035392093899e+0002L,
-   3.153510608818213929982940249162268971412e+0001L,
-   1.0e00L,
+
+static const long double S1[] = { /* 15 bottom coeffs with leading 1.0 hidden */
+	4.630195122654331529595606896287596843110e+0006L,
+	1.780411093345512024324781084220509055058e+0007L,
+	3.250113097051800703707108623715776848283e+0007L,
+	3.737857099176755050912193712123489115755e+0007L,
+	3.029787497516578821459174055870781168593e+0007L,
+	1.833850619965384765005769632103205777227e+0007L,
+	8.562719999736915722210391222639186586498e+0006L,
+	3.139684562074658971315545539760008136973e+0006L,
+	9.106421313731384880027703627454366930945e+0005L,
+	2.085108342384266508613267136003194920001e+0005L,
+	3.723126272693120340730491416449539290600e+0004L,
+	5.049169878567344046145695360784436929802e+0003L,
+	4.944274532748010767670150730035392093899e+0002L,
+	3.153510608818213929982940249162268971412e+0001L,
+	1.0e00L,
 };
 
 /*
  * erfc(x) = exp(-x*x)/x * R2(1/x)/S2(1/x) on [16/3, 107]
  */
-static const long double R2[] = { 	/*  15 top coeffs in reverse order!!*/
-   2.447288012254302966796326587537136931669e+0005L,
-   8.768592567189861896653369912716538739016e+0005L,
-   1.552293152581780065761497908005779524953e+0006L,
-   1.792075924835942935864231657504259926729e+0006L,
-   1.504001463155897344947500222052694835875e+0006L,
-   9.699485556326891411801230186016013019935e+0005L,
-   4.961449933661807969863435013364796037700e+0005L,
-   2.048726544693474028061176764716228273791e+0005L,
-   6.891532964330949722479061090551896886635e+0004L,
-   1.888014709010307507771964047905823237985e+0004L,
-   4.189692064988957745054734809642495644502e+0003L,
-   7.362346487427048068212968889642741734621e+0002L,
-   9.980359714211411423007641056580813116207e+0001L,
-   9.426910895135379181107191962193485174159e+0000L,
-   5.641895835477562869480794515623601280429e-0001L,
+static const long double R2[] = { /*  15 top coeffs in reverse order!! */
+	2.447288012254302966796326587537136931669e+0005L,
+	8.768592567189861896653369912716538739016e+0005L,
+	1.552293152581780065761497908005779524953e+0006L,
+	1.792075924835942935864231657504259926729e+0006L,
+	1.504001463155897344947500222052694835875e+0006L,
+	9.699485556326891411801230186016013019935e+0005L,
+	4.961449933661807969863435013364796037700e+0005L,
+	2.048726544693474028061176764716228273791e+0005L,
+	6.891532964330949722479061090551896886635e+0004L,
+	1.888014709010307507771964047905823237985e+0004L,
+	4.189692064988957745054734809642495644502e+0003L,
+	7.362346487427048068212968889642741734621e+0002L,
+	9.980359714211411423007641056580813116207e+0001L,
+	9.426910895135379181107191962193485174159e+0000L,
+	5.641895835477562869480794515623601280429e-0001L,
 };
-static const long double S2[] = { 	/* 16 coefficients */
-   2.447282203601902971246004716790604686880e+0005L,
-   1.153009852759385309367759460934808489833e+0006L,
-   2.608580649612639131548966265078663384849e+0006L,
-   3.766673917346623308850202792390569025740e+0006L,
-   3.890566255138383910789924920541335370691e+0006L,
-   3.052882073900746207613166259994150527732e+0006L,
-   1.885574519970380988460241047248519418407e+0006L,
-   9.369722034759943185851450846811445012922e+0005L,
-   3.792278350536686111444869752624492443659e+0005L,
-   1.257750606950115799965366001773094058720e+0005L,
-   3.410830600242369370645608634643620355058e+0004L,
-   7.513984469742343134851326863175067271240e+0003L,
-   1.313296320593190002554779998138695507840e+0003L,
-   1.773972700887629157006326333696896516769e+0002L,
-   1.670876451822586800422009013880457094162e+0001L,
-   1.000L,
+
+static const long double S2[] = {	/* 16 coefficients */
+	2.447282203601902971246004716790604686880e+0005L,
+	1.153009852759385309367759460934808489833e+0006L,
+	2.608580649612639131548966265078663384849e+0006L,
+	3.766673917346623308850202792390569025740e+0006L,
+	3.890566255138383910789924920541335370691e+0006L,
+	3.052882073900746207613166259994150527732e+0006L,
+	1.885574519970380988460241047248519418407e+0006L,
+	9.369722034759943185851450846811445012922e+0005L,
+	3.792278350536686111444869752624492443659e+0005L,
+	1.257750606950115799965366001773094058720e+0005L,
+	3.410830600242369370645608634643620355058e+0004L,
+	7.513984469742343134851326863175067271240e+0003L,
+	1.313296320593190002554779998138695507840e+0003L,
+	1.773972700887629157006326333696896516769e+0002L,
+	1.670876451822586800422009013880457094162e+0001L,
+	1.000L,
 };
 
-long double erfl(x)
-long double x;
+long double
+erfl(long double x)
 {
-	long double s,y,t;
+	long double s, y, t;
 
 	if (!finitel(x)) {
-	    if (x != x) return x+x; 	/* NaN */
-	    return copysignl(one,x);	/* return +-1.0 is x=Inf */
+		if (x != x)
+			return (x + x);		/* NaN */
+
+		return (copysignl(one, x));	/* return +-1.0 is x=Inf */
 	}
 
 	y = fabsl(x);
+
 	if (y <= 0.84375L) {
-	    if (y<=tiny) return x+P[0]*x;
-	    s = y*y;
-	    t = __poly_libmq(s,21,P);
-	    return  x+x*t;
+		if (y <= tiny)
+			return (x + P[0] * x);
+
+		s = y * y;
+		t = __poly_libmq(s, 21, P);
+		return (x + x * t);
 	}
-	if (y<=1.25L) {
-	    s = y-one;
-	    t = C1+__poly_libmq(s,12,P1)/(one+s*__poly_libmq(s,12,Q1));
-	    return (signbitl(x))? -t: t;
-	} else if (y<=1.75L) {
-	    s = y-onehalf;
-	    t = C2+__poly_libmq(s,12,P2)/(one+s*__poly_libmq(s,13,Q2));
-	    return (signbitl(x))? -t: t;
+
+	if (y <= 1.25L) {
+		s = y - one;
+		t = C1 + __poly_libmq(s, 12, P1) / (one + s * __poly_libmq(s,
+		    12, Q1));
+		return ((signbitl(x)) ? -t : t);
+	} else if (y <= 1.75L) {
+		s = y - onehalf;
+		t = C2 + __poly_libmq(s, 12, P2) / (one + s * __poly_libmq(s,
+		    13, Q2));
+		return ((signbitl(x)) ? -t : t);
 	}
-	if (y<=9.0L) t = erfcl(y); else t = tiny;
-	return (signbitl(x))? t-one: one-t;
+
+	if (y <= 9.0L)
+		t = erfcl(y);
+	else
+		t = tiny;
+
+	return ((signbitl(x)) ? t - one : one - t);
 }
 
-long double erfcl(x)
-long double x;
+long double
+erfcl(long double x)
 {
-	long double s,y,t;
+	long double s, y, t;
 
 	if (!finitel(x)) {
-	    if (x != x) return x+x; 	/* NaN */
-	    /* return 2.0 if x= -inf; 0.0 if x= +inf */
-	    if (x < 0.0L) return 2.0L; else return 0.0L;
+		if (x != x)
+			return (x + x);		/* NaN */
+
+		/* return 2.0 if x= -inf; 0.0 if x= +inf */
+		if (x < 0.0L)
+			return (2.0L);
+		else
+			return (0.0L);
 	}
 
 	if (x <= 0.84375L) {
-	    if (x<=0.25) return one-erfl(x);
-	    s = x*x;
-	    t = half-x;
-	    t = t - x*__poly_libmq(s,21,P);
-	    return  half+t;
+		if (x <= 0.25)
+			return (one - erfl(x));
+
+		s = x * x;
+		t = half - x;
+		t = t - x * __poly_libmq(s, 21, P);
+		return (half + t);
 	}
-	if (x<=1.25L) {
-	    s = x-one;
-	    t = one-C1;
-	    return t - __poly_libmq(s,12,P1)/(one+s*__poly_libmq(s,12,Q1));
-	} else if (x<=1.75L) {
-	    s = x-onehalf;
-	    t = one-C2;
-	    return t - __poly_libmq(s,12,P2)/(one+s*__poly_libmq(s,13,Q2));
+
+	if (x <= 1.25L) {
+		s = x - one;
+		t = one - C1;
+		return (t - __poly_libmq(s, 12, P1) / (one + s * __poly_libmq(s,
+		    12, Q1)));
+	} else if (x <= 1.75L) {
+		s = x - onehalf;
+		t = one - C2;
+		return (t - __poly_libmq(s, 12, P2) / (one + s * __poly_libmq(s,
+		    13, Q2)));
 	}
-	if (x>=107.0L) return nearunfl*nearunfl;		/* underflow */
-	else if (x >= L16_3) {
-	    y = __poly_libmq(x,15,R2);
-	    t = y/__poly_libmq(x,16,S2);
+
+	if (x >= 107.0L) {
+		return (nearunfl * nearunfl);	/* underflow */
+	} else if (x >= L16_3) {
+		y = __poly_libmq(x, 15, R2);
+		t = y / __poly_libmq(x, 16, S2);
 	} else {
-	    y = __poly_libmq(x,14,R1);
-	    t = y/__poly_libmq(x,15,S1);
+		y = __poly_libmq(x, 14, R1);
+		t = y / __poly_libmq(x, 15, S1);
 	}
+
 	/*
 	 * Note that exp(-x*x+d) = exp(-x*x)*exp(d), so to compute
 	 * exp(-x*x) with a small relative error, we need to compute
@@ -360,7 +393,7 @@
 	 * non-portable code is preferable.
 	 */
 	y = x;
-	*(2+(int*)&y) = *(3+(int*)&y) = 0;
-	t *= expl(-y*y)*expl(-(x-y)*(x+y));
-	return  t;
+	*(2 + (int *)&y) = *(3 + (int *)&y) = 0;
+	t *= expl(-y * y) * expl(-(x - y) * (x + y));
+	return (t);
 }
--- old/usr/src/lib/libm/common/Q/exp10l.c	2019-06-06 20:38:40.536723099 +0000
+++ new/usr/src/lib/libm/common/Q/exp10l.c	2019-06-06 20:38:40.552869293 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,27 +43,27 @@
  *		M = 48		quadruple precision (113 bits)
  */
 
-#define	TINY 	1.0e-20L	/* single: 1e-5, double: 1e-10, quad: 1e-20 */
+#define	TINY	1.0e-20L	/* single: 1e-5, double: 1e-10, quad: 1e-20 */
 #define	LG10OVT	4933.L		/* single:  39, double:  309, quad:  4933 */
 #define	LG10UFT	-4966.L		/* single: -45, double: -323, quad: -4966 */
-#define	M	48
-			/* logt2hi : last 32 bits is zero for quad prec */
-#define	LOGT2HI	0.30102999566398119521373889472420986034688L
-#define	LOGT2LO	2.831664213089468167896664371953e-31L
-
-static const long double
-	zero	= 0.0L,
-	tiny	= TINY * TINY,
-	one	= 1.0L,
-	lg10	= 3.321928094887362347870319429489390175865e+0000L,
-	ln10	= 2.302585092994045684017991454684364207601e+0000L,
-	logt2hi	= LOGT2HI,
-	logt2lo	= LOGT2LO,
-	lg10ovt	= LG10OVT,
-	lg10uft	= LG10UFT;
+#define	M		48
+/* logt2hi : last 32 bits is zero for quad prec */
+#define	LOGT2HI		0.30102999566398119521373889472420986034688L
+#define	LOGT2LO		2.831664213089468167896664371953e-31L
+
+static const long double zero = 0.0L,
+	tiny = TINY * TINY,
+	one = 1.0L,
+	lg10 = 3.321928094887362347870319429489390175865e+0000L,
+	ln10 = 2.302585092994045684017991454684364207601e+0000L,
+	logt2hi = LOGT2HI,
+	logt2lo = LOGT2LO,
+	lg10ovt = LG10OVT,
+	lg10uft = LG10UFT;
 
 long double
-exp10l(long double x) {
+exp10l(long double x)
+{
 	long double t, tenp;
 	int k;
 
@@ -72,31 +73,43 @@
 		else
 			return (zero);
 	}
+
 	if (fabsl(x) < tiny)
 		return (one + x);
-	if (x <= lg10ovt)
+
+	if (x <= lg10ovt) {
 		if (x >= lg10uft) {
-			k = (int) x;
+			k = (int)x;
 			tenp = 10.0L;
-					/* x is a small +integer */
-			if (0 <= k && k <= M && (long double) k == x) {
+
+			/* x is a small +integer */
+			if (0 <= k && k <= M && (long double)k == x) {
 				t = one;
+
 				if (k & 1)
 					t *= tenp;
+
 				k >>= 1;
+
 				while (k) {
 					tenp *= tenp;
+
 					if (k & 1)
 						t *= tenp;
+
 					k >>= 1;
 				}
+
 				return (t);
 			}
+
 			t = anintl(x * lg10);
-			return (scalbnl(expl(ln10 * ((x - t * logt2hi) -
-				t * logt2lo)), (int) t));
-		} else
+			return (scalbnl(expl(ln10 * ((x - t * logt2hi) - t *
+			    logt2lo)), (int)t));
+		} else {
 			return (scalbnl(one, -50000));	/* underflow */
-	else
-			return (scalbnl(one, 50000));	/* overflow  */
+		}
+	} else {
+		return (scalbnl(one, 50000));		/* overflow  */
+	}
 }
--- old/usr/src/lib/libm/common/Q/exp2l.c	2019-06-06 20:38:40.957883689 +0000
+++ new/usr/src/lib/libm/common/Q/exp2l.c	2019-06-06 20:38:40.973847368 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,19 +43,17 @@
 #define	OVFLEXP	16400		/* single: 130,  double  1030,  quad: 16400 */
 #define	UNFLEXP	-16520		/* single:-155,  double -1080,  quad:-16520 */
 
-static const long double
-	zero = 0.0L,
+static const long double zero = 0.0L,
 	tiny = TINY * TINY,
 	half = 0.5L,
 	ln2 = 6.931471805599453094172321214581765680755e-0001L,
 	one = 1.0L;
 
-static const int
-	ovflexp = OVFLEXP,
-	unflexp = UNFLEXP;
+static const int ovflexp = OVFLEXP, unflexp = UNFLEXP;
 
 long double
-exp2l(long double x) {
+exp2l(long double x)
+{
 	long double t;
 
 	if (!finitel(x)) {
@@ -63,19 +62,24 @@
 		else
 			return (zero);
 	}
+
 	t = fabsl(x);
+
 	if (t < half) {
 		if (t < tiny)
 			return (one + x);
 		else
 			return (expl(ln2 * x));
 	}
+
 	t = anintl(x);
+
 	if (t < ovflexp) {
 		if (t >= unflexp)
-			return (scalbnl(expl(ln2 * (x - t)), (int) t));
+			return (scalbnl(expl(ln2 * (x - t)), (int)t));
 		else
-			return (scalbnl(one, unflexp));	/* underflow */
-	} else
-		return (scalbnl(one, ovflexp));	/* overflow  */
+			return (scalbnl(one, unflexp));		/* underflow */
+	} else {
+		return (scalbnl(one, ovflexp));			/* overflow  */
+	}
 }
--- old/usr/src/lib/libm/common/Q/expl.c	2019-06-06 20:38:41.453541615 +0000
+++ new/usr/src/lib/libm/common/Q/expl.c	2019-06-06 20:38:41.471133706 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -72,55 +73,60 @@
 #include "libm.h"
 
 extern const long double _TBL_expl_hi[], _TBL_expl_lo[];
-
-static const long double
-one		=  1.0L,
-two		=  2.0L,
-ln2_64		=  1.083042469624914545964425189778400898568e-2L,
-ovflthreshold	=  1.135652340629414394949193107797076342845e+4L,
-unflthreshold	= -1.143346274333629787883724384345262150341e+4L,
-invln2_32	=  4.616624130844682903551758979206054839765e+1L,
-ln2_32hi	=  2.166084939249829091928849858592451515688e-2L,
-ln2_32lo	=  5.209643502595475652782654157501186731779e-27L;
+static const long double one = 1.0L,
+	two = 2.0L,
+	ln2_64 = 1.083042469624914545964425189778400898568e-2L,
+	ovflthreshold = 1.135652340629414394949193107797076342845e+4L,
+	unflthreshold = -1.143346274333629787883724384345262150341e+4L,
+	invln2_32 = 4.616624130844682903551758979206054839765e+1L,
+	ln2_32hi = 2.166084939249829091928849858592451515688e-2L,
+	ln2_32lo = 5.209643502595475652782654157501186731779e-27L;
 
 /* rational approximation coeffs for [-(ln2)/64,(ln2)/64] */
-static const long double
-t1 =   1.666666666666666666666666666660876387437e-1L,
-t2 =  -2.777777777777777777777707812093173478756e-3L,
-t3 =   6.613756613756613482074280932874221202424e-5L,
-t4 =  -1.653439153392139954169609822742235851120e-6L,
-t5 =   4.175314851769539751387852116610973796053e-8L;
+static const long double t1 = 1.666666666666666666666666666660876387437e-1L,
+	t2 = -2.777777777777777777777707812093173478756e-3L,
+	t3 = 6.613756613756613482074280932874221202424e-5L,
+	t4 = -1.653439153392139954169609822742235851120e-6L,
+	t5 = 4.175314851769539751387852116610973796053e-8L;
 
 long double
-expl(long double x) {
-	int *px = (int *) &x, ix, j, k, m;
+expl(long double x)
+{
+	int *px = (int *)&x, ix, j, k, m;
 	long double t, r;
 
-	ix = px[0];				/* high word of x */
+	ix = px[0];			/* high word of x */
+
 	if (ix >= 0x7fff0000)
-		return (x + x);			/* NaN of +inf */
-	if (((unsigned) ix) >= 0xffff0000)
-		return (-one / x);		/* NaN or -inf */
+		return (x + x);		/* NaN of +inf */
+
+	if (((unsigned)ix) >= 0xffff0000)
+		return (-one / x);	/* NaN or -inf */
+
 	if ((ix & 0x7fffffff) < 0x3fc30000) {
-		if ((int) x < 1)
+		if ((int)x < 1)
 			return (one + x);	/* |x|<2^-60 */
 	}
+
 	if (ix > 0) {
 		if (x > ovflthreshold)
 			return (scalbnl(x, 20000));
-		k = (int) (invln2_32 * (x + ln2_64));
+
+		k = (int)(invln2_32 * (x + ln2_64));
 	} else {
 		if (x < unflthreshold)
 			return (scalbnl(-x, -40000));
-		k = (int) (invln2_32 * (x - ln2_64));
+
+		k = (int)(invln2_32 * (x - ln2_64));
 	}
-	j  = k&0x1f;
-	m  = k>>5;
-	t  = (long double) k;
-	x  = (x - t * ln2_32hi) - t * ln2_32lo;
-	t  = x * x;
-	r  = (x - t * (t1 + t * (t2 + t * (t3 + t * (t4 + t * t5))))) - two;
-	x  = _TBL_expl_hi[j] - ((_TBL_expl_hi[j] * (x + x)) / r -
-		_TBL_expl_lo[j]);
+
+	j = k & 0x1f;
+	m = k >> 5;
+	t = (long double)k;
+	x = (x - t * ln2_32hi) - t * ln2_32lo;
+	t = x * x;
+	r = (x - t * (t1 + t * (t2 + t * (t3 + t * (t4 + t * t5))))) - two;
+	x = _TBL_expl_hi[j] - ((_TBL_expl_hi[j] * (x + x)) / r -
+	    _TBL_expl_lo[j]);
 	return (scalbnl(x, m));
 }
--- old/usr/src/lib/libm/common/Q/expm1l.c	2019-06-06 20:38:41.954833773 +0000
+++ new/usr/src/lib/libm/common/Q/expm1l.c	2019-06-06 20:38:41.974271779 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -43,7 +44,7 @@
  *	2. if |x| <= 0.0625 = 1/16, use approximation
  *		expm1(x) = x + x*P/(2-P)
  * where
- * 	P = x - z*(P1+z*(P2+z*(P3+z*(P4+z*(P5+z*P6+z*P7))))), z = x*x;
+ *      P = x - z*(P1+z*(P2+z*(P3+z*(P4+z*(P5+z*P6+z*P7))))), z = x*x;
  * (this formula is derived from
  *	2-P+x = R = x*(exp(x)+1)/(exp(x)-1) ~ 2 + x*x/6 - x^4/360 + ...)
  *
@@ -100,18 +101,16 @@
 
 extern const long double _TBL_expl_hi[], _TBL_expl_lo[];
 extern const long double _TBL_expm1lx[], _TBL_expm1l[];
-
-static const long double
-	zero		= +0.0L,
-	one		= +1.0L,
-	two		= +2.0L,
-	ln2_64		= +1.083042469624914545964425189778400898568e-2L,
-	ovflthreshold	= +1.135652340629414394949193107797076342845e+4L,
-	invln2_32	= +4.616624130844682903551758979206054839765e+1L,
-	ln2_32hi	= +2.166084939249829091928849858592451515688e-2L,
-	ln2_32lo	= +5.209643502595475652782654157501186731779e-27L,
-	huge		= +1.0e4000L,
-	tiny		= +1.0e-4000L,
+static const long double zero = +0.0L,
+	one = +1.0L,
+	two = +2.0L,
+	ln2_64 = +1.083042469624914545964425189778400898568e-2L,
+	ovflthreshold = +1.135652340629414394949193107797076342845e+4L,
+	invln2_32 = +4.616624130844682903551758979206054839765e+1L,
+	ln2_32hi = +2.166084939249829091928849858592451515688e-2L,
+	ln2_32lo = +5.209643502595475652782654157501186731779e-27L,
+	huge = +1.0e4000L,
+	tiny = +1.0e-4000L,
 	P1 = +1.66666666666666666666666666666638500528074603030e-0001L,
 	P2 = -2.77777777777777777777777759668391122822266551158e-0003L,
 	P3 = +6.61375661375661375657437408890138814721051293054e-0005L,
@@ -127,35 +126,44 @@
 	T5 = +4.175314851769539751387852116610973796053e-8L;
 
 long double
-expm1l(long double x) {
+expm1l(long double x)
+{
 	int hx, ix, j, k, m;
 	long double t, r, s, w;
 
-	hx = ((int *) &x)[HIXWORD];
+	hx = ((int *)&x)[HIXWORD];
 	ix = hx & ~0x80000000;
+
 	if (ix >= 0x7fff0000) {
 		if (x != x)
-			return (x + x);	/* NaN */
+			return (x + x);			/* NaN */
+
 		if (x < zero)
-			return (-one);	/* -inf */
-		return (x);	/* +inf */
+			return (-one);			/* -inf */
+
+		return (x);				/* +inf */
 	}
-	if (ix < 0x3fff4000) {	/* |x| < 1.25 */
-		if (ix < 0x3ffb0000) {	/* |x| < 0.0625 */
+
+	if (ix < 0x3fff4000) {				/* |x| < 1.25 */
+		if (ix < 0x3ffb0000) {			/* |x| < 0.0625 */
 			if (ix < 0x3f8d0000) {
-				if ((int) x == 0)
+				if ((int)x == 0)
 					return (x);	/* |x|<2^-114 */
 			}
+
 			t = x * x;
 			r = (x - t * (P1 + t * (P2 + t * (P3 + t * (P4 + t *
-				(P5 + t * (P6 + t * P7)))))));
+			    (P5 + t * (P6 + t * P7)))))));
 			return (x + (x * r) / (two - r));
 		}
+
 		/* compute i = [64*x] */
 		m = 0x4009 - (ix >> 16);
 		j = ((ix & 0x0000ffff) | 0x10000) >> m;	/* j=4,...,67 */
+
 		if (hx < 0)
 			j += 82;			/* negative */
+
 		s = x - _TBL_expm1lx[j];
 		t = s * s;
 		r = s - t * (T1 + t * (T2 + t * (T3 + t * (T4 + t * T5))));
@@ -163,22 +171,26 @@
 		w = _TBL_expm1l[j];
 		return (w + (w + one) * r);
 	}
+
 	if (hx > 0) {
 		if (x > ovflthreshold)
 			return (huge * huge);
-		k = (int) (invln2_32 * (x + ln2_64));
+
+		k = (int)(invln2_32 * (x + ln2_64));
 	} else {
 		if (x < -80.0)
 			return (tiny - x / x);
-		k = (int) (invln2_32 * (x - ln2_64));
+
+		k = (int)(invln2_32 * (x - ln2_64));
 	}
+
 	j = k & 0x1f;
 	m = k >> 5;
-	t = (long double) k;
+	t = (long double)k;
 	x = (x - t * ln2_32hi) - t * ln2_32lo;
 	t = x * x;
 	r = (x - t * (T1 + t * (T2 + t * (T3 + t * (T4 + t * T5))))) - two;
 	x = _TBL_expl_hi[j] - ((_TBL_expl_hi[j] * (x + x)) / r -
-		_TBL_expl_lo[j]);
+	    _TBL_expl_lo[j]);
 	return (scalbnl(x, m) - one);
 }
--- old/usr/src/lib/libm/common/Q/fabsl.c	2019-06-06 20:38:42.465088454 +0000
+++ new/usr/src/lib/libm/common/Q/fabsl.c	2019-06-06 20:38:42.483061984 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,8 +33,9 @@
 #include "libm.h"
 
 long double
-fabsl(long double x) {
-	int *px = (int *) &x;
+fabsl(long double x)
+{
+	int *px = (int *)&x;
 
 	px[0] &= 0x7fffffff;
 	return (x);
--- old/usr/src/lib/libm/common/Q/finitel.c	2019-06-06 20:38:42.932178286 +0000
+++ new/usr/src/lib/libm/common/Q/finitel.c	2019-06-06 20:38:42.945104969 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,18 +32,22 @@
 
 #if defined(__sparc)
 int
-finitel(long double x) {
-	int *px = (int *) &x;
+finitel(long double x)
+{
+	int *px = (int *)&x;
+
 	return ((px[0] & ~0x80000000) < 0x7fff0000);
 }
 #elif defined(__x86)
 int
-finitel(long double x) {
-	int *px = (int *) &x, t = px[2] & 0x7fff;
+finitel(long double x)
+{
+	int *px = (int *)&x, t = px[2] & 0x7fff;
+
 #if defined(HANDLE_UNSUPPORTED)
 	return (t != 0x7fff && ((px[1] & 0x80000000) != 0 || t == 0));
 #else
 	return (t != 0x7fff);
 #endif
 }
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
--- old/usr/src/lib/libm/common/Q/floorl.c	2019-06-06 20:38:43.366905214 +0000
+++ new/usr/src/lib/libm/common/Q/floorl.c	2019-06-06 20:38:43.382456169 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,29 +43,34 @@
 #include "longdouble.h"
 
 static const long double qone = 1.0L;
-
 long double
-ceill(long double x) {
+ceill(long double x)
+{
 	long double t;
 
 	if (!finitel(x))
 		return (x + x);
+
 	t = rintl(x);
-	if (t >= x) 			/* already ceil(x) */
+
+	if (t >= x)			/* already ceil(x) */
 		return (t);
 	else				/* t < x case: return t+1  */
 		return (copysignl(t + qone, x));
 }
 
 long double
-floorl(long double x) {
+floorl(long double x)
+{
 	long double t;
 
 	if (!finitel(x))
 		return (x + x);
+
 	t = rintl(x);
+
 	if (t <= x)
 		return (t);		/* already floor(x) */
-	else 				/* x < t case: return t-1  */
-	    return (copysignl(t - qone, x));
+	else				/* x < t case: return t-1  */
+		return (copysignl(t - qone, x));
 }
--- old/usr/src/lib/libm/common/Q/fmodl.c	2019-06-06 20:38:43.797013924 +0000
+++ new/usr/src/lib/libm/common/Q/fmodl.c	2019-06-06 20:38:43.812890215 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,29 +32,24 @@
 
 #include "libm.h"
 
-static const int
-	is = -0x7fffffff - 1,
-	im = 0x0000ffff,
-	iu = 0x00010000;
-
-static const long double
-	zero = 0.0L,
-	one = 1.0L;
+static const int is = -0x7fffffff - 1, im = 0x0000ffff, iu = 0x00010000;
+static const long double zero = 0.0L, one = 1.0L;
 
 #ifdef __LITTLE_ENDIAN
-#define	__H0(x) *(3 + (int *) &x)
-#define	__H1(x) *(2 + (int *) &x)
-#define	__H2(x) *(1 + (int *) &x)
-#define	__H3(x) *(0 + (int *) &x)
+#define	__H0(x)		*(3 + (int *)&x)
+#define	__H1(x)		*(2 + (int *)&x)
+#define	__H2(x)		*(1 + (int *)&x)
+#define	__H3(x)		*(0 + (int *)&x)
 #else
-#define	__H0(x) *(0 + (int *) &x)
-#define	__H1(x) *(1 + (int *) &x)
-#define	__H2(x) *(2 + (int *) &x)
-#define	__H3(x) *(3 + (int *) &x)
+#define	__H0(x)		*(0 + (int *)&x)
+#define	__H1(x)		*(1 + (int *)&x)
+#define	__H2(x)		*(2 + (int *)&x)
+#define	__H3(x)		*(3 + (int *)&x)
 #endif
 
 long double
-fmodl(long double x, long double y) {
+fmodl(long double x, long double y)
+{
 	long double a, b;
 	int n, ix, iy, k, sx;
 	int hx;
@@ -74,21 +70,25 @@
 	y0 &= 0x7fffffff;
 
 	/* purge off exception values */
-	if (x0 >= 0x7fff0000 ||	/* !finitel(x) */
+	if (x0 >= 0x7fff0000 ||		/* !finitel(x) */
 	    (y0 > 0x7fff0000) || (y0 == 0x7fff0000 && ((y1 | y2 | y3) != 0)) ||
 	    (y0 | y1 | y2 | y3) == 0)	/* isnanl(y) || y = 0 */
 		return ((x * y) / (x * y));
+
 	a = fabsl(x);
 	b = fabsl(y);
+
 	if (a <= b) {
 		if (a < b)
 			return (x);
 		else
 			return (zero * x);
 	}
+
 	/* determine ix = ilogbl(x) */
-	if (x0 < iu) {		/* subnormal x */
+	if (x0 < iu) {			/* subnormal x */
 		ix = -16382;
+
 		while (x0 == 0) {
 			ix -= 16;
 			x0 = x1 >> 16;
@@ -96,6 +96,7 @@
 			x2 = (x2 << 16) | (x3 >> 16);
 			x3 = (x3 << 16);
 		}
+
 		while (x0 < iu) {
 			ix -= 1;
 			x0 = (x0 << 1) | (x1 >> 31);
@@ -109,8 +110,9 @@
 	}
 
 	/* determine iy = ilogbl(y) */
-	if (y0 < iu) {		/* subnormal y */
+	if (y0 < iu) {			/* subnormal y */
 		iy = -16382;
+
 		while (y0 == 0) {
 			iy -= 16;
 			y0 = y1 >> 16;
@@ -118,6 +120,7 @@
 			y2 = (y2 << 16) | (y3 >> 16);
 			y3 = (y3 << 16);
 		}
+
 		while (y0 < iu) {
 			iy -= 1;
 			y0 = (y0 << 1) | (y1 >> 31);
@@ -132,6 +135,7 @@
 
 	/* fix point fmod */
 	n = ix - iy;
+
 	while (n--) {
 		while (x0 == 0 && n >= 16) {
 			n -= 16;
@@ -140,6 +144,7 @@
 			x2 = (x2 << 16) | (x3 >> 16);
 			x3 = (x3 << 16);
 		}
+
 		while (x0 < iu && n >= 1) {
 			n -= 1;
 			x0 = (x0 << 1) | (x1 >> 31);
@@ -147,9 +152,11 @@
 			x2 = (x2 << 1) | (x3 >> 31);
 			x3 = (x3 << 1);
 		}
+
 		carry = 0;
 		z3 = x3 - y3;
 		carry = (z3 > x3);
+
 		if (carry == 0) {
 			z2 = x2 - y2;
 			carry = (z2 > x2);
@@ -157,6 +164,7 @@
 			z2 = x2 - y2 - 1;
 			carry = (z2 >= x2);
 		}
+
 		if (carry == 0) {
 			z1 = x1 - y1;
 			carry = (z1 > x1);
@@ -164,8 +172,10 @@
 			z1 = x1 - y1 - 1;
 			carry = (z1 >= x1);
 		}
+
 		z0 = x0 - y0 - carry;
-		if (z0 < 0) {	/* double x */
+
+		if (z0 < 0) {		/* double x */
 			x0 = x0 + x0 + ((x1 & is) != 0);
 			x1 = x1 + x1 + ((x2 & is) != 0);
 			x2 = x2 + x2 + ((x3 & is) != 0);
@@ -178,6 +188,7 @@
 					return (a);
 				}
 			}
+
 			/* x = z << 1 */
 			z0 = z0 + z0 + ((z1 & is) != 0);
 			z1 = z1 + z1 + ((z2 & is) != 0);
@@ -193,6 +204,7 @@
 	carry = 0;
 	z3 = x3 - y3;
 	carry = (z3 > x3);
+
 	if (carry == 0) {
 		z2 = x2 - y2;
 		carry = (z2 > x2);
@@ -200,6 +212,7 @@
 		z2 = x2 - y2 - 1;
 		carry = (z2 >= x2);
 	}
+
 	if (carry == 0) {
 		z1 = x1 - y1;
 		carry = (z1 > x1);
@@ -207,19 +220,23 @@
 		z1 = x1 - y1 - 1;
 		carry = (z1 >= x1);
 	}
+
 	z0 = x0 - y0 - carry;
+
 	if (z0 >= 0) {
 		x0 = z0;
 		x1 = z1;
 		x2 = z2;
 		x3 = z3;
 	}
+
 	/* convert back to floating value and restore the sign */
 	if ((x0 | x1 | x2 | x3) == 0) {
 		__H0(a) = hx & is;
 		__H1(a) = __H2(a) = __H3(a) = 0;
 		return (a);
 	}
+
 	while (x0 < iu) {
 		if (x0 == 0) {
 			iy -= 16;
@@ -242,9 +259,10 @@
 		__H1(a) = x1;
 		__H2(a) = x2;
 		__H3(a) = x3;
-	} else {		/* subnormal output */
+	} else {			/* subnormal output */
 		n = -16382 - iy;
 		k = n & 31;
+
 		if (k != 0) {
 			if (k <= 16) {
 				x3 = (x2 << (32 - k)) | (x3 >> k);
@@ -258,6 +276,7 @@
 				x0 = 0;
 			}
 		}
+
 		while (n >= 32) {
 			n -= 32;
 			x3 = x2;
@@ -265,11 +284,13 @@
 			x1 = x0;
 			x0 = 0;
 		}
+
 		__H0(a) = x0 | sx;
 		__H1(a) = x1;
 		__H2(a) = x2;
 		__H3(a) = x3;
 		a *= one;
 	}
+
 	return (a);
 }
--- old/usr/src/lib/libm/common/Q/gammal.c	2019-06-06 20:38:44.241928570 +0000
+++ new/usr/src/lib/libm/common/Q/gammal.c	2019-06-06 20:38:44.257764512 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,9 +39,9 @@
 
 extern int signgam;
 extern int signgaml;
-
 long double
-gammal(long double x) {
+gammal(long double x)
+{
 	long double y = __k_lgammal(x, &signgaml);
 
 	signgam = signgaml;	/* SUSv3 requires the setting of signgam */
--- old/usr/src/lib/libm/common/Q/gammal_r.c	2019-06-06 20:38:44.678945662 +0000
+++ new/usr/src/lib/libm/common/Q/gammal_r.c	2019-06-06 20:38:44.694683525 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,6 +38,7 @@
 #include "longdouble.h"
 
 long double
-gammal_r(long double x, int *signgamlp) {
+gammal_r(long double x, int *signgamlp)
+{
 	return (__k_lgammal(x, signgamlp));
 }
--- old/usr/src/lib/libm/common/Q/hypotl.c	2019-06-06 20:38:45.105923267 +0000
+++ new/usr/src/lib/libm/common/Q/hypotl.c	2019-06-06 20:38:45.122160538 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -52,7 +53,7 @@
  *	hypot(x,y) is NAN if x or y is NAN.
  *
  * Accuracy:
- * 	hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
+ *      hypot(x,y) returns sqrt(x^2+y^2) with error less than 1 ulps (units
  *	in the last place)
  */
 
@@ -62,17 +63,17 @@
 extern enum fp_direction_type __swapRD(enum fp_direction_type);
 
 static const long double zero = 0.0L, one = 1.0L;
-
 long double
-hypotl(long double x, long double y) {
+hypotl(long double x, long double y)
+{
 	int n0, n1, n2, n3;
 	long double t1, t2, y1, y2, w;
-	int *px = (int *) &x, *py = (int *) &y;
-	int *pt1 = (int *) &t1, *py1 = (int *) &y1;
+	int *px = (int *)&x, *py = (int *)&y;
+	int *pt1 = (int *)&t1, *py1 = (int *)&y1;
 	enum fp_direction_type rd;
 	int j, k, nx, ny, nz;
 
-	if ((*(int *) &one) != 0) {	/* determine word ordering */
+	if ((*(int *)&one) != 0) {	/* determine word ordering */
 		n0 = 0;
 		n1 = 1;
 		n2 = 2;
@@ -84,11 +85,12 @@
 		n3 = 0;
 	}
 
-	px[n0] &= 0x7fffffff;	/* clear sign bit of x and y */
+	px[n0] &= 0x7fffffff;		/* clear sign bit of x and y */
 	py[n0] &= 0x7fffffff;
 	k = 0x7fff0000;
-	nx = px[n0] & k;	/* exponent of x and y */
+	nx = px[n0] & k;		/* exponent of x and y */
 	ny = py[n0] & k;
+
 	if (ny > nx) {
 		w = x;
 		x = y;
@@ -96,13 +98,16 @@
 		nz = ny;
 		ny = nx;
 		nx = nz;
-	}			/* force x > y */
+	}				/* force x > y */
+
 	if ((nx - ny) >= 0x00730000)
 		return (x + y);	/* x/y >= 2**116 */
+
 	if (nx < 0x5ff30000 && ny > 0x205b0000) {	/* medium x,y */
 		/* save and set RD to Rounding to nearest */
 		rd = __swapRD(fp_nearest);
 		w = x - y;
+
 		if (w > y) {
 			pt1[n0] = px[n0];
 			pt1[n1] = px[n1];
@@ -121,8 +126,10 @@
 			t2 = x - t1;
 			x = sqrtl(t1 * y1 - (w * (-w) - (t2 * y1 + y2 * x)));
 		}
+
 		if (rd != fp_nearest)
 			(void) __swapRD(rd);	/* restore rounding mode */
+
 		return (x);
 	} else {
 		if (nx == k || ny == k) {	/* x or y is INF or NaN */
@@ -132,16 +139,20 @@
 				t2 = y;
 			else
 				t2 = x + y;	/* invalid if x or y is sNaN */
+
 			return (t2);
 		}
+
 		if (ny == 0) {
 			if (y == zero || x == zero)
 				return (x + y);
+
 			t1 = scalbnl(one, 16381);
 			x *= t1;
 			y *= t1;
 			return (scalbnl(one, -16381) * hypotl(x, y));
 		}
+
 		j = nx - 0x3fff0000;
 		px[n0] -= j;
 		py[n0] -= j;
--- old/usr/src/lib/libm/common/Q/ieee_funcl.c	2019-06-06 20:38:45.577846642 +0000
+++ new/usr/src/lib/libm/common/Q/ieee_funcl.c	2019-06-06 20:38:45.596091667 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,75 +32,95 @@
 
 #if defined(__sparc)
 int
-isinfl(long double x) {
-	int *px = (int *) &x;
-	return ((px[0] & ~0x80000000) == 0x7fff0000 && px[1] == 0 &&
-		px[2] == 0 && px[3] == 0);
+isinfl(long double x)
+{
+	int *px = (int *)&x;
+
+	return ((px[0] & ~0x80000000) == 0x7fff0000 && px[1] == 0 && px[2] ==
+	    0 && px[3] == 0);
 }
 
 int
-isnormall(long double x) {
-	int *px = (int *) &x;
-	return ((unsigned) ((px[0] & 0x7fff0000) - 0x10000) < 0x7ffe0000);
+isnormall(long double x)
+{
+	int *px = (int *)&x;
+
+	return ((unsigned)((px[0] & 0x7fff0000) - 0x10000) < 0x7ffe0000);
 }
 
 int
-issubnormall(long double x) {
-	int *px = (int *) &x;
+issubnormall(long double x)
+{
+	int *px = (int *)&x;
+
 	px[0] &= ~0x80000000;
 	return (px[0] < 0x00010000 && (px[0] | px[1] | px[2] | px[3]) != 0);
 }
 
 int
-iszerol(long double x) {
-	int *px = (int *) &x;
+iszerol(long double x)
+{
+	int *px = (int *)&x;
+
 	return (((px[0] & ~0x80000000) | px[1] | px[2] | px[3]) == 0);
 }
 
 int
-signbitl(long double x) {
-	unsigned *px = (unsigned *) &x;
+signbitl(long double x)
+{
+	unsigned *px = (unsigned *)&x;
+
 	return (px[0] >> 31);
 }
 #elif defined(__x86)
 int
-isinfl(long double x) {
-	int *px = (int *) &x;
+isinfl(long double x)
+{
+	int *px = (int *)&x;
+
 #if defined(HANDLE_UNSUPPORTED)
-	return ((px[2] & 0x7fff) == 0x7fff &&
-		((px[1] ^ 0x80000000) | px[0]) == 0);
+	return ((px[2] & 0x7fff) == 0x7fff && ((px[1] ^ 0x80000000) | px[0]) ==
+	    0);
 #else
-	return ((px[2] & 0x7fff) == 0x7fff &&
-		((px[1] & ~0x80000000) | px[0]) == 0);
+	return ((px[2] & 0x7fff) == 0x7fff && ((px[1] & ~0x80000000) | px[0]) ==
+	    0);
 #endif
 }
 
 int
-isnormall(long double x) {
-	int *px = (int *) &x;
+isnormall(long double x)
+{
+	int *px = (int *)&x;
+
 #if defined(HANDLE_UNSUPPORTED)
-	return ((unsigned) ((px[2] & 0x7fff) - 1) < 0x7ffe &&
-		(px[1] & 0x80000000) != 0);
+	return ((unsigned)((px[2] & 0x7fff) - 1) < 0x7ffe && (px[1] &
+	    0x80000000) != 0);
 #else
-	return ((unsigned) ((px[2] & 0x7fff) - 1) < 0x7ffe);
+	return ((unsigned)((px[2] & 0x7fff) - 1) < 0x7ffe);
 #endif
 }
 
 int
-issubnormall(long double x) {
-	int *px = (int *) &x;
+issubnormall(long double x)
+{
+	int *px = (int *)&x;
+
 	return ((px[2] & 0x7fff) == 0 && (px[0] | px[1]) != 0);
 }
 
 int
-iszerol(long double x) {
-	int *px = (int *) &x;
+iszerol(long double x)
+{
+	int *px = (int *)&x;
+
 	return (((px[2] & 0x7fff) | px[0] | px[1]) == 0);
 }
 
 int
-signbitl(long double x) {
-	unsigned *px = (unsigned *) &x;
+signbitl(long double x)
+{
+	unsigned *px = (unsigned *)&x;
+
 	return ((px[2] >> 15) & 1);
 }
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
--- old/usr/src/lib/libm/common/Q/ilogbl.c	2019-06-06 20:38:46.065976155 +0000
+++ new/usr/src/lib/libm/common/Q/ilogbl.c	2019-06-06 20:38:46.085098571 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,31 +31,36 @@
 #pragma weak __ilogbl = ilogbl
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"				/* __xpg6 */
 
 #if defined(__sparc)
-#define	ISNORMALL(k, x)	(k != 0x7fff)			/* assuming k != 0 */
+#define	ISNORMALL(k, x)		(k != 0x7fff)	/* assuming k != 0 */
 #define	X86PDNRM(k, x)
-#define	XSCALE_OFFSET	0x406f				/* 0x3fff + 112 */
+#define	XSCALE_OFFSET		0x406f		/* 0x3fff + 112 */
+
 static const long double xscale = 5192296858534827628530496329220096.0L;
-								/* 2^112 */
+
+/* 2^112 */
 #elif defined(__x86)
 /*
  * if pseudo-denormal, replace by the equivalent normal
  */
-#define	X86PDNRM(k, x)	if (k == 0 && (((int *) &x)[1] & 0x80000000) != 0) \
-				((int *) &x)[2] |= k = 1
-#if defined(HANDLE_UNSUPPORTED)				/* assuming k != 0 */
-#define	ISNORMALL(k, x)	(k != 0x7fff && (((int *) &x)[1] & 0x80000000) != 0)
+#define	X86PDNRM(k, x)	\
+	if (k == 0 && (((int *)&x)[1] & 0x80000000) !=	0) \
+		((int *)&x)[2] |= k = 1
+#if defined(HANDLE_UNSUPPORTED)		/* assuming k != 0 */
+#define	ISNORMALL(k, x)	(k != 0x7fff && (((int *)&x)[1] & 0x80000000) != \
+	0)
 #else
-#define	ISNORMALL(k, x)	(k != 0x7fff)
+#define	ISNORMALL(k, x)		(k != 0x7fff)
 #endif
 #define	XSCALE_OFFSET	0x403e				/* 0x3fff + 63 */
 static const long double xscale = 9223372036854775808.0L;	/* 2^63 */
 #endif
 
 static int
-raise_invalid(int v) {	/* SUSv3 requires ilogbl(0,+/-Inf,NaN) raise invalid */
+raise_invalid(int v)   /* SUSv3 requires ilogbl(0,+/-Inf,NaN) raise invalid */
+{
 #ifndef lint
 	if ((__xpg6 & _C99SUSv3_ilogb_0InfNaN_raises_invalid) != 0) {
 		static const double zero = 0.0;
@@ -67,19 +73,22 @@
 }
 
 int
-ilogbl(long double x) {
+ilogbl(long double x)
+{
 	int k = XBIASED_EXP(x);
 
 	X86PDNRM(k, x);
+
 	if (k == 0) {
-		if (ISZEROL(x))
+		if (ISZEROL(x)) {
 			return (raise_invalid(0x80000001));
-		else {
-			x *= xscale;		/* scale up by 2^112 or 2^63 */
+		} else {
+			x *= xscale;	/* scale up by 2^112 or 2^63 */
 			return (XBIASED_EXP(x) - XSCALE_OFFSET);
 		}
-	} else if (ISNORMALL(k, x))
+	} else if (ISNORMALL(k, x)) {
 		return (k - 0x3fff);
-	else
+	} else {
 		return (raise_invalid(0x7fffffff));
+	}
 }
--- old/usr/src/lib/libm/common/Q/isnanl.c	2019-06-06 20:38:46.550813990 +0000
+++ new/usr/src/lib/libm/common/Q/isnanl.c	2019-06-06 20:38:46.568998140 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,20 +34,24 @@
 
 #if defined(__sparc)
 int
-isnanl(long double x) {
-	int *px = (int *) &x;
-	return ((px[0] & ~0x80000000) >= 0x7fff0000 &&
-		((px[0] & ~0xffff0000) | px[1] | px[2] | px[3]) != 0);
+isnanl(long double x)
+{
+	int *px = (int *)&x;
+
+	return ((px[0] & ~0x80000000) >= 0x7fff0000 && ((px[0] & ~0xffff0000) |
+	    px[1] | px[2] | px[3]) != 0);
 }
 #elif defined(__x86)
 int
-isnanl(long double x) {
-	int *px = (int *) &x, t = px[2] & 0x7fff;
+isnanl(long double x)
+{
+	int *px = (int *)&x, t = px[2] & 0x7fff;
+
 #if defined(HANDLE_UNSUPPORTED)
-	return (t == 0x7fff && ((px[1] & ~0x80000000) | px[0]) != 0 ||
-		t != 0 && (px[1] & 0x80000000) == 0);
+	return (t == 0x7fff && ((px[1] & ~0x80000000) | px[0]) != 0 || t != 0 &&
+	    (px[1] & 0x80000000) == 0);
 #else
 	return (t == 0x7fff && ((px[1] & ~0x80000000) | px[0]) != 0);
 #endif
 }
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
--- old/usr/src/lib/libm/common/Q/j0l.c	2019-06-06 20:38:47.058839912 +0000
+++ new/usr/src/lib/libm/common/Q/j0l.c	2019-06-06 20:38:47.077494619 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,697 +43,800 @@
 #include "libm.h"
 #include "longdouble.h"
 
-#define	GENERIC long double
-static const GENERIC
-zero    = 0.0L,
-small	= 1.0e-9L,
-tiny	= 1.0e-38L,
-one	= 1.0L,
-five	= 5.0L,
-eight   = 8.0L,
-invsqrtpi= 5.641895835477562869480794515607725858441e-0001L,
-tpi	= 0.636619772367581343075535053490057448L;
+#define	GENERIC	long double
+
+static const GENERIC zero = 0.0L,
+	small = 1.0e-9L,
+	tiny = 1.0e-38L,
+	one = 1.0L,
+	five = 5.0L,
+	eight = 8.0L,
+	invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
+	tpi = 0.636619772367581343075535053490057448L;
 
 static GENERIC pzero(GENERIC);
 static GENERIC qzero(GENERIC);
 
 static GENERIC r0[7] = {
-  -2.499999999999999999999999999999998934492e-0001L,
-   1.272657927360049786327618451133763714880e-0002L,
-  -2.694499763712963276900636693400659600898e-0004L,
-   2.724877475058977576903234070919616447883e-0006L,
-  -1.432617103214330236967477495393076320281e-0008L,
-   3.823248804080079168706683540513792224471e-0011L,
-  -4.183174277567983647337568504286313665065e-0014L,
+	-2.499999999999999999999999999999998934492e-0001L,
+	1.272657927360049786327618451133763714880e-0002L,
+	-2.694499763712963276900636693400659600898e-0004L,
+	2.724877475058977576903234070919616447883e-0006L,
+	-1.432617103214330236967477495393076320281e-0008L,
+	3.823248804080079168706683540513792224471e-0011L,
+	-4.183174277567983647337568504286313665065e-0014L,
 };
+
 static GENERIC s0[7] = {
-   1.0e0L,
-   1.159368290559800854689526195462884666395e-0002L,
-   6.629397597394973383009743876169946772559e-0005L,
-   2.426779981394054406305431142501735094340e-0007L,
-   6.097663491248511069094400469635449749883e-0010L,
-   1.017019133340929220238747413216052224036e-0012L,
-   9.012593179306197579518374581969371278481e-0016L,
+	1.0e0L,
+	1.159368290559800854689526195462884666395e-0002L,
+	6.629397597394973383009743876169946772559e-0005L,
+	2.426779981394054406305431142501735094340e-0007L,
+	6.097663491248511069094400469635449749883e-0010L,
+	1.017019133340929220238747413216052224036e-0012L,
+	9.012593179306197579518374581969371278481e-0016L,
 };
 
 GENERIC
-j0l(x) GENERIC x;{
-	GENERIC z, s,c,ss,cc,r,u,v;
+j0l(GENERIC x)
+{
+	GENERIC z, s, c, ss, cc, r, u, v;
 	int i;
 
-	if (isnanl(x)) return x+x;
+	if (isnanl(x))
+		return (x + x);
+
 	x = fabsl(x);
+
 	if (x > 1.28L) {
-		if (!finitel(x)) return zero;
+		if (!finitel(x))
+			return (zero);
+
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
-	 * where x0 = x-pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (cos(x) + sin(x))
-	 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (sin(x) - cos(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
-		if (x>1.0e2450L) {	/* x+x may overflow */
-			ss = s-c;
-			cc = s+c;
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
+		 * where x0 = x-pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (cos(x) + sin(x))
+		 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (sin(x) - cos(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
+		if (x > 1.0e2450L) {	/* x+x may overflow */
+			ss = s - c;
+			cc = s + c;
 		} else if (signbitl(s) != signbitl(c)) {
 			ss = s - c;
-			cc = -cosl(x+x)/ss;
+			cc = -cosl(x + x) / ss;
 		} else {
 			cc = s + c;
-			ss = -cosl(x+x)/cc;
+			ss = -cosl(x + x) / cc;
 		}
-	/*
-	 * j0(x) = 1/sqrt(pi) * (P(0,x)*cc - Q(0,x)*ss) / sqrt(x)
-	 * y0(x) = 1/sqrt(pi) * (P(0,x)*ss + Q(0,x)*cc) / sqrt(x)
-	 */
-		if (x>1.0e120L) return (invsqrtpi*cc)/sqrtl(x);
-		u = pzero(x); v = qzero(x);
-		return invsqrtpi*(u*cc-v*ss)/sqrtl(x);
+
+		/*
+		 * j0(x) = 1/sqrt(pi) * (P(0,x)*cc - Q(0,x)*ss) / sqrt(x)
+		 * y0(x) = 1/sqrt(pi) * (P(0,x)*ss + Q(0,x)*cc) / sqrt(x)
+		 */
+		if (x > 1.0e120L)
+			return ((invsqrtpi * cc) / sqrtl(x));
+
+		u = pzero(x);
+		v = qzero(x);
+		return (invsqrtpi * (u * cc - v * ss) / sqrtl(x));
 	}
-	if (x<=small) {
-	    if (x<=tiny) return one-x;
-	    else return one-x*x*0.25L;
+
+	if (x <= small) {
+		if (x <= tiny)
+			return (one - x);
+		else
+			return (one - x * x * 0.25L);
 	}
-	z = x*x;
-	r = r0[6]; s = s0[6];
-	for(i=5;i>=0;i--) {
-	    r = r*z + r0[i];
-	    s = s*z + s0[i];
+
+	z = x * x;
+	r = r0[6];
+	s = s0[6];
+
+	for (i = 5; i >= 0; i--) {
+		r = r * z + r0[i];
+		s = s * z + s0[i];
 	}
-	return(one+z*(r/s));
+
+	return (one + z * (r / s));
 }
 
 static const GENERIC u0[8] = {
-  -7.380429510868722527434392794848301631220e-0002L,
-   1.766855559625940791857536949301981816513e-0001L,
-  -1.386470722701047923235553251240162839408e-0002L,
-   3.520149242724811578636970811631224862615e-0004L,
-  -3.978599663243790049853642275624951870025e-0006L,
-   2.228801153263957224547222556806915479763e-0008L,
-  -6.121246764298785018658597179498837316177e-0011L,
-   6.677103629722678833475965810525587396596e-0014L,
+	-7.380429510868722527434392794848301631220e-0002L,
+	1.766855559625940791857536949301981816513e-0001L,
+	-1.386470722701047923235553251240162839408e-0002L,
+	3.520149242724811578636970811631224862615e-0004L,
+	-3.978599663243790049853642275624951870025e-0006L,
+	2.228801153263957224547222556806915479763e-0008L,
+	-6.121246764298785018658597179498837316177e-0011L,
+	6.677103629722678833475965810525587396596e-0014L,
 };
+
 static const GENERIC v0[8] = {
-   1.0e0L,
-   1.247164416539111311571676766127767127970e-0002L,
-   7.829144749639791500052900281489367443576e-0005L,
-   3.247126540422245330511218321013360336606e-0007L,
-   9.750516724789499678567062572549568447869e-0010L,
-   2.156713223173591212250543390258458098776e-0012L,
-   3.322169561597890004231482431236452752624e-0015L,
-   2.821213295314000924252226486305726805093e-0018L,
+	1.0e0L,
+	1.247164416539111311571676766127767127970e-0002L,
+	7.829144749639791500052900281489367443576e-0005L,
+	3.247126540422245330511218321013360336606e-0007L,
+	9.750516724789499678567062572549568447869e-0010L,
+	2.156713223173591212250543390258458098776e-0012L,
+	3.322169561597890004231482431236452752624e-0015L,
+	2.821213295314000924252226486305726805093e-0018L,
 };
 
 GENERIC
-y0l(x) GENERIC x;{
-	GENERIC z, s,c,ss,cc,u,v;
+y0l(GENERIC x)
+{
+	GENERIC z, s, c, ss, cc, u, v;
 	int i;
 	volatile GENERIC d;
 
-	if (isnanl(x)) return x+x;
+	if (isnanl(x))
+		return (x + x);
+
 	if (x <= zero) {
 		if (x == zero)
-		    d= -one/(x-x);
+			d = -one / (x - x);
 		else
-		    d = zero/(x-x);
+			d = zero / (x - x);
 	}
+
 #ifdef lint
 	d = d;
 #endif
+
 	if (x > 1.28L) {
-		if (!finitel(x)) return zero;
+		if (!finitel(x))
+			return (zero);
+
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
-	 * where x0 = x-pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (cos(x) + sin(x))
-	 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
-	 *			= 1/sqrt(2) * (sin(x) - cos(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
-		if (x>1.0e2450L) {	/* x+x may overflow */
-			ss = s-c;
-			cc = s+c;
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j0(x) = sqrt(2/(pi*x))*(p0(x)*cos(x0)-q0(x)*sin(x0))
+		 * where x0 = x-pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(pi/4)+sin(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (cos(x) + sin(x))
+		 *		sin(x0) = sin(x)cos(pi/4)-cos(x)sin(pi/4)
+		 *			= 1/sqrt(2) * (sin(x) - cos(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
+		if (x > 1.0e2450L) {	/* x+x may overflow */
+			ss = s - c;
+			cc = s + c;
 		} else if (signbitl(s) != signbitl(c)) {
 			ss = s - c;
-			cc = -cosl(x+x)/ss;
+			cc = -cosl(x + x) / ss;
 		} else {
 			cc = s + c;
-			ss = -cosl(x+x)/cc;
+			ss = -cosl(x + x) / cc;
 		}
-	/*
-	 * j0(x) = 1/sqrt(pi*x) * (P(0,x)*cc - Q(0,x)*ss)
-	 * y0(x) = 1/sqrt(pi*x) * (P(0,x)*ss + Q(0,x)*cc)
-	 */
-		if (x>1.0e120L) return (invsqrtpi*ss)/sqrtl(x);
-		return invsqrtpi*(pzero(x)*ss+qzero(x)*cc)/sqrtl(x);
 
+		/*
+		 * j0(x) = 1/sqrt(pi*x) * (P(0,x)*cc - Q(0,x)*ss)
+		 * y0(x) = 1/sqrt(pi*x) * (P(0,x)*ss + Q(0,x)*cc)
+		 */
+		if (x > 1.0e120L)
+			return ((invsqrtpi * ss) / sqrtl(x));
+
+		return (invsqrtpi * (pzero(x) * ss + qzero(x) * cc) / sqrtl(x));
 	}
-	if (x<=tiny) {
-	    return (u0[0] + tpi*logl(x));
-	}
-	z = x*x;
-	u = u0[7]; v = v0[7];
-	for(i=6;i>=0;i--) {
-	    u = u*z + u0[i];
-	    v = v*z + v0[i];
+
+	if (x <= tiny)
+		return (u0[0] + tpi * logl(x));
+
+	z = x * x;
+	u = u0[7];
+	v = v0[7];
+
+	for (i = 6; i >= 0; i--) {
+		u = u * z + u0[i];
+		v = v * z + v0[i];
 	}
-	return(u/v + tpi*(j0l(x)*logl(x)));
+
+	return (u / v + tpi * (j0l(x) * logl(x)));
 }
 
 static const GENERIC pr0[12] = {	/* [16 -- inf] */
-   9.999999999999999999999999999999999997515e-0001L,
-   1.065981615377273376425365823967550598358e+0003L,
-   4.390991200927588978306374718984240719130e+0005L,
-   9.072086218607986711847069407339321363103e+0007L,
-   1.022552886177375367408408501046461671528e+0010L,
-   6.420766912243658241570635854089597269031e+0011L,
-   2.206451725126933913591080211081242266908e+0013L,
-   3.928369596816895077363705478743346298368e+0014L,
-   3.258159928874124597286701119721482876596e+0015L,
-   1.025715808134188978860679130140685101348e+0016L,
-   7.537170874795721255796001687024031280685e+0015L,
-  -1.579413901450157332307745586004207687796e+0014L,
+	9.999999999999999999999999999999999997515e-0001L,
+	1.065981615377273376425365823967550598358e+0003L,
+	4.390991200927588978306374718984240719130e+0005L,
+	9.072086218607986711847069407339321363103e+0007L,
+	1.022552886177375367408408501046461671528e+0010L,
+	6.420766912243658241570635854089597269031e+0011L,
+	2.206451725126933913591080211081242266908e+0013L,
+	3.928369596816895077363705478743346298368e+0014L,
+	3.258159928874124597286701119721482876596e+0015L,
+	1.025715808134188978860679130140685101348e+0016L,
+	7.537170874795721255796001687024031280685e+0015L,
+	-1.579413901450157332307745586004207687796e+0014L,
 };
+
 static const GENERIC ps0[11] = {
-   1.0e0L,
-   1.066051927877273376425365823967550512687e+0003L,
-   4.391739647168381592399173804329266353038e+0005L,
-   9.075162261801343671805658294123888867884e+0007L,
-   1.023186118519904751819581912075985995058e+0010L,
-   6.427861860414223746340515376512730275061e+0011L,
-   2.210861503237823589735481303627993406235e+0013L,
-   3.943247335784292905915956840901818177989e+0014L,
-   3.283720976777545142150200110647270004481e+0015L,
-   1.045346918812754048903645641538728986759e+0016L,
-   8.043455468065618900750599584291193680463e+0015L,
+	1.0e0L,
+	1.066051927877273376425365823967550512687e+0003L,
+	4.391739647168381592399173804329266353038e+0005L,
+	9.075162261801343671805658294123888867884e+0007L,
+	1.023186118519904751819581912075985995058e+0010L,
+	6.427861860414223746340515376512730275061e+0011L,
+	2.210861503237823589735481303627993406235e+0013L,
+	3.943247335784292905915956840901818177989e+0014L,
+	3.283720976777545142150200110647270004481e+0015L,
+	1.045346918812754048903645641538728986759e+0016L,
+	8.043455468065618900750599584291193680463e+0015L,
 };
+
 static const GENERIC pr1[12] = {	/* [8 -- 16] */
-   9.999999999999999999999784422701108683618e-0001L,
-   6.796098532948334207755488692777907062894e+0002L,
-   1.840036112605722168824530758797169836042e+0005L,
-   2.598490483191916637264894340635847598122e+0007L,
-   2.105774863242707025525730249472054578523e+0009L,
-   1.015822044230542426666314997796944979959e+0011L,
-   2.931557457008110436764077699944189071875e+0012L,
-   4.962885121125457633655259224179322808824e+0013L,
-   4.705424055148223269155430598563351566279e+0014L,
-   2.294439854910747229152056080910427001110e+0015L,
-   4.905531843137486691500950019322475458629e+0015L,
-   3.187543169710339218793442542845735994565e+0015L,
+	9.999999999999999999999784422701108683618e-0001L,
+	6.796098532948334207755488692777907062894e+0002L,
+	1.840036112605722168824530758797169836042e+0005L,
+	2.598490483191916637264894340635847598122e+0007L,
+	2.105774863242707025525730249472054578523e+0009L,
+	1.015822044230542426666314997796944979959e+0011L,
+	2.931557457008110436764077699944189071875e+0012L,
+	4.962885121125457633655259224179322808824e+0013L,
+	4.705424055148223269155430598563351566279e+0014L,
+	2.294439854910747229152056080910427001110e+0015L,
+	4.905531843137486691500950019322475458629e+0015L,
+	3.187543169710339218793442542845735994565e+0015L,
 };
+
 static const GENERIC ps1[14] = {
-   1.0e0L,
-   6.796801657948334207754571576066758180288e+0002L,
-   1.840512891201300567325421059826676366447e+0005L,
-   2.599777028312918975306252167127695075221e+0007L,
-   2.107582572771047636846811284634244892537e+0009L,
-   1.017275794694156108975782763889979940348e+0011L,
-   2.938487645192463845428059755454762316011e+0012L,
-   4.982512164735557054521042916182317924466e+0013L,
-   4.737639900153703274792677468264564361437e+0014L,
-   2.323398719123742743524249528275097100646e+0015L,
-   5.033419107069210577868909797896984419391e+0015L,
-   3.409036105931068609601317076759804716059e+0015L,
-   7.505655364352679737585745147753521662166e+0013L,
-  -9.976837153983688250780198248297109118313e+0012L,
+	1.0e0L,
+	6.796801657948334207754571576066758180288e+0002L,
+	1.840512891201300567325421059826676366447e+0005L,
+	2.599777028312918975306252167127695075221e+0007L,
+	2.107582572771047636846811284634244892537e+0009L,
+	1.017275794694156108975782763889979940348e+0011L,
+	2.938487645192463845428059755454762316011e+0012L,
+	4.982512164735557054521042916182317924466e+0013L,
+	4.737639900153703274792677468264564361437e+0014L,
+	2.323398719123742743524249528275097100646e+0015L,
+	5.033419107069210577868909797896984419391e+0015L,
+	3.409036105931068609601317076759804716059e+0015L,
+	7.505655364352679737585745147753521662166e+0013L,
+	-9.976837153983688250780198248297109118313e+0012L,
 };
+
 static const GENERIC pr2[12] = {	/* [5 -- 8 ] */
-   9.999999999999999937857236789277366320220e-0001L,
-   3.692848765268649571651602420376358849214e+0002L,
-   5.373022067535476576926715900057760985410e+0004L,
-   4.038738891191314969971504035057219430725e+0006L,
-   1.728285706306940523397385566659762646999e+0008L,
-   4.375400819645889911158688737206054788534e+0009L,
-   6.598950418204912408375591217782088567076e+0010L,
-   5.827182039183238492480275401520072793783e+0011L,
-   2.884222642913492390887572414999490975844e+0012L,
-   7.373278873797767721932837830628688632775e+0012L,
-   8.338295457568973761205077964397969230489e+0012L,
-   2.911383183467288345772308817209806922143e+0012L,
+	9.999999999999999937857236789277366320220e-0001L,
+	3.692848765268649571651602420376358849214e+0002L,
+	5.373022067535476576926715900057760985410e+0004L,
+	4.038738891191314969971504035057219430725e+0006L,
+	1.728285706306940523397385566659762646999e+0008L,
+	4.375400819645889911158688737206054788534e+0009L,
+	6.598950418204912408375591217782088567076e+0010L,
+	5.827182039183238492480275401520072793783e+0011L,
+	2.884222642913492390887572414999490975844e+0012L,
+	7.373278873797767721932837830628688632775e+0012L,
+	8.338295457568973761205077964397969230489e+0012L,
+	2.911383183467288345772308817209806922143e+0012L,
 };
+
 static const GENERIC ps2[14] = {
-   1.0e0L,
-   3.693551890268649477288896267171993213102e+0002L,
-   5.375607880998361502474715133828068514297e+0004L,
-   4.042477764024108249744998862572786367328e+0006L,
-   1.731069838737016956685839588670132939513e+0008L,
-   4.387147674049898778738226585935491417728e+0009L,
-   6.628058659620653765349556940567715258165e+0010L,
-   5.869659904164177740471685856367322160664e+0011L,
-   2.919839445622817017058977559638969436383e+0012L,
-   7.535314897696671402628203718612309253907e+0012L,
-   8.696355561452933775773309859748610658935e+0012L,
-   3.216155103141537221173601557697083216257e+0012L,
-   4.756857081068942248246880159213789086363e+0010L,
-  -3.496356619666608032231074866481472824067e+0009L,
+	1.0e0L,
+	3.693551890268649477288896267171993213102e+0002L,
+	5.375607880998361502474715133828068514297e+0004L,
+	4.042477764024108249744998862572786367328e+0006L,
+	1.731069838737016956685839588670132939513e+0008L,
+	4.387147674049898778738226585935491417728e+0009L,
+	6.628058659620653765349556940567715258165e+0010L,
+	5.869659904164177740471685856367322160664e+0011L,
+	2.919839445622817017058977559638969436383e+0012L,
+	7.535314897696671402628203718612309253907e+0012L,
+	8.696355561452933775773309859748610658935e+0012L,
+	3.216155103141537221173601557697083216257e+0012L,
+	4.756857081068942248246880159213789086363e+0010L,
+	-3.496356619666608032231074866481472824067e+0009L,
 };
+
 static const GENERIC pr3[13] = {	/* [3.5 -- 5 ] */
-   9.999999999999916693107285612398196588247e-0001L,
-   2.263975921282917721194425320484974336945e+0002L,
-   1.994358386744245848889492762781484199966e+0004L,
-   8.980067458430542243559962493831661323168e+0005L,
-   2.282213787521372663705567756420087553508e+0007L,
-   3.409784374889063618250288699908375135923e+0008L,
-   3.024380857401448589254343517589811711108e+0009L,
-   1.571110368046740246895071721443082286379e+0010L,
-   4.603187020243604632153685300463160593768e+0010L,
-   7.087196453409712719449549280664058793403e+0010L,
-   5.046196021776346356803687409644239065041e+0010L,
-   1.287758439080165765709154276618854799932e+0010L,
-   5.900679773415023433787846658096813590784e+0008L,
+	9.999999999999916693107285612398196588247e-0001L,
+	2.263975921282917721194425320484974336945e+0002L,
+	1.994358386744245848889492762781484199966e+0004L,
+	8.980067458430542243559962493831661323168e+0005L,
+	2.282213787521372663705567756420087553508e+0007L,
+	3.409784374889063618250288699908375135923e+0008L,
+	3.024380857401448589254343517589811711108e+0009L,
+	1.571110368046740246895071721443082286379e+0010L,
+	4.603187020243604632153685300463160593768e+0010L,
+	7.087196453409712719449549280664058793403e+0010L,
+	5.046196021776346356803687409644239065041e+0010L,
+	1.287758439080165765709154276618854799932e+0010L,
+	5.900679773415023433787846658096813590784e+0008L,
 };
+
 static const GENERIC ps3[13] = {
-   1.0e0L,
-   2.264679046282855061328604619231774747116e+0002L,
-   1.995939523988944553755653255389812103448e+0004L,
-   8.993853144706348727038389967490183236820e+0005L,
-   2.288326099634588843906989983704795468773e+0007L,
-   3.424967100255240885169240956804790118282e+0008L,
-   3.046311797972463991368023759640028910016e+0009L,
-   1.589614961932826812790222479700797224003e+0010L,
-   4.692406624527744816497089139325073939927e+0010L,
-   7.320486495902008912866462849073108323948e+0010L,
-   5.345945972828978289935309597742981360994e+0010L,
-   1.444033091910423754121309915092247171008e+0010L,
-   7.987714685115314668378957273824383610525e+0008L,
+	1.0e0L,
+	2.264679046282855061328604619231774747116e+0002L,
+	1.995939523988944553755653255389812103448e+0004L,
+	8.993853144706348727038389967490183236820e+0005L,
+	2.288326099634588843906989983704795468773e+0007L,
+	3.424967100255240885169240956804790118282e+0008L,
+	3.046311797972463991368023759640028910016e+0009L,
+	1.589614961932826812790222479700797224003e+0010L,
+	4.692406624527744816497089139325073939927e+0010L,
+	7.320486495902008912866462849073108323948e+0010L,
+	5.345945972828978289935309597742981360994e+0010L,
+	1.444033091910423754121309915092247171008e+0010L,
+	7.987714685115314668378957273824383610525e+0008L,
 };
+
 static const GENERIC pr4[13] = {	/* [2.5, 3.5] */
-   9.999999999986736677961118722747757712260e-0001L,
-   1.453824980703800559037873123568378845663e+0002L,
-   8.097327216430682288267610447006508661032e+0003L,
-   2.273847252038264370231169686380192662135e+0005L,
-   3.561056728046211111354759998976985449622e+0006L,
-   3.244933588800096378434627029369680378599e+0007L,
-   1.740112392860717950376210038908476792588e+0008L,
-   5.426170187455893285197878563881579269524e+0008L,
-   9.490107486454362321004377336020526281371e+0008L,
-   8.688872439428470049801714121070005313806e+0008L,
-   3.673315853166437222811910656900123215515e+0008L,
-   5.577770470359303305164877446339693270239e+0007L,
-   1.540438642031689641308197880181291865714e+0006L,
+	9.999999999986736677961118722747757712260e-0001L,
+	1.453824980703800559037873123568378845663e+0002L,
+	8.097327216430682288267610447006508661032e+0003L,
+	2.273847252038264370231169686380192662135e+0005L,
+	3.561056728046211111354759998976985449622e+0006L,
+	3.244933588800096378434627029369680378599e+0007L,
+	1.740112392860717950376210038908476792588e+0008L,
+	5.426170187455893285197878563881579269524e+0008L,
+	9.490107486454362321004377336020526281371e+0008L,
+	8.688872439428470049801714121070005313806e+0008L,
+	3.673315853166437222811910656900123215515e+0008L,
+	5.577770470359303305164877446339693270239e+0007L,
+	1.540438642031689641308197880181291865714e+0006L,
 };
+
 static const GENERIC ps4[13] = {	/* [2.5, 3.5] */
-   1.0e0L,
-   1.454528105698159439773035951959131799816e+0002L,
-   8.107442215200392397172179900434987859618e+0003L,
-   2.279390393778242887574177096606328994140e+0005L,
-   3.576251625592252008424781111770934135844e+0006L,
-   3.267909499056932631405942058670933813863e+0007L,
-   1.760021515330805537499778238099704648805e+0008L,
-   5.525553787667353981242060222587465726729e+0008L,
-   9.769870295912820457889384082671269328511e+0008L,
-   9.110582071004774279226905629624018008454e+0008L,
-   3.981857678621955599371967680343918454345e+0008L,
-   6.482404686230769399073192961667697036706e+0007L,
-   2.210046943095878402443535460329391782298e+0006L,
+	1.0e0L,
+	1.454528105698159439773035951959131799816e+0002L,
+	8.107442215200392397172179900434987859618e+0003L,
+	2.279390393778242887574177096606328994140e+0005L,
+	3.576251625592252008424781111770934135844e+0006L,
+	3.267909499056932631405942058670933813863e+0007L,
+	1.760021515330805537499778238099704648805e+0008L,
+	5.525553787667353981242060222587465726729e+0008L,
+	9.769870295912820457889384082671269328511e+0008L,
+	9.110582071004774279226905629624018008454e+0008L,
+	3.981857678621955599371967680343918454345e+0008L,
+	6.482404686230769399073192961667697036706e+0007L,
+	2.210046943095878402443535460329391782298e+0006L,
 };
+
 static const GENERIC pr5[13] = {	/* [1.777..., 2.5] */
-   9.999999999114986107951817871144655880699e-0001L,
-   9.252583736048588342568344570315435947614e+0001L,
-   3.218726757856078715214631502407386264637e+0003L,
-   5.554009964621111656479588505862577040831e+0004L,
-   5.269993115643664338253196944523510290175e+0005L,
-   2.874613773778430691192912190618220544575e+0006L,
-   9.133538151103658353874146919613442436035e+0006L,
-   1.673067041410338922825193013077354249193e+0007L,
-   1.706913873848398011744790289200151840498e+0007L,
-   9.067766583853288534551600235576747618679e+0006L,
-   2.216746733457884568532695355036338655872e+0006L,
-   1.945753880802872541235703812722344514405e+0005L,
-   3.132374412921948071539195638885330951749e+0003L,
+	9.999999999114986107951817871144655880699e-0001L,
+	9.252583736048588342568344570315435947614e+0001L,
+	3.218726757856078715214631502407386264637e+0003L,
+	5.554009964621111656479588505862577040831e+0004L,
+	5.269993115643664338253196944523510290175e+0005L,
+	2.874613773778430691192912190618220544575e+0006L,
+	9.133538151103658353874146919613442436035e+0006L,
+	1.673067041410338922825193013077354249193e+0007L,
+	1.706913873848398011744790289200151840498e+0007L,
+	9.067766583853288534551600235576747618679e+0006L,
+	2.216746733457884568532695355036338655872e+0006L,
+	1.945753880802872541235703812722344514405e+0005L,
+	3.132374412921948071539195638885330951749e+0003L,
 };
+
 static const GENERIC ps5[13] = {	/* [1.777..., 2.5] */
-   1.0e0L,
-   9.259614983862181118883831670990340052982e+0001L,
-   3.225125275462903384842124075132609290304e+0003L,
-   5.575705362829101545292760055941855246492e+0004L,
-   5.306049863037087855496170121958448492522e+0005L,
-   2.907060758873509564309729903109018597215e+0006L,
-   9.298059206584995898298257827131208539289e+0006L,
-   1.720391071006963176836108026556547062980e+0007L,
-   1.782614812922865190479394509487941920612e+0007L,
-   9.708016389605273153536452032839879950155e+0006L,
-   2.476495084688170096480215640962175140027e+0006L,
-   2.363200660365585759668077790194604917187e+0005L,
-   4.803239569848196077121203575704356936731e+0003L,
+	1.0e0L,
+	9.259614983862181118883831670990340052982e+0001L,
+	3.225125275462903384842124075132609290304e+0003L,
+	5.575705362829101545292760055941855246492e+0004L,
+	5.306049863037087855496170121958448492522e+0005L,
+	2.907060758873509564309729903109018597215e+0006L,
+	9.298059206584995898298257827131208539289e+0006L,
+	1.720391071006963176836108026556547062980e+0007L,
+	1.782614812922865190479394509487941920612e+0007L,
+	9.708016389605273153536452032839879950155e+0006L,
+	2.476495084688170096480215640962175140027e+0006L,
+	2.363200660365585759668077790194604917187e+0005L,
+	4.803239569848196077121203575704356936731e+0003L,
 };
+
 static const GENERIC pr6[13] = {	/* [1.28, 1.777...] */
-   9.999999969777095495998606925524322559556e-0001L,
-   5.825486719466194430503283824096872219216e+0001L,
-   1.248155491637757281915184824965379905380e+0003L,
-   1.302093199842358609321338417071710477615e+0004L,
-   7.353835804186292782840961999810543016039e+0004L,
-   2.356471661113686180549195092555751341757e+0005L,
-   4.350553267429009581632987060942780847101e+0005L,
-   4.588762661876600638719159826652389418235e+0005L,
-   2.675796398548523436544221045225290128611e+0005L,
-   8.077649557108971388298292919988449940464e+0004L,
-   1.117640459221306873519068741664054573776e+0004L,
-   5.544400072396814695175787511557757885585e+0002L,
-   5.072550541191480498431289089905822910718e+0000L,
+	9.999999969777095495998606925524322559556e-0001L,
+	5.825486719466194430503283824096872219216e+0001L,
+	1.248155491637757281915184824965379905380e+0003L,
+	1.302093199842358609321338417071710477615e+0004L,
+	7.353835804186292782840961999810543016039e+0004L,
+	2.356471661113686180549195092555751341757e+0005L,
+	4.350553267429009581632987060942780847101e+0005L,
+	4.588762661876600638719159826652389418235e+0005L,
+	2.675796398548523436544221045225290128611e+0005L,
+	8.077649557108971388298292919988449940464e+0004L,
+	1.117640459221306873519068741664054573776e+0004L,
+	5.544400072396814695175787511557757885585e+0002L,
+	5.072550541191480498431289089905822910718e+0000L,
 };
+
 static const GENERIC ps6[13] = {	/* [1.28, 1.777...] */
-   1.0e0L,
-   5.832517925357165050639075848183613063291e+0001L,
-   1.252144364743592128171256104364976466898e+0003L,
-   1.310300234342216813579118022415585740772e+0004L,
-   7.434667697093812197817292154032863632923e+0004L,
-   2.398706595587719165726469002404004614711e+0005L,
-   4.472737517625103157004869372427480602511e+0005L,
-   4.786313523337761975294171429067037723611e+0005L,
-   2.851161872872731228472536061865365370192e+0005L,
-   8.891648269899148412331918021801385815586e+0004L,
-   1.297097489535351517572978123584751042287e+0004L,
-   7.096761640545975756202184143400469812618e+0002L,
-   8.378049338590233325977702401733340820351e+0000L,
+	1.0e0L,
+	5.832517925357165050639075848183613063291e+0001L,
+	1.252144364743592128171256104364976466898e+0003L,
+	1.310300234342216813579118022415585740772e+0004L,
+	7.434667697093812197817292154032863632923e+0004L,
+	2.398706595587719165726469002404004614711e+0005L,
+	4.472737517625103157004869372427480602511e+0005L,
+	4.786313523337761975294171429067037723611e+0005L,
+	2.851161872872731228472536061865365370192e+0005L,
+	8.891648269899148412331918021801385815586e+0004L,
+	1.297097489535351517572978123584751042287e+0004L,
+	7.096761640545975756202184143400469812618e+0002L,
+	8.378049338590233325977702401733340820351e+0000L,
 };
+
 static const GENERIC sixteen = 16.0L;
-static const GENERIC huge    = 1.0e30L;
+static const GENERIC huge = 1.0e30L;
 
-static GENERIC pzero(x)
-GENERIC x;
+static GENERIC
+pzero(GENERIC x)
 {
-	GENERIC s,r,t,z;
+	GENERIC s, r, t, z;
 	int i;
-	if (x>huge) return one;
-	t = one/x; z = t*t;
-	if (x>sixteen) {
-	    r = z*pr0[11]+pr0[10]; s = ps0[10];
-	    for (i=9;i>=0;i--) {
-		r = z*r + pr0[i];
-		s = z*s + ps0[i];
-	    }
+
+	if (x > huge)
+		return (one);
+
+	t = one / x;
+	z = t * t;
+
+	if (x > sixteen) {
+		r = z * pr0[11] + pr0[10];
+		s = ps0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + pr0[i];
+			s = z * s + ps0[i];
+		}
 	} else if (x > eight) {
-	    r = pr1[11]; s = ps1[11]+z*(ps1[12]+z*ps1[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + pr1[i];
-		s = z*s + ps1[i];
-	    }
-	} else if (x > five) { 	/* x > 5.0 */
-	    r = pr2[11]; s = ps2[11]+z*(ps2[12]+z*ps2[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + pr2[i];
-		s = z*s + ps2[i];
-	    }
-	} else if (x>3.5L) {
-	    r = pr3[12]; s = ps3[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + pr3[i];
-		s = z*s + ps3[i];
-	    }
-	} else if (x>2.5L) {
-	    r = pr4[12]; s = ps4[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + pr4[i];
-		s = z*s + ps4[i];
-	    }
-	} else if (x> (1.0L/0.5625L)) {
-	    r = pr5[12]; s = ps5[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + pr5[i];
-		s = z*s + ps5[i];
-	    }
-	} else {	/* assume x > 1.28 */
-	    r = pr6[12]; s = ps6[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + pr6[i];
-		s = z*s + ps6[i];
-	    }
-	}
-	return r/s;
-}
+		r = pr1[11];
+		s = ps1[11] + z * (ps1[12] + z * ps1[13]);
 
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr1[i];
+			s = z * s + ps1[i];
+		}
+	} else if (x > five) {		/* x > 5.0 */
+		r = pr2[11];
+		s = ps2[11] + z * (ps2[12] + z * ps2[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr2[i];
+			s = z * s + ps2[i];
+		}
+	} else if (x > 3.5L) {
+		r = pr3[12];
+		s = ps3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr3[i];
+			s = z * s + ps3[i];
+		}
+	} else if (x > 2.5L) {
+		r = pr4[12];
+		s = ps4[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr4[i];
+			s = z * s + ps4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = pr5[12];
+		s = ps5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr5[i];
+			s = z * s + ps5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = pr6[12];
+		s = ps6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr6[i];
+			s = z * s + ps6[i];
+		}
+	}
 
+	return (r / s);
+}
 static const GENERIC qr0[12] = {	/* [16, inf] */
-  -1.249999999999999999999999999999999972972e-0001L,
-  -1.425179595545670577414395762503991596897e+0002L,
-  -6.312499645625970845534460257936222407219e+0004L,
-  -1.411374326457208384315121243698814446848e+0007L,
-  -1.735034212758873581410984757860787252842e+0009L,
-  -1.199777647512789489421826342485055280680e+0011L,
-  -4.596025334081655714499860409699100373644e+0012L,
-  -9.262525628201284107792924477031653399187e+0013L,
-  -8.858394728685039245344398842180662867639e+0014L,
-  -3.267527953687534887623740622709505972113e+0015L,
-  -2.664222971186311967587129347029450062019e+0015L,
-   3.442464060723987869585180095344504100204e+0014L,
+	-1.249999999999999999999999999999999972972e-0001L,
+	-1.425179595545670577414395762503991596897e+0002L,
+	-6.312499645625970845534460257936222407219e+0004L,
+	-1.411374326457208384315121243698814446848e+0007L,
+	-1.735034212758873581410984757860787252842e+0009L,
+	-1.199777647512789489421826342485055280680e+0011L,
+	-4.596025334081655714499860409699100373644e+0012L,
+	-9.262525628201284107792924477031653399187e+0013L,
+	-8.858394728685039245344398842180662867639e+0014L,
+	-3.267527953687534887623740622709505972113e+0015L,
+	-2.664222971186311967587129347029450062019e+0015L,
+	3.442464060723987869585180095344504100204e+0014L,
 };
+
 static const GENERIC qs0[11] = {
-   1.0e0L,
-   1.140729613936536461931516610003185687881e+0003L,
-   5.056665510442299351009198186490085803580e+0005L,
-   1.132041763825642787943941650522718199115e+0008L,
-   1.394570111872581606392620678214246479767e+0010L,
-   9.677945218152264789534431079563744378421e+0011L,
-   3.731140327851536828225143058896348502096e+0013L,
-   7.612785951064869291722846681020881676410e+0014L,
-   7.476077016406764891730191004811863975940e+0015L,
-   2.951246482613592035421503427100393831709e+0016L,
-   3.108361803691811711136854587074302034901e+0016L,
+	1.0e0L,
+	1.140729613936536461931516610003185687881e+0003L,
+	5.056665510442299351009198186490085803580e+0005L,
+	1.132041763825642787943941650522718199115e+0008L,
+	1.394570111872581606392620678214246479767e+0010L,
+	9.677945218152264789534431079563744378421e+0011L,
+	3.731140327851536828225143058896348502096e+0013L,
+	7.612785951064869291722846681020881676410e+0014L,
+	7.476077016406764891730191004811863975940e+0015L,
+	2.951246482613592035421503427100393831709e+0016L,
+	3.108361803691811711136854587074302034901e+0016L,
 };
+
 static const GENERIC qr1[12] = {	/* [8, 16 ] */
-  -1.249999999999999999997949010383433818157e-0001L,
-  -9.051215166393822640636752244895124126934e+0001L,
-  -2.620782703428148837671179031904208303947e+0004L,
-  -3.975571261553504457766177974508785790884e+0006L,
-  -3.479029330759311306270072218074074994090e+0008L,
-  -1.823955008124268573036216746186239829089e+0010L,
-  -5.765932697111801375765156029221568664435e+0011L,
-  -1.079843680798742592954002192417934779114e+0013L,
-  -1.146893630504592739082205764611581332897e+0014L,
-  -6.367016059683898464936104447282880704182e+0014L,
-  -1.583109041961213490464459111903484209098e+0015L,
-  -1.230149555764242473103128650135795639412e+0015L,
+	-1.249999999999999999997949010383433818157e-0001L,
+	-9.051215166393822640636752244895124126934e+0001L,
+	-2.620782703428148837671179031904208303947e+0004L,
+	-3.975571261553504457766177974508785790884e+0006L,
+	-3.479029330759311306270072218074074994090e+0008L,
+	-1.823955008124268573036216746186239829089e+0010L,
+	-5.765932697111801375765156029221568664435e+0011L,
+	-1.079843680798742592954002192417934779114e+0013L,
+	-1.146893630504592739082205764611581332897e+0014L,
+	-6.367016059683898464936104447282880704182e+0014L,
+	-1.583109041961213490464459111903484209098e+0015L,
+	-1.230149555764242473103128650135795639412e+0015L,
 };
+
 static const GENERIC qs1[14] = {
-   1.0e0L,
-   7.246831508115058112438579847778014458432e+0002L,
-   2.100854184439168518399383786306927037611e+0005L,
-   3.192636418837951507430188285940994235122e+0007L,
-   2.801558443383354674538443461124434216152e+0009L,
-   1.475026997664373739293483927250653467487e+0011L,
-   4.694486824913954608552363821799927145318e+0012L,
-   8.890350100919200250838438709601547334021e+0013L,
-   9.626844429082905144874701068760469752067e+0014L,
-   5.541110744600460773528263862687521642140e+0015L,
-   1.486500494789452556727470329232123096563e+0016L,
-   1.415840104845959400365430773732093899210e+0016L,
-   1.780866095241517418081312567239682336483e+0015L,
-  -2.359230917384889357887631544079990129494e+0014L,
+	1.0e0L,
+	7.246831508115058112438579847778014458432e+0002L,
+	2.100854184439168518399383786306927037611e+0005L,
+	3.192636418837951507430188285940994235122e+0007L,
+	2.801558443383354674538443461124434216152e+0009L,
+	1.475026997664373739293483927250653467487e+0011L,
+	4.694486824913954608552363821799927145318e+0012L,
+	8.890350100919200250838438709601547334021e+0013L,
+	9.626844429082905144874701068760469752067e+0014L,
+	5.541110744600460773528263862687521642140e+0015L,
+	1.486500494789452556727470329232123096563e+0016L,
+	1.415840104845959400365430773732093899210e+0016L,
+	1.780866095241517418081312567239682336483e+0015L,
+	-2.359230917384889357887631544079990129494e+0014L,
 };
+
 static const GENERIC qr2[12] = {	/* [5, 8] */
-  -1.249999999999999531937744362527772181614e-0001L,
-  -4.944373897356969774839375977239241573966e+0001L,
-  -7.728449175433465285314261650078450473909e+0003L,
-  -6.262574329612752346336901434651220705903e+0005L,
-  -2.900948220220943306027235217424380672732e+0007L,
-  -7.988719647634192770463917157562874119535e+0008L,
-  -1.318228171927181389547760026626357012375e+0010L,
-  -1.282439773983029245309263271945424928196e+0011L,
-  -7.050925570827818040186149940257918845138e+0011L,
-  -2.021751882573871990004205616874202684429e+0012L,
-  -2.592939962400668552384333900573812635658e+0012L,
-  -1.038267109518891262840601514932972850326e+0012L,
+	-1.249999999999999531937744362527772181614e-0001L,
+	-4.944373897356969774839375977239241573966e+0001L,
+	-7.728449175433465285314261650078450473909e+0003L,
+	-6.262574329612752346336901434651220705903e+0005L,
+	-2.900948220220943306027235217424380672732e+0007L,
+	-7.988719647634192770463917157562874119535e+0008L,
+	-1.318228171927181389547760026626357012375e+0010L,
+	-1.282439773983029245309263271945424928196e+0011L,
+	-7.050925570827818040186149940257918845138e+0011L,
+	-2.021751882573871990004205616874202684429e+0012L,
+	-2.592939962400668552384333900573812635658e+0012L,
+	-1.038267109518891262840601514932972850326e+0012L,
 };
+
 static const GENERIC qs2[14] = {
-   1.0e0L,
-   3.961358492885570003202784022894248952116e+0002L,
-   6.205788738864701882828752634586510926968e+0004L,
-   5.045715603932670286550673813011764406749e+0006L,
-   2.349248611362658323353343389430968751429e+0008L,
-   6.520244524415828635917683553721880063911e+0009L,
-   1.089111211223507719337067159886281887722e+0011L,
-   1.080406000905359867958779409414903018610e+0012L,
-   6.135645280895514703514154680623769562148e+0012L,
-   1.862433040246625874245867151368643668215e+0013L,
-   2.667780805786648888840777888702193708994e+0013L,
-   1.394401107289087774765300711809313112824e+0013L,
-   1.093247500616320375562898297156722445484e+0012L,
-  -7.228875530378928722826604216491493780775e+0010L,
+	1.0e0L,
+	3.961358492885570003202784022894248952116e+0002L,
+	6.205788738864701882828752634586510926968e+0004L,
+	5.045715603932670286550673813011764406749e+0006L,
+	2.349248611362658323353343389430968751429e+0008L,
+	6.520244524415828635917683553721880063911e+0009L,
+	1.089111211223507719337067159886281887722e+0011L,
+	1.080406000905359867958779409414903018610e+0012L,
+	6.135645280895514703514154680623769562148e+0012L,
+	1.862433040246625874245867151368643668215e+0013L,
+	2.667780805786648888840777888702193708994e+0013L,
+	1.394401107289087774765300711809313112824e+0013L,
+	1.093247500616320375562898297156722445484e+0012L,
+	-7.228875530378928722826604216491493780775e+0010L,
 };
+
 static const GENERIC qr3[13] = {	/* [3.5 5] */
-  -1.249999999999473067748420379578481661075e-0001L,
-  -3.044549048635289351913574324803250977998e+0001L,
-  -2.890081140649769078496693003524681440869e+0003L,
-  -1.404922456817202235879343275330529107684e+0005L,
-  -3.862746614385573443518177403617349281869e+0006L,
-  -6.257517309110249049201133708911155047689e+0007L,
-  -6.031451330920839916987079782727323477520e+0008L,
-  -3.411542405173830611454025765755854382346e+0009L,
-  -1.089392478149726672133014498723021526099e+0010L,
-  -1.824934078420210941290140903415956782726e+0010L,
-  -1.400780278304358710423481070486939531139e+0010L,
-  -3.716484136064917363926635716743771092093e+0009L,
-  -1.397591075296425529970434890954904331580e+0008L,
+	-1.249999999999473067748420379578481661075e-0001L,
+	-3.044549048635289351913574324803250977998e+0001L,
+	-2.890081140649769078496693003524681440869e+0003L,
+	-1.404922456817202235879343275330529107684e+0005L,
+	-3.862746614385573443518177403617349281869e+0006L,
+	-6.257517309110249049201133708911155047689e+0007L,
+	-6.031451330920839916987079782727323477520e+0008L,
+	-3.411542405173830611454025765755854382346e+0009L,
+	-1.089392478149726672133014498723021526099e+0010L,
+	-1.824934078420210941290140903415956782726e+0010L,
+	-1.400780278304358710423481070486939531139e+0010L,
+	-3.716484136064917363926635716743771092093e+0009L,
+	-1.397591075296425529970434890954904331580e+0008L,
 };
+
 static const GENERIC qs3[13] = {
-   1.0e0L,
-   2.441498613904962049391000187014945858042e+0002L,
-   2.326188882072370711500164222341514337043e+0004L,
-   1.137138213121231338494977104659239578165e+0006L,
-   3.152918070735662728722998452605364253517e+0007L,
-   5.172877993426507259314270488444013595108e+0008L,
-   5.083086439731669807455961078856470774115e+0009L,
-   2.961842732066434123119325521139476909941e+0010L,
-   9.912185866862440735829781856081353151390e+0010L,
-   1.793560561251622234430564181567297983598e+0011L,
-   1.577090119341228122525265108497940403073e+0011L,
-   5.509910306780166194333889999985463681636e+0010L,
-   4.761691134078874491202320181517936758141e+0009L,
+	1.0e0L,
+	2.441498613904962049391000187014945858042e+0002L,
+	2.326188882072370711500164222341514337043e+0004L,
+	1.137138213121231338494977104659239578165e+0006L,
+	3.152918070735662728722998452605364253517e+0007L,
+	5.172877993426507259314270488444013595108e+0008L,
+	5.083086439731669807455961078856470774115e+0009L,
+	2.961842732066434123119325521139476909941e+0010L,
+	9.912185866862440735829781856081353151390e+0010L,
+	1.793560561251622234430564181567297983598e+0011L,
+	1.577090119341228122525265108497940403073e+0011L,
+	5.509910306780166194333889999985463681636e+0010L,
+	4.761691134078874491202320181517936758141e+0009L,
 };
+
 static const GENERIC qr4[13] = {	/* [2.5 3.5] */
-  -1.249999999928567734339745043490705340835e-0001L,
-  -1.967201748731419063051601624435565528481e+0001L,
-  -1.186329146714562236407099740615528170707e+0003L,
-  -3.607736959222941810356301491152457934060e+0004L,
-  -6.119200717978104904932828468575194267125e+0005L,
-  -6.037847781158358226670305078652205586384e+0006L,
-  -3.503558153336140359700536720393565984740e+0007L,
-  -1.180196478268225718757218523746787309773e+0008L,
-  -2.221860232085134915841426363505169680528e+0008L,
-  -2.173372505452747585296176761701746236760e+0008L,
-  -9.649364865061237558517730539506568013963e+0007L,
-  -1.465429227847933034546039640094862650385e+0007L,
-  -3.083003197920262085170581866246663380607e+0005L,
+	-1.249999999928567734339745043490705340835e-0001L,
+	-1.967201748731419063051601624435565528481e+0001L,
+	-1.186329146714562236407099740615528170707e+0003L,
+	-3.607736959222941810356301491152457934060e+0004L,
+	-6.119200717978104904932828468575194267125e+0005L,
+	-6.037847781158358226670305078652205586384e+0006L,
+	-3.503558153336140359700536720393565984740e+0007L,
+	-1.180196478268225718757218523746787309773e+0008L,
+	-2.221860232085134915841426363505169680528e+0008L,
+	-2.173372505452747585296176761701746236760e+0008L,
+	-9.649364865061237558517730539506568013963e+0007L,
+	-1.465429227847933034546039640094862650385e+0007L,
+	-3.083003197920262085170581866246663380607e+0005L,
 };
+
 static const GENERIC qs4[13] = {	/* [2.5 3.5] */
-   1.0e0L,
-   1.579620773732259142752614142139986854055e+0002L,
-   9.581372220329138733203879503753685054968e+0003L,
-   2.939598672379108095776114131010825885308e+0005L,
-   5.052183049314542218630341818692588448168e+0006L,
-   5.083497695595206639433839326338971980149e+0007L,
-   3.036385361800553388049719014005099206516e+0008L,
-   1.067826481452753409910563785161661492137e+0009L,
-   2.145644125557118044720741775125319669272e+0009L,
-   2.324115615959719949363946673491552216799e+0009L,
-   1.223262962112070757966959855619847011146e+0009L,
-   2.569765553318495423738478585947110270709e+0008L,
-   1.354744744299227127897905787732636565504e+0007L,
+	1.0e0L,
+	1.579620773732259142752614142139986854055e+0002L,
+	9.581372220329138733203879503753685054968e+0003L,
+	2.939598672379108095776114131010825885308e+0005L,
+	5.052183049314542218630341818692588448168e+0006L,
+	5.083497695595206639433839326338971980149e+0007L,
+	3.036385361800553388049719014005099206516e+0008L,
+	1.067826481452753409910563785161661492137e+0009L,
+	2.145644125557118044720741775125319669272e+0009L,
+	2.324115615959719949363946673491552216799e+0009L,
+	1.223262962112070757966959855619847011146e+0009L,
+	2.569765553318495423738478585947110270709e+0008L,
+	1.354744744299227127897905787732636565504e+0007L,
 };
+
 static const GENERIC qr5[13] = {	/* [1.777.., 2.5] */
-  -1.249999995936639697637680428174576069971e-0001L,
-  -1.260846055371311453485891923426489068315e+0001L,
-  -4.772398467544467480801174330290141578895e+0002L,
-  -8.939852599990298486613760833996490599724e+0003L,
-  -9.184070787149542050979542226446134243197e+0004L,
-  -5.406038945018274458362637897739280435171e+0005L,
-  -1.845896544705190261018653728678171084418e+0006L,
-  -3.613616990680809501878667570653308071547e+0006L,
-  -3.908782978135693252252557720414348623779e+0006L,
-  -2.173711022517323927109138170588442768176e+0006L,
-  -5.431253130679918485836408549007856244495e+0005L,
-  -4.591098546452684510082591587275940765959e+0004L,
-  -5.244711364168207806835520057792229646578e+0002L,
+	-1.249999995936639697637680428174576069971e-0001L,
+	-1.260846055371311453485891923426489068315e+0001L,
+	-4.772398467544467480801174330290141578895e+0002L,
+	-8.939852599990298486613760833996490599724e+0003L,
+	-9.184070787149542050979542226446134243197e+0004L,
+	-5.406038945018274458362637897739280435171e+0005L,
+	-1.845896544705190261018653728678171084418e+0006L,
+	-3.613616990680809501878667570653308071547e+0006L,
+	-3.908782978135693252252557720414348623779e+0006L,
+	-2.173711022517323927109138170588442768176e+0006L,
+	-5.431253130679918485836408549007856244495e+0005L,
+	-4.591098546452684510082591587275940765959e+0004L,
+	-5.244711364168207806835520057792229646578e+0002L,
 };
+
 static const GENERIC qs5[13] = {	/* [1.777.., 2.5] */
-   1.0e0L,
-   1.014536210851290878350892750972474861447e+0002L,
-   3.875547510687135314064434160096139681076e+0003L,
-   7.361913122670079814955259281995617732580e+0004L,
-   7.720288944218771126581086539585529314636e+0005L,
-   4.681529554446752496404431433608306558038e+0006L,
-   1.667882621940503925455031252308367745820e+0007L,
-   3.469403153761399881888272620855305156241e+0007L,
-   4.096992047964210711867089384719947863019e+0007L,
-   2.596804755829217449311530735959560630554e+0007L,
-   7.983933774697889238154465064019410763845e+0006L,
-   9.818133816979900819087242425280757938152e+0005L,
-   3.061083930868694396013541535670745443560e+0004L,
+	1.0e0L,
+	1.014536210851290878350892750972474861447e+0002L,
+	3.875547510687135314064434160096139681076e+0003L,
+	7.361913122670079814955259281995617732580e+0004L,
+	7.720288944218771126581086539585529314636e+0005L,
+	4.681529554446752496404431433608306558038e+0006L,
+	1.667882621940503925455031252308367745820e+0007L,
+	3.469403153761399881888272620855305156241e+0007L,
+	4.096992047964210711867089384719947863019e+0007L,
+	2.596804755829217449311530735959560630554e+0007L,
+	7.983933774697889238154465064019410763845e+0006L,
+	9.818133816979900819087242425280757938152e+0005L,
+	3.061083930868694396013541535670745443560e+0004L,
 };
 
 static const GENERIC qr6[13] = {	/* [1.28, 1.777..] */
-  -1.249999881577289001807137282824929082771e-0001L,
-  -7.998273510053110759610810594119533619282e+0000L,
-  -1.872481955335172543369089617771565632719e+0002L,
-  -2.122116786726300805079874003303799646812e+0003L,
-  -1.293850285839529282503178263484773478457e+0004L,
-  -4.445024742266316181033354192262529356093e+0004L,
-  -8.730161378334357767668344467356505347070e+0004L,
-  -9.706222895172078442801444972505315054736e+0004L,
-  -5.896325518259858270165531513618195321041e+0004L,
-  -1.823172034368108822276420827074668832233e+0004L,
-  -2.509304178635055926638833040337472387175e+0003L,
-  -1.156608965715779237316769828941729964099e+0002L,
-  -7.028005789650731396887346826397785210442e-0001L,
+	-1.249999881577289001807137282824929082771e-0001L,
+	-7.998273510053110759610810594119533619282e+0000L,
+	-1.872481955335172543369089617771565632719e+0002L,
+	-2.122116786726300805079874003303799646812e+0003L,
+	-1.293850285839529282503178263484773478457e+0004L,
+	-4.445024742266316181033354192262529356093e+0004L,
+	-8.730161378334357767668344467356505347070e+0004L,
+	-9.706222895172078442801444972505315054736e+0004L,
+	-5.896325518259858270165531513618195321041e+0004L,
+	-1.823172034368108822276420827074668832233e+0004L,
+	-2.509304178635055926638833040337472387175e+0003L,
+	-1.156608965715779237316769828941729964099e+0002L,
+	-7.028005789650731396887346826397785210442e-0001L,
 };
+
 static const GENERIC qs6[13] = {	/* [1.28, 1.777..] */
-   1.0e0L,
-   6.457211085058064845601261321277721075900e+0001L,
-   1.534005216588011210342824555136008682950e+0003L,
-   1.777217999176441782593357660462379097171e+0004L,
-   1.118372652642469468091084810263231199696e+0005L,
-   4.015242433858461813142365748386473605294e+0005L,
-   8.377081045517098645448616514388280497673e+0005L,
-   1.011495020008010352575398009604164287337e+0006L,
-   6.886722075290430568652227875200208955970e+0005L,
-   2.504735189948021472047157148613171956537e+0005L,
-   4.408138920171044846941001844352009817062e+0004L,
-   3.105572178072115145673058722853640854884e+0003L,
-   5.588294821118916113437396504573817033678e+0001L,
+	1.0e0L,
+	6.457211085058064845601261321277721075900e+0001L,
+	1.534005216588011210342824555136008682950e+0003L,
+	1.777217999176441782593357660462379097171e+0004L,
+	1.118372652642469468091084810263231199696e+0005L,
+	4.015242433858461813142365748386473605294e+0005L,
+	8.377081045517098645448616514388280497673e+0005L,
+	1.011495020008010352575398009604164287337e+0006L,
+	6.886722075290430568652227875200208955970e+0005L,
+	2.504735189948021472047157148613171956537e+0005L,
+	4.408138920171044846941001844352009817062e+0004L,
+	3.105572178072115145673058722853640854884e+0003L,
+	5.588294821118916113437396504573817033678e+0001L,
 };
-static GENERIC qzero(x)
-GENERIC x;
+
+static GENERIC
+qzero(GENERIC x)
 {
-	GENERIC s,r,t,z;
+	GENERIC s, r, t, z;
 	int i;
-	if (x>huge) return -0.125L/x;
-	t = one/x; z = t*t;
-	if (x>sixteen) {
-	    r = z*qr0[11]+qr0[10]; s = qs0[10];
-	    for (i=9;i>=0;i--) {
-		r = z*r + qr0[i];
-		s = z*s + qs0[i];
-	    }
-	} else if (x>eight) {
-	    r = qr1[11]; s = qs1[11]+z*(qs1[12]+z*qs1[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + qr1[i];
-		s = z*s + qs1[i];
-	    }
-	} else if (x>five) {  /* assume x > 5.0 */
-	    r = qr2[11]; s = qs2[11]+z*(qs2[12]+z*qs2[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + qr2[i];
-		s = z*s + qs2[i];
-	    }
-	} else if (x>3.5L) {
-	    r = qr3[12]; s = qs3[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + qr3[i];
-		s = z*s + qs3[i];
-	    }
-	} else if (x>2.5L) {
-	    r = qr4[12]; s = qs4[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + qr4[i];
-		s = z*s + qs4[i];
-	    }
-	} else if (x> (1.0L/0.5625L)) {
-	    r = qr5[12]; s = qs5[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + qr5[i];
-		s = z*s + qs5[i];
-	    }
-	} else {	/* assume x > 1.28 */
-	    r = qr6[12]; s = qs6[12];
-	    for (i=11;i>=0;i--) {
-		r = z*r + qr6[i];
-		s = z*s + qs6[i];
-	    }
+
+	if (x > huge)
+		return (-0.125L / x);
+
+	t = one / x;
+	z = t * t;
+
+	if (x > sixteen) {
+		r = z * qr0[11] + qr0[10];
+		s = qs0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + qr0[i];
+			s = z * s + qs0[i];
+		}
+	} else if (x > eight) {
+		r = qr1[11];
+		s = qs1[11] + z * (qs1[12] + z * qs1[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr1[i];
+			s = z * s + qs1[i];
+		}
+	} else if (x > five) {	/* assume x > 5.0 */
+		r = qr2[11];
+		s = qs2[11] + z * (qs2[12] + z * qs2[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr2[i];
+			s = z * s + qs2[i];
+		}
+	} else if (x > 3.5L) {
+		r = qr3[12];
+		s = qs3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr3[i];
+			s = z * s + qs3[i];
+		}
+	} else if (x > 2.5L) {
+		r = qr4[12];
+		s = qs4[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr4[i];
+			s = z * s + qs4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = qr5[12];
+		s = qs5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr5[i];
+			s = z * s + qs5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = qr6[12];
+		s = qs6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr6[i];
+			s = z * s + qs6[i];
+		}
 	}
-	return t*(r/s);
+
+	return (t * (r / s));
 }
--- old/usr/src/lib/libm/common/Q/j1l.c	2019-06-06 20:38:47.593083220 +0000
+++ new/usr/src/lib/libm/common/Q/j1l.c	2019-06-06 20:38:47.609404555 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,693 +43,804 @@
 #include "libm.h"
 #include "longdouble.h"
 
-#define	GENERIC long double
-static const GENERIC
-zero    = 0.0L,
-small	= 1.0e-9L,
-tiny 	= 1.0e-38L,
-one	= 1.0L,
-five   	= 5.0L,
-invsqrtpi= 5.641895835477562869480794515607725858441e-0001L,
-tpi	= 0.636619772367581343075535053490057448L;
+#define	GENERIC	long double
+
+static const GENERIC zero = 0.0L,
+	small = 1.0e-9L,
+	tiny = 1.0e-38L,
+	one = 1.0L,
+	five = 5.0L,
+	invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
+	tpi = 0.636619772367581343075535053490057448L;
 
 static GENERIC pone(GENERIC);
 static GENERIC qone(GENERIC);
 
 static const GENERIC r0[7] = {
-  -6.249999999999999999999999999999999627320e-0002L,
-   1.940606727194041716205384618494641565464e-0003L,
-  -3.005630423155733701856481469986459043883e-0005L,
-   2.345586219403918667468341047369572169358e-0007L,
-  -9.976809285885253587529010109133336669724e-0010L,
-   2.218743258363623946078958783775107473381e-0012L,
-  -2.071079656218700604767650924103578046280e-0015L,
+	-6.249999999999999999999999999999999627320e-0002L,
+	1.940606727194041716205384618494641565464e-0003L,
+	-3.005630423155733701856481469986459043883e-0005L,
+	2.345586219403918667468341047369572169358e-0007L,
+	-9.976809285885253587529010109133336669724e-0010L,
+	2.218743258363623946078958783775107473381e-0012L,
+	-2.071079656218700604767650924103578046280e-0015L,
 };
+
 static const GENERIC s0[7] = {
-   1.0e0L,
-   1.061695903156199920738051277075003059555e-0002L,
-   5.521860513111180371566951179398862692060e-0005L,
-   1.824214367413754193524107877084979441407e-0007L,
-   4.098957778439576834818838198039029353925e-0010L,
-   6.047735079699666389853240090925264056197e-0013L,
-   4.679044728878836197247923279512047035041e-0016L,
+	1.0e0L,
+	1.061695903156199920738051277075003059555e-0002L,
+	5.521860513111180371566951179398862692060e-0005L,
+	1.824214367413754193524107877084979441407e-0007L,
+	4.098957778439576834818838198039029353925e-0010L,
+	6.047735079699666389853240090925264056197e-0013L,
+	4.679044728878836197247923279512047035041e-0016L,
 };
 
 GENERIC
-j1l(x) GENERIC x;{
-	GENERIC z, d, s,c,ss,cc,r;
+j1l(GENERIC x)
+{
+	GENERIC z, d, s, c, ss, cc, r;
 	int i, sgn;
 
-	if (!finitel(x)) return one/x;
+	if (!finitel(x))
+		return (one / x);
+
 	sgn = signbitl(x);
 	x = fabsl(x);
+
 	if (x > 1.28L) {
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
-	 * where x0 = x-3pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
-	 *			=  1/sqrt(2) * (sin(x) - cos(x))
-	 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
-	 *			= -1/sqrt(2) * (cos(x) + sin(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
-		if (x>1.0e2450L) {	/* x+x may overflow */
-			ss = -s-c;
-			cc =  s-c;
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
+		 * where x0 = x-3pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
+		 *			=  1/sqrt(2) * (sin(x) - cos(x))
+		 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
+		 *			= -1/sqrt(2) * (cos(x) + sin(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
+		if (x > 1.0e2450L) {	/* x+x may overflow */
+			ss = -s - c;
+			cc = s - c;
 		} else if (signbitl(s) != signbitl(c)) {
 			cc = s - c;
-			ss = cosl(x+x)/cc;
+			ss = cosl(x + x) / cc;
 		} else {
-			ss = -s-c;
-			cc = cosl(x+x)/ss;
+			ss = -s - c;
+			cc = cosl(x + x) / ss;
 		}
-	/*
-	 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
-	 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
-	 */
-                if (x>1.0e120L) return (invsqrtpi*cc)/sqrtl(x);
-                d =  invsqrtpi*(pone(x)*cc-qone(x)*ss)/sqrtl(x);
-		if (sgn == 0) return d; else return -d;
+
+		/*
+		 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
+		 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
+		 */
+		if (x > 1.0e120L)
+			return ((invsqrtpi * cc) / sqrtl(x));
+
+		d = invsqrtpi * (pone(x) * cc - qone(x) * ss) / sqrtl(x);
+
+		if (sgn == 0)
+			return (d);
+		else
+			return (-d);
+	}
+
+	if (x <= small) {
+		if (x <= tiny)
+			d = 0.5L * x;
+		else
+			d = x * (0.5L - x * x * 0.125L);
+
+		if (sgn == 0)
+			return (d);
+		else
+			return (-d);
 	}
-	if (x<=small) {
-            if (x<=tiny) d = 0.5L*x;
-            else d =  x*(0.5L-x*x*0.125L);
-	    if (sgn == 0) return d; else return -d;
-        }
-	z = x*x;
-	    r = r0[6];
-	    s = s0[6];
-	    for (i=5;i>=0;i--) {
-		r = r*z + r0[i];
-		s = s*z + s0[i];
-	    }
-	d = x*0.5L+x*(z*(r/s));
-	if (sgn == 0) return d; else return -d;
+
+	z = x * x;
+	r = r0[6];
+	s = s0[6];
+
+	for (i = 5; i >= 0; i--) {
+		r = r * z + r0[i];
+		s = s * z + s0[i];
+	}
+
+	d = x * 0.5L + x * (z * (r / s));
+
+	if (sgn == 0)
+		return (d);
+	else
+		return (-d);
 }
 
 static const GENERIC u0[7] = {
-  -1.960570906462389484060557273467558703503e-0001L,
-   5.166389353148318460304315890665450006495e-0002L,
-  -2.229699464105910913337190798743451115604e-0003L,
-   3.625437034548863342715657067759078267158e-0005L,
-  -2.689902826993117212255524537353883987171e-0007L,
-   9.304570592456930912969387719010256018466e-0010L,
-  -1.234878126794286643318321347997500346131e-0012L,
+	-1.960570906462389484060557273467558703503e-0001L,
+	5.166389353148318460304315890665450006495e-0002L,
+	-2.229699464105910913337190798743451115604e-0003L,
+	3.625437034548863342715657067759078267158e-0005L,
+	-2.689902826993117212255524537353883987171e-0007L,
+	9.304570592456930912969387719010256018466e-0010L,
+	-1.234878126794286643318321347997500346131e-0012L,
 };
+
 static const GENERIC v0[8] = {
-   1.0e0L,
-   1.369394302535807332517110204820556695644e-0002L,
-   9.508438148097659501433367062605935379588e-0005L,
-   4.399007309420092056052714797296467565655e-0007L,
-   1.488083087443756398305819693177715000787e-0009L,
-   3.751609832625793536245746965768587624922e-0012L,
-   6.680926434086257291872903276124244131448e-0015L,
-   6.676602383908906988160099057991121446058e-0018L,
+	1.0e0L,
+	1.369394302535807332517110204820556695644e-0002L,
+	9.508438148097659501433367062605935379588e-0005L,
+	4.399007309420092056052714797296467565655e-0007L,
+	1.488083087443756398305819693177715000787e-0009L,
+	3.751609832625793536245746965768587624922e-0012L,
+	6.680926434086257291872903276124244131448e-0015L,
+	6.676602383908906988160099057991121446058e-0018L,
 };
 
 GENERIC
-y1l(x) GENERIC x;{
-	GENERIC z, s,c,ss,cc,u,v;
+y1l(GENERIC x)
+{
+	GENERIC z, s, c, ss, cc, u, v;
 	int i;
 
-	if (isnanl(x)) return x+x;
+	if (isnanl(x))
+		return (x + x);
+
 	if (x <= zero) {
 		if (x == zero)
-		    return -one/zero;
+			return (-one / zero);
 		else
-		    return zero/zero;
+			return (zero / zero);
 	}
+
 	if (x > 1.28L) {
-		if (!finitel(x)) return zero;
+		if (!finitel(x))
+			return (zero);
+
 		s = sinl(x);
 		c = cosl(x);
-	/*
-	 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
-	 * where x0 = x-3pi/4
-	 * 	Better formula:
-	 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
-	 *			=  1/sqrt(2) * (sin(x) - cos(x))
-	 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
-	 *			= -1/sqrt(2) * (cos(x) + sin(x))
-	 * To avoid cancellation, use
-	 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
-	 * to compute the worse one.
-	 */
-		if (x>1.0e2450L) {	/* x+x may overflow */
-			ss = -s-c;
-			cc =  s-c;
+
+		/* BEGIN CSTYLED */
+		/*
+		 * j1(x) = sqrt(2/(pi*x))*(p1(x)*cos(x0)-q1(x)*sin(x0))
+		 * where x0 = x-3pi/4
+		 *      Better formula:
+		 *		cos(x0) = cos(x)cos(3pi/4)+sin(x)sin(3pi/4)
+		 *			=  1/sqrt(2) * (sin(x) - cos(x))
+		 *		sin(x0) = sin(x)cos(3pi/4)-cos(x)sin(3pi/4)
+		 *			= -1/sqrt(2) * (cos(x) + sin(x))
+		 * To avoid cancellation, use
+		 *		sin(x) +- cos(x) = -cos(2x)/(sin(x) -+ cos(x))
+		 * to compute the worse one.
+		 */
+		/* END CSTYLED */
+		if (x > 1.0e2450L) {	/* x+x may overflow */
+			ss = -s - c;
+			cc = s - c;
 		} else if (signbitl(s) != signbitl(c)) {
 			cc = s - c;
-			ss = cosl(x+x)/cc;
+			ss = cosl(x + x) / cc;
 		} else {
-			ss = -s-c;
-			cc = cosl(x+x)/ss;
+			ss = -s - c;
+			cc = cosl(x + x) / ss;
 		}
-	/*
-	 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
-	 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
-	 */
-		if (x>1.0e91L) return (invsqrtpi*ss)/sqrtl(x);
-                return invsqrtpi*(pone(x)*ss+qone(x)*cc)/sqrtl(x);
+
+		/*
+		 * j1(x) = 1/sqrt(pi*x) * (P(1,x)*cc - Q(1,x)*ss)
+		 * y1(x) = 1/sqrt(pi*x) * (P(1,x)*ss + Q(1,x)*cc)
+		 */
+		if (x > 1.0e91L)
+			return ((invsqrtpi * ss) / sqrtl(x));
+
+		return (invsqrtpi * (pone(x) * ss + qone(x) * cc) / sqrtl(x));
+	}
+
+	if (x <= tiny)
+		return (-tpi / x);
+
+	z = x * x;
+	u = u0[6];
+	v = v0[6] + z * v0[7];
+
+	for (i = 5; i >= 0; i--) {
+		u = u * z + u0[i];
+		v = v * z + v0[i];
 	}
-        if (x<=tiny) {
-            return (-tpi/x);
-        }
-	z = x*x;
-	    u = u0[6]; v = v0[6]+z*v0[7];
-	    for (i=5;i>=0;i--) {
-		u = u*z + u0[i];
-		v = v*z + v0[i];
-	    }
-	return(x*(u/v) + tpi*(j1l(x)*logl(x)-one/x));
+
+	return (x * (u / v) + tpi * (j1l(x) * logl(x) - one / x));
 }
 
 static const GENERIC pr0[12] = {
-   1.000000000000000000000000000000000000267e+0000L,
-   1.060717875045891455602180843276758003035e+0003L,
-   4.344347542892127024446687712181105852335e+0005L,
-   8.915680220724007016377924252717410457094e+0007L,
-   9.969502259938406062809873257569171272819e+0009L,
-   6.200290193138613035646510338707386316595e+0011L,
-   2.105978548788015119851815854422247330118e+0013L,
-   3.696635772784601239371730810311998368948e+0014L,
-   3.015913097920694682057958412534134515156e+0015L,
-   9.370298471339353098123277427328592725921e+0015L,
-   7.190349005196335967340799265074029443057e+0015L,
-   2.736097786240689996880391074927552517982e+0014L,
+	1.000000000000000000000000000000000000267e+0000L,
+	1.060717875045891455602180843276758003035e+0003L,
+	4.344347542892127024446687712181105852335e+0005L,
+	8.915680220724007016377924252717410457094e+0007L,
+	9.969502259938406062809873257569171272819e+0009L,
+	6.200290193138613035646510338707386316595e+0011L,
+	2.105978548788015119851815854422247330118e+0013L,
+	3.696635772784601239371730810311998368948e+0014L,
+	3.015913097920694682057958412534134515156e+0015L,
+	9.370298471339353098123277427328592725921e+0015L,
+	7.190349005196335967340799265074029443057e+0015L,
+	2.736097786240689996880391074927552517982e+0014L,
 };
+
 static const GENERIC ps0[11] = {
-   1.0e0L,
-   1.060600687545891455602180843276758095107e+0003L,
-   4.343106093416975589147153906505338900961e+0005L,
-   8.910605869002176566582072242244353399059e+0007L,
-   9.959122058635087888690713917622056540190e+0009L,
-   6.188744967234948231792482949171041843894e+0011L,
-   2.098863976953783506401759873801990304907e+0013L,
-   3.672870357018063196746729751479938908450e+0014L,
-   2.975538419246824921049011529574385888420e+0015L,
-   9.063657659995043205018686029284479837091e+0015L,
-   6.401953344314747916729366441508892711691e+0015L,
+	1.0e0L,
+	1.060600687545891455602180843276758095107e+0003L,
+	4.343106093416975589147153906505338900961e+0005L,
+	8.910605869002176566582072242244353399059e+0007L,
+	9.959122058635087888690713917622056540190e+0009L,
+	6.188744967234948231792482949171041843894e+0011L,
+	2.098863976953783506401759873801990304907e+0013L,
+	3.672870357018063196746729751479938908450e+0014L,
+	2.975538419246824921049011529574385888420e+0015L,
+	9.063657659995043205018686029284479837091e+0015L,
+	6.401953344314747916729366441508892711691e+0015L,
 };
+
 static const GENERIC pr1[12] = {
-   1.000000000000000000000023667524130660984e+0000L,
-   6.746154419979618754354803488126452971204e+0002L,
-   1.811210781083390154857018330296145970502e+0005L,
-   2.533098390379924268038005329095287842244e+0007L,
-   2.029683619805342145252338570875424600729e+0009L,
-   9.660859662192711465301069401598929980319e+0010L,
-   2.743396238644831519934098967716621316316e+0012L,
-   4.553097354140854377931023170263455246288e+0013L,
-   4.210245069852219757476169864974870720374e+0014L,
-   1.987334056229596485076645967176169801727e+0015L,
-   4.067120052787096893838970455751338930462e+0015L,
-   2.486539606380406398310845264910691398133e+0015L,
+	1.000000000000000000000023667524130660984e+0000L,
+	6.746154419979618754354803488126452971204e+0002L,
+	1.811210781083390154857018330296145970502e+0005L,
+	2.533098390379924268038005329095287842244e+0007L,
+	2.029683619805342145252338570875424600729e+0009L,
+	9.660859662192711465301069401598929980319e+0010L,
+	2.743396238644831519934098967716621316316e+0012L,
+	4.553097354140854377931023170263455246288e+0013L,
+	4.210245069852219757476169864974870720374e+0014L,
+	1.987334056229596485076645967176169801727e+0015L,
+	4.067120052787096893838970455751338930462e+0015L,
+	2.486539606380406398310845264910691398133e+0015L,
 };
+
 static const GENERIC ps1[14] = {
-   1.0e0L,
-   6.744982544979618754355808680196859521782e+0002L,
-   1.810421795396966762032155290441364740350e+0005L,
-   2.530986460644310651529583759699988435573e+0007L,
-   2.026743276048023121360249288818290224145e+0009L,
-   9.637461924407405935245269407052641341836e+0010L,
-   2.732378628423766417402292797028314160831e+0012L,
-   4.522345274960527124354844364012184278488e+0013L,
-   4.160650668341743132685335758415469856545e+0014L,
-   1.943730242988858208243492424892435901211e+0015L,
-   3.880228532692127989901131618598067450001e+0015L,
-   2.178020816161154615841000173683302999728e+0015L,
-  -8.994062666842225551554346698171600634173e+0013L,
-   1.368520368508851253495764806934619574990e+0013L,
+	1.0e0L,
+	6.744982544979618754355808680196859521782e+0002L,
+	1.810421795396966762032155290441364740350e+0005L,
+	2.530986460644310651529583759699988435573e+0007L,
+	2.026743276048023121360249288818290224145e+0009L,
+	9.637461924407405935245269407052641341836e+0010L,
+	2.732378628423766417402292797028314160831e+0012L,
+	4.522345274960527124354844364012184278488e+0013L,
+	4.160650668341743132685335758415469856545e+0014L,
+	1.943730242988858208243492424892435901211e+0015L,
+	3.880228532692127989901131618598067450001e+0015L,
+	2.178020816161154615841000173683302999728e+0015L,
+	-8.994062666842225551554346698171600634173e+0013L,
+	1.368520368508851253495764806934619574990e+0013L,
 };
+
 static const GENERIC pr2[12] = {
-   1.000000000000000006938651621840396237282e+0000L,
-   3.658416291850404981407101077037948144698e+0002L,
-   5.267073772170356547709794670602812447537e+0004L,
-   3.912012101226837463014925210735894620442e+0006L,
-   1.651295648974103957193874928714180765625e+0008L,
-   4.114901144480797609972484998142146783499e+0009L,
-   6.092524309766036681542980572526335147672e+0010L,
-   5.263913178071282616719249969074134570577e+0011L,
-   2.538408581124324223367341020538081330994e+0012L,
-   6.288607929360291027895126983015365677648e+0012L,
-   6.848330048211148419047055075386525945280e+0012L,
-   2.290309646838867941423178163991423244690e+0012L,
+	1.000000000000000006938651621840396237282e+0000L,
+	3.658416291850404981407101077037948144698e+0002L,
+	5.267073772170356547709794670602812447537e+0004L,
+	3.912012101226837463014925210735894620442e+0006L,
+	1.651295648974103957193874928714180765625e+0008L,
+	4.114901144480797609972484998142146783499e+0009L,
+	6.092524309766036681542980572526335147672e+0010L,
+	5.263913178071282616719249969074134570577e+0011L,
+	2.538408581124324223367341020538081330994e+0012L,
+	6.288607929360291027895126983015365677648e+0012L,
+	6.848330048211148419047055075386525945280e+0012L,
+	2.290309646838867941423178163991423244690e+0012L,
 };
+
 static const GENERIC ps2[14] = {
-   1.0e0L,
-   3.657244416850405086459410165762319861856e+0002L,
-   5.262802358425023243992387075861237306312e+0004L,
-   3.905896813959919648136295861661483848364e+0006L,
-   1.646791907791461220742694842108202772763e+0008L,
-   4.096132803064256022224954120208201437344e+0009L,
-   6.046665195915950447544429445730680236759e+0010L,
-   5.198061739781991313414052212328653295168e+0011L,
-   2.484233851814333966401527626421254279796e+0012L,
-   6.047868806925315879339651539434315255940e+0012L,
-   6.333103831254091652501642567294101813354e+0012L,
-   1.875143098754284994467609936924685024968e+0012L,
-  -5.238330920563392692965412762508813601534e+0010L,
-   4.656888609439364725427789198383779259957e+0009L,
+	1.0e0L,
+	3.657244416850405086459410165762319861856e+0002L,
+	5.262802358425023243992387075861237306312e+0004L,
+	3.905896813959919648136295861661483848364e+0006L,
+	1.646791907791461220742694842108202772763e+0008L,
+	4.096132803064256022224954120208201437344e+0009L,
+	6.046665195915950447544429445730680236759e+0010L,
+	5.198061739781991313414052212328653295168e+0011L,
+	2.484233851814333966401527626421254279796e+0012L,
+	6.047868806925315879339651539434315255940e+0012L,
+	6.333103831254091652501642567294101813354e+0012L,
+	1.875143098754284994467609936924685024968e+0012L,
+	-5.238330920563392692965412762508813601534e+0010L,
+	4.656888609439364725427789198383779259957e+0009L,
 };
+
 static const GENERIC pr3[13] = {
-   1.000000000000009336887318068056137842897e+0000L,
-   2.242719942728459588488051572002835729183e+0002L,
-   1.955450611382026550266257737331095691092e+0004L,
-   8.707143293993619899395400562409175590739e+0005L,
-   2.186267894487004565948324289010954505316e+0007L,
-   3.224328510541957792360691585667502864688e+0008L,
-   2.821057355151380597331792896882741364897e+0009L,
-   1.445371387295422404365584793796028979840e+0010L,
-   4.181743160669891357783011002656658107864e+0010L,
-   6.387371088767993119325536137794535513922e+0010L,
-   4.575619999412716078064070587767416436396e+0010L,
-   1.228415651211639160620284441690503550842e+0010L,
-   7.242170349875563053436050532153112882072e+0008L,
+	1.000000000000009336887318068056137842897e+0000L,
+	2.242719942728459588488051572002835729183e+0002L,
+	1.955450611382026550266257737331095691092e+0004L,
+	8.707143293993619899395400562409175590739e+0005L,
+	2.186267894487004565948324289010954505316e+0007L,
+	3.224328510541957792360691585667502864688e+0008L,
+	2.821057355151380597331792896882741364897e+0009L,
+	1.445371387295422404365584793796028979840e+0010L,
+	4.181743160669891357783011002656658107864e+0010L,
+	6.387371088767993119325536137794535513922e+0010L,
+	4.575619999412716078064070587767416436396e+0010L,
+	1.228415651211639160620284441690503550842e+0010L,
+	7.242170349875563053436050532153112882072e+0008L,
 };
+
 static const GENERIC ps3[13] = {
-   1.0e0L,
-   2.241548067728529551049804610486061401070e+0002L,
-   1.952838216795552145132137932931237181307e+0004L,
-   8.684574926493185744628127341069974575526e+0005L,
-   2.176357771067037962940853412819852189164e+0007L,
-   3.199958682356132977319258783167122100567e+0008L,
-   2.786218931525334687844675219914201872570e+0009L,
-   1.416283776951741549631417572317916039767e+0010L,
-   4.042962659271567948735676834609348842922e+0010L,
-   6.028168462646694510083847222968444402161e+0010L,
-   4.118410226794641413833887606580085281111e+0010L,
-   9.918735736297038430744161253338202230263e+0009L,
-   4.092967198238098023219124487437130332038e+0008L,
+	1.0e0L,
+	2.241548067728529551049804610486061401070e+0002L,
+	1.952838216795552145132137932931237181307e+0004L,
+	8.684574926493185744628127341069974575526e+0005L,
+	2.176357771067037962940853412819852189164e+0007L,
+	3.199958682356132977319258783167122100567e+0008L,
+	2.786218931525334687844675219914201872570e+0009L,
+	1.416283776951741549631417572317916039767e+0010L,
+	4.042962659271567948735676834609348842922e+0010L,
+	6.028168462646694510083847222968444402161e+0010L,
+	4.118410226794641413833887606580085281111e+0010L,
+	9.918735736297038430744161253338202230263e+0009L,
+	4.092967198238098023219124487437130332038e+0008L,
 };
+
 static const GENERIC pr4[13] = {
-   1.000000000001509220978157399042059553390e+0000L,
-   1.437551868378147851133499996323782607787e+0002L,
-   7.911335537418177296041518061404505428004e+0003L,
-   2.193710939115317214716518908935756104804e+0005L,
-   3.390662495136730962513489796538274984382e+0006L,
-   3.048655347929348891006070609293884274789e+0007L,
-   1.613781633489496606354045161527450975195e+0008L,
-   4.975089835037230277110156150038482159988e+0008L,
-   8.636047087015115403880904418339566323264e+0008L,
-   7.918202912328366140110671223076949101509e+0008L,
-   3.423294665798984733439650311722794853294e+0008L,
-   5.621904953441963961040503934782662613621e+0007L,
-   2.086303543310240260758670404509484499793e+0006L,
+	1.000000000001509220978157399042059553390e+0000L,
+	1.437551868378147851133499996323782607787e+0002L,
+	7.911335537418177296041518061404505428004e+0003L,
+	2.193710939115317214716518908935756104804e+0005L,
+	3.390662495136730962513489796538274984382e+0006L,
+	3.048655347929348891006070609293884274789e+0007L,
+	1.613781633489496606354045161527450975195e+0008L,
+	4.975089835037230277110156150038482159988e+0008L,
+	8.636047087015115403880904418339566323264e+0008L,
+	7.918202912328366140110671223076949101509e+0008L,
+	3.423294665798984733439650311722794853294e+0008L,
+	5.621904953441963961040503934782662613621e+0007L,
+	2.086303543310240260758670404509484499793e+0006L,
 };
+
 static const GENERIC ps4[13] = {
-   1.0e0L,
-   1.436379993384532371670493319591847362304e+0002L,
-   7.894647154785430678061053848847436659499e+0003L,
-   2.184659753392097529008981741550878586174e+0005L,
-   3.366109083305465176803513738147049499361e+0006L,
-   3.011911545968996817697665866587226343186e+0007L,
-   1.582262913779689851316760148459414895301e+0008L,
-   4.819268809494937919217938589530138201770e+0008L,
-   8.201355762990450679702837123432527154830e+0008L,
-   7.268232093982510937417446421282341425212e+0008L,
-   2.950911909015572933262131323934036480462e+0008L,
-   4.242839924305934423010858966540621219396e+0007L,
-   1.064387620445090779182117666330405186866e+0006L,
+	1.0e0L,
+	1.436379993384532371670493319591847362304e+0002L,
+	7.894647154785430678061053848847436659499e+0003L,
+	2.184659753392097529008981741550878586174e+0005L,
+	3.366109083305465176803513738147049499361e+0006L,
+	3.011911545968996817697665866587226343186e+0007L,
+	1.582262913779689851316760148459414895301e+0008L,
+	4.819268809494937919217938589530138201770e+0008L,
+	8.201355762990450679702837123432527154830e+0008L,
+	7.268232093982510937417446421282341425212e+0008L,
+	2.950911909015572933262131323934036480462e+0008L,
+	4.242839924305934423010858966540621219396e+0007L,
+	1.064387620445090779182117666330405186866e+0006L,
 };
+
 static const GENERIC pr5[13] = {
-   1.000000000102434805241171427253847353861e+0000L,
-   9.129332257083629259060502249025963234821e+0001L,
-   3.132238483586953037576119377504557191413e+0003L,
-   5.329782528269307971278943122454171107861e+0004L,
-   4.988460157184117790692873002103052944145e+0005L,
-   2.686602071615786816147010334256047469378e+0006L,
-   8.445418526028961197703799808701268301831e+0006L,
-   1.536575358646141157475725889907900827390e+0007L,
-   1.568405818236523821796862770586544811945e+0007L,
-   8.450876239888770102387618667362302173547e+0006L,
-   2.154414900139567328424026827163203446077e+0006L,
-   2.105656926565043898888460254808062352205e+0005L,
-   4.739165011023396507022134303736862812975e+0003L,
+	1.000000000102434805241171427253847353861e+0000L,
+	9.129332257083629259060502249025963234821e+0001L,
+	3.132238483586953037576119377504557191413e+0003L,
+	5.329782528269307971278943122454171107861e+0004L,
+	4.988460157184117790692873002103052944145e+0005L,
+	2.686602071615786816147010334256047469378e+0006L,
+	8.445418526028961197703799808701268301831e+0006L,
+	1.536575358646141157475725889907900827390e+0007L,
+	1.568405818236523821796862770586544811945e+0007L,
+	8.450876239888770102387618667362302173547e+0006L,
+	2.154414900139567328424026827163203446077e+0006L,
+	2.105656926565043898888460254808062352205e+0005L,
+	4.739165011023396507022134303736862812975e+0003L,
 };
+
 static const GENERIC ps5[13] = {
-   1.0e0L,
-   9.117613509595327476509152673394703847793e+0001L,
-   3.121697972484015639301279229281770795147e+0003L,
-   5.294447222735893568040911873834576440255e+0004L,
-   4.930368882192772335798256684110887882807e+0005L,
-   2.634854685641165298302167435798357437768e+0006L,
-   8.185462775400326393555896157031818280918e+0006L,
-   1.462417423080215192609668642663030667086e+0007L,
-   1.450624993985851675982860844153954896015e+0007L,
-   7.460467647561995283219086567162006113864e+0006L,
-   1.754210981405612478869227142579056338965e+0006L,
-   1.463286721155271971526264914524746699596e+0005L,
-   2.155894725796702015341211116579827039459e+0003L,
+	1.0e0L,
+	9.117613509595327476509152673394703847793e+0001L,
+	3.121697972484015639301279229281770795147e+0003L,
+	5.294447222735893568040911873834576440255e+0004L,
+	4.930368882192772335798256684110887882807e+0005L,
+	2.634854685641165298302167435798357437768e+0006L,
+	8.185462775400326393555896157031818280918e+0006L,
+	1.462417423080215192609668642663030667086e+0007L,
+	1.450624993985851675982860844153954896015e+0007L,
+	7.460467647561995283219086567162006113864e+0006L,
+	1.754210981405612478869227142579056338965e+0006L,
+	1.463286721155271971526264914524746699596e+0005L,
+	2.155894725796702015341211116579827039459e+0003L,
 };
+
 static const GENERIC pr6[13] = {
-   1.000000003564855546741735920315743157129e+0000L,
-   5.734003934862540458119423509909510288366e+0001L,
-   1.209572491935850486086559692291796887976e+0003L,
-   1.243398391422281247933674779163660286838e+0004L,
-   6.930996755181437937258220998601708278787e+0004L,
-   2.198067659532757598646722249966767620099e+0005L,
-   4.033659432712058633933179115820576858455e+0005L,
-   4.257759657219008027016047206574574358678e+0005L,
-   2.511917395876004349480721277445763916389e+0005L,
-   7.813756153070623654178731651381881953552e+0004L,
-   1.152069173381127881385588092905864352891e+0004L,
-   6.548580782804088553777816037551523398082e+0002L,
-   8.668725370116906132327542766127938496880e+0000L,
+	1.000000003564855546741735920315743157129e+0000L,
+	5.734003934862540458119423509909510288366e+0001L,
+	1.209572491935850486086559692291796887976e+0003L,
+	1.243398391422281247933674779163660286838e+0004L,
+	6.930996755181437937258220998601708278787e+0004L,
+	2.198067659532757598646722249966767620099e+0005L,
+	4.033659432712058633933179115820576858455e+0005L,
+	4.257759657219008027016047206574574358678e+0005L,
+	2.511917395876004349480721277445763916389e+0005L,
+	7.813756153070623654178731651381881953552e+0004L,
+	1.152069173381127881385588092905864352891e+0004L,
+	6.548580782804088553777816037551523398082e+0002L,
+	8.668725370116906132327542766127938496880e+0000L,
 };
+
 static const GENERIC ps6[13] = {
-   1.0e0L,
-   5.722285236357114566499221525736286205184e+0001L,
-   1.203010842878317935444582950620339570506e+0003L,
-   1.230058335378583550155825502172435371208e+0004L,
-   6.800998550607861288865300438648089894412e+0004L,
-   2.130767829599304262987769347536850885921e+0005L,
-   3.840483466643916681759936972992155310026e+0005L,
-   3.947432373459225542861819148108081160393e+0005L,
-   2.237816239393081111481588434457838526738e+0005L,
-   6.545820495124419723398946273790921540774e+0004L,
-   8.729563630320892741500726213278834737196e+0003L,
-   4.130762660291894753450174794196998813709e+0002L,
-   3.480368898672684645130335786015075595598e+0000L,
+	1.0e0L,
+	5.722285236357114566499221525736286205184e+0001L,
+	1.203010842878317935444582950620339570506e+0003L,
+	1.230058335378583550155825502172435371208e+0004L,
+	6.800998550607861288865300438648089894412e+0004L,
+	2.130767829599304262987769347536850885921e+0005L,
+	3.840483466643916681759936972992155310026e+0005L,
+	3.947432373459225542861819148108081160393e+0005L,
+	2.237816239393081111481588434457838526738e+0005L,
+	6.545820495124419723398946273790921540774e+0004L,
+	8.729563630320892741500726213278834737196e+0003L,
+	4.130762660291894753450174794196998813709e+0002L,
+	3.480368898672684645130335786015075595598e+0000L,
 };
+
 static const GENERIC sixteen = 16.0L;
-static const GENERIC eight   = 8.0L;
-static const GENERIC huge    = 1.0e30L;
+static const GENERIC eight = 8.0L;
+static const GENERIC huge = 1.0e30L;
 
-static GENERIC pone(x)
-GENERIC x;
+static GENERIC
+pone(GENERIC x)
 {
-	GENERIC s,r,t,z;
+	GENERIC s, r, t, z;
 	int i;
-	if (x>huge) return one;
-	t = one/x; z = t*t;
-	if (x>sixteen) {
-	    r = z*pr0[11]+pr0[10]; s = ps0[10];
-	    for (i=9;i>=0;i--) {
-		r = z*r + pr0[i];
-		s = z*s + ps0[i];
-	    }
-	} else if (x>eight) {
-	    r = pr1[11]; s = ps1[11]+z*(ps1[12]+z*ps1[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + pr1[i];
-		s = z*s + ps1[i];
-	    }
-	} else if (x>five) {
-	    r = pr2[11]; s = ps2[11]+z*(ps2[12]+z*ps2[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + pr2[i];
-		s = z*s + ps2[i];
-	    }
-        } else if (x>3.5L) {
-            r = pr3[12]; s = ps3[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + pr3[i];
-                s = z*s + ps3[i];
-            }
-        } else if (x>2.5L) {
-            r = pr4[12]; s = ps4[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + pr4[i];
-                s = z*s + ps4[i];
-            }
-        } else if (x> (1.0L/0.5625L)) {
-            r = pr5[12]; s = ps5[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + pr5[i];
-                s = z*s + ps5[i];
-            }
-        } else {        /* assume x > 1.28 */
-            r = pr6[12]; s = ps6[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + pr6[i];
-                s = z*s + ps6[i];
-            }
-        }
-	return r/s;
-}
 
+	if (x > huge)
+		return (one);
+
+	t = one / x;
+	z = t * t;
+
+	if (x > sixteen) {
+		r = z * pr0[11] + pr0[10];
+		s = ps0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + pr0[i];
+			s = z * s + ps0[i];
+		}
+	} else if (x > eight) {
+		r = pr1[11];
+		s = ps1[11] + z * (ps1[12] + z * ps1[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr1[i];
+			s = z * s + ps1[i];
+		}
+	} else if (x > five) {
+		r = pr2[11];
+		s = ps2[11] + z * (ps2[12] + z * ps2[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + pr2[i];
+			s = z * s + ps2[i];
+		}
+	} else if (x > 3.5L) {
+		r = pr3[12];
+		s = ps3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr3[i];
+			s = z * s + ps3[i];
+		}
+	} else if (x > 2.5L) {
+		r = pr4[12];
+		s = ps4[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr4[i];
+			s = z * s + ps4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = pr5[12];
+		s = ps5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr5[i];
+			s = z * s + ps5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = pr6[12];
+		s = ps6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + pr6[i];
+			s = z * s + ps6[i];
+		}
+	}
 
+	return (r / s);
+}
 static const GENERIC qr0[12] = {
-   3.749999999999999999999999999999999971033e-0001L,
-   4.256726035237050601607682277433094262226e+0002L,
-   1.875976490812878489192409978945401066066e+0005L,
-   4.170314268048041914273603680317745592790e+0007L,
-   5.092750132543855817293451118974555746551e+0009L,
-   3.494749676278488654103505795794139483404e+0011L,
-   1.327062148257437316997667817096694173709e+0013L,
-   2.648993138273427226907503742066551150490e+0014L,
-   2.511695665909547412222430494473998127684e+0015L,
-   9.274694506662289043224310499164702306096e+0015L,
-   8.150904170663663829331320302911792892002e+0015L,
-  -5.001918733707662355772037829620388765122e+0014L,
+	3.749999999999999999999999999999999971033e-0001L,
+	4.256726035237050601607682277433094262226e+0002L,
+	1.875976490812878489192409978945401066066e+0005L,
+	4.170314268048041914273603680317745592790e+0007L,
+	5.092750132543855817293451118974555746551e+0009L,
+	3.494749676278488654103505795794139483404e+0011L,
+	1.327062148257437316997667817096694173709e+0013L,
+	2.648993138273427226907503742066551150490e+0014L,
+	2.511695665909547412222430494473998127684e+0015L,
+	9.274694506662289043224310499164702306096e+0015L,
+	8.150904170663663829331320302911792892002e+0015L,
+	-5.001918733707662355772037829620388765122e+0014L,
 };
+
 static const GENERIC qs0[11] = {
-   1.0e0L,
-   1.135400380229880160428715273982155760093e+0003L,
-   5.005701183877126164326765545516590744360e+0005L,
-   1.113444200113712167984337603933040102987e+0008L,
-   1.361074819925223062778717565699039471124e+0010L,
-   9.355750985802849484438933905325982809653e+0011L,
-   3.563462786008988825003965543857998084828e+0013L,
-   7.155145113900094163648726863803802910454e+0014L,
-   6.871266835834472758055559013851843654113e+0015L,
-   2.622030899226736712644974988157345234092e+0016L,
-   2.602912729172876330650077021706139707746e+0016L,
+	1.0e0L,
+	1.135400380229880160428715273982155760093e+0003L,
+	5.005701183877126164326765545516590744360e+0005L,
+	1.113444200113712167984337603933040102987e+0008L,
+	1.361074819925223062778717565699039471124e+0010L,
+	9.355750985802849484438933905325982809653e+0011L,
+	3.563462786008988825003965543857998084828e+0013L,
+	7.155145113900094163648726863803802910454e+0014L,
+	6.871266835834472758055559013851843654113e+0015L,
+	2.622030899226736712644974988157345234092e+0016L,
+	2.602912729172876330650077021706139707746e+0016L,
 };
+
 static const GENERIC qr1[12] = {
-   3.749999999999999999997762458207284405806e-0001L,
-   2.697883998881706839929255517498189980485e+0002L,
-   7.755195925781028489386938870473834411019e+0004L,
-   1.166777762104017777198211072895528968355e+0007L,
-   1.011504772984321168320010084520261069362e+0009L,
-   5.246007703574156853577754571720205550010e+0010L,
-   1.637692549885592683166116551691266537647e+0012L,
-   3.022303623698185669912990310925039382495e+0013L,
-   3.154769927290655684846107030265909987946e+0014L,
-   1.715819913441554770089730934808123360921e+0015L,
-   4.165044355759732622273534445131736188510e+0015L,
-   3.151381420874174705643100381708086287596e+0015L,
+	3.749999999999999999997762458207284405806e-0001L,
+	2.697883998881706839929255517498189980485e+0002L,
+	7.755195925781028489386938870473834411019e+0004L,
+	1.166777762104017777198211072895528968355e+0007L,
+	1.011504772984321168320010084520261069362e+0009L,
+	5.246007703574156853577754571720205550010e+0010L,
+	1.637692549885592683166116551691266537647e+0012L,
+	3.022303623698185669912990310925039382495e+0013L,
+	3.154769927290655684846107030265909987946e+0014L,
+	1.715819913441554770089730934808123360921e+0015L,
+	4.165044355759732622273534445131736188510e+0015L,
+	3.151381420874174705643100381708086287596e+0015L,
 };
+
 static const GENERIC qs1[14] = {
-   1.0e0L,
-   7.197091705351218239785633172408276982828e+0002L,
-   2.070012799599548685544883041297609861055e+0005L,
-   3.117014815317656221871840152778458754516e+0007L,
-   2.705719678902554974863325877025902971727e+0009L,
-   1.406113614727345726925060648750867264098e+0011L,
-   4.403777536067131320363005978631674817359e+0012L,
-   8.170725690209322283061499386703167242894e+0013L,
-   8.609458844975495289227794126964431210566e+0014L,
-   4.766766367015473481257280600694952920204e+0015L,
-   1.202286587943342194863557940888115641650e+0016L,
-   1.012474328306200909525063936061756024120e+0016L,
-   6.183552022678917858273222879615824070703e+0014L,
-  -9.756731548558226997573737400988225722740e+0013L,
+	1.0e0L,
+	7.197091705351218239785633172408276982828e+0002L,
+	2.070012799599548685544883041297609861055e+0005L,
+	3.117014815317656221871840152778458754516e+0007L,
+	2.705719678902554974863325877025902971727e+0009L,
+	1.406113614727345726925060648750867264098e+0011L,
+	4.403777536067131320363005978631674817359e+0012L,
+	8.170725690209322283061499386703167242894e+0013L,
+	8.609458844975495289227794126964431210566e+0014L,
+	4.766766367015473481257280600694952920204e+0015L,
+	1.202286587943342194863557940888115641650e+0016L,
+	1.012474328306200909525063936061756024120e+0016L,
+	6.183552022678917858273222879615824070703e+0014L,
+	-9.756731548558226997573737400988225722740e+0013L,
 };
+
 static const GENERIC qr2[12] = {
-   3.749999999999999481245647262226994293189e-0001L,
-   1.471366807289771354491181140167359026735e+0002L,
-   2.279432486768448220142080962843526951250e+0004L,
-   1.828943048523771225163804043356958285893e+0006L,
-   8.379828388647823135832220596417725010837e+0007L,
-   2.279814029335044024585393671278378022053e+0009L,
-   3.711653952257118120832817785271466441420e+0010L,
-   3.557650914518554549916730572553105048068e+0011L,
-   1.924583483146095896259774329498934160650e+0012L,
-   5.424386256063736390759567088291887140278e+0012L,
-   6.839325621241776786206509704671746841737e+0012L,
-   2.702169563144001166291686452305436313971e+0012L,
+	3.749999999999999481245647262226994293189e-0001L,
+	1.471366807289771354491181140167359026735e+0002L,
+	2.279432486768448220142080962843526951250e+0004L,
+	1.828943048523771225163804043356958285893e+0006L,
+	8.379828388647823135832220596417725010837e+0007L,
+	2.279814029335044024585393671278378022053e+0009L,
+	3.711653952257118120832817785271466441420e+0010L,
+	3.557650914518554549916730572553105048068e+0011L,
+	1.924583483146095896259774329498934160650e+0012L,
+	5.424386256063736390759567088291887140278e+0012L,
+	6.839325621241776786206509704671746841737e+0012L,
+	2.702169563144001166291686452305436313971e+0012L,
 };
+
 static const GENERIC qs2[14] = {
-   1.0e0L,
-   3.926379194439388135703211933895203191089e+0002L,
-   6.089148804106598297488336063007609312276e+0004L,
-   4.893546162973278583711376356041614150645e+0006L,
-   2.247571119114497845046388801813832219404e+0008L,
-   6.137635663350177751290469334200757872645e+0009L,
-   1.005115019784102856424493519524998953678e+0011L,
-   9.725664462014503832860151384604677240620e+0011L,
-   5.345525100485511116148634192844434636072e+0012L,
-   1.549944007398946691720862738173956994779e+0013L,
-   2.067148441178952625710302124163264760362e+0013L,
-   9.401565402641963611295119487242595462301e+0012L,
-   3.548217088622398274748837287769709374385e+0011L,
-  -2.934470341719047120076509938432417352365e+0010L,
+	1.0e0L,
+	3.926379194439388135703211933895203191089e+0002L,
+	6.089148804106598297488336063007609312276e+0004L,
+	4.893546162973278583711376356041614150645e+0006L,
+	2.247571119114497845046388801813832219404e+0008L,
+	6.137635663350177751290469334200757872645e+0009L,
+	1.005115019784102856424493519524998953678e+0011L,
+	9.725664462014503832860151384604677240620e+0011L,
+	5.345525100485511116148634192844434636072e+0012L,
+	1.549944007398946691720862738173956994779e+0013L,
+	2.067148441178952625710302124163264760362e+0013L,
+	9.401565402641963611295119487242595462301e+0012L,
+	3.548217088622398274748837287769709374385e+0011L,
+	-2.934470341719047120076509938432417352365e+0010L,
 };
+
 static const GENERIC qr3[13] = {
-   3.749999999999412724084579833297451472091e-0001L,
-   9.058478580291706212422978492938435582527e+0001L,
-   8.524056033161038750461083666711724381171e+0003L,
-   4.105967158629109427753434569223631014730e+0005L,
-   1.118326603378531348259783091972623333657e+0007L,
-   1.794636683403578918528064904714132329343e+0008L,
-   1.714314157463635959556133236004368896724e+0009L,
-   9.622092032236084846572067257267661456030e+0009L,
-   3.057759524485859159957762858780768355020e+0010L,
-   5.129306780754798531609621454415938890020e+0010L,
-   3.999122002794961070680636194346316041352e+0010L,
-   1.122298454643493485989721564358100345388e+0010L,
-   5.603981987645989709668830968522362582221e+0008L,
+	3.749999999999412724084579833297451472091e-0001L,
+	9.058478580291706212422978492938435582527e+0001L,
+	8.524056033161038750461083666711724381171e+0003L,
+	4.105967158629109427753434569223631014730e+0005L,
+	1.118326603378531348259783091972623333657e+0007L,
+	1.794636683403578918528064904714132329343e+0008L,
+	1.714314157463635959556133236004368896724e+0009L,
+	9.622092032236084846572067257267661456030e+0009L,
+	3.057759524485859159957762858780768355020e+0010L,
+	5.129306780754798531609621454415938890020e+0010L,
+	3.999122002794961070680636194346316041352e+0010L,
+	1.122298454643493485989721564358100345388e+0010L,
+	5.603981987645989709668830968522362582221e+0008L,
 };
+
 static const GENERIC qs3[13] = {
-   1.0e0L,
-   2.418328663076578169836155170053634419922e+0002L,
-   2.279620205900121042587523541281272875520e+0004L,
-   1.100984222585729521470129014992217092794e+0006L,
-   3.010743223679247091004262516286654516282e+0007L,
-   4.860925542827367817289619265215599433996e+0008L,
-   4.686668111035348691982715864307839581243e+0009L,
-   2.668701788405102017427214705946730894074e+0010L,
-   8.677395746106802640390580944836650584903e+0010L,
-   1.511936455574951790658498795945106643036e+0011L,
-   1.260845604432623478002018696873608353093e+0011L,
-   4.052692278419853853911440231600864589805e+0010L,
-   2.965516519212226064983267822243329694729e+0009L,
+	1.0e0L,
+	2.418328663076578169836155170053634419922e+0002L,
+	2.279620205900121042587523541281272875520e+0004L,
+	1.100984222585729521470129014992217092794e+0006L,
+	3.010743223679247091004262516286654516282e+0007L,
+	4.860925542827367817289619265215599433996e+0008L,
+	4.686668111035348691982715864307839581243e+0009L,
+	2.668701788405102017427214705946730894074e+0010L,
+	8.677395746106802640390580944836650584903e+0010L,
+	1.511936455574951790658498795945106643036e+0011L,
+	1.260845604432623478002018696873608353093e+0011L,
+	4.052692278419853853911440231600864589805e+0010L,
+	2.965516519212226064983267822243329694729e+0009L,
 };
+
 static const GENERIC qr4[13] = {
-   3.749999999919234164154669754440123072618e-0001L,
-   5.844218580776819864791168253485055101858e+0001L,
-   3.489273514092912982675669411371435670220e+0003L,
-   1.050523637774575684509663430018995479594e+0005L,
-   1.764549172059701565500717319792780115289e+0006L,
-   1.725532438844133795028063102681497371154e+0007L,
-   9.938114847359778539965140247590176334874e+0007L,
-   3.331710808184595545396883770200772842314e+0008L,
-   6.271970557641881511609560444872797282698e+0008L,
-   6.188529798677357075020774923903737913285e+0008L,
-   2.821905302742849974509982167877885011629e+0008L,
-   4.615467358646911976773290256984329814896e+0007L,
-   1.348140608731546467396685802693380693275e+0006L,
+	3.749999999919234164154669754440123072618e-0001L,
+	5.844218580776819864791168253485055101858e+0001L,
+	3.489273514092912982675669411371435670220e+0003L,
+	1.050523637774575684509663430018995479594e+0005L,
+	1.764549172059701565500717319792780115289e+0006L,
+	1.725532438844133795028063102681497371154e+0007L,
+	9.938114847359778539965140247590176334874e+0007L,
+	3.331710808184595545396883770200772842314e+0008L,
+	6.271970557641881511609560444872797282698e+0008L,
+	6.188529798677357075020774923903737913285e+0008L,
+	2.821905302742849974509982167877885011629e+0008L,
+	4.615467358646911976773290256984329814896e+0007L,
+	1.348140608731546467396685802693380693275e+0006L,
 };
+
 static const GENERIC qs4[13] = {
-   1.0e0L,
-   1.561192663112345185261418296389902133372e+0002L,
-   9.346678031144098270547225423124213083072e+0003L,
-   2.825851246482293547838023847601704751590e+0005L,
-   4.776572711622156091710902891124911556293e+0006L,
-   4.715106953717135402977938048006267859302e+0007L,
-   2.753962350894311316439652227611209035193e+0008L,
-   9.428501434615463207768964787500411575223e+0008L,
-   1.832650858775206787088236896454141572617e+0009L,
-   1.901697378939743226948920874296595242257e+0009L,
-   9.433322226854293780627188599226380812725e+0008L,
-   1.808520540608671608680284520798858587370e+0008L,
-   7.983342331736662753157217446919462398008e+0006L,
+	1.0e0L,
+	1.561192663112345185261418296389902133372e+0002L,
+	9.346678031144098270547225423124213083072e+0003L,
+	2.825851246482293547838023847601704751590e+0005L,
+	4.776572711622156091710902891124911556293e+0006L,
+	4.715106953717135402977938048006267859302e+0007L,
+	2.753962350894311316439652227611209035193e+0008L,
+	9.428501434615463207768964787500411575223e+0008L,
+	1.832650858775206787088236896454141572617e+0009L,
+	1.901697378939743226948920874296595242257e+0009L,
+	9.433322226854293780627188599226380812725e+0008L,
+	1.808520540608671608680284520798858587370e+0008L,
+	7.983342331736662753157217446919462398008e+0006L,
 };
+
 static const GENERIC qr5[13] = {
-      3.749999995331364437028988850515190446719e-0001L,
-      3.739356381766559882677514593041627547911e+0001L,
-      1.399562500629413529355265462912819802551e+0003L,
-      2.594154053098947925345332218062210111753e+0004L,
-      2.640149879297408640394163979394594318371e+0005L,
-      1.542471854873199142031889093591449397995e+0006L,
-      5.242272868972053374067572098992335425895e+0006L,
-      1.025834487769410221329633071426044839935e+0007L,
-      1.116553924239448940142230579060124209622e+0007L,
-      6.318076065595910176374916303525884653514e+0006L,
-      1.641218086168640408527639735915512881785e+0006L,
-      1.522369793529178644168813882912134706444e+0005L,
-      2.526530541062297200914180060208669584055e+0003L,
+	3.749999995331364437028988850515190446719e-0001L,
+	3.739356381766559882677514593041627547911e+0001L,
+	1.399562500629413529355265462912819802551e+0003L,
+	2.594154053098947925345332218062210111753e+0004L,
+	2.640149879297408640394163979394594318371e+0005L,
+	1.542471854873199142031889093591449397995e+0006L,
+	5.242272868972053374067572098992335425895e+0006L,
+	1.025834487769410221329633071426044839935e+0007L,
+	1.116553924239448940142230579060124209622e+0007L,
+	6.318076065595910176374916303525884653514e+0006L,
+	1.641218086168640408527639735915512881785e+0006L,
+	1.522369793529178644168813882912134706444e+0005L,
+	2.526530541062297200914180060208669584055e+0003L,
 };
+
 static const GENERIC qs5[13] = {
-      1.0e0L,
-      9.998960735935075380397545659016287506660e+0001L,
-      3.758767417842043742686475060540416737562e+0003L,
-      7.013652806952306520121959742519780781653e+0004L,
-      7.208949808818615099246529616211730446850e+0005L,
-      4.272753927109614455417836186072202009252e+0006L,
-      1.482524411356470699336129814111025434703e+0007L,
-      2.988750366665678233425279237627700803473e+0007L,
-      3.396957890261080492694709150553619185065e+0007L,
-      2.050652487738593004111578091156304540386e+0007L,
-      5.900504120811732547616511555946279451316e+0006L,
-      6.563391409260160897024498082273183468347e+0005L,
-      1.692629845012790205348966731477187041419e+0004L,
+	1.0e0L,
+	9.998960735935075380397545659016287506660e+0001L,
+	3.758767417842043742686475060540416737562e+0003L,
+	7.013652806952306520121959742519780781653e+0004L,
+	7.208949808818615099246529616211730446850e+0005L,
+	4.272753927109614455417836186072202009252e+0006L,
+	1.482524411356470699336129814111025434703e+0007L,
+	2.988750366665678233425279237627700803473e+0007L,
+	3.396957890261080492694709150553619185065e+0007L,
+	2.050652487738593004111578091156304540386e+0007L,
+	5.900504120811732547616511555946279451316e+0006L,
+	6.563391409260160897024498082273183468347e+0005L,
+	1.692629845012790205348966731477187041419e+0004L,
 };
+
 static const GENERIC qr6[13] = {
-    3.749999861516664133157566870858975421296e-0001L,
-    2.367863756747764863120797431599473468918e+0001L,
-    5.476715802114976248882067325630793143777e+0002L,
-    6.143190357869842894025012945444096170251e+0003L,
-    3.716250534677997850513733595140463851730e+0004L,
-    1.270883463823876752138326905022875657430e+0005L,
-    2.495301449636814481646371665429083801388e+0005L,
-    2.789578988212952248340486296254398601942e+0005L,
-    1.718247946911109055931819087137397324634e+0005L,
-    5.458973214011665714330326732204106364229e+0004L,
-    7.912102686687948786048943339759596652813e+0003L,
-    4.077961006160866935722030715149087938091e+0002L,
-    3.765206972770245085551057237882528510428e+0000L,
+	3.749999861516664133157566870858975421296e-0001L,
+	2.367863756747764863120797431599473468918e+0001L,
+	5.476715802114976248882067325630793143777e+0002L,
+	6.143190357869842894025012945444096170251e+0003L,
+	3.716250534677997850513733595140463851730e+0004L,
+	1.270883463823876752138326905022875657430e+0005L,
+	2.495301449636814481646371665429083801388e+0005L,
+	2.789578988212952248340486296254398601942e+0005L,
+	1.718247946911109055931819087137397324634e+0005L,
+	5.458973214011665714330326732204106364229e+0004L,
+	7.912102686687948786048943339759596652813e+0003L,
+	4.077961006160866935722030715149087938091e+0002L,
+	3.765206972770245085551057237882528510428e+0000L,
 };
+
 static const GENERIC qs6[13] = {
-    1.0e0L,
-    6.341646532940517305641893852673926809601e+0001L,
-    1.477058277414040790932597537920671025359e+0003L,
-    1.674406564031044491436044253393536487604e+0004L,
-    1.028516501369755949895050806908994650768e+0005L,
-    3.593620042532885295087463507733285434207e+0005L,
-    7.267924991381020915185873399453724799625e+0005L,
-    8.462277510768818399961191426205006083088e+0005L,
-    5.514399892230892163373611895645500250514e+0005L,
-    1.898084241009259353540620272932188102299e+0005L,
-    3.102941242117739015721984123081026253068e+0004L,
-    1.958971184431466907681440650181421086143e+0003L,
-    2.878853357310495087181721613889455121867e+0001L,
+	1.0e0L, 6.341646532940517305641893852673926809601e+0001L,
+	1.477058277414040790932597537920671025359e+0003L,
+	1.674406564031044491436044253393536487604e+0004L,
+	1.028516501369755949895050806908994650768e+0005L,
+	3.593620042532885295087463507733285434207e+0005L,
+	7.267924991381020915185873399453724799625e+0005L,
+	8.462277510768818399961191426205006083088e+0005L,
+	5.514399892230892163373611895645500250514e+0005L,
+	1.898084241009259353540620272932188102299e+0005L,
+	3.102941242117739015721984123081026253068e+0004L,
+	1.958971184431466907681440650181421086143e+0003L,
+	2.878853357310495087181721613889455121867e+0001L,
 };
-static GENERIC qone(x)
-GENERIC x;
+
+static GENERIC
+qone(GENERIC x)
 {
-	GENERIC s,r,t,z;
+	GENERIC s, r, t, z;
 	int i;
-	if (x>huge) return 0.375L/x;
-	t = one/x; z = t*t;
-	if (x>sixteen) {
-	    r = z*qr0[11]+qr0[10]; s = qs0[10];
-	    for (i=9;i>=0;i--) {
-		r = z*r + qr0[i];
-		s = z*s + qs0[i];
-	    }
-	} else if (x>eight) {
-	    r = qr1[11]; s = qs1[11]+z*(qs1[12]+z*qs1[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + qr1[i];
-		s = z*s + qs1[i];
-	    }
-	} else if (x>five) {	/* x > 5.0 */
-	    r = qr2[11]; s = qs2[11]+z*(qs2[12]+z*qs2[13]);
-	    for (i=10;i>=0;i--) {
-		r = z*r + qr2[i];
-		s = z*s + qs2[i];
-	    }
-        } else if (x>3.5L) {
-            r = qr3[12]; s = qs3[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + qr3[i];
-                s = z*s + qs3[i];
-            }
-        } else if (x>2.5L) {
-            r = qr4[12]; s = qs4[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + qr4[i];
-                s = z*s + qs4[i];
-            }
-        } else if (x> (1.0L/0.5625L)) {
-            r = qr5[12]; s = qs5[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + qr5[i];
-                s = z*s + qs5[i];
-            }
-        } else {        /* assume x > 1.28 */
-            r = qr6[12]; s = qs6[12];
-            for (i=11;i>=0;i--) {
-                r = z*r + qr6[i];
-                s = z*s + qs6[i];
-            }
-        }
-	return t*(r/s);
+
+	if (x > huge)
+		return (0.375L / x);
+
+	t = one / x;
+	z = t * t;
+
+	if (x > sixteen) {
+		r = z * qr0[11] + qr0[10];
+		s = qs0[10];
+
+		for (i = 9; i >= 0; i--) {
+			r = z * r + qr0[i];
+			s = z * s + qs0[i];
+		}
+	} else if (x > eight) {
+		r = qr1[11];
+		s = qs1[11] + z * (qs1[12] + z * qs1[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr1[i];
+			s = z * s + qs1[i];
+		}
+	} else if (x > five) {		/* x > 5.0 */
+		r = qr2[11];
+		s = qs2[11] + z * (qs2[12] + z * qs2[13]);
+
+		for (i = 10; i >= 0; i--) {
+			r = z * r + qr2[i];
+			s = z * s + qs2[i];
+		}
+	} else if (x > 3.5L) {
+		r = qr3[12];
+		s = qs3[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr3[i];
+			s = z * s + qs3[i];
+		}
+	} else if (x > 2.5L) {
+		r = qr4[12];
+		s = qs4[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr4[i];
+			s = z * s + qs4[i];
+		}
+	} else if (x > (1.0L / 0.5625L)) {
+		r = qr5[12];
+		s = qs5[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr5[i];
+			s = z * s + qs5[i];
+		}
+	} else {			/* assume x > 1.28 */
+		r = qr6[12];
+		s = qs6[12];
+
+		for (i = 11; i >= 0; i--) {
+			r = z * r + qr6[i];
+			s = z * s + qs6[i];
+		}
+	}
+
+	return (t * (r / s));
 }
--- old/usr/src/lib/libm/common/Q/jnl.c	2019-06-06 20:38:48.150869971 +0000
+++ new/usr/src/lib/libm/common/Q/jnl.c	2019-06-06 20:38:48.169995298 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -57,15 +58,15 @@
 
 #include "libm.h"
 #include "longdouble.h"
-#include <float.h>	/* LDBL_MAX */
+#include <float.h>			/* LDBL_MAX */
 
-#define	GENERIC long double
+#define	GENERIC	long double
 
 static const GENERIC
-invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
-two  = 2.0L,
-zero = 0.0L,
-one  = 1.0L;
+	invsqrtpi = 5.641895835477562869480794515607725858441e-0001L,
+	two = 2.0L,
+	zero = 0.0L,
+	one = 1.0L;
 
 GENERIC
 jnl(int n, GENERIC x)
@@ -81,70 +82,81 @@
 		n = -n;
 		x = -x;
 	}
+
 	if (n == 0)
 		return (j0l(x));
+
 	if (n == 1)
 		return (j1l(x));
+
 	if (x != x)
-		return (x+x);
-	if ((n&1) == 0)
-		sgn = 0;			/* even n */
+		return (x + x);
+
+	if ((n & 1) == 0)
+		sgn = 0;		/* even n */
 	else
 		sgn = signbitl(x);	/* old n  */
+
 	x = fabsl(x);
-	if (x == zero || !finitel(x)) b = zero;
-	else if ((GENERIC)n <= x) {
-					/*
-					 * Safe to use
-					 * J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
-					 */
+
+	if (x == zero || !finitel(x)) {
+		b = zero;
+	} else if ((GENERIC)n <= x) {
+		/*
+		 * Safe to use
+		 * J(n+1,x)=2n/x *J(n,x)-J(n-1,x)
+		 */
 		if (x > 1.0e91L) {
-				/*
-				 * x >> n**2
-				 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *   Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
-				 *   Let s=sin(x), c=cos(x),
-				 *	xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
-				 *
-				 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
-				 *	----------------------------------
-				 *	   0	 s-c		 c+s
-				 *	   1	-s-c		-c+s
-				 *	   2	-s+c		-c-s
-				 *	   3	 s+c		 c-s
-				 */
-			switch (n&3) {
+			/*
+			 * x >> n**2
+			 *  Jn(x) = cos(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+			 *   Yn(x) = sin(x-(2n+1)*pi/4)*sqrt(2/x*pi)
+			 *   Let s=sin(x), c=cos(x),
+			 *	xn=x-(2n+1)*pi/4, sqt2 = sqrt(2),then
+			 *
+			 *	   n	sin(xn)*sqt2	cos(xn)*sqt2
+			 *	----------------------------------
+			 *	   0	 s-c		 c+s
+			 *	   1	-s-c		-c+s
+			 *	   2	-s+c		-c-s
+			 *	   3	 s+c		 c-s
+			 */
+			switch (n & 3) {
 			case 0:
-				temp =  cosl(x)+sinl(x);
+				temp = cosl(x) + sinl(x);
 				break;
 			case 1:
-				temp = -cosl(x)+sinl(x);
+				temp = -cosl(x) + sinl(x);
 				break;
 			case 2:
-				temp = -cosl(x)-sinl(x);
+				temp = -cosl(x) - sinl(x);
 				break;
 			case 3:
-				temp =  cosl(x)-sinl(x);
+				temp = cosl(x) - sinl(x);
 				break;
 			}
-			b = invsqrtpi*temp/sqrtl(x);
+
+			b = invsqrtpi * temp / sqrtl(x);
 		} else {
 			a = j0l(x);
 			b = j1l(x);
+
 			for (i = 1; i < n; i++) {
 				temp = b;
 				/* avoid underflow */
-				b = b*((GENERIC)(i+i)/x) - a;
+				b = b * ((GENERIC)(i + i) / x) - a;
 				a = temp;
 			}
 		}
 	} else {
 		if (x < 1e-17L) {	/* use J(n,x) = 1/n!*(x/2)^n */
-			b = powl(0.5L*x, (GENERIC)n);
+			b = powl(0.5L * x, (GENERIC)n);
+
 			if (b != zero) {
 				for (a = one, i = 1; i <= n; i++)
 					a *= (GENERIC)i;
-				b = b/a;
+
+				b = b / a;
 			}
 		} else {
 			/* use backward recurrence */
@@ -182,24 +194,30 @@
 			GENERIC t, v;
 			double q0, q1, h, tmp;
 			int k, m;
-			w  = (n+n)/(double)x;
-			h = 2.0/(double)x;
+
+			w = (n + n) / (double)x;
+			h = 2.0 / (double)x;
 			q0 = w;
-			z = w+h;
-			q1 = w*z - 1.0;
+			z = w + h;
+			q1 = w * z - 1.0;
 			k = 1;
+
 			while (q1 < 1.0e17) {
 				k += 1;
 				z += h;
-				tmp = z*q1 - q0;
+				tmp = z * q1 - q0;
 				q0 = q1;
 				q1 = tmp;
 			}
-			m = n+n;
-			for (t = zero, i = 2*(n+k); i >= m; i -= 2)
-				t = one/(i/x-t);
+
+			m = n + n;
+
+			for (t = zero, i = 2 * (n + k); i >= m; i -= 2)
+				t = one / (i / x - t);
+
 			a = t;
 			b = one;
+
 			/*
 			 * estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
 			 * hence, if n*(log(2n/x)) > ...
@@ -213,29 +231,33 @@
 			 *  likely underflow to zero
 			 */
 			tmp = n;
-			v = two/x;
-			tmp = tmp*logl(fabsl(v*tmp));
+			v = two / x;
+			tmp = tmp * logl(fabsl(v * tmp));
+
 			if (tmp < 1.1356523406294143949491931077970765e+04L) {
-				for (i = n-1; i > 0; i--) {
+				for (i = n - 1; i > 0; i--) {
 					temp = b;
-					b = ((i+i)/x)*b - a;
+					b = ((i + i) / x) * b - a;
 					a = temp;
 				}
 			} else {
-				for (i = n-1; i > 0; i--) {
+				for (i = n - 1; i > 0; i--) {
 					temp = b;
-					b = ((i+i)/x)*b - a;
+					b = ((i + i) / x) * b - a;
 					a = temp;
+
 					if (b > 1e1000L) {
 						a /= b;
 						t /= b;
-						b  = 1.0;
+						b = 1.0;
 					}
 				}
 			}
-			b = (t*j0l(x)/b);
+
+			b = (t * j0l(x) / b);
 		}
 	}
+
 	if (sgn != 0)
 		return (-b);
 	else
@@ -250,22 +272,30 @@
 	GENERIC a, b, temp;
 
 	if (x != x)
-		return (x+x);
+		return (x + x);
+
 	if (x <= zero) {
 		if (x == zero)
-			return (-one/zero);
+			return (-one / zero);
 		else
-			return (zero/zero);
+			return (zero / zero);
 	}
+
 	sign = 1;
+
 	if (n < 0) {
 		n = -n;
-		if ((n&1) == 1) sign = -1;
+
+		if ((n & 1) == 1)
+			sign = -1;
 	}
+
 	if (n == 0)
 		return (y0l(x));
+
 	if (n == 1)
-		return (sign*y1l(x));
+		return (sign * y1l(x));
+
 	if (!finitel(x))
 		return (zero);
 
@@ -284,36 +314,41 @@
 		 *	   2	-s+c		-c-s
 		 *	   3	 s+c		 c-s
 		 */
-		switch (n&3) {
+		switch (n & 3) {
 		case 0:
-			temp =  sinl(x)-cosl(x);
+			temp = sinl(x) - cosl(x);
 			break;
 		case 1:
-			temp = -sinl(x)-cosl(x);
+			temp = -sinl(x) - cosl(x);
 			break;
 		case 2:
-			temp = -sinl(x)+cosl(x);
+			temp = -sinl(x) + cosl(x);
 			break;
 		case 3:
-			temp =  sinl(x)+cosl(x);
+			temp = sinl(x) + cosl(x);
 			break;
 		}
-		b = invsqrtpi*temp/sqrtl(x);
+
+		b = invsqrtpi * temp / sqrtl(x);
 	} else {
 		a = y0l(x);
 		b = y1l(x);
+
 		/*
 		 * fix 1262058 and take care of non-default rounding
 		 */
 		for (i = 1; i < n; i++) {
 			temp = b;
-			b *= (GENERIC) (i + i) / x;
+			b *= (GENERIC)(i + i) / x;
+
 			if (b <= -LDBL_MAX)
 				break;
+
 			b -= a;
 			a = temp;
 		}
 	}
+
 	if (sign > 0)
 		return (b);
 	else
--- old/usr/src/lib/libm/common/Q/lgammal.c	2019-06-06 20:38:48.684109136 +0000
+++ new/usr/src/lib/libm/common/Q/lgammal.c	2019-06-06 20:38:48.703094452 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,9 +39,9 @@
 
 extern int signgam;
 extern int signgaml;
-
 long double
-lgammal(long double x) {
+lgammal(long double x)
+{
 	long double y = __k_lgammal(x, &signgaml);
 
 	signgam = signgaml;	/* SUSv3 requires the setting of signgam */
--- old/usr/src/lib/libm/common/Q/lgammal_r.c	2019-06-06 20:38:49.206780538 +0000
+++ new/usr/src/lib/libm/common/Q/lgammal_r.c	2019-06-06 20:38:49.227195432 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,6 +38,7 @@
 #include "longdouble.h"
 
 long double
-lgammal_r(long double x, int *signgamlp) {
+lgammal_r(long double x, int *signgamlp)
+{
 	return (__k_lgammal(x, signgamlp));
 }
--- old/usr/src/lib/libm/common/Q/log10l.c	2019-06-06 20:38:49.750988398 +0000
+++ new/usr/src/lib/libm/common/Q/log10l.c	2019-06-06 20:38:49.771189101 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -65,12 +66,11 @@
 #if defined(__x86)
 #define	__swapRD	__swap87RD
 #endif
-extern enum fp_direction_type __swapRD(enum fp_direction_type);
 
-static const long double
-	zero	  = 0.0L,
-	ivln10    = 4.342944819032518276511289189166050822944e-0001L,
-	one	  = 1.0L,
+extern enum fp_direction_type __swapRD(enum fp_direction_type);
+static const long double zero = 0.0L,
+	ivln10 = 4.342944819032518276511289189166050822944e-0001L,
+	one = 1.0L,
 #if defined(__x86)
 	log10_2hi = 3.010299956639803653501985536422580480576e-01L,
 	log10_2lo = 8.298635403410822349787106337291183585413e-16L;
@@ -82,27 +82,33 @@
 #endif
 
 long double
-log10l(long double x) {
+log10l(long double x)
+{
 	long double y, z;
 	enum fp_direction_type rd;
 	int n;
 
-	if (!finitel(x))
+	if (!finitel(x)) {
 		return (x + fabsl(x));	/* x is +-INF or NaN */
-	else if (x > zero) {
+	} else if (x > zero) {
 		n = ilogbl(x);
+
 		if (n < 0)
 			n += 1;
+
 		rd = __swapRD(fp_nearest);
 		y = n;
 		x = scalbnl(x, -n);
 		z = y * log10_2lo + ivln10 * logl(x);
 		z += y * log10_2hi;
+
 		if (rd != fp_nearest)
 			(void) __swapRD(rd);
+
 		return (z);
-	} else if (x == zero)	/* -INF */
+	} else if (x == zero) {		/* -INF */
 		return (-one / zero);
-	else			/* x <0, return NaN */
+	} else {			/* x <0, return NaN */
 		return (zero / zero);
+	}
 }
--- old/usr/src/lib/libm/common/Q/log1pl.c	2019-06-06 20:38:50.255711228 +0000
+++ new/usr/src/lib/libm/common/Q/log1pl.c	2019-06-06 20:38:50.273069374 +0000
@@ -22,21 +22,22 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
 #ifdef __LITTLE_ENDIAN
-#define	H0(x)	*(3 + (int *) &x)
-#define	H1(x)	*(2 + (int *) &x)
-#define	H2(x)	*(1 + (int *) &x)
-#define	H3(x)	*(int *) &x
+#define	H0(x)		*(3 + (int *)&x)
+#define	H1(x)		*(2 + (int *)&x)
+#define	H2(x)		*(1 + (int *)&x)
+#define	H3(x)		*(int *)&x
 #else
-#define	H0(x)	*(int *) &x
-#define	H1(x)	*(1 + (int *) &x)
-#define	H2(x)	*(2 + (int *) &x)
-#define	H3(x)	*(3 + (int *) &x)
+#define	H0(x)		*(int *)&x
+#define	H1(x)		*(1 + (int *)&x)
+#define	H2(x)		*(2 + (int *)&x)
+#define	H3(x)		*(3 + (int *)&x)
 #endif
 
 /*
@@ -51,7 +52,7 @@
  *	(i.e., x is in [-2/33,2/31])
  *
  * (b). Otherwise, normalize 1+x = 2^n * 1.f.
- * 	Here we may need a correction term for 1+x rounded.
+ *      Here we may need a correction term for 1+x rounded.
  *	Use a 6-bit table look-up: find a 6 bit g that match f to 6.5 bits,
  *	then
  *	    log(1+x) = n*ln2 + log(1.g) + log(1.f/1.g).
@@ -74,14 +75,14 @@
  *	in 1+x.  Therefore, to recover the lost bits, one need to compute
  *	1.f-1.g accurately.
  *
- * 	Let hx = HI(x), m = (hx>>16)-0x3fff (=ilogbl(x)), note that
+ *      Let hx = HI(x), m = (hx>>16)-0x3fff (=ilogbl(x)), note that
  *		-2/33 = -0.0606...= 2^-5 * 1.939...,
  *		 2/31 =  0.09375  = 2^-4 * 1.500...,
  *	so for x in (-0.5,-2/33], -5<=m<=-2,  n= -1, 1+f=2*(1+x)
  *	   for x in [2/33,1),     -4<=m<=-1,  n=  0, f=x
  *
  *      In short:
- * 	if x>0, let g: hg= ((hx + (0x200<<(-m)))>>(10-m))<<(10-m)
+ *      if x>0, let g: hg= ((hx + (0x200<<(-m)))>>(10-m))<<(10-m)
  *	then 1.f-1.g = x-g
  *	if x<0, let g': hg' =((ix-(0x200)<<(-m-1))>>(9-m))<<(9-m)
  *	(ix=hx&0x7fffffff)
@@ -114,84 +115,91 @@
 #include "libm.h"
 
 extern const long double _TBL_logl_hi[], _TBL_logl_lo[];
-
-static const long double
-zero	=   0.0L,
-one	=   1.0L,
-two	=   2.0L,
-ln2hi	=   6.931471805599453094172319547495844850203e-0001L,
-ln2lo	=   1.667085920830552208890449330400379754169e-0025L,
-A1	=   2.000000000000000000000000000000000000024e+0000L,
-A2	=   6.666666666666666666666666666666091393804e-0001L,
-A3	=   4.000000000000000000000000407167070220671e-0001L,
-A4	=   2.857142857142857142730077490612903681164e-0001L,
-A5	=   2.222222222222242577702836920812882605099e-0001L,
-A6	=   1.818181816435493395985912667105885828356e-0001L,
-A7	=   1.538537835211839751112067512805496931725e-0001L,
-B1	=   6.666666666666666666666666666666961498329e-0001L,
-B2	=   3.999999999999999999999999990037655042358e-0001L,
-B3	=   2.857142857142857142857273426428347457918e-0001L,
-B4	=   2.222222222222222221353229049747910109566e-0001L,
-B5	=   1.818181818181821503532559306309070138046e-0001L,
-B6	=   1.538461538453809210486356084587356788556e-0001L,
-B7	=   1.333333344463358756121456892645178795480e-0001L,
-B8	=   1.176460904783899064854645174603360383792e-0001L,
-B9	=   1.057293869956598995326368602518056990746e-0001L;
+static const long double zero = 0.0L,
+	one = 1.0L,
+	two = 2.0L,
+	ln2hi = 6.931471805599453094172319547495844850203e-0001L,
+	ln2lo = 1.667085920830552208890449330400379754169e-0025L,
+	A1 = 2.000000000000000000000000000000000000024e+0000L,
+	A2 = 6.666666666666666666666666666666091393804e-0001L,
+	A3 = 4.000000000000000000000000407167070220671e-0001L,
+	A4 = 2.857142857142857142730077490612903681164e-0001L,
+	A5 = 2.222222222222242577702836920812882605099e-0001L,
+	A6 = 1.818181816435493395985912667105885828356e-0001L,
+	A7 = 1.538537835211839751112067512805496931725e-0001L,
+	B1 = 6.666666666666666666666666666666961498329e-0001L,
+	B2 = 3.999999999999999999999999990037655042358e-0001L,
+	B3 = 2.857142857142857142857273426428347457918e-0001L,
+	B4 = 2.222222222222222221353229049747910109566e-0001L,
+	B5 = 1.818181818181821503532559306309070138046e-0001L,
+	B6 = 1.538461538453809210486356084587356788556e-0001L,
+	B7 = 1.333333344463358756121456892645178795480e-0001L,
+	B8 = 1.176460904783899064854645174603360383792e-0001L,
+	B9 = 1.057293869956598995326368602518056990746e-0001L;
 
 long double
-log1pl(long double x) {
+log1pl(long double x)
+{
 	long double f, s, z, qn, h, t, y, g;
 	int i, j, ix, iy, n, hx, m;
 
 	hx = H0(x);
 	ix = hx & 0x7fffffff;
-	if (ix < 0x3ffaf07c) {	/* |x|<2/33 */
+
+	if (ix < 0x3ffaf07c) {		/* |x|<2/33 */
 		if (ix <= 0x3f8d0000) {	/* x <= 2**-114, return x */
-			if ((int) x == 0)
+			if ((int)x == 0)
 				return (x);
 		}
+
 		s = x / (two + x);	/* |s|<2**-8 */
 		z = s * s;
-		return (x - s * (x - z * (B1 + z * (B2 + z * (B3 + z * (B4 +
-		    z * (B5 + z * (B6 + z * (B7 + z * (B8 + z * B9))))))))));
+		return (x - s * (x - z * (B1 + z * (B2 + z * (B3 + z * (B4 + z *
+		    (B5 + z * (B6 + z * (B7 + z * (B8 + z * B9))))))))));
 	}
-	if (ix >= 0x7fff0000) {	/* x is +inf or NaN */
+
+	if (ix >= 0x7fff0000)		/* x is +inf or NaN */
 		return (x + fabsl(x));
-	}
+
 	if (hx < 0 && ix >= 0x3fff0000) {
 		if (ix > 0x3fff0000 || (H1(x) | H2(x) | H3(x)) != 0)
 			x = zero;
+
 		return (x / zero);	/* log1p(x) is NaN  if x<-1 */
 		/* log1p(-1) is -inf */
 	}
+
 	if (ix >= 0x7ffeffff)
-		y = x;		/* avoid spurious overflow */
+		y = x;			/* avoid spurious overflow */
 	else
 		y = one + x;
+
 	iy = H0(y);
 	n = ((iy + 0x200) >> 16) - 0x3fff;
 	iy = (iy & 0x0000ffff) | 0x3fff0000;	/* scale 1+x to [1,2] */
 	H0(y) = iy;
 	z = zero;
 	m = (ix >> 16) - 0x3fff;
+
 	/* HI(1+x) = (((hx&0xffff)|0x10000)>>(-m))|0x3fff0000 */
-	if (n == 0) {		/* x in [2/33,1) */
+	if (n == 0) {			/* x in [2/33,1) */
 		g = zero;
 		H0(g) = ((hx + (0x200 << (-m))) >> (10 - m)) << (10 - m);
 		t = x - g;
 		i = (((((hx & 0xffff) | 0x10000) >> (-m)) | 0x3fff0000) +
-			0x200) >> 10;
+		    0x200) >> 10;
 		H0(z) = i << 10;
-
 	} else if ((1 + n) == 0 && (ix < 0x3ffe0000)) {	/* x in (-0.5,-2/33] */
 		g = zero;
 		H0(g) = ((ix + (0x200 << (-m - 1))) >> (9 - m)) << (9 - m);
 		t = g + x;
 		t = t + t;
+
 		/*
 		 * HI(2*(1+x)) =
 		 * ((0x10000-(((hx&0xffff)|0x10000)>>(-m)))<<1)|0x3fff0000
 		 */
+
 		/*
 		 * i =
 		 * ((((0x10000-(((hx&0xffff)|0x10000)>>(-m)))<<1)|0x3fff0000)+
@@ -208,10 +216,10 @@
 	s = t / (y + z);
 	j = i & 0x3f;
 	z = s * s;
-	qn = (long double) n;
+	qn = (long double)n;
 	t = qn * ln2lo + _TBL_logl_lo[j];
 	h = qn * ln2hi + _TBL_logl_hi[j];
-	f = t + s * (A1 + z * (A2 + z * (A3 + z * (A4 + z * (A5 + z * (A6 +
-		z * A7))))));
+	f = t + s * (A1 + z * (A2 + z * (A3 + z * (A4 + z * (A5 + z * (A6 + z *
+	    A7))))));
 	return (h + f);
 }
--- old/usr/src/lib/libm/common/Q/log2l.c	2019-06-06 20:38:50.758296017 +0000
+++ new/usr/src/lib/libm/common/Q/log2l.c	2019-06-06 20:38:50.775791068 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,23 +45,28 @@
 #include "libm.h"
 #include "longdouble.h"
 
-static const long double
-	zero 	= 0.0L,
-	half	= 0.5L,
-	one	= 1.0L,
-	invln2	= 1.442695040888963407359924681001892137427e+0000L;
+static const long double zero = 0.0L,
+	half = 0.5L,
+	one = 1.0L,
+	invln2 = 1.442695040888963407359924681001892137427e+0000L;
 
 long double
-log2l(long double x) {
+log2l(long double x)
+{
 	int n;
 
 	if (x == zero || !finitel(x))
 		return (logl(x));
+
 	n = ilogbl(x);
+
 	if (n < 0)
 		n += 1;
+
 	x = scalbnl(x, -n);
+
 	if (x == half)
 		return (n - one);
+
 	return (n + invln2 * logl(x));
 }
--- old/usr/src/lib/libm/common/Q/logbl.c	2019-06-06 20:38:51.256992010 +0000
+++ new/usr/src/lib/libm/common/Q/logbl.c	2019-06-06 20:38:51.274713520 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,23 +31,27 @@
 #pragma weak __logbl = logbl
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
-#define	_C99SUSv3_logb	_C99SUSv3_logb_subnormal_is_like_ilogb
+#include "xpg6.h"			/* __xpg6 */
+#define	_C99SUSv3_logb		_C99SUSv3_logb_subnormal_is_like_ilogb
 
 #if defined(__sparc)
-#define	ISNORMALL(k, x)	(k != 0x7fff)			/* assuming k != 0 */
+#define	ISNORMALL(k, x)		(k != 0x7fff)	/* assuming k != 0 */
 #define	X86PDNRM(k, x)
-#define	XSCALE_OFFSET	0x406f				/* 0x3fff + 112 */
+#define	XSCALE_OFFSET		0x406f		/* 0x3fff + 112 */
+
 static const long double xscale = 5192296858534827628530496329220096.0L;
-								/* 2^112 */
+
+/* 2^112 */
 #elif defined(__x86)
 /*
  * if pseudo-denormal, replace by the equivalent normal
  */
-#define	X86PDNRM(k, x)	if (k == 0 && (((int *) &x)[1] & 0x80000000) != 0) \
-				((int *) &x)[2] |= k = 1
-#if defined(HANDLE_UNSUPPORTED)				/* assuming k != 0 */
-#define	ISNORMALL(k, x)	(k != 0x7fff && (((int *) &x)[1] & 0x80000000) != 0)
+#define	X86PDNRM(k, x)	\
+	if (k == 0 && (((int *)&x)[1] & 0x80000000) !=	0) \
+		((int *)&x)[2] |= k = 1
+#if defined(HANDLE_UNSUPPORTED)		/* assuming k != 0 */
+#define	ISNORMALL(k, x)	(k != 0x7fff && (((int *)&x)[1] & 0x80000000) != \
+	0)
 #else
 #define	ISNORMALL(k, x)	(k != 0x7fff)
 #endif
@@ -55,27 +60,34 @@
 #endif
 
 static long double
-raise_division(long double v) {
+raise_division(long double v)
+{
 #pragma STDC FENV_ACCESS ON
+
 	static const long double zero = 0.0L;
+
 	return (v / zero);
 }
 
 long double
-logbl(long double x) {
+logbl(long double x)
+{
 	int k = XBIASED_EXP(x);
 
 	X86PDNRM(k, x);
+
 	if (k == 0) {
-		if (ISZEROL(x))
+		if (ISZEROL(x)) {
 			return (raise_division(-1.0L));
-		else if ((__xpg6 & _C99SUSv3_logb) != 0) {
-			x *= xscale;		/* scale up by 2^112 or 2^63 */
-			return (long double) (XBIASED_EXP(x) - XSCALE_OFFSET);
-		} else
+		} else if ((__xpg6 & _C99SUSv3_logb) != 0) {
+			x *= xscale;	/* scale up by 2^112 or 2^63 */
+			return ((long double)(XBIASED_EXP(x) - XSCALE_OFFSET));
+		} else {
 			return (-16382.L);
-	} else if (ISNORMALL(k, x))
-		return ((long double) (k - 0x3fff));
-	else
+		}
+	} else if (ISNORMALL(k, x)) {
+		return ((long double)(k - 0x3fff));
+	} else {
 		return (x * x);
+	}
 }
--- old/usr/src/lib/libm/common/Q/logl.c	2019-06-06 20:38:51.764200061 +0000
+++ new/usr/src/lib/libm/common/Q/logl.c	2019-06-06 20:38:51.783660865 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -78,40 +79,39 @@
 #include "libm.h"
 
 extern const long double _TBL_logl_hi[], _TBL_logl_lo[];
-
-static const long double
-	zero	=   0.0L,
-	one	=   1.0L,
-	two	=   2.0L,
-	two113  =   10384593717069655257060992658440192.0L,
-	ln2hi	=   6.931471805599453094172319547495844850203e-0001L,
-	ln2lo	=   1.667085920830552208890449330400379754169e-0025L,
-	A1	=   2.000000000000000000000000000000000000024e+0000L,
-	A2	=   6.666666666666666666666666666666091393804e-0001L,
-	A3	=   4.000000000000000000000000407167070220671e-0001L,
-	A4	=   2.857142857142857142730077490612903681164e-0001L,
-	A5	=   2.222222222222242577702836920812882605099e-0001L,
-	A6	=   1.818181816435493395985912667105885828356e-0001L,
-	A7	=   1.538537835211839751112067512805496931725e-0001L,
-	B1	=   6.666666666666666666666666666666961498329e-0001L,
-	B2	=   3.999999999999999999999999990037655042358e-0001L,
-	B3	=   2.857142857142857142857273426428347457918e-0001L,
-	B4	=   2.222222222222222221353229049747910109566e-0001L,
-	B5	=   1.818181818181821503532559306309070138046e-0001L,
-	B6	=   1.538461538453809210486356084587356788556e-0001L,
-	B7	=   1.333333344463358756121456892645178795480e-0001L,
-	B8	=   1.176460904783899064854645174603360383792e-0001L,
-	B9	=   1.057293869956598995326368602518056990746e-0001L;
+static const long double zero = 0.0L,
+	one = 1.0L,
+	two = 2.0L,
+	two113 = 10384593717069655257060992658440192.0L,
+	ln2hi = 6.931471805599453094172319547495844850203e-0001L,
+	ln2lo = 1.667085920830552208890449330400379754169e-0025L,
+	A1 = 2.000000000000000000000000000000000000024e+0000L,
+	A2 = 6.666666666666666666666666666666091393804e-0001L,
+	A3 = 4.000000000000000000000000407167070220671e-0001L,
+	A4 = 2.857142857142857142730077490612903681164e-0001L,
+	A5 = 2.222222222222242577702836920812882605099e-0001L,
+	A6 = 1.818181816435493395985912667105885828356e-0001L,
+	A7 = 1.538537835211839751112067512805496931725e-0001L,
+	B1 = 6.666666666666666666666666666666961498329e-0001L,
+	B2 = 3.999999999999999999999999990037655042358e-0001L,
+	B3 = 2.857142857142857142857273426428347457918e-0001L,
+	B4 = 2.222222222222222221353229049747910109566e-0001L,
+	B5 = 1.818181818181821503532559306309070138046e-0001L,
+	B6 = 1.538461538453809210486356084587356788556e-0001L,
+	B7 = 1.333333344463358756121456892645178795480e-0001L,
+	B8 = 1.176460904783899064854645174603360383792e-0001L,
+	B9 = 1.057293869956598995326368602518056990746e-0001L;
 
 long double
-logl(long double x) {
+logl(long double x)
+{
 	long double f, s, z, qn, h, t;
-	int *px = (int *) &x;
-	int *pz = (int *) &z;
+	int *px = (int *)&x;
+	int *pz = (int *)&z;
 	int i, j, ix, i0, i1, n;
 
 	/* get long double precision word ordering */
-	if (*(int *) &one == 0) {
+	if (*(int *)&one == 0) {
 		i0 = 3;
 		i1 = 0;
 	} else {
@@ -121,35 +121,45 @@
 
 	n = 0;
 	ix = px[i0];
-	if (ix > 0x3ffee0f8) {	/* if x >  31/33 */
+
+	if (ix > 0x3ffee0f8) {		/* if x >  31/33 */
 		if (ix < 0x3fff1084) {	/* if x < 33/31 */
 			f = x - one;
 			z = f * f;
-			if (((ix - 0x3fff0000) | px[i1] | px[2] | px[1]) == 0) {
+
+			if (((ix - 0x3fff0000) | px[i1] | px[2] | px[1]) == 0)
 				return (zero);	/* log(1)= +0 */
-			}
+
 			s = f / (two + f);	/* |s|<2**-8 */
 			z = s * s;
-			return (f - s * (f - z * (B1 + z * (B2 + z * (B3 +
-				z * (B4 + z * (B5 + z * (B6 + z * (B7 +
-				z * (B8 + z * B9))))))))));
+			return (f - s * (f - z * (B1 + z * (B2 + z * (B3 + z *
+			    (B4 + z * (B5 + z * (B6 + z * (B7 + z * (B8 + z *
+			    B9))))))))));
 		}
+
 		if (ix >= 0x7fff0000)
-			return (x + x);	/* x is +inf or NaN */
+			return (x + x);		/* x is +inf or NaN */
+
 		goto LARGE_N;
 	}
+
 	if (ix >= 0x00010000)
 		goto LARGE_N;
+
 	i = ix & 0x7fffffff;
+
 	if ((i | px[i1] | px[2] | px[1]) == 0) {
 		px[i0] |= 0x80000000;
 		return (one / x);	/* log(0.0) = -inf */
 	}
+
 	if (ix < 0) {
-		if ((unsigned) ix >= 0xffff0000)
-			return (x - x);	/* x is -inf or NaN */
-		return (zero / zero);	/* log(x<0) is NaN  */
+		if ((unsigned)ix >= 0xffff0000)
+			return (x - x);		/* x is -inf or NaN */
+
+		return (zero / zero);		/* log(x<0) is NaN  */
 	}
+
 	/* subnormal x */
 	x *= two113;
 	n = -113;
@@ -164,10 +174,10 @@
 	s = (x - z) / (x + z);
 	j = (i >> 10) & 0x3f;
 	z = s * s;
-	qn = (long double) n;
+	qn = (long double)n;
 	t = qn * ln2lo + _TBL_logl_lo[j];
 	h = qn * ln2hi + _TBL_logl_hi[j];
-	f = t + s * (A1 + z * (A2 + z * (A3 + z * (A4 + z * (A5 +
-		z * (A6 + z * A7))))));
+	f = t + s * (A1 + z * (A2 + z * (A3 + z * (A4 + z * (A5 + z * (A6 + z *
+	    A7))))));
 	return (h + f);
 }
--- old/usr/src/lib/libm/common/Q/longdouble.h	2019-06-06 20:38:52.276084927 +0000
+++ new/usr/src/lib/libm/common/Q/longdouble.h	2019-06-06 20:38:52.294346927 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-#ifndef	_Q_LONGDOUBLE_H
+#ifndef _Q_LONGDOUBLE_H
 #define	_Q_LONGDOUBLE_H
 
 #include <sys/ieeefp.h>
@@ -39,7 +40,6 @@
 extern long double __k_tanl(long double, long double, int);
 extern long double __poly_libmq(long double, int, const long double *);
 extern int __rem_pio2l(long double, long double *);
-
 extern long double acosdl(long double);
 extern long double acoshl(long double);
 extern long double acosl(long double);
@@ -134,7 +134,6 @@
 extern long double y0l(long double);
 extern long double y1l(long double);
 extern long double ynl(int, long double);
-
 extern long double q_copysign_(long double *, long double *);
 extern long double q_fabs_(long double *);
 extern int iq_finite_(long double *);
@@ -157,5 +156,4 @@
 extern long double q_scalbn_(long double *, int *);
 extern long double q_signaling_nan_(long *);
 extern int iq_signbit_(long double *);
-
-#endif	/* _Q_LONGDOUBLE_H */
+#endif /* _Q_LONGDOUBLE_H */
--- old/usr/src/lib/libm/common/Q/nextafterl.c	2019-06-06 20:38:52.768101106 +0000
+++ new/usr/src/lib/libm/common/Q/nextafterl.c	2019-06-06 20:38:52.785358423 +0000
@@ -58,9 +58,9 @@
 /*
  * if pseudo-denormal, replace by the equivalent normal
  */
-#define	X86PDNRM1(x)	if (XBIASED_EXP(x) == 0 && (((int *) &x)[1] & \
+#define	X86PDNRM1(x)	if (XBIASED_EXP(x) == 0 && (((int *)&x)[1] & \
 				0x80000000) != 0) \
-				((int *) &x)[2] |= 1
+				((int *)&x)[2] |= 1
 #define	INC(px)	{ \
 			if (++px[n2] == 0) \
 				if ((++px[n1] & ~0x80000000) == 0) \
@@ -75,9 +75,10 @@
 #endif
 
 long double
-nextafterl(long double x, long double y) {
-	int *px = (int *) &x;
-	int *py = (int *) &y;
+nextafterl(long double x, long double y)
+{
+	int *px = (int *)&x;
+	int *py = (int *)&y;
 
 	if (x == y)
 		return (y);		/* C99 requirement */
--- old/usr/src/lib/libm/common/Q/powl.c	2019-06-06 20:38:53.267207489 +0000
+++ new/usr/src/lib/libm/common/Q/powl.c	2019-06-06 20:38:53.286254053 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,21 +31,18 @@
 #pragma weak __powl = powl
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
-#define	_C99SUSv3_pow	_C99SUSv3_pow_treats_Inf_as_an_even_int
+#include "xpg6.h"			/* __xpg6 */
+#define	_C99SUSv3_pow		_C99SUSv3_pow_treats_Inf_as_an_even_int
 
 #if defined(__sparc)
-#define	i0	0
-#define	i1	1
-#define	i2	2
-#define	i3	3
+#define	i0			0
+#define	i1			1
+#define	i2			2
+#define	i3			3
 
 static const long double zero = 0.0L, one = 1.0L, two = 2.0L;
-
 extern const long double _TBL_logl_hi[], _TBL_logl_lo[];
-
-static const long double
-	two113 = 10384593717069655257060992658440192.0L,
+static const long double two113 = 10384593717069655257060992658440192.0L,
 	ln2hi = 6.931471805599453094172319547495844850203e-0001L,
 	ln2lo = 1.667085920830552208890449330400379754169e-0025L,
 	A2 = 6.666666666666666666666666666666091393804e-0001L,
@@ -64,38 +62,44 @@
 	B9 = 1.053794891561452331722969901564862497132e-0001L;
 
 static long double
-logl_x(long double x, long double *w) {
+logl_x(long double x, long double *w)
+{
 	long double f, f1, v, s, z, qn, h, t;
-	int *px = (int *) &x;
-	int *pz = (int *) &z;
+	int *px = (int *)&x;
+	int *pz = (int *)&z;
 	int i, j, ix, n;
 
 	n = 0;
 	ix = px[i0];
+
 	if (ix > 0x3ffef03f && ix < 0x3fff0820) {	/* 65/63 > x > 63/65 */
 		f = x - one;
 		z = f * f;
+
 		if (((ix - 0x3fff0000) | px[i1] | px[i2] | px[i3]) == 0) {
 			*w = zero;
 			return (zero);	/* log(1)= +0 */
 		}
+
 		qn = one / (two + f);
-		s = f * qn;	/* |s|<2**-6 */
+		s = f * qn;		/* |s|<2**-6 */
 		v = s * s;
-		h = (long double) (2.0 * (double) s);
-		f1 = (long double) ((double) f);
-		t = ((two * (f - h) - h * f1) - h * (f - f1)) * qn +
-			s * (v * (B1 + v * (B2 + v * (B3 + v * (B4 +
-			v * (B5 + v * (B6 + v * (B7 + v * (B8 + v * B9)))))))));
-		s = (long double) ((double) (h + t));
+		h = (long double)(2.0 * (double)s);
+		f1 = (long double)((double)f);
+		t = ((two * (f - h) - h * f1) - h * (f - f1)) * qn + s * (v *
+		    (B1 + v * (B2 + v * (B3 + v * (B4 + v * (B5 + v * (B6 + v *
+		    (B7 + v * (B8 + v * B9)))))))));
+		s = (long double)((double)(h + t));
 		*w = t - (s - h);
 		return (s);
 	}
-	if (ix < 0x00010000) {	/* subnormal x */
+
+	if (ix < 0x00010000) {		/* subnormal x */
 		x *= two113;
 		n = -113;
 		ix = px[i0];
 	}
+
 	/* LARGE_N */
 	n += ((ix + 0x200) >> 16) - 0x3fff;
 	ix = (ix & 0x0000ffff) | 0x3fff0000;	/* scale x to [1,2] */
@@ -106,19 +110,19 @@
 	qn = one / (x + z);
 	f = x - z;
 	s = f * qn;
-	f1 = (long double) ((double) f);
-	h = (long double) (2.0 * (double) s);
+	f1 = (long double)((double)f);
+	h = (long double)(2.0 * (double)s);
 	t = qn * ((two * (f - z * h) - h * f1) - h * (f - f1));
 	j = (i >> 10) & 0x3f;
 	v = s * s;
-	qn = (long double) n;
+	qn = (long double)n;
 	t += qn * ln2lo + _TBL_logl_lo[j];
-	t += s * (v * (A2 + v * (A3 + v * (A4 + v * (A5 + v * (A6 +
-		v * A7))))));
+	t += s * (v * (A2 + v * (A3 + v * (A4 + v * (A5 + v * (A6 + v *
+	    A7))))));
 	v = qn * ln2hi + _TBL_logl_hi[j];
 	s = h + v;
 	t += (h - (s - v));
-	z = (long double) ((double) (s + t));
+	z = (long double)((double)(s + t));
 	*w = t - (z - s);
 	return (z);
 }
@@ -131,14 +135,15 @@
 	ln2_64 = 1.083042469624914545964425189778400898568e-2L;
 
 long double
-powl(long double x, long double y) {
+powl(long double x, long double y)
+{
 	long double z, ax;
 	long double y1, y2, w1, w2;
 	int sbx, sby, j, k, yisint, m;
 	int hx, lx, hy, ly, ahx, ahy;
-	int *pz = (int *) &z;
-	int *px = (int *) &x;
-	int *py = (int *) &y;
+	int *pz = (int *)&z;
+	int *px = (int *)&x;
+	int *py = (int *)&y;
 
 	hx = px[i0];
 	lx = px[i1] | px[i2] | px[i3];
@@ -149,16 +154,17 @@
 
 	if ((ahy | ly) == 0)
 		return (one);		/* x**+-0 = 1 */
-	else if (hx == 0x3fff0000 && lx == 0 &&
-		(__xpg6 & _C99SUSv3_pow) != 0)
+	else if (hx == 0x3fff0000 && lx == 0 && (__xpg6 & _C99SUSv3_pow) != 0)
 		return (one);		/* C99: 1**anything = 1 */
-	else if (ahx > 0x7fff0000 || (ahx == 0x7fff0000 && lx != 0) ||
-		ahy > 0x7fff0000 || (ahy == 0x7fff0000 && ly != 0))
+	else if (ahx > 0x7fff0000 || (ahx == 0x7fff0000 && lx != 0) || ahy >
+	    0x7fff0000 || (ahy == 0x7fff0000 && ly != 0))
 		return (x + y);		/* +-NaN return x+y */
-					/* includes Sun: 1**NaN = NaN */
-	sbx = (unsigned) hx >> 31;
-	sby = (unsigned) hy >> 31;
+
+	/* includes Sun: 1**NaN = NaN */
+	sbx = (unsigned)hx >> 31;
+	sby = (unsigned)hy >> 31;
 	ax = fabsl(x);
+
 	/*
 	 * determine if y is an odd int when x < 0
 	 * yisint = 0 ... y is not an integer
@@ -166,25 +172,31 @@
 	 * yisint = 2 ... y is an even int
 	 */
 	yisint = 0;
+
 	if (sbx) {
-		if (ahy >= 0x40700000)	/* if |y|>=2**113 */
-			yisint = 2;	/* even integer y */
-		else if (ahy >= 0x3fff0000) {
+		if (ahy >= 0x40700000) { /* if |y|>=2**113 */
+			yisint = 2;			/* even integer y */
+		} else if (ahy >= 0x3fff0000) {
 			k = (ahy >> 16) - 0x3fff;	/* exponent */
+
 			if (k > 80) {
-				j = ((unsigned) py[i3]) >> (112 - k);
+				j = ((unsigned)py[i3]) >> (112 - k);
+
 				if ((j << (112 - k)) == py[i3])
 					yisint = 2 - (j & 1);
 			} else if (k > 48) {
-				j = ((unsigned) py[i2]) >> (80 - k);
+				j = ((unsigned)py[i2]) >> (80 - k);
+
 				if ((j << (80 - k)) == py[i2])
 					yisint = 2 - (j & 1);
 			} else if (k > 16) {
-				j = ((unsigned) py[i1]) >> (48 - k);
+				j = ((unsigned)py[i1]) >> (48 - k);
+
 				if ((j << (48 - k)) == py[i1])
 					yisint = 2 - (j & 1);
 			} else if (ly == 0) {
 				j = ahy >> (16 - k);
+
 				if ((j << (16 - k)) == ahy)
 					yisint = 2 - (j & 1);
 			}
@@ -197,25 +209,27 @@
 			if (((ahx - 0x3fff0000) | lx) == 0) {
 				if ((__xpg6 & _C99SUSv3_pow) != 0)
 					return (one);
-						/* C99: (-1)**+-inf = 1 */
+				/* C99: (-1)**+-inf = 1 */
 				else
 					return (y - y);
-						/* Sun: (+-1)**+-inf = NaN */
-			} else if (ahx >= 0x3fff0000)
-						/* (|x|>1)**+,-inf = inf,0 */
+
+				/* Sun: (+-1)**+-inf = NaN */
+			} else if (ahx >= 0x3fff0000) {
+				/* (|x|>1)**+,-inf = inf,0 */
 				return (sby == 0 ? y : zero);
-			else			/* (|x|<1)**-,+inf = inf,0 */
+			} else {		/* (|x|<1)**-,+inf = inf,0 */
 				return (sby != 0 ? -y : zero);
+			}
 		} else if (ahy == 0x3fff0000) {	/* y is +-1 */
 			if (sby != 0)
 				return (one / x);
 			else
 				return (x);
-		} else if (hy == 0x40000000)	/* y is 2 */
+		} else if (hy == 0x40000000) {	/* y is 2 */
 			return (x * x);
-		else if (hy == 0x3ffe0000) {	/* y is 0.5 */
+		} else if (hy == 0x3ffe0000) {	/* y is 0.5 */
 			if (!((ahx | lx) == 0 || ((ahx - 0x7fff0000) | lx) ==
-				0))
+			    0))
 				return (sqrtl(x));
 		}
 	}
@@ -223,17 +237,20 @@
 	/* special value of x */
 	if (lx == 0) {
 		if (ahx == 0x7fff0000 || ahx == 0 || ahx == 0x3fff0000) {
-							/* x is +-0,+-inf,+-1 */
+			/* x is +-0,+-inf,+-1 */
 			z = ax;
+
 			if (sby == 1)
 				z = one / z;	/* z = 1/|x| if y is negative */
+
 			if (sbx == 1) {
 				if (ahx == 0x3fff0000 && yisint == 0)
 					z = zero / zero;
-						/* (-1)**non-int is NaN */
+				/* (-1)**non-int is NaN */
 				else if (yisint == 1)
 					z = -z;	/* (x<0)**odd = -(|x|**odd) */
 			}
+
 			return (z);
 		}
 	}
@@ -242,8 +259,10 @@
 	if (sbx == 1 && yisint == 0)
 		return (zero / zero);	/* should be volatile */
 
-	/* Now ax is finite, y is finite */
-	/* first compute log(ax) = w1+w2, with 53 bits w1 */
+	/*
+	 * Now ax is finite, y is finite
+	 * first compute log(ax) = w1+w2, with 53 bits w1
+	 */
 	w1 = logl_x(ax, &w2);
 
 	/* split up y into y1+y2 and compute (y1+y2)*(w1+w2) */
@@ -251,13 +270,15 @@
 		y1 = y * w1;
 		y2 = y * w2;
 	} else {
-		y1 = (long double) ((double) y);
+		y1 = (long double)((double)y);
 		y2 = (y - y1) * w1 + y * w2;
 		y1 *= w1;
 	}
+
 	z = y1 + y2;
 	j = pz[i0];
-	if ((unsigned) j >= 0xffff0000) {		/* NaN or -inf */
+
+	if ((unsigned)j >= 0xffff0000) {	/* NaN or -inf */
 		if (sbx == 1 && yisint == 1)
 			return (one / z);
 		else
@@ -274,45 +295,49 @@
 			else
 				return (scalbnl(one, 20000));
 		}
-		k = (int) (invln2_32 * (z + ln2_64));
+
+		k = (int)(invln2_32 * (z + ln2_64));
 	} else {
-		if ((unsigned) j > 0xc00d0000) {
+		if ((unsigned)j > 0xc00d0000) {
 			if (sbx == 1 && yisint == 1)
 				return (scalbnl(-one, -20000));
 			else
 				return (scalbnl(one, -20000));
 		}
-		k = (int) (invln2_32 * (z - ln2_64));
+
+		k = (int)(invln2_32 * (z - ln2_64));
 	}
+
 	j = k & 0x1f;
 	m = k >> 5;
 	{
 		/* rational approximation coeffs for [-(ln2)/64,(ln2)/64] */
-		long double
-			t1 = 1.666666666666666666666666666660876387437e-1L,
-			t2 = -2.777777777777777777777707812093173478756e-3L,
-			t3 = 6.613756613756613482074280932874221202424e-5L,
-			t4 = -1.653439153392139954169609822742235851120e-6L,
-			t5 = 4.175314851769539751387852116610973796053e-8L;
-		long double t = (long double) k;
+		long double t1 = 1.666666666666666666666666666660876387437e-1L,
+		    t2 = -2.777777777777777777777707812093173478756e-3L,
+		    t3 = 6.613756613756613482074280932874221202424e-5L,
+		    t4 = -1.653439153392139954169609822742235851120e-6L,
+		    t5 = 4.175314851769539751387852116610973796053e-8L;
+		long double t = (long double)k;
 
 		w1 = (y2 - (t * ln2_32hi - y1)) - t * ln2_32lo;
 		t = w1 * w1;
 		w2 = (w1 - t * (t1 + t * (t2 + t * (t3 + t * (t4 + t * t5))))) -
-			two;
+		    two;
 		z = _TBL_expl_hi[j] - ((_TBL_expl_hi[j] * (w1 + w1)) / w2 -
-			_TBL_expl_lo[j]);
+		    _TBL_expl_lo[j]);
 	}
 	j = m + (pz[i0] >> 16);
-	if (j && (unsigned) j < 0x7fff)
+
+	if (j && (unsigned)j < 0x7fff)
 		pz[i0] += m << 16;
 	else
 		z = scalbnl(z, m);
 
 	if (sbx == 1 && yisint == 1)
-		z = -z;		/* (-ve)**(odd int) */
+		z = -z;			/* (-ve)**(odd int) */
+
 	return (z);
 }
 #else
 #error Unsupported Architecture
-#endif	/* defined(__sparc) */
+#endif /* defined(__sparc) */
--- old/usr/src/lib/libm/common/Q/remainderl.c	2019-06-06 20:38:53.783925944 +0000
+++ new/usr/src/lib/libm/common/Q/remainderl.c	2019-06-06 20:38:53.802125709 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -41,48 +42,57 @@
  *	Based on fmodl() return x-[x/p]chopped*p exactly.
  */
 
-#define	HFMAX	5.948657476786158825428796633140035080982e+4931L
-#define	DBMIN	6.724206286224187012525355634643505205196e-4932L
+#define	HFMAX		5.948657476786158825428796633140035080982e+4931L
+#define	DBMIN		6.724206286224187012525355634643505205196e-4932L
 
-static const long double
-	zero = 0.0L,
+static const long double zero = 0.0L,
 	half = 0.5L,
 	hfmax = HFMAX,	/* half of the maximum number */
 	dbmin = DBMIN;	/* double of the minimum (normal) number */
 
 long double
-remainderl(long double x, long double p) {
+remainderl(long double x, long double p)
+{
 	long double hp;
 	int sx;
 
 	if (isnanl(p))
 		return (x + p);
+
 	if (!finitel(x))
 		return (x - x);
+
 	p = fabsl(p);
+
 	if (p <= hfmax)
 		x = fmodl(x, p + p);
+
 	sx = signbitl(x);
 	x = fabsl(x);
+
 	if (p < dbmin) {
 		if (x + x > p) {
 			if (x == p)
 				x = zero;
 			else
-				x -= p;	/* avoid x-x=-0 in RM mode */
+				x -= p;		/* avoid x-x=-0 in RM mode */
+
 			if (x + x >= p)
 				x -= p;
 		}
 	} else {
 		hp = half * p;
+
 		if (x > hp) {
 			if (x == p)
 				x = zero;
 			else
-				x -= p;	/* avoid x-x=-0 in RM mode */
+				x -= p;		/* avoid x-x=-0 in RM mode */
+
 			if (x >= hp)
 				x -= p;
 		}
 	}
+
 	return (sx == 0 ? x : -x);
 }
--- old/usr/src/lib/libm/common/Q/rintl.c	2019-06-06 20:38:54.309572911 +0000
+++ new/usr/src/lib/libm/common/Q/rintl.c	2019-06-06 20:38:54.327943775 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,17 +45,17 @@
 
 static const double one = 1.0;
 static const long double qzero = 0.0L;
-
 long double
-rintl(long double x) {
+rintl(long double x)
+{
 	enum fp_precision_type rp;
 	long double t, w, two112;
-	int *pt = (int *) &two112;
+	int *pt = (int *)&two112;
 
 	if (!finitel(x))
 		return (x + x);
 
-	if (*(int *) &one != 0) {	/* set two112 = 2^112 */
+	if (*(int *)&one != 0) {	/* set two112 = 2^112 */
 		pt[0] = 0x406f0000;
 		pt[1] = pt[2] = pt[3] = 0;
 	} else {
@@ -63,11 +64,13 @@
 	}
 
 	if (fabsl(x) >= two112)
-		return (x);	/* already an integer */
+		return (x);			/* already an integer */
+
 	t = copysignl(two112, x);
-	rp = __swapRP(fp_extended);	/* make sure precision is long double */
-	w = x + t;			/* x+sign(x)*2^112 rounded to integer */
-	(void) __swapRP(rp);		/* restore precision mode */
+	rp = __swapRP(fp_extended); /* make sure precision is long double */
+	w = x + t;		    /* x+sign(x)*2^112 rounded to integer */
+	(void) __swapRP(rp);	    /* restore precision mode */
+
 	if (w == t)
 		return (copysignl(qzero, x));	/* x rounded to zero */
 	else
--- old/usr/src/lib/libm/common/Q/rndintl.c	2019-06-06 20:38:54.826805390 +0000
+++ new/usr/src/lib/libm/common/Q/rndintl.c	2019-06-06 20:38:54.844659292 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,68 +44,88 @@
 extern enum fp_direction_type __swapRD(enum fp_direction_type);
 
 static const long double qone = 1.0L, qhalf = 0.5L, qmhalf = -0.5L;
-
 long double
-aintl(long double x) {
+aintl(long double x)
+{
 	long double t, w;
 
 	if (!finitel(x))
 		return (x + x);
+
 	w = fabsl(x);
 	t = rintl(w);
+
 	if (t <= w)
-		return (copysignl(t, x));	/* NaN or already aint(|x|) */
-	else	/* |t|>|x| case */
-		return (copysignl(t - qone, x));	/* |t-1|*sign(x) */
+		return (copysignl(t, x)); /* NaN or already aint(|x|) */
+	else				  /* |t|>|x| case */
+		return (copysignl(t - qone, x)); /* |t-1|*sign(x) */
 }
 
 long double
-anintl(long double x) {
+anintl(long double x)
+{
 	long double t, w, z;
 
 	if (!finitel(x))
 		return (x + x);
+
 	w = fabsl(x);
 	t = rintl(w);
+
 	if (t == w)
 		return (copysignl(t, x));
+
 	z = t - w;
+
 	if (z > qhalf)
 		t = t - qone;
 	else if (z <= qmhalf)
 		t = t + qone;
+
 	return (copysignl(t, x));
 }
 
 int
-irintl(long double x) {
+irintl(long double x)
+{
 	enum fp_direction_type rd;
 
 	rd = __swapRD(fp_nearest);
-	(void) __swapRD(rd);	/* restore Rounding Direction */
+	(void) __swapRD(rd);		/* restore Rounding Direction */
+
 	switch (rd) {
 	case fp_nearest:
+
 		if (x < 2147483647.5L && x >= -2147483648.5L)
 			return ((int)rintl(x));
+
 		break;
 	case fp_tozero:
+
 		if (x < 2147483648.0L && x > -2147483649.0L)
 			return ((int)rintl(x));
+
 		break;
 	case fp_positive:
+
 		if (x <= 2147483647.0L && x > -2147483649.0L)
 			return ((int)rintl(x));
+
 		break;
 	case fp_negative:
+
 		if (x < 2147483648.0L && x >= -2147483648.0L)
 			return ((int)rintl(x));
+
 		break;
 	}
+
 	return ((int)copysignl(1.0e100L, x));
 }
 
 int
-nintl(long double x) {
+nintl(long double x)
+{
 	if ((x < 2147483647.5L) && (x > -2147483648.5L))
 		return ((int)anintl(x));
 	else
--- old/usr/src/lib/libm/common/Q/scalbl.c	2019-06-06 20:38:55.336226511 +0000
+++ new/usr/src/lib/libm/common/Q/scalbl.c	2019-06-06 20:38:55.354910105 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,8 +39,9 @@
 #define	n0	0
 
 long double
-scalbl(long double x, long double fn) {
-	int *py = (int *) &fn, n;
+scalbl(long double x, long double fn)
+{
+	int *py = (int *)&fn, n;
 	long double z;
 
 	if (isnanl(x) || isnanl(fn))
@@ -54,15 +56,18 @@
 		else
 			return (x * fn);
 	}
+
 	if (rintl(fn) != fn)
 		return ((fn - fn) / (fn - fn));
-	if (fn > 65000.0L)
+
+	if (fn > 65000.0L) {
 		z = scalbnl(x, 65000);
-	else if (-fn > 65000.0L)
+	} else if (-fn > 65000.0L) {
 		z = scalbnl(x, -65000);
-	else {
-		n = (int) fn;
+	} else {
+		n = (int)fn;
 		z = scalbnl(x, n);
 	}
+
 	return (z);
 }
--- old/usr/src/lib/libm/common/Q/scalbnl.c	2019-06-06 20:38:55.814802498 +0000
+++ new/usr/src/lib/libm/common/Q/scalbnl.c	2019-06-06 20:38:55.832548583 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,53 +31,65 @@
 #pragma weak __scalbnl = scalbnl
 
 #include "libm.h"
-#include <float.h>		/* LDBL_MAX, LDBL_MIN */
-#include <stdlib.h>		/* abs */
+#include <float.h>			/* LDBL_MAX, LDBL_MIN */
+#include <stdlib.h>			/* abs */
 
 #if defined(__sparc)
-#define	XSET_EXP(k, x)	((int *) &x)[0] = (((int *) &x)[0] & ~0x7fff0000) | \
-				(k << 16)
-#define	ISINFNANL(k, x)	(k == 0x7fff)
-#define	XTWOT_OFFSET	113
-static const long double xtwot = 10384593717069655257060992658440192.0L,
-								/* 2^113 */
-	twomtm1 = 4.814824860968089632639944856462318296E-35L;	/* 2^-114 */
+#define	XSET_EXP(k, x)		((int *)&x)[0] = (((int *)&x)[0] & \
+	    ~0x7fff0000) | (k << 16)
+#define	ISINFNANL(k, x)		(k == 0x7fff)
+#define	XTWOT_OFFSET		113
+
+/* 2^113 */
+static const long double xtwot = 10384593717069655257060992658440192.0L;
+/* 2^-114 */
+static const long double twomtm1 = 4.814824860968089632639944856462318296E-35L;
 #elif defined(__x86)
-#define	XSET_EXP(k, x)	((int *) &x)[2] = (((int *) &x)[2] & ~0x7fff) | k
+#define	XSET_EXP(k, x)		((int *)&x)[2] = (((int *)&x)[2] & ~0x7fff) | k
 #if defined(HANDLE_UNSUPPORTED)
-#define	ISINFNANL(k, x)	(k == 0x7fff || k != 0 && \
-				(((int *) &x)[1] & 0x80000000) == 0)
+#define	ISINFNANL(k, x)		(k == 0x7fff || k != 0 && (((int *)&x)[1] & \
+	0x80000000) == 0)
 #else
-#define	ISINFNANL(k, x)	(k == 0x7fff)
+#define	ISINFNANL(k, x)		(k == 0x7fff)
 #endif
-#define	XTWOT_OFFSET	64
+#define	XTWOT_OFFSET		64
+
 static const long double xtwot = 18446744073709551616.0L,	/* 2^64 */
 	twomtm1 = 2.7105054312137610850186E-20L;		/* 2^-65 */
 #endif
 
 long double
-scalbnl(long double x, int n) {
+scalbnl(long double x, int n)
+{
 	int k = XBIASED_EXP(x);
 
 	if (ISINFNANL(k, x))
 		return (x + x);
+
 	if (ISZEROL(x) || n == 0)
 		return (x);
+
 	if (k == 0) {
 		x *= xtwot;
 		k = XBIASED_EXP(x) - XTWOT_OFFSET;
 	}
-	if ((unsigned) abs(n) >= 131072)	/* cast to unsigned for -2^31 */
+
+	if ((unsigned)abs(n) >= 131072)	/* cast to unsigned for -2^31 */
 		n >>= 1;		/* avoid subsequent integer overflow */
+
 	k += n;
+
 	if (k > 0x7ffe)
 		return (LDBL_MAX * copysignl(LDBL_MAX, x));
+
 	if (k <= -XTWOT_OFFSET - 1)
 		return (LDBL_MIN * copysignl(LDBL_MIN, x));
+
 	if (k > 0) {
 		XSET_EXP(k, x);
 		return (x);
 	}
+
 	k += XTWOT_OFFSET + 1;
 	XSET_EXP(k, x);
 	return (x * twomtm1);
--- old/usr/src/lib/libm/common/Q/signgaml.c	2019-06-06 20:38:56.324517834 +0000
+++ new/usr/src/lib/libm/common/Q/signgaml.c	2019-06-06 20:38:56.342679872 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/Q/significandl.c	2019-06-06 20:38:56.852297274 +0000
+++ new/usr/src/lib/libm/common/Q/significandl.c	2019-06-06 20:38:56.872180288 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,7 +33,8 @@
 #include "libm.h"
 
 long double
-significandl(long double x) {
+significandl(long double x)
+{
 	if (ISZEROL(x) || XBIASED_EXP(x) == 0x7fff)	/* 0/+-Inf/NaN */
 		return (x + x);
 	else
--- old/usr/src/lib/libm/common/Q/sincosl.c	2019-06-06 20:38:57.384616630 +0000
+++ new/usr/src/lib/libm/common/Q/sincosl.c	2019-06-06 20:38:57.402892576 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -64,20 +65,23 @@
 #include "longdouble.h"
 
 void
-sincosl(long double x, long double *s, long double *c) {
+sincosl(long double x, long double *s, long double *c)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
 
-	ix = *(int *) &x;	/* High word of x */
+	ix = *(int *)&x;		/* High word of x */
 
 	/* |x| ~< pi/4 */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)
+
+	if (ix <= 0x3ffe9220) {
 		*s = __k_sincosl(x, z, c);
-	else if (ix >= 0x7fff0000)
+	} else if (ix >= 0x7fff0000) {
 		*s = *c = x - x;	/* trig(Inf or NaN) is NaN */
-	else {			/* argument reduction needed */
+	} else {		/* argument reduction needed */
 		n = __rem_pio2l(x, y);
+
 		switch (n & 3) {
 		case 0:
 			*s = __k_sincosl(y[0], y[1], c);
--- old/usr/src/lib/libm/common/Q/sincospil.c	2019-06-06 20:38:57.875396653 +0000
+++ new/usr/src/lib/libm/common/Q/sincospil.c	2019-06-06 20:38:57.894112847 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -71,34 +72,38 @@
 #include "libm.h"
 #include "longdouble.h"
 
-#define	I(q, m)	((int *) &(q))[m]
-#define	U(q, m)	((unsigned *) &(q))[m]
+#define	I(q, m)				((int *)&(q))[m]
+#define	U(q, m)				((unsigned *)&(q))[m]
 #if defined(__LITTLE_ENDIAN) || defined(__x86)
-#define	LDBL_MOST_SIGNIF_I(ld)	((I(ld, 2) << 16) | (0xffff & (I(ld, 1) >> 15)))
-#define	LDBL_LEAST_SIGNIF_U(ld)	U(ld, 0)
-#define	PREC	64
-#define	PRECM1	63
-#define	PRECM2	62
+#define	LDBL_MOST_SIGNIF_I(ld)		((I(ld, 2) << 16) | (0xffff & (I(ld, \
+	1) >> 15)))
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, 0)
+#define	PREC				64
+#define	PRECM1				63
+#define	PRECM2				62
+
 static const long double twoPRECM2 = 9.223372036854775808000000000000000e+18L;
 #else
-#define	LDBL_MOST_SIGNIF_I(ld)	I(ld, 0)
-#define	LDBL_LEAST_SIGNIF_U(ld)	U(ld, sizeof (long double) / sizeof (int) - 1)
-#define	PREC	113
-#define	PRECM1	112
-#define	PRECM2	111
+#define	LDBL_MOST_SIGNIF_I(ld)		I(ld, 0)
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, sizeof (long double) / \
+	sizeof (int) - 1)
+#define	PREC				113
+#define	PRECM1				112
+#define	PRECM2				111
+
 static const long double twoPRECM2 = 5.192296858534827628530496329220096e+33L;
 #endif
 
-static const long double
-zero	= 0.0L,
-quater	= 0.25L,
-one	= 1.0L,
-pi	= 3.141592653589793238462643383279502884197e+0000L,
-sqrth	= 0.707106781186547524400844362104849039284835937688474,
-tiny	= 1.0e-100;
+static const long double zero = 0.0L,
+	quater = 0.25L,
+	one = 1.0L,
+	pi = 3.141592653589793238462643383279502884197e+0000L,
+	sqrth = 0.707106781186547524400844362104849039284835937688474,
+	tiny = 1.0e-100;
 
 void
-sincospil(long double x, long double *s, long double *c) {
+sincospil(long double x, long double *s, long double *c)
+{
 	long double y, z, t;
 	int hx, n, k;
 	unsigned lx;
@@ -106,6 +111,7 @@
 	hx = LDBL_MOST_SIGNIF_I(x);
 	lx = LDBL_LEAST_SIGNIF_U(x);
 	k = ((hx & 0x7fff0000) >> 16) - 0x3fff;
+
 	if (k >= PRECM2) {		/* |x| >= 2**(Prec-2) */
 		if (k >= 16384) {
 			*s = *c = x - x;
@@ -129,64 +135,75 @@
 					*s = one;
 					*c = zero;
 				}
+
 				if ((lx & 2) != 0) {
 					*s = -*s;
 					*c = -*c;
 				}
 			}
 		}
-	} else if (k < -2) 	/* |x| < 0.25 */
+	} else if (k < -2) {		/* |x| < 0.25 */
 		*s = __k_sincosl(pi * fabsl(x), zero, c);
-	else {
+	} else {
 		/* y = |4x|, z = floor(y), and n = (int)(z mod 8.0) */
 		y = 4.0L * fabsl(x);
+
 		if (k < PRECM2) {
 			z = y + twoPRECM2;
 			n = LDBL_LEAST_SIGNIF_U(z) & 7;	/* 3 LSb of z */
 			t = z - twoPRECM2;
 			k = 0;
-			if (t == y)
+
+			if (t == y) {
 				k = 1;
-			else if (t > y) {
+			} else if (t > y) {
 				n -= 1;
 				t = quater + (y - t) * quater;
-			} else
+			} else {
 				t = (y - t) * quater;
-		} else { 	/* k = Prec-3 */
+			}
+		} else {				/* k = Prec-3 */
 			n = LDBL_LEAST_SIGNIF_U(y) & 7;	/* 3 LSb of z */
 			k = 1;
 		}
-		if (k) {	/* x = N/4 */
-			if ((n & 1) != 0)
+
+		if (k) {		/* x = N/4 */
+			if ((n & 1) != 0) {
 				*s = *c = sqrth + tiny;
-			else
-				if ((n & 2) == 0) {
-					*s = zero;
-					*c = one;
-				} else {
-					*s = one;
-					*c = zero;
-				}
+			} else if ((n & 2) == 0) {
+				*s = zero;
+				*c = one;
+			} else {
+				*s = one;
+				*c = zero;
+			}
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 1) & 4) != 0)
 				*c = -*c;
 		} else {
 			if ((n & 1) != 0)
 				t = quater - t;
+
 			if (((n + (n & 1)) & 2) == 0)
 				*s = __k_sincosl(pi * t, zero, c);
 			else
 				*c = __k_sincosl(pi * t, zero, s);
+
 			if ((n & 4) != 0)
 				*s = -*s;
+
 			if (((n + 2) & 4) != 0)
 				*c = -*c;
 		}
 	}
+
 	if (hx < 0)
 		*s = -*s;
 }
+
 #undef U
 #undef LDBL_LEAST_SIGNIF_U
 #undef I
--- old/usr/src/lib/libm/common/Q/sinhl.c	2019-06-06 20:38:58.384111279 +0000
+++ new/usr/src/lib/libm/common/Q/sinhl.c	2019-06-06 20:38:58.401914392 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -58,27 +59,29 @@
  *
  */
 
-#define	ME	16383
-#define	MEP1	16384
-#define	LNOVFT	1.135652340629414394949193107797076342845e+4L
-		/* last 32 bits of LN2HI is zero */
-#define	LN2HI   6.931471805599453094172319547495844850203e-0001L
-#define	LN2LO   1.667085920830552208890449330400379754169e-0025L
-
-static const long double
-	half	= 0.5L,
-	one	= 1.0L,
-	ln2hi	= LN2HI,
-	ln2lo	= LN2LO,
-	lnovftL	= LNOVFT;
+#define	ME		16383
+#define	MEP1		16384
+#define	LNOVFT		1.135652340629414394949193107797076342845e+4L
+/* last 32 bits of LN2HI is zero */
+#define	LN2HI		6.931471805599453094172319547495844850203e-0001L
+#define	LN2LO		1.667085920830552208890449330400379754169e-0025L
+
+static const long double half = 0.5L,
+	one = 1.0L,
+	ln2hi = LN2HI,
+	ln2lo = LN2LO,
+	lnovftL = LNOVFT;
 
 long double
-sinhl(long double x) {
+sinhl(long double x)
+{
 	long double r, t;
 
 	if (!finitel(x))
-		return (x + x);	/* sinh of NaN or +-INF is itself */
+		return (x + x);		/* sinh of NaN or +-INF is itself */
+
 	r = fabsl(x);
+
 	if (r < lnovftL) {
 		t = expm1l(r);
 		r = copysignl((t + t / (one + t)) * half, x);
@@ -86,5 +89,6 @@
 		r = copysignl(expl((r - MEP1 * ln2hi) - MEP1 * ln2lo), x);
 		r = scalbnl(r, ME);
 	}
+
 	return (r);
 }
--- old/usr/src/lib/libm/common/Q/sinl.c	2019-06-06 20:38:58.872038495 +0000
+++ new/usr/src/lib/libm/common/Q/sinl.c	2019-06-06 20:38:58.889147348 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -65,29 +66,33 @@
 #include "longdouble.h"
 
 long double
-sinl(long double x) {
+sinl(long double x)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
 
-	ix = *(int *) &x;		/* High word of x */
+	ix = *(int *)&x;		/* High word of x */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)		/* |x| ~< pi/4 */
+
+	if (ix <= 0x3ffe9220) {		/* |x| ~< pi/4 */
 		return (__k_sinl(x, z));
-	else if (ix >= 0x7fff0000)	/* sin(Inf or NaN) is NaN */
+	} else if (ix >= 0x7fff0000) {	/* sin(Inf or NaN) is NaN */
 		return (x - x);
-	else {				/* argument reduction needed */
+	} else {			/* argument reduction needed */
 		n = __rem_pio2l(x, y);
+
 		switch (n & 3) {
-			case 0:
-				return (__k_sinl(y[0], y[1]));
-			case 1:
-				return (__k_cosl(y[0], y[1]));
-			case 2:
-				return (-__k_sinl(y[0], y[1]));
-			case 3:
-				return (-__k_cosl(y[0], y[1]));
+		case 0:
+			return (__k_sinl(y[0], y[1]));
+		case 1:
+			return (__k_cosl(y[0], y[1]));
+		case 2:
+			return (-__k_sinl(y[0], y[1]));
+		case 3:
+			return (-__k_cosl(y[0], y[1]));
 		}
 	}
+
 	/* NOTREACHED */
-    return 0.0L;
+	return (0.0L);
 }
--- old/usr/src/lib/libm/common/Q/sinpil.c	2019-06-06 20:38:59.350437070 +0000
+++ new/usr/src/lib/libm/common/Q/sinpil.c	2019-06-06 20:38:59.372200680 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -71,34 +72,38 @@
 #include "libm.h"
 #include "longdouble.h"
 
-#define	I(q, m)	((int *) &(q))[m]
-#define	U(q, m)	((unsigned *) &(q))[m]
+#define	I(q, m)				((int *)&(q))[m]
+#define	U(q, m)				((unsigned *)&(q))[m]
 #if defined(__LITTLE_ENDIAN) || defined(__x86)
-#define	LDBL_MOST_SIGNIF_I(ld)	((I(ld, 2) << 16) | (0xffff & (I(ld, 1) >> 15)))
-#define	LDBL_LEAST_SIGNIF_U(ld)	U(ld, 0)
-#define	PREC	64
-#define	PRECM1	63
-#define	PRECM2	62
+#define	LDBL_MOST_SIGNIF_I(ld)		((I(ld, 2) << 16) | (0xffff & (I(ld, \
+	1) >> 15)))
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, 0)
+#define	PREC				64
+#define	PRECM1				63
+#define	PRECM2				62
+
 static const long double twoPRECM2 = 9.223372036854775808000000000000000e+18L;
 #else
-#define	LDBL_MOST_SIGNIF_I(ld)	I(ld, 0)
-#define	LDBL_LEAST_SIGNIF_U(ld)	U(ld, sizeof (long double) / sizeof (int) - 1)
-#define	PREC	113
-#define	PRECM1	112
-#define	PRECM2	111
+#define	LDBL_MOST_SIGNIF_I(ld)		I(ld, 0)
+#define	LDBL_LEAST_SIGNIF_U(ld)		U(ld, sizeof (long double) / \
+	sizeof (int) - 1)
+#define	PREC				113
+#define	PRECM1				112
+#define	PRECM2				111
+
 static const long double twoPRECM2 = 5.192296858534827628530496329220096e+33L;
 #endif
 
-static const long double
-zero	= 0.0L,
-quater	= 0.25L,
-one	= 1.0L,
-pi	= 3.141592653589793238462643383279502884197e+0000L,
-sqrth   = 0.707106781186547524400844362104849039284835937688474,
-tiny    = 1.0e-100;
+static const long double zero = 0.0L,
+	quater = 0.25L,
+	one = 1.0L,
+	pi = 3.141592653589793238462643383279502884197e+0000L,
+	sqrth = 0.707106781186547524400844362104849039284835937688474,
+	tiny = 1.0e-100;
 
 long double
-sinpil(long double x) {
+sinpil(long double x)
+{
 	long double y, z, t;
 	int hx, n, k;
 	unsigned lx;
@@ -106,61 +111,72 @@
 	hx = LDBL_MOST_SIGNIF_I(x);
 	lx = LDBL_LEAST_SIGNIF_U(x);
 	k = ((hx & 0x7fff0000) >> 16) - 0x3fff;
+
 	if (k >= PRECM2) {		/* |x| >= 2**(Prec-2) */
-		if (k >= 16384)
+		if (k >= 16384) {
 			y = x - x;
-		else {
-			if (k >= PREC)
+		} else {
+			if (k >= PREC) {
 				y = zero;
-			else if (k == PRECM1)
-				y = (lx & 1) == 0 ? zero: -zero;
-			else {	/* k = Prec - 2 */
+			} else if (k == PRECM1) {
+				y = (lx & 1) == 0 ? zero : -zero;
+			} else { /* k = Prec - 2 */
 				y = (lx & 1) == 0 ? zero : one;
+
 				if ((lx & 2) != 0)
 					y = -y;
 			}
 		}
-	} else if (k < -2) 	/* |x| < 0.25 */
+	} else if (k < -2) {		/* |x| < 0.25 */
 		y = __k_sinl(pi * fabsl(x), zero);
-	else {
+	} else {
 		/* y = |4x|, z = floor(y), and n = (int)(z mod 8.0) */
 		y = 4.0L * fabsl(x);
+
 		if (k < PRECM2) {
 			z = y + twoPRECM2;
 			n = LDBL_LEAST_SIGNIF_U(z) & 7;	/* 3 LSb of z */
 			t = z - twoPRECM2;
 			k = 0;
-			if (t == y)
+
+			if (t == y) {
 				k = 1;
-			else if (t > y) {
+			} else if (t > y) {
 				n -= 1;
 				t = quater + (y - t) * quater;
-			} else
+			} else {
 				t = (y - t) * quater;
-		} else { 	/* k = Prec-3 */
+			}
+		} else {				/* k = Prec-3 */
 			n = LDBL_LEAST_SIGNIF_U(y) & 7;	/* 3 LSb of z */
 			k = 1;
 		}
-		if (k) {	/* x = N/4 */
+
+		if (k) {		/* x = N/4 */
 			if ((n & 1) != 0)
 				y = sqrth + tiny;
 			else
 				y = (n & 2) == 0 ? zero : one;
+
 			if ((n & 4) != 0)
 				y = -y;
 		} else {
 			if ((n & 1) != 0)
 				t = quater - t;
+
 			if (((n + (n & 1)) & 2) == 0)
 				y = __k_sinl(pi * t, zero);
 			else
 				y = __k_cosl(pi * t, zero);
+
 			if ((n & 4) != 0)
 				y = -y;
 		}
 	}
+
 	return (hx >= 0 ? y : -y);
 }
+
 #undef U
 #undef LDBL_LEAST_SIGNIF_U
 #undef I
--- old/usr/src/lib/libm/common/Q/sqrtl.c	2019-06-06 20:38:59.879152005 +0000
+++ new/usr/src/lib/libm/common/Q/sqrtl.c	2019-06-06 20:38:59.896753689 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,64 +45,60 @@
  */
 
 #ifdef __LITTLE_ENDIAN
-
 /* array indices used to access words within a double */
-#define	HIWORD	1
-#define	LOWORD	0
+#define	HIWORD		1
+#define	LOWORD		0
 
 /* structure used to access words within a quad */
 union longdouble {
 	struct {
-		unsigned int	frac4;
-		unsigned int	frac3;
-		unsigned int	frac2;
-		unsigned int	msw;
+		unsigned int frac4;
+		unsigned int frac3;
+		unsigned int frac2;
+		unsigned int msw;
 	} l;
-	long double	d;
+	long double d;
 };
 
 /* default NaN returned for sqrt(neg) */
-static const union longdouble
-	qnan = { 0xffffffff, 0xffffffff, 0xffffffff, 0x7fffffff };
+static const union longdouble qnan = {
+	0xffffffff, 0xffffffff, 0xffffffff, 0x7fffffff
+};
 
 /* signalling NaN used to raise invalid */
 static const union {
 	unsigned u[2];
 	double d;
 } snan = { 0, 0x7ff00001 };
-
 #else
-
 /* array indices used to access words within a double */
-#define	HIWORD	0
-#define	LOWORD	1
+#define	HIWORD		0
+#define	LOWORD		1
 
 /* structure used to access words within a quad */
 union longdouble {
 	struct {
-		unsigned int	msw;
-		unsigned int	frac2;
-		unsigned int	frac3;
-		unsigned int	frac4;
+		unsigned int msw;
+		unsigned int frac2;
+		unsigned int frac3;
+		unsigned int frac4;
 	} l;
-	long double	d;
+	long double d;
 };
 
 /* default NaN returned for sqrt(neg) */
-static const union longdouble
-	qnan = { 0x7fffffff, 0xffffffff, 0xffffffff, 0xffffffff };
+static const union longdouble qnan = {
+	0x7fffffff, 0xffffffff, 0xffffffff, 0xffffffff
+};
 
 /* signalling NaN used to raise invalid */
 static const union {
 	unsigned u[2];
 	double d;
 } snan = { 0x7ff00001, 0 };
-
 #endif /* __LITTLE_ENDIAN */
 
-
-static const double
-	zero = 0.0,
+static const double zero = 0.0,
 	half = 0.5,
 	one = 1.0,
 	huge = 1.0e300,
@@ -120,64 +117,55 @@
 	twom113 = 9.62964972193617926528e-35,
 	twom124 = 4.70197740328915003187e-38;
 
-
 /*
-*	Extract the exponent and normalized significand (represented as
-*	an array of five doubles) from a finite, nonzero quad.
-*/
+ *	Extract the exponent and normalized significand (represented as
+ *	an array of five doubles) from a finite, nonzero quad.
+ */
 static int
 __q_unpack(const union longdouble *x, double *s)
 {
 	union {
-		double			d;
-		unsigned int	l[2];
+		double d;
+		unsigned int l[2];
 	} u;
-	double			b;
-	unsigned int	lx, w[3];
-	int				ex;
+
+	double b;
+	unsigned int lx, w[3];
+	int ex;
 
 	/* get the normalized significand and exponent */
-	ex = (int) ((x->l.msw & 0x7fffffff) >> 16);
+	ex = (int)((x->l.msw & 0x7fffffff) >> 16);
 	lx = x->l.msw & 0xffff;
-	if (ex)
-	{
+
+	if (ex) {
 		lx |= 0x10000;
 		w[0] = x->l.frac2;
 		w[1] = x->l.frac3;
 		w[2] = x->l.frac4;
-	}
-	else
-	{
-		if (lx | (x->l.frac2 & 0xfffe0000))
-		{
+	} else {
+		if (lx | (x->l.frac2 & 0xfffe0000)) {
 			w[0] = x->l.frac2;
 			w[1] = x->l.frac3;
 			w[2] = x->l.frac4;
 			ex = 1;
-		}
-		else if (x->l.frac2 | (x->l.frac3 & 0xfffe0000))
-		{
+		} else if (x->l.frac2 | (x->l.frac3 & 0xfffe0000)) {
 			lx = x->l.frac2;
 			w[0] = x->l.frac3;
 			w[1] = x->l.frac4;
 			w[2] = 0;
 			ex = -31;
-		}
-		else if (x->l.frac3 | (x->l.frac4 & 0xfffe0000))
-		{
+		} else if (x->l.frac3 | (x->l.frac4 & 0xfffe0000)) {
 			lx = x->l.frac3;
 			w[0] = x->l.frac4;
 			w[1] = w[2] = 0;
 			ex = -63;
-		}
-		else
-		{
+		} else {
 			lx = x->l.frac4;
 			w[0] = w[1] = w[2] = 0;
 			ex = -95;
 		}
-		while ((lx & 0x10000) == 0)
-		{
+
+		while ((lx & 0x10000) == 0) {
 			lx = (lx << 1) | (w[0] >> 31);
 			w[0] = (w[0] << 1) | (w[1] >> 31);
 			w[1] = (w[1] << 1) | (w[2] >> 31);
@@ -219,25 +207,25 @@
 	u.l[LOWORD] = w[2] & 0xffffff;
 	s[4] = u.d - b;
 
-	return ex - 0x3fff;
+	return (ex - 0x3fff);
 }
 
-
 /*
-*	Pack an exponent and array of three doubles representing a finite,
-*	nonzero number into a quad.  Assume the sign is already there and
-*	the rounding mode has been fudged accordingly.
-*/
+ *	Pack an exponent and array of three doubles representing a finite,
+ *	nonzero number into a quad.  Assume the sign is already there and
+ *	the rounding mode has been fudged accordingly.
+ */
 static void
 __q_pack(const double *z, int exp, enum fp_direction_type rm,
-	union longdouble *x, int *inexact)
+    union longdouble *x, int *inexact)
 {
 	union {
-		double			d;
-		unsigned int	l[2];
+		double d;
+		unsigned int l[2];
 	} u;
-	double			s[3], t, t2;
-	unsigned int	msw, frac2, frac3, frac4;
+
+	double s[3], t, t2;
+	unsigned int msw, frac2, frac3, frac4;
 
 	/* bias exponent and strip off integer bit */
 	exp += 0x3fff;
@@ -282,23 +270,23 @@
 	t = s[0] + s[1];
 	t2 = (s[0] - t) + s[1];
 
-	if (t != zero)
-	{
+	if (t != zero) {
 		*inexact = 1;
 
 		/* decide whether to round the fraction up */
 		if (rm == fp_positive || (rm == fp_nearest && (t > twom113 ||
-			(t == twom113 && (t2 != zero || frac4 & 1)))))
-		{
+		    (t == twom113 && (t2 != zero || frac4 & 1))))) {
 			/* round up and renormalize if necessary */
-			if (++frac4 == 0)
-				if (++frac3 == 0)
-					if (++frac2 == 0)
-						if (++msw == 0x10000)
-						{
+			if (++frac4 == 0) {
+				if (++frac3 == 0) {
+					if (++frac2 == 0) {
+						if (++msw == 0x10000) {
 							msw = 0;
 							exp++;
 						}
+					}
+				}
+			}
 		}
 	}
 
@@ -309,14 +297,13 @@
 	x->l.frac4 = frac4;
 }
 
-
 /*
-*	Compute the square root of x and place the TP result in s.
-*/
+ *	Compute the square root of x and place the TP result in s.
+ */
 static void
 __q_tp_sqrt(const double *x, double *s)
 {
-	double	c, rr, r[3], tt[3], t[5];
+	double c, rr, r[3], tt[3], t[5];
 
 	/* approximate the divisor for the Newton iteration */
 	c = sqrt((x[0] + x[1]) + x[2]);
@@ -353,8 +340,8 @@
 	t[4] = (rr * (r[0] + r[1]) + twom66) - twom66;
 
 	/* here we just need to get the sign of the remainder */
-	c = (((((r[0] - tt[0] * t[4]) - tt[1] * t[4]) + r[1])
-		- tt[2] * t[4]) - (t[3] + t[3]) * t[4]) - t[4] * t[4];
+	c = (((((r[0] - tt[0] * t[4]) - tt[1] * t[4]) + r[1]) - tt[2] * t[4]) -
+	    (t[3] + t[3]) * t[4]) - t[4] * t[4];
 
 	/* reduce to three doubles */
 	t[0] += t[1];
@@ -362,8 +349,7 @@
 	t[2] = t[4];
 
 	/* if the third term might lie on a rounding boundary, perturb it */
-	if (c != zero && t[2] == (twom62 + t[2]) - twom62)
-	{
+	if (c != zero && t[2] == (twom62 + t[2]) - twom62) {
 		if (c < zero)
 			t[2] -= twom124;
 		else
@@ -377,30 +363,27 @@
 	c = t[0] + t[1];
 	s[1] = t[1] + (t[0] - c);
 	s[0] = c;
-	if (s[1] == zero)
-	{
+
+	if (s[1] == zero) {
 		c = s[0] + t[2];
 		s[1] = t[2] + (s[0] - c);
 		s[0] = c;
 		s[2] = zero;
-	}
-	else
-	{
+	} else {
 		c = s[1] + t[2];
 		s[2] = t[2] + (s[1] - c);
 		s[1] = c;
 	}
 }
 
-
 long double
 sqrtl(long double ldx)
 {
-	union	longdouble		x;
-	volatile double			t;
-	double					xx[5], zz[3];
-	enum fp_direction_type	rm;
-	int				ex, inexact, exc, traps;
+	union   longdouble x;
+	volatile double t;
+	double xx[5], zz[3];
+	enum fp_direction_type rm;
+	int ex, inexact, exc, traps;
 
 	/* clear cexc */
 	t = zero;
@@ -408,39 +391,38 @@
 
 	/* check for zero operand */
 	x.d = ldx;
+
 	if (!((x.l.msw & 0x7fffffff) | x.l.frac2 | x.l.frac3 | x.l.frac4))
-		return ldx;
+		return (ldx);
 
 	/* handle nan and inf cases */
-	if ((x.l.msw & 0x7fffffff) >= 0x7fff0000)
-	{
-		if ((x.l.msw & 0xffff) | x.l.frac2 | x.l.frac3 | x.l.frac4)
-		{
-			if (!(x.l.msw & 0x8000))
-			{
+	if ((x.l.msw & 0x7fffffff) >= 0x7fff0000) {
+		if ((x.l.msw & 0xffff) | x.l.frac2 | x.l.frac3 | x.l.frac4) {
+			if (!(x.l.msw & 0x8000)) {
 				/* snan, signal invalid */
 				t += snan.d;
 			}
+
 			x.l.msw |= 0x8000;
-			return x.d;
+			return (x.d);
 		}
-		if (x.l.msw & 0x80000000)
-		{
+
+		if (x.l.msw & 0x80000000) {
 			/* sqrt(-inf), signal invalid */
 			t = -one;
 			t = sqrt(t);
-			return qnan.d;
+			return (qnan.d);
 		}
+
 		/* sqrt(inf), return inf */
-		return x.d;
+		return (x.d);
 	}
 
 	/* handle negative numbers */
-	if (x.l.msw & 0x80000000)
-	{
+	if (x.l.msw & 0x80000000) {
 		t = -one;
 		t = sqrt(t);
-		return qnan.d;
+		return (qnan.d);
 	}
 
 	/* now x is finite, positive */
@@ -450,8 +432,8 @@
 	rm = __swapRD(fp_nearest);
 
 	ex = __q_unpack(&x, xx);
-	if (ex & 1)
-	{
+
+	if (ex & 1) {
 		/* make exponent even */
 		xx[0] += xx[0];
 		xx[1] += xx[1];
@@ -460,6 +442,7 @@
 		xx[4] += xx[4];
 		ex--;
 	}
+
 	__q_tp_sqrt(xx, zz);
 
 	/* put everything together */
@@ -470,10 +453,11 @@
 	(void) __swapRD(rm);
 	(void) __swapEX(exc);
 	(void) __swapTE(traps);
-	if (inexact)
-	{
+
+	if (inexact) {
 		t = huge;
 		t += tiny;
 	}
-	return x.d;
+
+	return (x.d);
 }
--- old/usr/src/lib/libm/common/Q/tanhl.c	2019-06-06 20:39:00.419145638 +0000
+++ new/usr/src/lib/libm/common/Q/tanhl.c	2019-06-06 20:39:00.436883936 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -45,9 +46,9 @@
  *     threshold <  x <= INF       :  tanhl(x) := 1.
  *
  * where
- *	single : 	small = 1.e-5		threshold = 11.0
- *	double : 	small = 1.e-10		threshold = 22.0
- *	quad   : 	small = 1.e-20		threshold = 45.0
+ *	single :        small = 1.e-5		threshold = 11.0
+ *	double :        small = 1.e-10		threshold = 22.0
+ *	quad   :        small = 1.e-20		threshold = 45.0
  *
  * Note: threshold was chosen so that
  *		fl(1.0+2/(expm1(2*threshold)+2)) == 1.
@@ -60,41 +61,49 @@
 #include "libm.h"
 #include "longdouble.h"
 
-static const long double small = 1.0e-20L, one = 1.0, two = 2.0,
+static const long double small = 1.0e-20L,
+	one = 1.0,
+	two = 2.0,
 #ifndef lint
 	big = 1.0e+20L,
 #endif
 	threshold = 45.0L;
 
 long double
-tanhl(long double x) {
+tanhl(long double x)
+{
 	long double t, y, z;
 	int signx;
+
 #ifndef lint
 	volatile long double dummy;
 #endif
 
 	if (isnanl(x))
 		return (x + x);		/* x is NaN */
+
 	signx = signbitl(x);
 	t = fabsl(x);
 	z = one;
+
 	if (t <= threshold) {
-		if (t > one)
+		if (t > one) {
 			z = one - two / (expm1l(t + t) + two);
-		else if (t > small) {
+		} else if (t > small) {
 			y = expm1l(-t - t);
 			z = -y / (y + two);
 		} else {
 #ifndef lint
 			dummy = t + big;
-							/* inexact if t != 0 */
+			/* inexact if t != 0 */
 #endif
 			return (x);
 		}
-	} else if (!finitel(t))
+	} else if (!finitel(t)) {
 		return (copysignl(one, x));
-	else
+	} else {
 		return (signx ? -z + small * small : z - small * small);
+	}
+
 	return (signx ? -z : z);
 }
--- old/usr/src/lib/libm/common/Q/tanl.c	2019-06-06 20:39:00.937972421 +0000
+++ new/usr/src/lib/libm/common/Q/tanl.c	2019-06-06 20:39:00.957285294 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -64,17 +65,19 @@
 #include "longdouble.h"
 
 long double
-tanl(long double x) {
+tanl(long double x)
+{
 	long double y[2], z = 0.0L;
 	int n, ix;
 
-	ix = *(int *) &x;		/* High word of x */
+	ix = *(int *)&x;		/* High word of x */
 	ix &= 0x7fffffff;
-	if (ix <= 0x3ffe9220)		/* |x| ~< pi/4 */
+
+	if (ix <= 0x3ffe9220) {		/* |x| ~< pi/4 */
 		return (__k_tanl(x, z, 0));
-	else if (ix >= 0x7fff0000)	/* trig(Inf or NaN) is NaN */
+	} else if (ix >= 0x7fff0000) {	/* trig(Inf or NaN) is NaN */
 		return (x - x);
-	else {				/* argument reduction needed */
+	} else {			/* argument reduction needed */
 		n = __rem_pio2l(x, y);
 		return (__k_tanl(y[0], y[1], (n & 1)));
 	}
--- old/usr/src/lib/libm/common/R/_TBL_r_atan_.c	2019-06-06 20:39:01.428346182 +0000
+++ new/usr/src/lib/libm/common/R/_TBL_r_atan_.c	2019-06-06 20:39:01.445930800 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/R/__cosf.c	2019-06-06 20:39:01.927584383 +0000
+++ new/usr/src/lib/libm/common/R/__cosf.c	2019-06-06 20:39:01.944931378 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #include "libm.h"
 
-/* INDENT OFF */
+
 /*
  * float __k_cos(double x);
  * kernel (float) cos function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -52,35 +53,38 @@
  * from decimal to binary accurately enough to produce the hexadecimal values
  * shown.
  */
-/* INDENT ON */
 
 static const double q[] = {
-/* C0 = */   1.09349482127188401868272000389539985058873853699e-0003,
-/* C1 = */  -5.03324285989964979398034700054920226866107675091e-0004,
-/* C2 = */   2.43792880266971107750418061559602239831538067410e-0005,
-/* C3 = */   9.14499072605666582228127405245558035523741471271e+0002,
-/* C4 = */  -3.63151270591815439197122504991683846785293207730e+0001,
-};
-
-#define	C0	q[0]
-#define	C1	q[1]
-#define	C2	q[2]
-#define	C3	q[3]
-#define	C4	q[4]
+/* C0 = */
+	1.09349482127188401868272000389539985058873853699e-0003,
+/* C1 = */ -5.03324285989964979398034700054920226866107675091e-0004,
+/* C2 = */ 2.43792880266971107750418061559602239831538067410e-0005,
+/* C3 = */ 9.14499072605666582228127405245558035523741471271e+0002,
+/* C4 = */ -3.63151270591815439197122504991683846785293207730e+0001, };
+
+#define	C0		q[0]
+#define	C1		q[1]
+#define	C2		q[2]
+#define	C3		q[3]
+#define	C4		q[4]
 
 float
-__k_cosf(double x) {
+__k_cosf(double x)
+{
 	float ft;
 	double z;
 	int hx;
 
-	hx = ((int *) &x)[HIWORD];	/* hx = leading x  */
+	hx = ((int *)&x)[HIWORD];		/* hx = leading x  */
+
 	if ((hx & ~0x80000000) < 0x3f100000) {	/* |x| < 2**-14 */
-		ft = (float) 1;
-		if (((int) x) == 0)	/* raise inexact if x != 0 */
+		ft = (float)1;
+
+		if (((int)x) == 0)		/* raise inexact if x != 0 */
 			return (ft);
 	}
+
 	z = x * x;
-	ft = (float) (((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 + z)));
+	ft = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 + z)));
 	return (ft);
 }
--- old/usr/src/lib/libm/common/R/__sincosf.c	2019-06-06 20:39:02.397758555 +0000
+++ new/usr/src/lib/libm/common/R/__sincosf.c	2019-06-06 20:39:02.414616620 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #include "libm.h"
 
-/* INDENT OFF */
+
 /*
  * void __k_sincosf(double x, float *s, float *c);
  * kernel (float) sincos function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -58,44 +59,47 @@
  * from decimal to binary accurately enough to produce the hexadecimal values
  * shown.
  */
-/* INDENT ON */
 
 static const double q[] = {
-/* S0 = */  1.85735322054308378716204874632872525989806770558e-0003,
+/* S0 = */
+	1.85735322054308378716204874632872525989806770558e-0003,
 /* S1 = */ -1.95035094218403635082921458859320791358115801259e-0004,
-/* S2 = */  5.38400550766074785970952495168558701485841707252e+0002,
+/* S2 = */ 5.38400550766074785970952495168558701485841707252e+0002,
 /* S3 = */ -3.31975110777873728964197739157371509422022905947e+0001,
-/* C0 = */  1.09349482127188401868272000389539985058873853699e-0003,
+/* C0 = */ 1.09349482127188401868272000389539985058873853699e-0003,
 /* C1 = */ -5.03324285989964979398034700054920226866107675091e-0004,
-/* C2 = */  2.43792880266971107750418061559602239831538067410e-0005,
-/* C3 = */  9.14499072605666582228127405245558035523741471271e+0002,
-/* C4 = */ -3.63151270591815439197122504991683846785293207730e+0001,
-};
-
-
-#define	S0	q[0]
-#define	S1	q[1]
-#define	S2	q[2]
-#define	S3	q[3]
-#define	C0	q[4]
-#define	C1	q[5]
-#define	C2	q[6]
-#define	C3	q[7]
-#define	C4	q[8]
+/* C2 = */ 2.43792880266971107750418061559602239831538067410e-0005,
+/* C3 = */ 9.14499072605666582228127405245558035523741471271e+0002,
+/* C4 = */ -3.63151270591815439197122504991683846785293207730e+0001, };
+
+#define	S0		q[0]
+#define	S1		q[1]
+#define	S2		q[2]
+#define	S3		q[3]
+#define	C0		q[4]
+#define	C1		q[5]
+#define	C2		q[6]
+#define	C3		q[7]
+#define	C4		q[8]
 
 void
-__k_sincosf(double x, float *s, float *c) {
+__k_sincosf(double x, float *s, float *c)
+{
 	double z;
 	int hx;
 
-	hx = ((int *) &x)[HIWORD];	/* hx = leading x */
+	hx = ((int *)&x)[HIWORD];		/* hx = leading x */
+
 	/* small argument */
 	if ((hx & ~0x80000000) < 0x3f100000) {	/* if |x| < 2**-14 */
-		*s = (float) x; *c = (float) 1;
-		if ((int) x == 0)	/* raise inexact if x != 0 */
+		*s = (float)x;
+		*c = (float)1;
+
+		if ((int)x == 0)	/* raise inexact if x != 0 */
 			return;
 	}
+
 	z = x * x;
-	*s = (float) ((x * (S0 + z * S1)) * (S2 + z * (S3 + z)));
-	*c = (float) (((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 + z)));
+	*s = (float)((x * (S0 + z * S1)) * (S2 + z * (S3 + z)));
+	*c = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 + z)));
 }
--- old/usr/src/lib/libm/common/R/__sinf.c	2019-06-06 20:39:02.870880988 +0000
+++ new/usr/src/lib/libm/common/R/__sinf.c	2019-06-06 20:39:02.887659642 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #include "libm.h"
 
-/* INDENT OFF */
+
 /*
  * float __k_sin(double x);
  * kernel (float) sin function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -51,33 +52,36 @@
  * from decimal to binary accurately enough to produce the hexadecimal values
  * shown.
  */
-/* INDENT ON */
 
 static const double q[] = {
-/* S0 = */  1.85735322054308378716204874632872525989806770558e-0003,
+/* S0 = */
+	1.85735322054308378716204874632872525989806770558e-0003,
 /* S1 = */ -1.95035094218403635082921458859320791358115801259e-0004,
-/* S2 = */  5.38400550766074785970952495168558701485841707252e+0002,
-/* S3 = */ -3.31975110777873728964197739157371509422022905947e+0001,
-};
-
-#define	S0  q[0]
-#define	S1  q[1]
-#define	S2  q[2]
-#define	S3  q[3]
+/* S2 = */ 5.38400550766074785970952495168558701485841707252e+0002,
+/* S3 = */ -3.31975110777873728964197739157371509422022905947e+0001, };
+
+#define	S0		q[0]
+#define	S1		q[1]
+#define	S2		q[2]
+#define	S3		q[3]
 
 float
-__k_sinf(double x) {
+__k_sinf(double x)
+{
 	float ft;
 	double z;
 	int hx;
 
-	hx = ((int *) &x)[HIWORD];	/* hx = leading x */
+	hx = ((int *)&x)[HIWORD];		/* hx = leading x */
+
 	if ((hx & ~0x80000000) < 0x3f100000) {	/* if |x| < 2**-14 */
-		ft = (float) x;
-		if ((int) x == 0)	/* raise inexact if x != 0 */
+		ft = (float)x;
+
+		if ((int)x == 0)		/* raise inexact if x != 0 */
 			return (ft);
 	}
+
 	z = x * x;
-	ft = (float) ((x * (S0 + z * S1)) * (S2 + z * (S3 + z)));
+	ft = (float)((x * (S0 + z * S1)) * (S2 + z * (S3 + z)));
 	return (ft);
 }
--- old/usr/src/lib/libm/common/R/__tanf.c	2019-06-06 20:39:03.347248282 +0000
+++ new/usr/src/lib/libm/common/R/__tanf.c	2019-06-06 20:39:03.366517172 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #include "libm.h"
 
-/* INDENT OFF */
+
 /*
  * float __k_tan(double x);
  * kernel (float) tan function on [-pi/4, pi/4], pi/4 ~ 0.785398164
@@ -43,54 +44,59 @@
  */
 
 static const double q[] = {
-/* one */ 1.0,
-/* P0 */  4.46066928428959230679140546271810308098793029785e-0003,
-/* P1 */  4.92165316309189027066395283327437937259674072266e+0000,
+/* one */
+	1.0,
+/* P0 */ 4.46066928428959230679140546271810308098793029785e-0003,
+/* P1 */ 4.92165316309189027066395283327437937259674072266e+0000,
 /* P2 */ -7.11410648161473480044492134766187518835067749023e-0001,
-/* P3 */  4.08549808374053391446523164631798863410949707031e+0000,
-/* P4 */  2.50411070398050927821032018982805311679840087891e+0000,
-/* P5 */  1.11492064560251158411574579076841473579406738281e+0001,
+/* P3 */ 4.08549808374053391446523164631798863410949707031e+0000,
+/* P4 */ 2.50411070398050927821032018982805311679840087891e+0000,
+/* P5 */ 1.11492064560251158411574579076841473579406738281e+0001,
 /* P6 */ -1.50565540968422650891511693771462887525558471680e+0000,
 /* P7 */ -1.81484378878349295050043110677506774663925170898e+0000,
-/* T0 */  3.333335997532835641297409611782510896641e-0001,
-/* T1 */  2.999997598248363761541668282006867229939e+00,
+/* T0 */ 3.333335997532835641297409611782510896641e-0001,
+/* T1 */ 2.999997598248363761541668282006867229939e+00,
 };
-/* INDENT ON */
 
-#define	one q[0]
-#define	P0 q[1]
-#define	P1 q[2]
-#define	P2 q[3]
-#define	P3 q[4]
-#define	P4 q[5]
-#define	P5 q[6]
-#define	P6 q[7]
-#define	P7 q[8]
-#define	T0 q[9]
-#define	T1 q[10]
+
+#define	one		q[0]
+#define	P0		q[1]
+#define	P1		q[2]
+#define	P2		q[3]
+#define	P3		q[4]
+#define	P4		q[5]
+#define	P5		q[6]
+#define	P6		q[7]
+#define	P7		q[8]
+#define	T0		q[9]
+#define	T1		q[10]
 
 float
-__k_tanf(double x, int n) {
+__k_tanf(double x, int n)
+{
 	float ft = 0.0;
 	double z, w;
 	int ix;
 
-	ix = ((int *) &x)[HIWORD] & ~0x80000000;	/* ix = leading |x| */
+	ix = ((int *)&x)[HIWORD] & ~0x80000000;	/* ix = leading |x| */
+
 	/* small argument */
-	if (ix < 0x3f800000) {		/* if |x| < 0.0078125 = 2**-7 */
-		if (ix < 0x3f100000) {	/* if |x| < 2**-14 */
-			if ((int) x == 0) {	/* raise inexact if x != 0 */
-				ft = n == 0 ? (float) x : (float) (-one / x);
-			}
+	if (ix < 0x3f800000) {			/* if |x| < 0.0078125 = 2**-7 */
+		if (ix < 0x3f100000) {		/* if |x| < 2**-14 */
+			if ((int)x == 0)	/* raise inexact if x != 0 */
+				ft = n == 0 ? (float)x : (float)(-one / x);
+
 			return (ft);
 		}
+
 		z = (x * T0) * (T1 + x * x);
-		ft = n == 0 ? (float) z : (float) (-one / z);
+		ft = n == 0 ? (float)z : (float)(-one / z);
 		return (ft);
 	}
+
 	z = x * x;
-	w = ((P0 * x) * (P1 + z * (P2 + z)) * (P3 + z * (P4 + z)))
-		* (P5 + z * (P6 + z * (P7 + z)));
-	ft = n == 0 ? (float) w : (float) (-one / w);
+	w = ((P0 * x) * (P1 + z * (P2 + z)) * (P3 + z * (P4 + z))) * (P5 + z *
+	    (P6 + z * (P7 + z)));
+	ft = n == 0 ? (float)w : (float)(-one / w);
 	return (ft);
 }
--- old/usr/src/lib/libm/common/R/acosf.c	2019-06-06 20:39:03.788055528 +0000
+++ new/usr/src/lib/libm/common/R/acosf.c	2019-06-06 20:39:03.803931618 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,11 +35,14 @@
 static const float zero = 0.0f;
 
 float
-acosf(float x) {
-	int	ix;
+acosf(float x)
+{
+	int ix;
 
 	ix = *(int *)&x & ~0x80000000;
-	if (ix > 0x3f800000)	/* |x| > 1 or x is nan */
+
+	if (ix > 0x3f800000)		/* |x| > 1 or x is nan */
 		return ((x * zero) / zero);
+
 	return ((float)acos((double)x));
 }
--- old/usr/src/lib/libm/common/R/acoshf.c	2019-06-06 20:39:04.277906567 +0000
+++ new/usr/src/lib/libm/common/R/acoshf.c	2019-06-06 20:39:04.295149447 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,11 +35,14 @@
 static const float zero = 0.0f;
 
 float
-acoshf(float x) {
-	int	hx;
+acoshf(float x)
+{
+	int hx;
 
 	hx = *(int *)&x;
+
 	if (hx < 0x3f800000 || hx > 0x7f800000)	/* x < 1 or x is nan */
 		return ((x * zero) / zero);
+
 	return ((float)acosh((double)x));
 }
--- old/usr/src/lib/libm/common/R/asinf.c	2019-06-06 20:39:04.791466374 +0000
+++ new/usr/src/lib/libm/common/R/asinf.c	2019-06-06 20:39:04.808827395 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,11 +35,14 @@
 static const float zero = 0.0f;
 
 float
-asinf(float x) {
-	int	ix;
+asinf(float x)
+{
+	int ix;
 
 	ix = *(int *)&x & ~0x80000000;
-	if (ix > 0x3f800000)	/* |x| > 1 or x is nan */
+
+	if (ix > 0x3f800000)		/* |x| > 1 or x is nan */
 		return ((x * zero) / zero);
+
 	return ((float)asin((double)x));
 }
--- old/usr/src/lib/libm/common/R/asinhf.c	2019-06-06 20:39:05.294430629 +0000
+++ new/usr/src/lib/libm/common/R/asinhf.c	2019-06-06 20:39:05.313276192 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,10 +33,10 @@
 #include "libm.h"
 
 float
-asinhf(float x) {
-	if (isnanf(x)) {
+asinhf(float x)
+{
+	if (isnanf(x))
 		return (x * x);		/* + -> * for Cheetah */
-	} else {
-		return ((float) asinh((double) x));
-	}
+	else
+		return ((float)asinh((double)x));
 }
--- old/usr/src/lib/libm/common/R/atan2f.c	2019-06-06 20:39:05.803084834 +0000
+++ new/usr/src/lib/libm/common/R/atan2f.c	2019-06-06 20:39:05.821305583 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -237,23 +239,23 @@
 };
 
 static const double
-	pio4	=  7.8539816339744827900e-01,
-	pio2	=  1.5707963267948965580e+00,
-	negpi	= -3.1415926535897931160e+00,
-	q1	= -3.3333333333296428046e-01,
-	q2	=  1.9999999186853752618e-01,
-	zero	=  0.0;
-
+	pio4 = 7.8539816339744827900e-01,
+	pio2 = 1.5707963267948965580e+00,
+	negpi = -3.1415926535897931160e+00,
+	q1 = -3.3333333333296428046e-01,
+	q2 = 1.9999999186853752618e-01,
+	zero = 0.0;
 static const float two24 = 16777216.0;
 
 float
 atan2f(float fy, float fx)
 {
-	double	a, t, s, dbase;
-	float	x, y, base;
-	int	i, k, hx, hy, ix, iy, sign;
+	double a, t, s, dbase;
+	float x, y, base;
+	int i, k, hx, hy, ix, iy, sign;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	iy = *(int *)&fy;
@@ -262,16 +264,19 @@
 	hx = ix & ~0x80000000;
 
 	sign = 0;
+
 	if (hy > hx) {
 		x = fy;
 		y = fx;
 		i = hx;
 		hx = hy;
 		hy = i;
+
 		if (iy < 0) {
 			x = -x;
 			sign = 1;
 		}
+
 		if (ix < 0) {
 			y = -y;
 			a = pio2;
@@ -282,10 +287,12 @@
 	} else {
 		y = fy;
 		x = fx;
+
 		if (iy < 0) {
 			y = -y;
 			sign = 1;
 		}
+
 		if (ix < 0) {
 			x = -x;
 			a = negpi;
@@ -297,19 +304,21 @@
 
 	if (hx >= 0x7f800000 || hx - hy >= 0x0c800000) {
 		if (hx >= 0x7f800000) {
-			if (hx > 0x7f800000) /* nan */
+			if (hx > 0x7f800000)	/* nan */
 				return (x * y);
 			else if (hy >= 0x7f800000)
 				a += pio4;
 		} else if ((int)a == 0) {
 			a = (double)y / x;
 		}
-		return ((float)((sign)? -a : a));
+
+		return ((float)((sign) ? -a : a));
 	}
 
 	if (hy < 0x00800000) {
 		if (hy == 0)
-			return ((float)((sign)? -a : a));
+			return ((float)((sign) ? -a : a));
+
 		/* scale subnormal y */
 		y *= two24;
 		x *= two24;
@@ -321,7 +330,8 @@
 	rp = __swapRP(fp_extended);
 #endif
 	k = (hy - hx + 0x3f800000) & 0xfff80000;
-	if (k >= 0x3c800000) {	/* |y/x| >= 1/64 */
+
+	if (k >= 0x3c800000) {		/* |y/x| >= 1/64 */
 		*(int *)&base = k;
 		k = (k - 0x3c800000) >> 19;
 		a += TBL[k];
@@ -332,6 +342,7 @@
 		 */
 		*(int *)&base = 0;
 	}
+
 	dbase = (double)base;
 	t = (y - x * dbase) / (x + y * dbase);
 	s = t * t;
@@ -340,5 +351,5 @@
 	if (rp != fp_extended)
 		(void) __swapRP(rp);
 #endif
-	return ((float)((sign)? -a : a));
+	return ((float)((sign) ? -a : a));
 }
--- old/usr/src/lib/libm/common/R/atan2pif.c	2019-06-06 20:39:06.319091976 +0000
+++ new/usr/src/lib/libm/common/R/atan2pif.c	2019-06-06 20:39:06.337420097 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,20 +33,25 @@
 static const double invpi = 0.3183098861837906715377675;
 
 float
-atan2pif(float y, float x) {
-	int	ix, iy, hx, hy;
+atan2pif(float y, float x)
+{
+	int ix, iy, hx, hy;
 
 	ix = *(int *)&x;
 	iy = *(int *)&y;
 	hx = ix & ~0x80000000;
 	hy = iy & ~0x80000000;
-	if (hx > 0x7f800000 || hy > 0x7f800000) /* x or y is nan */
+
+	if (hx > 0x7f800000 || hy > 0x7f800000)	/* x or y is nan */
 		return (x * y);
+
 	if ((hx | hy) == 0) {
 		/* x and y are both zero */
 		if (ix == 0)
 			return (y);
-		return ((iy == 0)? 1.0f : -1.0f);
+
+		return ((iy == 0) ? 1.0f : -1.0f);
 	}
+
 	return ((float)(invpi * atan2((double)y, (double)x)));
 }
--- old/usr/src/lib/libm/common/R/atanf.c	2019-06-06 20:39:06.819030324 +0000
+++ new/usr/src/lib/libm/common/R/atanf.c	2019-06-06 20:39:06.836649550 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __atanf = atanf
 
-/* INDENT OFF */
+
 /*
  * float atanf(float x);
  * Table look-up algorithm
@@ -40,9 +41,9 @@
  * The algorithm is based on atan(x)=atan(y)+atan((x-y)/(1+x*y)).
  * We use poly1(x) to approximate atan(x) for x in [0,1/8] with
  * error (relative)
- * 	|(atan(x)-poly1(x))/x|<= 2^-115.94 	long double
- * 	|(atan(x)-poly1(x))/x|<= 2^-58.85	double
- * 	|(atan(x)-poly1(x))/x|<= 2^-25.53 	float
+ *      |(atan(x)-poly1(x))/x|<= 2^-115.94      long double
+ *      |(atan(x)-poly1(x))/x|<= 2^-58.85	double
+ *      |(atan(x)-poly1(x))/x|<= 2^-25.53       float
  * and use poly2(x) to approximate atan(x) for x in [0,1/65] with
  * error (absolute)
  *	|atan(x)-poly2(x)|<= 2^-122.15		long double
@@ -50,7 +51,7 @@
  *	|atan(x)-poly2(x)|<= 2^-35.36		float
  * and use poly3(x) to approximate atan(x) for x in [1/8,7/16] with
  * error (relative, on for single precision)
- * 	|(atan(x)-poly1(x))/x|<= 2^-25.53 	float
+ *      |(atan(x)-poly1(x))/x|<= 2^-25.53       float
  *
  * Here poly1-3 are odd polynomial with the following form:
  *		x + x^3*(a1+x^2*(a2+...))
@@ -86,42 +87,44 @@
 #include "libm.h"
 
 extern const float _TBL_r_atan_hi[], _TBL_r_atan_lo[];
-static const float
-	big	=   1.0e37F,
-	one	=   1.0F,
-	p1	=  -3.333185951111688247225368498733544672172e-0001F,
-	p2	=   1.969352894213455405211341983203180636021e-0001F,
-	q1	=  -3.332921964095646819563419704110132937456e-0001F,
-	a1	=  -3.333323465223893614063523351509338934592e-0001F,
-	a2	=   1.999425625935277805494082274808174062403e-0001F,
-	a3	=  -1.417547090509737780085769846290301788559e-0001F,
-	a4	=   1.016250813871991983097273733227432685084e-0001F,
-	a5	=  -5.137023693688358515753093811791755221805e-0002F,
-	pio2hi	=   1.570796371e+0000F,
-	pio2lo	=  -4.371139000e-0008F;
-/* INDENT ON */
+static const float big = 1.0e37F,
+	one = 1.0F,
+	p1 = -3.333185951111688247225368498733544672172e-0001F,
+	p2 = 1.969352894213455405211341983203180636021e-0001F,
+	q1 = -3.332921964095646819563419704110132937456e-0001F,
+	a1 = -3.333323465223893614063523351509338934592e-0001F,
+	a2 = 1.999425625935277805494082274808174062403e-0001F,
+	a3 = -1.417547090509737780085769846290301788559e-0001F,
+	a4 = 1.016250813871991983097273733227432685084e-0001F,
+	a5 = -5.137023693688358515753093811791755221805e-0002F,
+	pio2hi = 1.570796371e+0000F,
+	pio2lo = -4.371139000e-0008F;
+
 
 float
-atanf(float xx) {
+atanf(float xx)
+{
 	float x, y, z, r, p, s;
 	volatile double dummy __unused;
 	int ix, iy, sign, j;
 
 	x = xx;
-	ix = *(int *) &x;
+	ix = *(int *)&x;
 	sign = ix & 0x80000000;
 	ix ^= sign;
 
 	/* for |x| < 1/8 */
 	if (ix < 0x3e000000) {
-		if (ix < 0x38800000) {	/* if |x| < 2**(-prec/2-2) */
+		if (ix < 0x38800000) {		/* if |x| < 2**(-prec/2-2) */
 			dummy = big + x;	/* get inexact flag if x != 0 */
 #ifdef lint
 			dummy = dummy;
 #endif
 			return (x);
 		}
+
 		z = x * x;
+
 		if (ix < 0x3c000000) {	/* if |x| < 2**(-prec/4-1) */
 			x = x + (x * z) * p1;
 			return (x);
@@ -133,25 +136,26 @@
 
 	/* for |x| >= 8.0 */
 	if (ix >= 0x41000000) {
-		*(int *) &x = ix;
-		if (ix < 0x42820000) {	/* x <  65 */
+		*(int *)&x = ix;
+
+		if (ix < 0x42820000) {				/* x <  65 */
 			r = one / x;
 			z = r * r;
 			y = r * (one + z * (p1 + z * p2));	/* poly1 */
 			y -= pio2lo;
-		} else if (ix < 0x44800000) {	/* x <  2**(prec/3+2) */
+		} else if (ix < 0x44800000) { /* x <  2**(prec/3+2) */
 			r = one / x;
 			z = r * r;
 			y = r * (one + z * q1);	/* poly2 */
 			y -= pio2lo;
-		} else if (ix < 0x4c800000) {	/* x <  2**(prec+2) */
+		} else if (ix < 0x4c800000) { /* x <  2**(prec+2) */
 			y = one / x - pio2lo;
-		} else if (ix < 0x7f800000) {	/* x <  inf */
+		} else if (ix < 0x7f800000) { /* x <  inf */
 			y = -pio2lo;
-		} else {		/* x is inf or NaN */
-			if (ix > 0x7f800000) {
+		} else {	/* x is inf or NaN */
+			if (ix > 0x7f800000)
 				return (x * x);	/* - -> * for Cheetah */
-			}
+
 			y = -pio2lo;
 		}
 
@@ -159,32 +163,35 @@
 			x = pio2hi - y;
 		else
 			x = y - pio2hi;
+
 		return (x);
 	}
 
-
 	/* now x is between 1/8 and 8 */
-	if (ix < 0x3f000000) {	/* between 1/8 and 1/2 */
+	if (ix < 0x3f000000) {		/* between 1/8 and 1/2 */
 		z = x * x;
-		x = x + (x * z) * (a1 + z * (a2 + z * (a3 + z * (a4 +
-			z * a5))));
+		x = x + (x * z) * (a1 + z * (a2 + z * (a3 + z * (a4 + z *
+		    a5))));
 		return (x);
 	}
-	*(int *) &x = ix;
+
+	*(int *)&x = ix;
 	iy = (ix + 0x00040000) & 0x7ff80000;
-	*(int *) &y = iy;
+	*(int *)&y = iy;
 	j = (iy - 0x3f000000) >> 19;
 
-	if (ix == iy)
-		p = x - y;	/* p=0.0 */
-	else {
+	if (ix == iy) {
+		p = x - y;		/* p=0.0 */
+	} else {
 		if (sign == 0)
 			s = (x - y) / (one + x * y);
 		else
 			s = (y - x) / (one + x * y);
+
 		z = s * s;
 		p = s * (one + z * q1);
 	}
+
 	if (sign == 0) {
 		r = p + _TBL_r_atan_lo[j];
 		x = r + _TBL_r_atan_hi[j];
@@ -192,5 +199,6 @@
 		r = p - _TBL_r_atan_lo[j];
 		x = r - _TBL_r_atan_hi[j];
 	}
+
 	return (x);
 }
--- old/usr/src/lib/libm/common/R/atanhf.c	2019-06-06 20:39:07.349884205 +0000
+++ new/usr/src/lib/libm/common/R/atanhf.c	2019-06-06 20:39:07.369361514 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,13 +35,17 @@
 static const float zero = 0.0f;
 
 float
-atanhf(float x) {
-	int	ix;
+atanhf(float x)
+{
+	int ix;
 
 	ix = *((int *)&x) & ~0x80000000;
-	if (ix > 0x3f800000)	/* |x| > 1 or x is nan */
+
+	if (ix > 0x3f800000)		/* |x| > 1 or x is nan */
 		return ((x * zero) / zero);
-	if (ix == 0x3f800000)	/* |x| == 1 */
+
+	if (ix == 0x3f800000)		/* |x| == 1 */
 		return (x / zero);
+
 	return ((float)atanh((double)x));
 }
--- old/usr/src/lib/libm/common/R/besself.c	2019-06-06 20:39:07.840461031 +0000
+++ new/usr/src/lib/libm/common/R/besself.c	2019-06-06 20:39:07.859854849 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -40,9 +42,7 @@
 extern int __swapRP(int);
 #endif
 
-static const float
-	zerof	= 0.0f,
-	onef	= 1.0f;
+static const float zerof = 0.0f, onef = 1.0f;
 
 static const double C[] = {
 	0.0,
@@ -54,21 +54,21 @@
 	2.0,
 	8.0,
 	0.5641895835477562869480794515607725858441,	/* 1/sqrt(pi) */
-	0.636619772367581343075535053490057448,	/* 2/pi */
+	0.636619772367581343075535053490057448,		/* 2/pi */
 	1.0e9,
 };
 
-#define	zero	C[0]
-#define	neighth	C[1]
-#define	quarter	C[2]
-#define	three8	C[3]
-#define	half	C[4]
-#define	one	C[5]
-#define	two	C[6]
-#define	eight   C[7]
-#define	isqrtpi	C[8]
-#define	tpi	C[9]
-#define	big	C[10]
+#define	zero		C[0]
+#define	neighth		C[1]
+#define	quarter		C[2]
+#define	three8		C[3]
+#define	half		C[4]
+#define	one		C[5]
+#define	two		C[6]
+#define	eight		C[7]
+#define	isqrtpi		C[8]
+#define	tpi		C[9]
+#define	big		C[10]
 
 static const double Cj0y0[] = {
 	0.4861344183386052721391238447e5,	/* pr */
@@ -101,17 +101,17 @@
 	1.0,
 };
 
-#define	pr	Cj0y0
-#define	ps	(Cj0y0+7)
-#define	qr	(Cj0y0+14)
-#define	qs	(Cj0y0+21)
+#define	pr		Cj0y0
+#define	ps		(Cj0y0 + 7)
+#define	qr		(Cj0y0 + 14)
+#define	qs		(Cj0y0 + 21)
 
 static const double Cj0[] = {
 	-2.500000000000003622131880894830476755537e-0001,	/* r0 */
 	1.095597547334830263234433855932375353303e-0002,
 	-1.819734750463320921799187258987098087697e-0004,
 	9.977001946806131657544212501069893930846e-0007,
-	1.0,							/* s0 */
+	1.0,	/* s0 */
 	1.867609810662950169966782360588199673741e-0002,
 	1.590389206181565490878430827706972074208e-0004,
 	6.520867386742583632375520147714499522721e-0007,
@@ -124,7 +124,7 @@
 	5.072306160724884775085431059052611737827e-0011,
 	-8.187060730684066824228914775146536139112e-0014,
 	5.422219326959949863954297860723723423842e-0017,
-	1.0,							/* s1 */
+	1.0,	/* s1 */
 	1.101122772686807702762104741932076228349e-0002,
 	6.140169310641649223411427764669143978228e-0005,
 	2.292035877515152097976946119293215705250e-0007,
@@ -135,10 +135,10 @@
 	2.073101088320349159764410261466350732968e-0021,
 };
 
-#define	r0	Cj0
-#define	s0	(Cj0+4)
-#define	r1	(Cj0+8)
-#define	s1	(Cj0+17)
+#define	r0		Cj0
+#define	s0		(Cj0 + 4)
+#define	r1		(Cj0 + 8)
+#define	s1		(Cj0 + 17)
 
 static const double Cy0[] = {
 	-7.380429510868722526754723020704317641941e-0002,	/* u0 */
@@ -154,15 +154,15 @@
 	-9.060556574619677567323741194079797987200e-0021,
 	7.124435467408860515265552217131230511455e-0024,
 	-2.709726774636397615328813121715432044771e-0027,
-	1.0,							/* v0 */
+	1.0,	/* v0 */
 	4.678678931512549002587702477349214886475e-0003,
 	9.486828955529948534822800829497565178985e-0006,
 	1.001495929158861646659010844136682454906e-0008,
 	4.725338116256021660204443235685358593611e-0012,
 };
 
-#define	u0	Cy0
-#define	v0	(Cy0+13)
+#define	u0		Cy0
+#define	v0		(Cy0 + 13)
 
 static const double Cj1y1[] = {
 	-0.4435757816794127857114720794e7,	/* pr0 */
@@ -191,17 +191,17 @@
 	0.8638367769604990967475517183e3,
 };
 
-#define	pr0	Cj1y1
-#define	ps0	(Cj1y1+6)
-#define	qr0	(Cj1y1+12)
-#define	qs0	(Cj1y1+18)
+#define	pr0		Cj1y1
+#define	ps0		(Cj1y1 + 6)
+#define	qr0		(Cj1y1 + 12)
+#define	qs0		(Cj1y1 + 18)
 
 static const double Cj1[] = {
 	-6.250000000000002203053200981413218949548e-0002,	/* a0 */
 	1.600998455640072901321605101981501263762e-0003,
 	-1.963888815948313758552511884390162864930e-0005,
 	8.263917341093549759781339713418201620998e-0008,
-	1.0e0,							/* b0 */
+	1.0e0,	/* b0 */
 	1.605069137643004242395356851797873766927e-0002,
 	1.149454623251299996428500249509098499383e-0004,
 	3.849701673735260970379681807910852327825e-0007,
@@ -217,24 +217,24 @@
 	-1.009457448277522275262808398517024439084e-0019,
 	8.520158355824819796968771418801019930585e-0023,
 	-3.458159926081163274483854614601091361424e-0026,
-	1.0e0,							/* b1 */
+	1.0e0,	/* b1 */
 	4.923499437590484879081138588998986303306e-0003,
 	1.054389489212184156499666953501976688452e-0005,
 	1.180768373106166527048240364872043816050e-0008,
 	5.942665743476099355323245707680648588540e-0012,
 };
 
-#define	a0	Cj1
-#define	b0	(Cj1+4)
-#define	a1	(Cj1+8)
-#define	b1	(Cj1+20)
+#define	a0		Cj1
+#define	b0		(Cj1 + 4)
+#define	a1		(Cj1 + 8)
+#define	b1		(Cj1 + 20)
 
 static const double Cy1[] = {
 	-1.960570906462389461018983259589655961560e-0001,	/* c0 */
 	4.931824118350661953459180060007970291139e-0002,
 	-1.626975871565393656845930125424683008677e-0003,
 	1.359657517926394132692884168082224258360e-0005,
-	1.0e0,							/* d0 */
+	1.0e0,	/* d0 */
 	2.565807214838390835108224713630901653793e-0002,
 	3.374175208978404268650522752520906231508e-0004,
 	2.840368571306070719539936935220728843177e-0006,
@@ -251,32 +251,33 @@
 	2.020392498726806769468143219616642940371e-0019,
 	-1.761371948595104156753045457888272716340e-0022,
 	7.352828391941157905175042420249225115816e-0026,
-	1.0e0,							/* d1 */
+	1.0e0,	/* d1 */
 	5.029187436727947764916247076102283399442e-0003,
 	1.102693095808242775074856548927801750627e-0005,
 	1.268035774543174837829534603830227216291e-0008,
 	6.579416271766610825192542295821308730206e-0012,
 };
 
-#define	c0	Cy1
-#define	d0	(Cy1+4)
-#define	c1	(Cy1+9)
-#define	d1	(Cy1+21)
-
+#define	c0		Cy1
+#define	d0		(Cy1 + 4)
+#define	c1		(Cy1 + 9)
+#define	d1		(Cy1 + 21)
 
 /* core of j0f computation; assumes fx is finite */
 static double
 __k_j0f(float fx)
 {
-	double	x, z, s, c, ss, cc, r, t, p0, q0;
-	int	ix, i;
+	double x, z, s, c, ss, cc, r, t, p0, q0;
+	int ix, i;
 
 	ix = *(int *)&fx & ~0x80000000;
 	x = fabs((double)fx);
+
 	if (ix > 0x41000000) {
 		/* x > 8; see comments in j0.c */
 		s = sin(x);
 		c = cos(x);
+
 		if (signbit(s) != signbit(c)) {
 			ss = s - c;
 			cc = -cos(x + x) / ss;
@@ -284,6 +285,7 @@
 			cc = s + c;
 			ss = -cos(x + x) / cc;
 		}
+
 		if (ix > 0x501502f9) {
 			/* x > 1.0e10 */
 			p0 = one;
@@ -291,52 +293,63 @@
 		} else {
 			t = eight / x;
 			z = t * t;
-			p0 = (pr[0] + z * (pr[1] + z * (pr[2] + z * (pr[3] +
-			    z * (pr[4] + z * (pr[5] + z * pr[6])))))) /
-			    (ps[0] + z * (ps[1] + z * (ps[2] + z * (ps[3] +
-			    z * (ps[4] + z * (ps[5] + z))))));
+			p0 = (pr[0] + z * (pr[1] + z * (pr[2] + z * (pr[3] + z *
+			    (pr[4] + z * (pr[5] + z * pr[6])))))) / (ps[0] + z *
+			    (ps[1] + z * (ps[2] + z * (ps[3] + z * (ps[4] + z *
+			    (ps[5] + z))))));
 			q0 = ((qr[0] + z * (qr[1] + z * (qr[2] + z * (qr[3] +
-			    z * (qr[4] + z * (qr[5] + z * qr[6])))))) /
-			    (qs[0] + z * (qs[1] + z * (qs[2] + z * (qs[3] +
-			    z * (qs[4] + z * (qs[5] + z))))))) * t;
+			    z * (qr[4] + z * (qr[5] + z * qr[6])))))) / (qs[0] +
+			    z * (qs[1] + z * (qs[2] + z * (qs[3] + z * (qs[4] +
+			    z * (qs[5] + z))))))) * t;
 		}
+
 		return (isqrtpi * (p0 * cc - q0 * ss) / sqrt(x));
 	}
+
 	if (ix <= 0x3727c5ac) {
 		/* x <= 1.0e-5 */
-		if (ix <= 0x219392ef) /* x <= 1.0e-18 */
+		if (ix <= 0x219392ef)	/* x <= 1.0e-18 */
 			return (one - x);
+
 		return (one - x * x * quarter);
 	}
+
 	z = x * x;
+
 	if (ix <= 0x3fa3d70a) {
 		/* x <= 1.28 */
 		r = r0[0] + z * (r0[1] + z * (r0[2] + z * r0[3]));
 		s = s0[0] + z * (s0[1] + z * (s0[2] + z * s0[3]));
 		return (one + z * (r / s));
 	}
+
 	r = r1[8];
 	s = s1[8];
+
 	for (i = 7; i >= 0; i--) {
 		r = r * z + r1[i];
 		s = s * z + s1[i];
 	}
+
 	return (r / s);
 }
 
 float
 j0f(float fx)
 {
-	float	f;
-	int	ix;
+	float f;
+	int ix;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	ix = *(int *)&fx & ~0x80000000;
-	if (ix >= 0x7f800000) {			/* nan or inf */
+
+	if (ix >= 0x7f800000) {		/* nan or inf */
 		if (ix > 0x7f800000)
 			return (fx * fx);
+
 		return (zerof);
 	}
 
@@ -355,15 +368,17 @@
 static double
 __k_y0f(float fx)
 {
-	double	x, z, s, c, ss, cc, t, p0, q0, u, v;
-	int	ix, i;
+	double x, z, s, c, ss, cc, t, p0, q0, u, v;
+	int ix, i;
 
 	ix = *(int *)&fx;
 	x = (double)fx;
+
 	if (ix > 0x41000000) {
 		/* x > 8; see comments in j0.c */
 		s = sin(x);
 		c = cos(x);
+
 		if (signbit(s) != signbit(c)) {
 			ss = s - c;
 			cc = -cos(x + x) / ss;
@@ -371,6 +386,7 @@
 			cc = s + c;
 			ss = -cos(x + x) / cc;
 		}
+
 		if (ix > 0x501502f9) {
 			/* x > 1.0e10 */
 			p0 = one;
@@ -378,23 +394,28 @@
 		} else {
 			t = eight / x;
 			z = t * t;
-			p0 = (pr[0] + z * (pr[1] + z * (pr[2] + z * (pr[3] +
-			    z * (pr[4] + z * (pr[5] + z * pr[6])))))) /
-			    (ps[0] + z * (ps[1] + z * (ps[2] + z * (ps[3] +
-			    z * (ps[4] + z * (ps[5] + z))))));
+			p0 = (pr[0] + z * (pr[1] + z * (pr[2] + z * (pr[3] + z *
+			    (pr[4] + z * (pr[5] + z * pr[6])))))) / (ps[0] + z *
+			    (ps[1] + z * (ps[2] + z * (ps[3] + z * (ps[4] + z *
+			    (ps[5] + z))))));
 			q0 = ((qr[0] + z * (qr[1] + z * (qr[2] + z * (qr[3] +
-			    z * (qr[4] + z * (qr[5] + z * qr[6])))))) /
-			    (qs[0] + z * (qs[1] + z * (qs[2] + z * (qs[3] +
-			    z * (qs[4] + z * (qs[5] + z))))))) * t;
+			    z * (qr[4] + z * (qr[5] + z * qr[6])))))) / (qs[0] +
+			    z * (qs[1] + z * (qs[2] + z * (qs[3] + z * (qs[4] +
+			    z * (qs[5] + z))))))) * t;
 		}
+
 		return (isqrtpi * (p0 * ss + q0 * cc) / sqrt(x));
 	}
-	if (ix <= 0x219392ef) /* x <= 1.0e-18 */
+
+	if (ix <= 0x219392ef)		/* x <= 1.0e-18 */
 		return (u0[0] + tpi * log(x));
+
 	z = x * x;
 	u = u0[12];
+
 	for (i = 11; i >= 0; i--)
 		u = u * z + u0[i];
+
 	v = v0[0] + z * (v0[1] + z * (v0[2] + z * (v0[3] + z * v0[4])));
 	return (u / v + tpi * (__k_j0f(fx) * log(x)));
 }
@@ -402,21 +423,26 @@
 float
 y0f(float fx)
 {
-	float	f;
-	int	ix;
+	float f;
+	int ix;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	ix = *(int *)&fx;
+
 	if ((ix & ~0x80000000) > 0x7f800000)	/* nan */
 		return (fx * fx);
+
 	if (ix <= 0) {				/* zero or negative */
 		if ((ix << 1) == 0)
 			return (-onef / zerof);
+
 		return (zerof / zerof);
 	}
-	if (ix == 0x7f800000)			/* +inf */
+
+	if (ix == 0x7f800000)		/* +inf */
 		return (zerof);
 
 #if defined(__i386) && !defined(__amd64)
@@ -434,17 +460,19 @@
 static double
 __k_j1f(float fx)
 {
-	double	x, z, s, c, ss, cc, r, t, p1, q1;
-	int	i, ix, sgn;
+	double x, z, s, c, ss, cc, r, t, p1, q1;
+	int i, ix, sgn;
 
 	ix = *(int *)&fx;
 	sgn = (unsigned)ix >> 31;
 	ix &= ~0x80000000;
 	x = fabs((double)fx);
+
 	if (ix > 0x41000000) {
 		/* x > 8; see comments in j1.c */
 		s = sin(x);
 		c = cos(x);
+
 		if (signbit(s) != signbit(c)) {
 			cc = s - c;
 			ss = cos(x + x) / cc;
@@ -452,6 +480,7 @@
 			ss = -s - c;
 			cc = cos(x + x) / ss;
 		}
+
 		if (ix > 0x501502f9) {
 			/* x > 1.0e10 */
 			p1 = one;
@@ -459,27 +488,32 @@
 		} else {
 			t = eight / x;
 			z = t * t;
-			p1 = (pr0[0] + z * (pr0[1] + z * (pr0[2] + z *
-			    (pr0[3] + z * (pr0[4] + z * pr0[5]))))) /
-			    (ps0[0] + z * (ps0[1] + z * (ps0[2] + z *
-			    (ps0[3] + z * (ps0[4] + z * (ps0[5] + z))))));
+			p1 = (pr0[0] + z * (pr0[1] + z * (pr0[2] + z * (pr0[3] +
+			    z * (pr0[4] + z * pr0[5]))))) / (ps0[0] + z *
+			    (ps0[1] + z * (ps0[2] + z * (ps0[3] + z * (ps0[4] +
+			    z * (ps0[5] + z))))));
 			q1 = ((qr0[0] + z * (qr0[1] + z * (qr0[2] + z *
-			    (qr0[3] + z * (qr0[4] + z * qr0[5]))))) /
-			    (qs0[0] + z * (qs0[1] + z * (qs0[2] + z *
-			    (qs0[3] + z * (qs0[4] + z * (qs0[5] + z))))))) * t;
+			    (qr0[3] + z * (qr0[4] + z * qr0[5]))))) / (qs0[0] +
+			    z * (qs0[1] + z * (qs0[2] + z * (qs0[3] + z *
+			    (qs0[4] + z * (qs0[5] + z))))))) * t;
 		}
+
 		t = isqrtpi * (p1 * cc - q1 * ss) / sqrt(x);
-		return ((sgn)? -t : t);
+		return ((sgn) ? -t : t);
 	}
+
 	if (ix <= 0x3727c5ac) {
 		/* x <= 1.0e-5 */
-		if (ix <= 0x219392ef) /* x <= 1.0e-18 */
+		if (ix <= 0x219392ef)	/* x <= 1.0e-18 */
 			t = half * x;
 		else
 			t = x * (half + neighth * x * x);
-		return ((sgn)? -t : t);
+
+		return ((sgn) ? -t : t);
 	}
+
 	z = x * x;
+
 	if (ix < 0x3fa3d70a) {
 		/* x < 1.28 */
 		r = a0[0] + z * (a0[1] + z * (a0[2] + z * a0[3]));
@@ -487,25 +521,30 @@
 		t = x * half + x * (z * (r / s));
 	} else {
 		r = a1[11];
+
 		for (i = 10; i >= 0; i--)
 			r = r * z + a1[i];
+
 		s = b1[0] + z * (b1[1] + z * (b1[2] + z * (b1[3] + z * b1[4])));
 		t = x * (r / s);
 	}
-	return ((sgn)? -t : t);
+
+	return ((sgn) ? -t : t);
 }
 
 float
 j1f(float fx)
 {
-	float	f;
-	int	ix;
+	float f;
+	int ix;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	ix = *(int *)&fx & ~0x80000000;
-	if (ix >= 0x7f800000)			/* nan or inf */
+
+	if (ix >= 0x7f800000)		/* nan or inf */
 		return (onef / fx);
 
 #if defined(__i386) && !defined(__amd64)
@@ -523,15 +562,17 @@
 static double
 __k_y1f(float fx)
 {
-	double	x, z, s, c, ss, cc, u, v, p1, q1, t;
-	int	i, ix;
+	double x, z, s, c, ss, cc, u, v, p1, q1, t;
+	int i, ix;
 
 	ix = *(int *)&fx;
 	x = (double)fx;
+
 	if (ix > 0x41000000) {
 		/* x > 8; see comments in j1.c */
 		s = sin(x);
 		c = cos(x);
+
 		if (signbit(s) != signbit(c)) {
 			cc = s - c;
 			ss = cos(x + x) / cc;
@@ -539,6 +580,7 @@
 			ss = -s - c;
 			cc = cos(x + x) / ss;
 		}
+
 		if (ix > 0x501502f9) {
 			/* x > 1.0e10 */
 			p1 = one;
@@ -546,51 +588,63 @@
 		} else {
 			t = eight / x;
 			z = t * t;
-			p1 = (pr0[0] + z * (pr0[1] + z * (pr0[2] + z *
-			    (pr0[3] + z * (pr0[4] + z * pr0[5]))))) /
-			    (ps0[0] + z * (ps0[1] + z * (ps0[2] + z *
-			    (ps0[3] + z * (ps0[4] + z * (ps0[5] + z))))));
+			p1 = (pr0[0] + z * (pr0[1] + z * (pr0[2] + z * (pr0[3] +
+			    z * (pr0[4] + z * pr0[5]))))) / (ps0[0] + z *
+			    (ps0[1] + z * (ps0[2] + z * (ps0[3] + z * (ps0[4] +
+			    z * (ps0[5] + z))))));
 			q1 = ((qr0[0] + z * (qr0[1] + z * (qr0[2] + z *
-			    (qr0[3] + z * (qr0[4] + z * qr0[5]))))) /
-			    (qs0[0] + z * (qs0[1] + z * (qs0[2] + z *
-			    (qs0[3] + z * (qs0[4] + z * (qs0[5] + z))))))) * t;
+			    (qr0[3] + z * (qr0[4] + z * qr0[5]))))) / (qs0[0] +
+			    z * (qs0[1] + z * (qs0[2] + z * (qs0[3] + z *
+			    (qs0[4] + z * (qs0[5] + z))))))) * t;
 		}
+
 		return (isqrtpi * (p1 * ss + q1 * cc) / sqrt(x));
 	}
-	if (ix <= 0x219392ef) /* x <= 1.0e-18 */
+
+	if (ix <= 0x219392ef)		/* x <= 1.0e-18 */
 		return (-tpi / x);
+
 	z = x * x;
+
 	if (ix < 0x3fa3d70a) {
 		/* x < 1.28 */
 		u = c0[0] + z * (c0[1] + z * (c0[2] + z * c0[3]));
 		v = d0[0] + z * (d0[1] + z * (d0[2] + z * (d0[3] + z * d0[4])));
 	} else {
 		u = c1[11];
+
 		for (i = 10; i >= 0; i--)
 			u = u * z + c1[i];
+
 		v = d1[0] + z * (d1[1] + z * (d1[2] + z * (d1[3] + z * d1[4])));
 	}
+
 	return (x * (u / v) + tpi * (__k_j1f(fx) * log(x) - one / x));
 }
 
 float
 y1f(float fx)
 {
-	float	f;
-	int	ix;
+	float f;
+	int ix;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	ix = *(int *)&fx;
+
 	if ((ix & ~0x80000000) > 0x7f800000)	/* nan */
 		return (fx * fx);
+
 	if (ix <= 0) {				/* zero or negative */
 		if ((ix << 1) == 0)
 			return (-onef / zerof);
+
 		return (zerof / zerof);
 	}
-	if (ix == 0x7f800000)			/* +inf */
+
+	if (ix == 0x7f800000)		/* +inf */
 		return (zerof);
 
 #if defined(__i386) && !defined(__amd64)
@@ -607,70 +661,84 @@
 float
 jnf(int n, float fx)
 {
-	double	a, b, temp, x, z, w, t, q0, q1, h;
-	float	f;
-	int	i, ix, sgn, m, k;
+	double a, b, temp, x, z, w, t, q0, q1, h;
+	float f;
+	int i, ix, sgn, m, k;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	if (n < 0) {
 		n = -n;
 		fx = -fx;
 	}
+
 	if (n == 0)
 		return (j0f(fx));
+
 	if (n == 1)
 		return (j1f(fx));
 
 	ix = *(int *)&fx;
-	sgn = (n & 1)? ((unsigned)ix >> 31) : 0;
+	sgn = (n & 1) ? ((unsigned)ix >> 31) : 0;
 	ix &= ~0x80000000;
+
 	if (ix >= 0x7f800000) {		/* nan or inf */
 		if (ix > 0x7f800000)
 			return (fx * fx);
-		return ((sgn)? -zerof : zerof);
+
+		return ((sgn) ? -zerof : zerof);
 	}
+
 	if ((ix << 1) == 0)
-		return ((sgn)? -zerof : zerof);
+		return ((sgn) ? -zerof : zerof);
 
 #if defined(__i386) && !defined(__amd64)
 	rp = __swapRP(fp_extended);
 #endif
 	fx = fabsf(fx);
 	x = (double)fx;
+
 	if ((double)n <= x) {
 		/* safe to use J(n+1,x) = 2n/x * J(n,x) - J(n-1,x) */
 		a = __k_j0f(fx);
 		b = __k_j1f(fx);
+
 		for (i = 1; i < n; i++) {
 			temp = b;
 			b = b * ((double)(i + i) / x) - a;
 			a = temp;
 		}
+
 		f = (float)b;
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
 			(void) __swapRP(rp);
 #endif
-		return ((sgn)? -f : f);
+		return ((sgn) ? -f : f);
 	}
+
 	if (ix < 0x3089705f) {
 		/* x < 1.0e-9; use J(n,x) = 1/n! * (x / 2)^n */
 		if (n > 6)
 			n = 6;	/* result underflows to zero for n >= 6 */
+
 		b = t = half * x;
 		a = one;
+
 		for (i = 2; i <= n; i++) {
 			b *= t;
 			a *= (double)i;
 		}
+
 		b /= a;
 	} else {
+		/* BEGIN CSTYLED */
 		/*
 		 * Use the backward recurrence:
 		 *
-		 * 			x      x^2	x^2
+		 *                      x      x^2	x^2
 		 *  J(n,x)/J(n-1,x) =  ---- - ------ - ------   .....
 		 *			2n    2(n+1)   2(n+2)
 		 *
@@ -681,7 +749,7 @@
 		 *			1
 		 *	   w - -----------------
 		 *			  1
-		 * 		w+h - ---------
+		 *              w+h - ---------
 		 *			w+2h - ...
 		 *
 		 * To determine how many terms are needed, run the
@@ -694,6 +762,7 @@
 		 * Then when Q(k) > 1e4, k is large enough for single
 		 * precision.
 		 */
+		/* END CSTYLED  */
 /* XXX NOT DONE - rework this */
 		w = (n + n) / x;
 		h = two / x;
@@ -701,6 +770,7 @@
 		z = w + h;
 		q1 = w * z - one;
 		k = 1;
+
 		while (q1 < big) {
 			k++;
 			z += h;
@@ -708,12 +778,16 @@
 			q0 = q1;
 			q1 = temp;
 		}
+
 		m = n + n;
 		t = zero;
+
 		for (i = (n + k) << 1; i >= m; i -= 2)
 			t = one / ((double)i / x - t);
+
 		a = t;
 		b = one;
+
 		/*
 		 * estimate log((2/x)^n*n!) = n*log(2/x)+n*ln(n)
 		 * hence, if n*(log(2n/x)) > ...
@@ -724,6 +798,7 @@
 		 */
 		temp = (double)n;
 		temp *= log((two / x) * temp);
+
 		if (temp < 7.09782712893383973096e+02) {
 			for (i = n - 1; i > 0; i--) {
 				temp = b;
@@ -735,6 +810,7 @@
 				temp = b;
 				b = b * ((double)(i + i) / x) - a;
 				a = temp;
+
 				if (b > 1.0e100) {
 					a /= b;
 					t /= b;
@@ -742,46 +818,57 @@
 				}
 			}
 		}
+
 		b = (t * __k_j0f(fx) / b);
 	}
+
 	f = (float)b;
 #if defined(__i386) && !defined(__amd64)
 	if (rp != fp_extended)
 		(void) __swapRP(rp);
 #endif
-	return ((sgn)? -f : f);
+	return ((sgn) ? -f : f);
 }
 
 float
 ynf(int n, float fx)
 {
-	double	a, b, temp, x;
-	float	f;
-	int	i, sign, ix;
+	double a, b, temp, x;
+	float f;
+	int i, sign, ix;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	sign = 0;
+
 	if (n < 0) {
 		n = -n;
+
 		if (n & 1)
 			sign = 1;
 	}
+
 	if (n == 0)
 		return (y0f(fx));
+
 	if (n == 1)
-		return ((sign)? -y1f(fx) : y1f(fx));
+		return ((sign) ? -y1f(fx) : y1f(fx));
 
 	ix = *(int *)&fx;
+
 	if ((ix & ~0x80000000) > 0x7f800000)	/* nan */
 		return (fx * fx);
+
 	if (ix <= 0) {				/* zero or negative */
 		if ((ix << 1) == 0)
 			return (-onef / zerof);
+
 		return (zerof / zerof);
 	}
-	if (ix == 0x7f800000)			/* +inf */
+
+	if (ix == 0x7f800000)		/* +inf */
 		return (zerof);
 
 #if defined(__i386) && !defined(__amd64)
@@ -790,18 +877,22 @@
 	a = __k_y0f(fx);
 	b = __k_y1f(fx);
 	x = (double)fx;
+
 	for (i = 1; i < n; i++) {
 		temp = b;
 		b *= (double)(i + i) / x;
+
 		if (b <= -DBL_MAX)
 			break;
+
 		b -= a;
 		a = temp;
 	}
+
 	f = (float)b;
 #if defined(__i386) && !defined(__amd64)
 	if (rp != fp_extended)
 		(void) __swapRP(rp);
 #endif
-	return ((sign)? -f : f);
+	return ((sign) ? -f : f);
 }
--- old/usr/src/lib/libm/common/R/cbrtf.c	2019-06-06 20:39:08.410890172 +0000
+++ new/usr/src/lib/libm/common/R/cbrtf.c	2019-06-06 20:39:08.428438357 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,11 +33,12 @@
 #include "libm.h"
 
 float
-cbrtf(float x) {
+cbrtf(float x)
+{
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 	if (isnanf(x))
 		return (x * x);
 	else
 #endif
-	return ((float) cbrt((double) x));
+	return ((float)cbrt((double)x));
 }
--- old/usr/src/lib/libm/common/R/copysignf.c	2019-06-06 20:39:08.901296504 +0000
+++ new/usr/src/lib/libm/common/R/copysignf.c	2019-06-06 20:39:08.918778893 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,9 +33,10 @@
 #include "libm.h"
 
 float
-copysignf(float x, float y) {
+copysignf(float x, float y)
+{
 	float w;
 
-	*(int *) &w = (*(int *) &x & ~0x80000000) | (*(int *) &y & 0x80000000);
+	*(int *)&w = (*(int *)&x & ~0x80000000) | (*(int *)&y & 0x80000000);
 	return (w);
 }
--- old/usr/src/lib/libm/common/R/cosf.c	2019-06-06 20:39:09.407033896 +0000
+++ new/usr/src/lib/libm/common/R/cosf.c	2019-06-06 20:39:09.428279476 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,6 +38,7 @@
 
 extern const int _TBL_ipio2_inf[];
 extern int __rem_pio2m(double *, double *, int, int, int, const int *);
+
 #if defined(__i386) && !defined(__amd64)
 extern int __swapRP(int);
 #endif
@@ -56,26 +59,26 @@
 	6.077100506506192601475e-11,	/* 2^-34  * 1.0B4611A626331 */
 };
 
-#define	S0	C[0]
-#define	S1	C[1]
-#define	S2	C[2]
-#define	S3	C[3]
-#define	C0	C[4]
-#define	C1	C[5]
-#define	C2	C[6]
-#define	C3	C[7]
-#define	C4	C[8]
-#define	invpio2	C[9]
-#define	half	C[10]
-#define	pio2_1  C[11]
-#define	pio2_t	C[12]
+#define	S0		C[0]
+#define	S1		C[1]
+#define	S2		C[2]
+#define	S3		C[3]
+#define	C0		C[4]
+#define	C1		C[5]
+#define	C2		C[6]
+#define	C3		C[7]
+#define	C4		C[8]
+#define	invpio2		C[9]
+#define	half		C[10]
+#define	pio2_1		C[11]
+#define	pio2_t		C[12]
 
 float
 cosf(float x)
 {
-	double	y, z, w;
-	float	f;
-	int	n, ix, hx, hy;
+	double y, z, w;
+	float f;
+	int n, ix, hx, hy;
 	volatile int i __unused;
 
 	hx = *((int *)&x);
@@ -83,7 +86,7 @@
 
 	y = (double)x;
 
-	if (ix <= 0x4016cbe4) {		/* |x| < 3*pi/4 */
+	if (ix <= 0x4016cbe4) {			/* |x| < 3*pi/4 */
 		if (ix <= 0x3f490fdb) {		/* |x| < pi/4 */
 			if (ix <= 0x39800000) {	/* |x| <= 2**-12 */
 				i = (int)y;
@@ -92,31 +95,34 @@
 #endif
 				return (1.0f);
 			}
+
 			z = y * y;
-			return ((float)(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z))));
+			return ((float)(((C0 + z * C1) + (z * z) * C2) * (C3 +
+			    z * (C4 + z))));
 		} else if (hx > 0) {
 			y = (y - pio2_1) - pio2_t;
 			z = y * y;
-			return ((float)-((y * (S0 + z * S1)) *
-			    (S2 + z * (S3 + z))));
+			return ((float)-((y * (S0 + z * S1)) * (S2 + z * (S3 +
+			    z))));
 		} else {
 			y = (y + pio2_1) + pio2_t;
 			z = y * y;
-			return ((float)((y * (S0 + z * S1)) *
-			    (S2 + z * (S3 + z))));
+			return ((float)((y * (S0 + z * S1)) * (S2 + z * (S3 +
+			    z))));
 		}
 	} else if (ix <= 0x49c90fdb) {	/* |x| < 2^19*pi */
 #if defined(__i386) && !defined(__amd64)
-		int	rp;
+		int rp;
 
 		rp = __swapRP(fp_extended);
 #endif
 		w = y * invpio2;
+
 		if (hx < 0)
 			n = (int)(w - half);
 		else
 			n = (int)(w + half);
+
 		y = (y - n * pio2_1) - n * pio2_t;
 		n++;
 #if defined(__i386) && !defined(__amd64)
@@ -125,7 +131,8 @@
 #endif
 	} else {
 		if (ix >= 0x7f800000)
-			return (x / x); /* cos(Inf or NaN) is NaN */
+			return (x / x);		/* cos(Inf or NaN) is NaN */
+
 		hy = ((int *)&y)[HIWORD];
 		n = ((hy >> 20) & 0x7ff) - 1046;
 		((int *)&w)[HIWORD] = (hy & 0xfffff) | 0x41600000;
@@ -136,13 +143,13 @@
 	if (n & 1) {
 		/* compute cos y */
 		z = y * y;
-		f = (float)(((C0 + z * C1) + (z * z) * C2) *
-		    (C3 + z * (C4 + z)));
+		f = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 +
+		    z)));
 	} else {
 		/* compute sin y */
 		z = y * y;
 		f = (float)((y * (S0 + z * S1)) * (S2 + z * (S3 + z)));
 	}
 
-	return ((n & 2)? -f : f);
+	return ((n & 2) ? -f : f);
 }
--- old/usr/src/lib/libm/common/R/coshf.c	2019-06-06 20:39:09.923525106 +0000
+++ new/usr/src/lib/libm/common/R/coshf.c	2019-06-06 20:39:09.941645901 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,20 +33,24 @@
 #include "libm.h"
 
 float
-coshf(float x) {
-	double	c;
-	float	w;
-	int	ix;
+coshf(float x)
+{
+	double c;
+	float w;
+	int ix;
 
 	ix = *(int *)&x & ~0x80000000;
+
 	if (ix >= 0x7f800000) {
 		/* coshf(x) is |x| if x is +-Inf or NaN */
 		return (x * x);
 	}
-	if (ix >= 0x43000000)	/* coshf(x) trivially overflows */
+
+	if (ix >= 0x43000000)		/* coshf(x) trivially overflows */
 		c = 1.0e100;
 	else
 		c = cosh((double)x);
+
 	w = (float)c;
 	return (w);
 }
--- old/usr/src/lib/libm/common/R/erff.c	2019-06-06 20:39:10.431904156 +0000
+++ new/usr/src/lib/libm/common/R/erff.c	2019-06-06 20:39:10.449826462 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,25 +38,31 @@
 #endif
 
 float
-erff(float x) {
-	int	ix;
+erff(float x)
+{
+	int ix;
 
 	ix = *(int *)&x & ~0x80000000;
-	if (ix > 0x7f800000)	/* x is NaN */
+
+	if (ix > 0x7f800000)		/* x is NaN */
 		return (x * x);
+
 	return ((float)erf((double)x));
 }
 
 float
-erfcf(float x) {
-	float	f;
-	int	ix;
+erfcf(float x)
+{
+	float f;
+	int ix;
+
 #if defined(__i386) && !defined(__amd64)
-	int	rp;
+	int rp;
 #endif
 
 	ix = *(int *)&x & ~0x80000000;
-	if (ix > 0x7f800000)	/* x is NaN */
+
+	if (ix > 0x7f800000)		/* x is NaN */
 		return (x * x);
 
 #if defined(__i386) && !defined(__amd64)
--- old/usr/src/lib/libm/common/R/exp10f.c	2019-06-06 20:39:10.945715341 +0000
+++ new/usr/src/lib/libm/common/R/exp10f.c	2019-06-06 20:39:10.963934415 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,11 +33,12 @@
 extern double exp10(double);
 
 float
-exp10f(float x) {
+exp10f(float x)
+{
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 	if (isnanf(x))
 		return (x * x);
 	else
 #endif
-	return ((float) exp10((double) x));
+	return ((float)exp10((double)x));
 }
--- old/usr/src/lib/libm/common/R/exp2f.c	2019-06-06 20:39:11.433059219 +0000
+++ new/usr/src/lib/libm/common/R/exp2f.c	2019-06-06 20:39:11.451298014 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,11 +33,12 @@
 #include "libm.h"
 
 float
-exp2f(float x) {
+exp2f(float x)
+{
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 	if (isnanf(x))
 		return (x * x);
 	else
 #endif
-	return ((float) exp2((double) x));
+	return ((float)exp2((double)x));
 }
--- old/usr/src/lib/libm/common/R/expf.c	2019-06-06 20:39:11.954587974 +0000
+++ new/usr/src/lib/libm/common/R/expf.c	2019-06-06 20:39:11.972942705 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __expf = expf
 
-/* INDENT OFF */
+
 /*
  * float expf(float x);
  * Code by K.C. Ng for SUN 5.0 libmopt
@@ -100,7 +102,6 @@
  *      defined and the result is subnormal, the error can be as
  *      large as 0.75 ulp.
  */
-/* INDENT ON */
 
 #include "libm.h"
 
@@ -331,38 +332,42 @@
 #endif
 };
 
-#define	zero	F[0]
-#define	one	F[1]
-#define	p1	F[2]
-#define	p2	F[3]
-#define	big	F[4]
-#define	tiny	F[5]
+#define	zero		F[0]
+#define	one		F[1]
+#define	p1		F[2]
+#define	p2		F[3]
+#define	big		F[4]
+#define	tiny		F[5]
 #if defined(FDTOS_TRAPS_INCOMPLETE_IN_FNS_MODE)
-#define	twom60	F[6]
+#define	twom60		F[6]
 #endif
 
 float
-expf(float xf) {
-	double	w, p, q;
-	int	hx, ix, n;
+expf(float xf)
+{
+	double w, p, q;
+	int hx, ix, n;
 
 	hx = *(int *)&xf;
 	ix = hx & ~0x80000000;
 
-	if (ix < 0x3c800000) {	/* |x| < 2**-6 */
+	if (ix < 0x3c800000) {		/* |x| < 2**-6 */
 		if (ix < 0x38800000)	/* |x| < 2**-14 */
 			return (one + xf);
+
 		return (one + (xf + (xf * xf) * (p1 + xf * p2)));
 	}
 
-	n = ix >> 23;		/* biased exponent */
+	n = ix >> 23;				/* biased exponent */
 
-	if (n >= 0x86) {	/* |x| >= 2^7 */
-		if (n >= 0xff) {	/* x is nan of +-inf */
+	if (n >= 0x86) {			/* |x| >= 2^7 */
+		if (n >= 0xff) {		/* x is nan of +-inf */
 			if (hx == 0xff800000)
 				return (zero);	/* exp(-inf)=0 */
+
 			return (xf * xf);	/* exp(nan/inf) is nan or inf */
 		}
+
 		if (hx > 0)
 			return (big * big);	/* overflow */
 		else
@@ -370,30 +375,35 @@
 	}
 
 	ix -= n << 23;
+
 	if (hx > 0)
 		ix += 0x800000;
 	else
 		ix = 0x800000 - ix;
-	if (n >= 0x7f) {	/* n >= 0 */
+
+	if (n >= 0x7f) {		/* n >= 0 */
 		ix <<= n - 0x7f;
 		w = ET[(ix & 0x3f) + 64] * ET[((ix >> 6) & 0x3f) + 128];
-		p = ET[((ix >> 12) & 0x3f) + 192] *
-		    ET[((ix >> 18) & 0x3f) + 256];
+		p = ET[((ix >> 12) & 0x3f) + 192] * ET[((ix >> 18) & 0x3f) +
+		    256];
 		q = ET[((ix >> 24) & 0x3f) + 320];
 	} else {
 		ix <<= n - 0x79;
 		w = ET[ix & 0x3f] * ET[((ix >> 6) & 0x3f) + 64];
-		p = ET[((ix >> 12) & 0x3f) + 128] *
-		    ET[((ix >> 18) & 0x3f) + 192];
+		p = ET[((ix >> 12) & 0x3f) + 128] * ET[((ix >> 18) & 0x3f) +
+		    192];
 		q = ET[((ix >> 24) & 0x3f) + 256];
 	}
+
 	xf = (float)((w * p) * (hx < 0 ? q * EN[n - 0x79] : q));
 #if defined(FDTOS_TRAPS_INCOMPLETE_IN_FNS_MODE)
 	if ((unsigned)hx >= 0xc2800000u) {
-		if ((unsigned)hx >= 0xc2aeac50) { /* force underflow */
-			volatile float	t = tiny;
+		if ((unsigned)hx >= 0xc2aeac50) {	/* force underflow */
+			volatile float t = tiny;
+
 			t *= t;
 		}
+
 		return (xf * twom60);
 	}
 #endif
--- old/usr/src/lib/libm/common/R/expm1f.c	2019-06-06 20:39:12.482180782 +0000
+++ new/usr/src/lib/libm/common/R/expm1f.c	2019-06-06 20:39:12.501541089 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,11 +33,12 @@
 #include "libm.h"
 
 float
-expm1f(float x) {
+expm1f(float x)
+{
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 	if (isnanf(x))
 		return (x * x);
 	else
 #endif
-	return ((float) expm1((double) x));
+	return ((float)expm1((double)x));
 }
--- old/usr/src/lib/libm/common/R/fabsf.c	2019-06-06 20:39:12.978763603 +0000
+++ new/usr/src/lib/libm/common/R/fabsf.c	2019-06-06 20:39:12.997931313 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,7 +33,8 @@
 #include "libm.h"
 
 float
-fabsf(float x) {
-	*(int *) &x &= ~0x80000000;
+fabsf(float x)
+{
+	*(int *)&x &= ~0x80000000;
 	return (x);
 }
--- old/usr/src/lib/libm/common/R/floorf.c	2019-06-06 20:39:13.498229506 +0000
+++ new/usr/src/lib/libm/common/R/floorf.c	2019-06-06 20:39:13.515654117 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,7 +31,7 @@
 #pragma weak __ceilf = ceilf
 #pragma weak __floorf = floorf
 
-/* INDENT OFF */
+
 /*
  * ceilf(x)	return the biggest integral value (in float) below x
  * floorf(x)	return the least integral value (in float) above x
@@ -42,70 +43,81 @@
 #include "libm.h"
 
 static const float xf[] = {
-/* ZEROF */	0.0f,
-/* ONEF */	1.0f,
-/* MONEF */	-1.0f,
-/* HUGEF */	1.0e30f,
-};
-
-#define	ZEROF	xf[0]
-#define	ONEF	xf[1]
-#define	MONEF	xf[2]
-#define	HUGEF	xf[3]
-/* INDENT ON */
+/* ZEROF */
+	0.0f,
+/* ONEF */ 1.0f,
+/* MONEF */ -1.0f,
+/* HUGEF */ 1.0e30f, };
+
+#define	ZEROF		xf[0]
+#define	ONEF		xf[1]
+#define	MONEF		xf[2]
+#define	HUGEF		xf[3]
 
 float
-ceilf(float x) {
+ceilf(float x)
+{
 	volatile float dummy __unused;
 	int hx, k, j, ix;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	ix = hx & ~0x80000000;
 	k = ix >> 23;
+
 	if (((k - 127) ^ (k - 150)) < 0) {
 		k = (1 << (150 - k)) - 1;
+
 		if ((k & hx) != 0)
 			dummy = HUGEF + x;	/* raise inexact */
+
 		j = k & (~(hx >> 31));
-		*(int *) &x = (hx + j) & ~k;
+		*(int *)&x = (hx + j) & ~k;
 		return (x);
 	} else if (k <= 126) {
 		dummy = HUGEF + x;
+
 		if (hx > 0)
 			return (ONEF);
 		else if (ix == 0)
 			return (x);
 		else
 			return (-ZEROF);
-	} else
+	} else {
 		/* signal invalid if x is a SNaN */
-		return (x * ONEF);		/* +0 -> *1 for Cheetah */
+		return (x * ONEF);	/* +0 -> *1 for Cheetah */
+	}
 }
 
 float
-floorf(float x) {
+floorf(float x)
+{
 	volatile float dummy __unused;
 	int hx, k, j, ix;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	ix = hx & ~0x80000000;
 	k = ix >> 23;
+
 	if (((k - 127) ^ (k - 150)) < 0) {
 		k = (1 << (150 - k)) - 1;
+
 		if ((k & hx) != 0)
 			dummy = HUGEF + x;	/* raise inexact */
+
 		j = k & (hx >> 31);
-		*(int *) &x = (hx + j) & ~k;
+		*(int *)&x = (hx + j) & ~k;
 		return (x);
 	} else if (k <= 126) {
 		dummy = HUGEF + x;
+
 		if (hx > 0)
 			return (ZEROF);
 		else if (ix == 0)
 			return (x);
 		else
 			return (MONEF);
-	} else
+	} else {
 		/* signal invalid if x is a SNaN */
-		return (x * ONEF);		/* +0 -> *1 for Cheetah */
+		return (x * ONEF);	/* +0 -> *1 for Cheetah */
+	}
 }
--- old/usr/src/lib/libm/common/R/fmodf.c	2019-06-06 20:39:13.987143492 +0000
+++ new/usr/src/lib/libm/common/R/fmodf.c	2019-06-06 20:39:14.004727472 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,20 +32,18 @@
 
 #include "libm.h"
 
-/* INDENT OFF */
-static const int
-	is = (int)0x80000000,
+static const int is = (int)0x80000000,
 	im = 0x007fffff,
 	ii = 0x7f800000,
 	iu = 0x00800000;
-/* INDENT ON */
 
-static const float zero	= 0.0;
+static const float zero = 0.0;
 
 float
-fmodf(float x, float y) {
-	float	w;
-	int	hx, ix, iy, iz, k, ny, nd;
+fmodf(float x, float y)
+{
+	float w;
+	int hx, ix, iy, iz, k, ny, nd;
 
 	hx = *(int *)&x;
 	ix = hx & 0x7fffffff;
@@ -55,30 +55,33 @@
 		w = w / w;
 	} else if (ix <= iy) {
 		if (ix < iy)
-			w = x;	/* return x if |x|<|y| */
+			w = x;		/* return x if |x|<|y| */
 		else
 			w = zero * x;	/* return sign(x)*0.0 */
 	} else {
-		/* INDENT OFF */
+
 		/*
 		 * scale x,y to "normal" with
 		 *	ny = exponent of y
 		 *	nd = exponent of x minus exponent of y
 		 */
-		/* INDENT ON */
 		ny = iy >> 23;
 		k = ix >> 23;
 
 		/* special case for subnormal y or x */
 		if (ny == 0) {
 			ny = 1;
+
 			while (iy < iu) {
 				ny -= 1;
 				iy += iy;
 			}
+
 			nd = k - ny;
+
 			if (k == 0) {
 				nd += 1;
+
 				while (ix < iu) {
 					nd -= 1;
 					ix += ix;
@@ -92,11 +95,14 @@
 			iy = iu | (iy & im);
 		}
 
-		/* fix point fmod for normalized ix and iy */
-		/* INDENT OFF */
+		/*
+		 * fix point fmod for normalized ix and iy
+		 */
+
+		/* BEGIN CSTYLED */
 		/*
 		 * while (nd--) {
-		 * 	iz = ix - iy;
+		 *      iz = ix - iy;
 		 * if (iz < 0)
 		 *	ix = ix + ix;
 		 * else if (iz == 0) {
@@ -107,46 +113,62 @@
 		 *	ix = iz + iz;
 		 * }
 		 */
-		/* INDENT ON */
-		/* unroll the above loop 4 times to gain performance */
+		/* END CSTYLED */
+
+		/*
+		 * unroll the above loop 4 times to gain performance
+		 */
 		k = nd >> 2;
 		nd -= k << 2;
+
 		while (k--) {
 			iz = ix - iy;
+
 			if (iz >= 0)
 				ix = iz + iz;
 			else
 				ix += ix;
+
 			iz = ix - iy;
+
 			if (iz >= 0)
 				ix = iz + iz;
 			else
 				ix += ix;
+
 			iz = ix - iy;
+
 			if (iz >= 0)
 				ix = iz + iz;
 			else
 				ix += ix;
+
 			iz = ix - iy;
+
 			if (iz >= 0)
 				ix = iz + iz;
 			else
 				ix += ix;
+
 			if (iz == 0) {
 				*(int *)&w = is & hx;
 				return (w);
 			}
 		}
+
 		while (nd--) {
 			iz = ix - iy;
+
 			if (iz >= 0)
 				ix = iz + iz;
 			else
 				ix += ix;
 		}
+
 		/* end of unrolling */
 
 		iz = ix - iy;
+
 		if (iz >= 0)
 			ix = iz;
 
@@ -155,14 +177,17 @@
 			*(int *)&w = is & hx;
 			return (w);
 		}
+
 		while (ix < iu) {
 			ix += ix;
 			ny -= 1;
 		}
+
 		while (ix > (iu + iu)) {
 			ny += 1;
 			ix >>= 1;
 		}
+
 		if (ny > 0) {
 			*(int *)&w = (is & hx) | (ix & im) | (ny << 23);
 		} else {
@@ -172,5 +197,6 @@
 			*(int *)&w = (is & hx) | ix;
 		}
 	}
+
 	return (w);
 }
--- old/usr/src/lib/libm/common/R/gammaf.c	2019-06-06 20:39:14.586680874 +0000
+++ new/usr/src/lib/libm/common/R/gammaf.c	2019-06-06 20:39:14.607173755 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,6 +33,7 @@
 #include "libm.h"
 
 float
-gammaf(float x) {
+gammaf(float x)
+{
 	return (lgammaf(x));
 }
--- old/usr/src/lib/libm/common/R/gammaf_r.c	2019-06-06 20:39:15.091845049 +0000
+++ new/usr/src/lib/libm/common/R/gammaf_r.c	2019-06-06 20:39:15.109701056 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,6 +33,7 @@
 #include "libm.h"
 
 float
-gammaf_r(float x, int *signgamfp) {
+gammaf_r(float x, int *signgamfp)
+{
 	return (lgammaf_r(x, signgamfp));
 }
--- old/usr/src/lib/libm/common/R/hypotf.c	2019-06-06 20:39:15.558761081 +0000
+++ new/usr/src/lib/libm/common/R/hypotf.c	2019-06-06 20:39:15.577851742 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,33 +33,36 @@
 #include "libm.h"
 
 float
-hypotf(float x, float y) {
+hypotf(float x, float y)
+{
 	double dx, dy;
 	float w;
 	int ix, iy;
 
-	ix = (*(int *) &x) & 0x7fffffff;
-	iy = (*(int *) &y) & 0x7fffffff;
+	ix = (*(int *)&x) & 0x7fffffff;
+	iy = (*(int *)&y) & 0x7fffffff;
+
 	if (ix >= 0x7f800000) {
 		if (ix == 0x7f800000)
-			*(int *) &w = x == y ? iy : ix;	/* w = |x| = inf */
+			*(int *)&w = x == y ? iy : ix; /* w = |x| = inf */
 		else if (iy == 0x7f800000)
-			*(int *) &w = x == y ? ix : iy;	/* w = |y| = inf */
+			*(int *)&w = x == y ? ix : iy; /* w = |y| = inf */
 		else
-			w = fabsf(x) * fabsf(y);	/* + -> * for Cheetah */
+			w = fabsf(x) * fabsf(y); /* + -> * for Cheetah */
 	} else if (iy >= 0x7f800000) {
 		if (iy == 0x7f800000)
-			*(int *) &w = x == y ? ix : iy;	/* w = |y| = inf */
+			*(int *)&w = x == y ? ix : iy;	/* w = |y| = inf */
 		else
-			w = fabsf(x) * fabsf(y);	/* + -> * for Cheetah */
-	} else if (ix == 0)
-		*(int *) &w = iy;	/* w = |y|  */
-	else if (iy == 0)
-		*(int *) &w = ix;	/* w = |x|  */
-	else {
-		dx = (double) x;
-		dy = (double) y;
-		w = (float) sqrt(dx * dx + dy * dy);
+			w = fabsf(x) * fabsf(y); /* + -> * for Cheetah */
+	} else if (ix == 0) {
+		*(int *)&w = iy; /* w = |y|  */
+	} else if (iy == 0) {
+		*(int *)&w = ix; /* w = |x|  */
+	} else {
+		dx = (double)x;
+		dy = (double)y;
+		w = (float)sqrt(dx * dx + dy * dy);
 	}
+
 	return (w);
 }
--- old/usr/src/lib/libm/common/R/ilogbf.c	2019-06-06 20:39:16.068019489 +0000
+++ new/usr/src/lib/libm/common/R/ilogbf.c	2019-06-06 20:39:16.086201951 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,7 +31,7 @@
 #pragma weak __ilogbf = ilogbf
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"			/* __xpg6 */
 
 #if defined(__x86)
 static const float two25 = 33554432.0F;
@@ -39,22 +40,27 @@
  * v: a non-zero subnormal |x|
  */
 static int
-ilogbf_subnormal(unsigned v) {
+ilogbf_subnormal(unsigned v)
+{
 	int r = -126 - 23;
 
 	if (v & 0xffff0000)
 		r += 16, v >>= 16;
+
 	if (v & 0xff00)
 		r += 8, v >>= 8;
+
 	if (v & 0xf0)
 		r += 4, v >>= 4;
+
 	v <<= 1;
 	return (r + ((0xffffaa50 >> v) & 0x3));
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 static int
-raise_invalid(int v) {	/* SUSv3 requires ilogbf(0,+/-Inf,NaN) raise invalid */
+raise_invalid(int v)   /* SUSv3 requires ilogbf(0,+/-Inf,NaN) raise invalid */
+{
 #ifndef lint
 	if ((__xpg6 & _C99SUSv3_ilogb_0InfNaN_raises_invalid) != 0) {
 		static const double zero = 0.0;
@@ -67,22 +73,24 @@
 }
 
 int
-ilogbf(float x) {
-	int k = *((int *) &x) & ~0x80000000;
+ilogbf(float x)
+{
+	int k = *((int *)&x) & ~0x80000000;
 
 	if (k < 0x00800000) {
-		if (k == 0)
+		if (k == 0) {
 			return (raise_invalid(0x80000001));
-		else {
+		} else {
 #if defined(__x86)
 			x *= two25;
-			return (((*((int *) &x) & 0x7f800000) >> 23) - 152);
+			return (((*((int *)&x) & 0x7f800000) >> 23) - 152);
 #else
 			return (ilogbf_subnormal(k));
 #endif
 		}
-	} else if (k < 0x7f800000)
+	} else if (k < 0x7f800000) {
 		return ((k >> 23) - 127);
-	else
+	} else {
 		return (raise_invalid(0x7fffffff));
+	}
 }
--- old/usr/src/lib/libm/common/R/isnanf.c	2019-06-06 20:39:16.553704584 +0000
+++ new/usr/src/lib/libm/common/R/isnanf.c	2019-06-06 20:39:16.571039191 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "libm.h"
 
 int
-isnanf(float x) {
-	return ((*(int *) &x & ~0x80000000) > 0x7f800000);
+isnanf(float x)
+{
+	return ((*(int *)&x & ~0x80000000) > 0x7f800000);
 }
--- old/usr/src/lib/libm/common/R/lgammaf.c	2019-06-06 20:39:17.057458850 +0000
+++ new/usr/src/lib/libm/common/R/lgammaf.c	2019-06-06 20:39:17.075181327 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,11 +35,13 @@
 extern int signgamf;
 
 float
-lgammaf(float x) {
-	float	 y;
+lgammaf(float x)
+{
+	float y;
 
 	if (isnanf(x))
 		return (x * x);
+
 	y = (float)__k_lgamma((double)x, &signgamf);
 	signgam = signgamf;	/* SUSv3 requires the setting of signgam */
 	return (y);
--- old/usr/src/lib/libm/common/R/lgammaf_r.c	2019-06-06 20:39:17.557051315 +0000
+++ new/usr/src/lib/libm/common/R/lgammaf_r.c	2019-06-06 20:39:17.574558741 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,8 +33,10 @@
 #include "libm.h"
 
 float
-lgammaf_r(float x, int *signgamfp) {
+lgammaf_r(float x, int *signgamfp)
+{
 	if (isnanf(x))
 		return (x * x);
+
 	return ((float)__k_lgamma((double)x, signgamfp));
 }
--- old/usr/src/lib/libm/common/R/log10f.c	2019-06-06 20:39:18.016206304 +0000
+++ new/usr/src/lib/libm/common/R/log10f.c	2019-06-06 20:39:18.034442815 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,23 +35,29 @@
 static const float zero = 0.0f, mone = -1.0f;
 
 float
-log10f(float x) {
-	int	hx, ix;
-	float	w;
+log10f(float x)
+{
+	int hx, ix;
+	float w;
 
 	hx = *(int *)&x;
 	ix = hx & ~0x80000000;
+
 	if (ix > 0x7f800000)
 		return (x * x);
+
 	if (ix == 0x7f800000)
 		return (x + x * x);
+
 	if (ix == 0) {
 		w = mone;
 		return (w / zero);
 	}
+
 	if (hx < 0) {
 		w = zero;
 		return (w / zero);
 	}
+
 	return ((float)log10((double)x));
 }
--- old/usr/src/lib/libm/common/R/log1pf.c	2019-06-06 20:39:18.463040376 +0000
+++ new/usr/src/lib/libm/common/R/log1pf.c	2019-06-06 20:39:18.479306438 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,20 +35,26 @@
 static const float zero = 0.0f;
 
 float
-log1pf(float x) {
-	int	ix;
+log1pf(float x)
+{
+	int ix;
 
 	ix = *(int *)&x;
+
 	if (ix >= 0x7f800000) {
 		/* x is +inf or nan */
 		return (x * x);
 	}
+
 	if (ix < 0) {
 		ix &= ~0x80000000;
-		if (ix == 0x3f800000) /* x is -1 */
+
+		if (ix == 0x3f800000)	/* x is -1 */
 			return (x / zero);
-		if (ix > 0x3f800000) /* x is < -1 or nan */
+
+		if (ix > 0x3f800000)	/* x is < -1 or nan */
 			return ((x * zero) / zero);
 	}
+
 	return ((float)log1p((double)x));
 }
--- old/usr/src/lib/libm/common/R/log2f.c	2019-06-06 20:39:18.969634907 +0000
+++ new/usr/src/lib/libm/common/R/log2f.c	2019-06-06 20:39:18.989670178 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,11 +33,12 @@
 #include "libm.h"
 
 float
-log2f(float x) {
+log2f(float x)
+{
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 	if (isnanf(x))
 		return (x * x);
 	else
 #endif
-	return ((float) log2((double) x));
+	return ((float)log2((double)x));
 }
--- old/usr/src/lib/libm/common/R/logbf.c	2019-06-06 20:39:19.507284366 +0000
+++ new/usr/src/lib/libm/common/R/logbf.c	2019-06-06 20:39:19.526214932 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,7 +31,7 @@
 #pragma weak __logbf = logbf
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"			/* __xpg6 */
 #define	_C99SUSv3_logb	_C99SUSv3_logb_subnormal_is_like_ilogb
 
 #if defined(__x86)
@@ -40,46 +41,56 @@
  * v: a non-zero subnormal |x|
  */
 static int
-ilogbf_subnormal(unsigned v) {
+ilogbf_subnormal(unsigned v)
+{
 	int r = -126 - 23;
 
 	if (v & 0xffff0000)
 		r += 16, v >>= 16;
+
 	if (v & 0xff00)
 		r += 8, v >>= 8;
+
 	if (v & 0xf0)
 		r += 4, v >>= 4;
+
 	v <<= 1;
 	return (r + ((0xffffaa50 >> v) & 0x3));
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 static float
-raise_division(float t) {
+raise_division(float t)
+{
 #pragma STDC FENV_ACCESS ON
+
 	static const float zero = 0.0F;
+
 	return (t / zero);
 }
 
 float
-logbf(float x) {
-	int k = *((int *) &x) & ~0x80000000;
+logbf(float x)
+{
+	int k = *((int *)&x) & ~0x80000000;
 
 	if (k < 0x00800000) {
-		if (k == 0)
+		if (k == 0) {
 			return (raise_division(-1.0F));
-		else if ((__xpg6 & _C99SUSv3_logb) != 0) {
+		} else if ((__xpg6 & _C99SUSv3_logb) != 0) {
 #if defined(__x86)
 			x *= two25;
-			return ((float) (((*((int *) &x) & 0x7f800000) >> 23) -
-				152));
+			return ((float)(((*((int *)&x) & 0x7f800000) >> 23) -
+			    152));
 #else
-			return ((float) ilogbf_subnormal(k));
+			return ((float)ilogbf_subnormal(k));
 #endif
-		} else
+		} else {
 			return (-126.F);
-	} else if (k < 0x7f800000)
-		return ((float) ((k >> 23) - 127));
-	else
+		}
+	} else if (k < 0x7f800000) {
+		return ((float)((k >> 23) - 127));
+	} else {
 		return (x * x);
+	}
 }
--- old/usr/src/lib/libm/common/R/logf.c	2019-06-06 20:39:20.016093471 +0000
+++ new/usr/src/lib/libm/common/R/logf.c	2019-06-06 20:39:20.034715622 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -105,29 +107,30 @@
 	-5.00000008402474976565e-01
 };
 
-#define	ln2	C[0]
-#define	K3	C[1]
-#define	K2	C[2]
-#define	K1	C[3]
+#define	ln2		C[0]
+#define	K3		C[1]
+#define	K2		C[2]
+#define	K1		C[3]
 
 float
 logf(float x)
 {
-	double	v, t;
-	float	f;
-	int	hx, ix, i, exp, iy;
+	double v, t;
+	float f;
+	int hx, ix, i, exp, iy;
 
 	hx = *(int *)&x;
 	ix = hx & ~0x80000000;
 
-	if (ix >= 0x7f800000)	/* nan or inf */
-		return ((hx < 0)? x * 0.0f : x * x);
+	if (ix >= 0x7f800000)		/* nan or inf */
+		return ((hx < 0) ? x * 0.0f : x *x);
 
 	exp = 0;
-	if (hx < 0x00800000) { /* negative, zero, or subnormal */
+
+	if (hx < 0x00800000) {		/* negative, zero, or subnormal */
 		if (hx <= 0) {
 			f = 0.0f;
-			return ((ix == 0)? -1.0f / f : f / f);
+			return ((ix == 0) ? -1.0f / f : f / f);
 		}
 
 		/* subnormal; scale by 2^149 */
--- old/usr/src/lib/libm/common/R/nextafterf.c	2019-06-06 20:39:20.512656268 +0000
+++ new/usr/src/lib/libm/common/R/nextafterf.c	2019-06-06 20:39:20.530265756 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,24 +33,29 @@
 #include "libm.h"
 
 float
-nextafterf(float x, float y) {
+nextafterf(float x, float y)
+{
 	float w;
-	int *pw = (int *) &w;
-	int *px = (int *) &x;
-	int *py = (int *) &y;
+	int *pw = (int *)&w;
+	int *px = (int *)&x;
+	int *py = (int *)&y;
 	int ix, iy, iz;
 
 	ix = px[0];
 	iy = py[0];
+
 	if ((ix & ~0x80000000) > 0x7f800000)
 		return (x * y);		/* + -> * for Cheetah */
+
 	if ((iy & ~0x80000000) > 0x7f800000)
 		return (y * x);		/* + -> * for Cheetah */
+
 	if (ix == iy || (ix | iy) == 0x80000000)
 		return (y);		/* C99 requirement */
-	if ((ix & ~0x80000000) == 0)
+
+	if ((ix & ~0x80000000) == 0) {
 		iz = 1 | (iy & 0x80000000);
-	else if (ix > 0) {
+	} else if (ix > 0) {
 		if (ix > iy)
 			iz = ix - 1;
 		else
@@ -60,20 +66,23 @@
 		else
 			iz = ix - 1;
 	}
+
 	pw[0] = iz;
 	ix = iz & 0x7f800000;
+
 	if (ix == 0x7f800000) {
 		/* raise overflow */
 		volatile float t;
 
-		*(int *) &t = 0x7f7fffff;
+		*(int *)&t = 0x7f7fffff;
 		t *= t;
 	} else if (ix == 0) {
 		/* raise underflow */
 		volatile float t;
 
-		*(int *) &t = 0x00800000;
+		*(int *)&t = 0x00800000;
 		t *= t;
 	}
+
 	return (w);
 }
--- old/usr/src/lib/libm/common/R/powf.c	2019-06-06 20:39:20.988289104 +0000
+++ new/usr/src/lib/libm/common/R/powf.c	2019-06-06 20:39:21.004966599 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,17 +31,16 @@
 #pragma weak __powf = powf
 
 #include "libm.h"
-#include "xpg6.h"	/* __xpg6 */
+#include "xpg6.h"			/* __xpg6 */
 #define	_C99SUSv3_pow	_C99SUSv3_pow_treats_Inf_as_an_even_int
 
 #if defined(__i386) && !defined(__amd64)
 extern int __swapRP(int);
 #endif
 
-/* INDENT OFF */
 static const double
-	ln2 = 6.93147180559945286227e-01,	/* 0x3fe62e42, 0xfefa39ef */
-	invln2 = 1.44269504088896338700e+00,	/* 0x3ff71547, 0x652b82fe */
+	ln2 = 6.93147180559945286227e-01,    /* 0x3fe62e42, 0xfefa39ef */
+	invln2 = 1.44269504088896338700e+00, /* 0x3ff71547, 0x652b82fe */
 	dtwo = 2.0,
 	done = 1.0,
 	dhalf = 0.5,
@@ -86,48 +87,33 @@
 };
 
 static const double TBL[] = {
-	0.00000000000000000e+00,
-	3.07716586667536873e-02,
-	6.06246218164348399e-02,
-	8.96121586896871380e-02,
-	1.17783035656383456e-01,
-	1.45182009844497889e-01,
-	1.71850256926659228e-01,
-	1.97825743329919868e-01,
-	2.23143551314209765e-01,
-	2.47836163904581269e-01,
-	2.71933715483641758e-01,
-	2.95464212893835898e-01,
-	3.18453731118534589e-01,
-	3.40926586970593193e-01,
-	3.62905493689368475e-01,
-	3.84411698910332056e-01,
-	4.05465108108164385e-01,
-	4.26084395310900088e-01,
-	4.46287102628419530e-01,
-	4.66089729924599239e-01,
-	4.85507815781700824e-01,
-	5.04556010752395312e-01,
-	5.23248143764547868e-01,
-	5.41597282432744409e-01,
-	5.59615787935422659e-01,
-	5.77315365034823613e-01,
-	5.94707107746692776e-01,
-	6.11801541105992941e-01,
-	6.28608659422374094e-01,
-	6.45137961373584701e-01,
-	6.61398482245365016e-01,
-	6.77398823591806143e-01,
+	0.00000000000000000e+00, 3.07716586667536873e-02,
+	6.06246218164348399e-02, 8.96121586896871380e-02,
+	1.17783035656383456e-01, 1.45182009844497889e-01,
+	1.71850256926659228e-01, 1.97825743329919868e-01,
+	2.23143551314209765e-01, 2.47836163904581269e-01,
+	2.71933715483641758e-01, 2.95464212893835898e-01,
+	3.18453731118534589e-01, 3.40926586970593193e-01,
+	3.62905493689368475e-01, 3.84411698910332056e-01,
+	4.05465108108164385e-01, 4.26084395310900088e-01,
+	4.46287102628419530e-01, 4.66089729924599239e-01,
+	4.85507815781700824e-01, 5.04556010752395312e-01,
+	5.23248143764547868e-01, 5.41597282432744409e-01,
+	5.59615787935422659e-01, 5.77315365034823613e-01,
+	5.94707107746692776e-01, 6.11801541105992941e-01,
+	6.28608659422374094e-01, 6.45137961373584701e-01,
+	6.61398482245365016e-01, 6.77398823591806143e-01,
 };
 
 static const float zero = 0.0F, one = 1.0F, huge = 1.0e25f, tiny = 1.0e-25f;
-/* INDENT ON */
+
 
 float
-powf(float x, float y) {
-	float	fx = x, fy = y;
-	float	fz;
-	int	ix, iy, jx, jy, k, iw, yisint;
+powf(float x, float y)
+{
+	float fx = x, fy = y;
+	float fz;
+	int ix, iy, jx, jy, k, iw, yisint;
 
 	ix = *(int *)&x;
 	iy = *(int *)&y;
@@ -135,27 +121,31 @@
 	jy = iy & ~0x80000000;
 
 	if (jy == 0)
-		return (one);	/* x**+-0 = 1 */
+		return (one);		/* x**+-0 = 1 */
 	else if (ix == 0x3f800000 && (__xpg6 & _C99SUSv3_pow) != 0)
-		return (one);	/* C99: 1**anything = 1 */
+		return (one);		/* C99: 1**anything = 1 */
 	else if (((0x7f800000 - jx) | (0x7f800000 - jy)) < 0)
 		return (fx * fy);	/* at least one of x or y is NaN */
-					/* includes Sun: 1**NaN = NaN */
-	/* INDENT OFF */
+
+	/*
+	 * includes Sun: 1**NaN = NaN
+	 */
+
 	/*
 	 * determine if y is an odd int
 	 * yisint = 0 ... y is not an integer
 	 * yisint = 1 ... y is an odd int
 	 * yisint = 2 ... y is an even int
 	 */
-	/* INDENT ON */
 	yisint = 0;
+
 	if (ix < 0) {
 		if (jy >= 0x4b800000) {
-			yisint = 2;	/* |y|>=2**24: y must be even */
+			yisint = 2;		/* |y|>=2**24: y must be even */
 		} else if (jy >= 0x3f800000) {
 			k = (jy >> 23) - 0x7f;	/* exponent */
 			iw = jy >> (23 - k);
+
 			if ((iw << (23 - k)) == jy)
 				yisint = 2 - (iw & 1);
 		}
@@ -163,30 +153,33 @@
 
 	/* special value of y */
 	if ((jy & ~0x7f800000) == 0) {
-		if (jy == 0x7f800000) {		/* y is +-inf */
+		if (jy == 0x7f800000) {	/* y is +-inf */
 			if (jx == 0x3f800000) {
 				if ((__xpg6 & _C99SUSv3_pow) != 0)
 					fz = one;
-						/* C99: (-1)**+-inf is 1 */
+				/* C99: (-1)**+-inf is 1 */
 				else
 					fz = fy - fy;
-						/* Sun: (+-1)**+-inf = NaN */
+
+				/* Sun: (+-1)**+-inf = NaN */
 			} else if (jx > 0x3f800000) {
-						/* (|x|>1)**+,-inf = inf,0 */
+				/* (|x|>1)**+,-inf = inf,0 */
 				if (iy > 0)
 					fz = fy;
 				else
 					fz = zero;
-			} else {		/* (|x|<1)**-,+inf = inf,0 */
+			} else {	/* (|x|<1)**-,+inf = inf,0 */
 				if (iy < 0)
 					fz = -fy;
 				else
 					fz = zero;
 			}
+
 			return (fz);
 		} else if (jy == 0x3f800000) {	/* y is +-1 */
 			if (iy < 0)
 				fx = one / fx;	/* y is -1 */
+
 			return (fx);
 		} else if (iy == 0x40000000) {	/* y is 2 */
 			return (fx * fx);
@@ -201,8 +194,10 @@
 		if (jx == 0x7f800000 || jx == 0 || jx == 0x3f800000) {
 			/* x is +-0,+-inf,-1; set fz = |x|**y */
 			*(int *)&fz = jx;
+
 			if (iy < 0)
 				fz = one / fz;
+
 			if (ix < 0) {
 				if (jx == 0x3f800000 && yisint == 0) {
 					/* (-1)**non-int is NaN */
@@ -213,6 +208,7 @@
 					fz = -fz;
 				}
 			}
+
 			return (fz);
 		}
 	}
@@ -229,10 +225,11 @@
 	 * fz = (float) exp(((double) fy) * log((double) fx));
 	 */
 	{
-		double	dx, dy, dz, ds;
-		int	*px = (int *)&dx, *pz = (int *)&dz, i, n, m;
+		double dx, dy, dz, ds;
+		int *px = (int *)&dx, *pz = (int *)&dz, i, n, m;
+
 #if defined(__i386) && !defined(__amd64)
-		int	rp = __swapRP(fp_extended);
+		int rp = __swapRP(fp_extended);
 #endif
 
 		fx = *(float *)&jx;
@@ -247,6 +244,7 @@
 		i = (i >> 15) & 0x1f;
 		dz = ds * ds;
 		dy = invln2 * (TBL[i] + ds * (A0 + dz * A1));
+
 		if (n == 0)
 			dz = (double)fy * dy;
 		else
@@ -254,12 +252,15 @@
 
 		/* compute exp2(dz=y*ln(x)) */
 		i = pz[HIWORD];
+
 		if ((i & ~0x80000000) >= 0x40640000) {	/* |z| >= 160.0 */
-			fz = (i > 0)? huge : tiny;
+			fz = (i > 0) ? huge : tiny;
+
 			if (ix < 0 && yisint == 1)
 				fz *= -fz;	/* (-ve)**(odd int) */
 			else
 				fz *= fz;
+
 #if defined(__i386) && !defined(__amd64)
 			if (rp != fp_extended)
 				(void) __swapRP(rp);
@@ -272,8 +273,10 @@
 		m = n >> 5;
 		dy = ln2 * (dz - d1_32 * (double)n);
 		dx = S[i] * (done - (dtwo * dy) / (dy * (done - dy * t1) - t0));
+
 		if (m != 0)
 			px[HIWORD] += m << 20;
+
 		fz = (float)dx;
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
@@ -283,6 +286,7 @@
 
 	/* end of computing exp(y*log(x)) */
 	if (ix < 0 && yisint == 1)
-		fz = -fz;	/* (-ve)**(odd int) */
+		fz = -fz;		/* (-ve)**(odd int) */
+
 	return (fz);
 }
--- old/usr/src/lib/libm/common/R/remainderf.c	2019-06-06 20:39:21.460527019 +0000
+++ new/usr/src/lib/libm/common/R/remainderf.c	2019-06-06 20:39:21.476511210 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,14 +33,17 @@
 #include "libm.h"
 
 float
-remainderf(float x, float y) {
+remainderf(float x, float y)
+{
 	if (isnanf(x) || isnanf(y))
 		return (x * y);
-	if (y == 0.0f || (*(int *) &x & ~0x80000000) == 0x7f800000) {
+
+	if (y == 0.0f || (*(int *)&x & ~0x80000000) == 0x7f800000) {
 		/* y is 0 or x is infinite; raise invalid and return NaN */
 		y = 0.0f;
-		*(int *) &x = 0x7f800000;
+		*(int *)&x = 0x7f800000;
 		return (x * y);
 	}
-	return ((float) remainder((double) x, (double) y));
+
+	return ((float)remainder((double)x, (double)y));
 }
--- old/usr/src/lib/libm/common/R/rintf.c	2019-06-06 20:39:21.910424484 +0000
+++ new/usr/src/lib/libm/common/R/rintf.c	2019-06-06 20:39:21.927074596 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __rintf = rintf
 
-/* INDENT OFF */
+
 /*
  * aintf(x)	return x chopped to integral value
  * anintf(x)	return sign(x)*(|x|+0.5) chopped to integral value
@@ -44,14 +45,15 @@
 #include "libm.h"
 
 static const float xf[] = {
-/* ZEROF */	0.0f,
-/* TWO_23F */	8.3886080000e6f,
-/* MTWO_23F */	-8.3886080000e6f,
-/* ONEF */	1.0f,
-/* MONEF */	-1.0f,
-/* HALFF */	0.5f,
-/* MHALFF */	-0.5f,
-/* HUGEF */	1.0e30f,
+/* ZEROF */
+	0.0f,
+/* TWO_23F */ 8.3886080000e6f,
+/* MTWO_23F */ -8.3886080000e6f,
+/* ONEF */ 1.0f,
+/* MONEF */ -1.0f,
+/* HALFF */ 0.5f,
+/* MHALFF */ -0.5f,
+/* HUGEF */ 1.0e30f,
 };
 
 #define	ZEROF		xf[0]
@@ -62,97 +64,114 @@
 #define	HALFF		xf[5]
 #define	MHALFF		xf[6]
 #define	HUGEF		xf[7]
-/* INDENT ON */
 
 float
-aintf(float x) {
+aintf(float x)
+{
 	int hx, k;
 	float y;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	k = (hx & ~0x80000000) >> 23;
+
 	if (k < 150) {
-		y = (float) ((int) x);
+		y = (float)((int)x);
+
 		/*
 		 * make sure y has the same sign of x when |x|<0.5
 		 * (i.e., y=0.0)
 		 */
 		return (((k - 127) & hx) < 0 ? -y : y);
-	} else
+	} else {
 		/* signal invalid if x is a SNaN */
-		return (x * ONEF);		/* +0 -> *1 for Cheetah */
+		return (x * ONEF);	/* +0 -> *1 for Cheetah */
+	}
 }
 
 float
-anintf(float x) {
+anintf(float x)
+{
 	volatile float dummy __unused;
 	int hx, k, j, ix;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	ix = hx & ~0x80000000;
 	k = ix >> 23;
+
 	if (((k - 127) ^ (k - 150)) < 0) {
 		j = 1 << (149 - k);
 		k = j + j - 1;
+
 		if ((k & hx) != 0)
 			dummy = HUGEF + x;	/* raise inexact */
-		*(int *) &x = (hx + j) & ~k;
+
+		*(int *)&x = (hx + j) & ~k;
 		return (x);
 	} else if (k <= 126) {
 		dummy = HUGEF + x;
-		*(int *) &x = (0x3f800000 & ((125 - k) >> 31)) |
-			(0x80000000 & hx);
+		*(int *)&x = (0x3f800000 & ((125 - k) >> 31)) |
+		    (0x80000000 & hx);
 		return (x);
-	} else
+	} else {
 		/* signal invalid if x is a SNaN */
-		return (x * ONEF);		/* +0 -> *1 for Cheetah */
+		return (x * ONEF);	/* +0 -> *1 for Cheetah */
+	}
 }
 
 int
-irintf(float x) {
+irintf(float x)
+{
 	float v;
 	int hx, k;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	k = (hx & ~0x80000000) >> 23;
 	v = xf[((k - 150) >> 31) & (1 - (hx >> 31))];
-	return ((int) ((float) (x + v) - v));
+	return ((int)((float)(x + v) - v));
 }
 
 int
-nintf(float x) {
+nintf(float x)
+{
 	int hx, ix, k, j, m;
 	volatile float dummy __unused;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	k = (hx & ~0x80000000) >> 23;
+
 	if (((k - 126) ^ (k - 150)) < 0) {
 		ix = (hx & 0x00ffffff) | 0x800000;
 		m = 149 - k;
 		j = 1 << m;
+
 		if ((ix & (j + j - 1)) != 0)
 			dummy = HUGEF + x;
+
 		hx = hx >> 31;
 		return ((((ix + j) >> (m + 1)) ^ hx) - hx);
-	} else
-		return ((int) x);
+	} else {
+		return ((int)x);
+	}
 }
 
 float
-rintf(float x) {
+rintf(float x)
+{
 	float w, v;
 	int hx, k;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	k = (hx & ~0x80000000) >> 23;
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 	if (k >= 150)
 		return (x * ONEF);
+
 	v = xf[1 - (hx >> 31)];
 #else
 	v = xf[((k - 150) >> 31) & (1 - (hx >> 31))];
 #endif
-	w = (float) (x + v);
+	w = (float)(x + v);
+
 	if (k < 127 && w == v)
 		return (ZEROF * x);
 	else
--- old/usr/src/lib/libm/common/R/scalbf.c	2019-06-06 20:39:22.389432325 +0000
+++ new/usr/src/lib/libm/common/R/scalbf.c	2019-06-06 20:39:22.406322450 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,8 +33,9 @@
 #include "libm.h"
 
 float
-scalbf(float x, float y) {
-	int	ix, iy, hx, hy, n;
+scalbf(float x, float y)
+{
+	int ix, iy, hx, hy, n;
 
 	ix = *(int *)&x;
 	iy = *(int *)&y;
@@ -41,20 +44,22 @@
 
 	if (hx > 0x7f800000 || hy >= 0x7f800000) {
 		/* x is nan or y is inf or nan */
-		return ((iy < 0)? x / -y : x * y);
+		return ((iy < 0) ? x / -y : x *y);
 	}
 
 	/* see if y is an integer without raising inexact */
 	if (hy >= 0x4b000000) {
 		/* |y| >= 2^23, so it must be an integer */
-		n = (iy < 0)? -65000 : 65000;
+		n = (iy < 0) ? -65000 : 65000;
 	} else if (hy < 0x3f800000) {
 		/* |y| < 1, so it must be zero or non-integer */
-		return ((hy == 0)? x : (x - x) / (x - x));
+		return ((hy == 0) ? x : (x - x) / (x - x));
 	} else {
 		if (hy & ((1 << (0x96 - (hy >> 23))) - 1))
 			return ((y - y) / (y - y));
+
 		n = (int)y;
 	}
+
 	return (scalbnf(x, n));
 }
--- old/usr/src/lib/libm/common/R/scalbnf.c	2019-06-06 20:39:22.861751136 +0000
+++ new/usr/src/lib/libm/common/R/scalbnf.c	2019-06-06 20:39:22.878653727 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,10 +31,11 @@
 #pragma weak __scalbnf = scalbnf
 
 #include "libm.h"
-#include <float.h>		/* FLT_MAX, FLT_MIN */
-#include <stdlib.h>		/* abs */
+#include <float.h>			/* FLT_MAX, FLT_MIN */
+#include <stdlib.h>			/* abs */
 
 static const float twom25f = 2.98023223876953125e-8F;
+
 #if defined(__x86)
 static const float two23f = 8388608.0F;
 #else
@@ -41,34 +43,42 @@
  * v: a non-zero subnormal |x|; returns [-22, 0]
  */
 static int
-ilogbf_biased(unsigned v) {
+ilogbf_biased(unsigned v)
+{
 	int r = -22;
 
 	if (v & 0xffff0000)
 		r += 16, v >>= 16;
+
 	if (v & 0xff00)
 		r += 8, v >>= 8;
+
 	if (v & 0xf0)
 		r += 4, v >>= 4;
+
 	v <<= 1;
 	return (r + ((0xffffaa50 >> v) & 0x3));
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 float
-scalbnf(float x, int n) {
-	int *px = (int *) &x, ix, k;
+scalbnf(float x, int n)
+{
+	int *px = (int *)&x, ix, k;
 
 	ix = *px & ~0x80000000;
 	k = ix >> 23;
+
 	if (k == 0xff)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (ix > 0x7f800000 ? x * x : x);
 #else
 		return (x + x);
 #endif
+
 	if (ix == 0 || n == 0)
 		return (x);
+
 	if (k == 0) {
 #if defined(__x86)
 		x *= two23f;
@@ -78,17 +88,23 @@
 		*px = (*px & 0x80000000) | (ix << (-k + 1));
 #endif
 	}
-	if ((unsigned) abs(n) >= 131072)	/* cast to unsigned for -2^31 */
+
+	if ((unsigned)abs(n) >= 131072)	/* cast to unsigned for -2^31 */
 		n >>= 1;		/* avoid subsequent integer overflow */
+
 	k += n;
+
 	if (k > 0xfe)
 		return (FLT_MAX * copysignf(FLT_MAX, x));
+
 	if (k <= -25)
 		return (FLT_MIN * copysignf(FLT_MIN, x));
+
 	if (k > 0) {
 		*px = (*px & ~0x7f800000) | (k << 23);
 		return (x);
 	}
+
 	k += 25;
 	*px = (*px & ~0x7f800000) | (k << 23);
 	return (x * twom25f);
--- old/usr/src/lib/libm/common/R/signgamf.c	2019-06-06 20:39:23.331178992 +0000
+++ new/usr/src/lib/libm/common/R/signgamf.c	2019-06-06 20:39:23.349481374 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
--- old/usr/src/lib/libm/common/R/significandf.c	2019-06-06 20:39:23.826910812 +0000
+++ new/usr/src/lib/libm/common/R/significandf.c	2019-06-06 20:39:23.845144334 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,8 +33,9 @@
 #include "libm.h"
 
 float
-significandf(float x) {
-	int ix = *(int *) &x & ~0x80000000;
+significandf(float x)
+{
+	int ix = *(int *)&x & ~0x80000000;
 
 	if (ix == 0 || ix >= 0x7f800000)	/* 0/+-Inf/NaN */
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
--- old/usr/src/lib/libm/common/R/sincosf.c	2019-06-06 20:39:24.347168335 +0000
+++ new/usr/src/lib/libm/common/R/sincosf.c	2019-06-06 20:39:24.371097282 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak __sincosf = sincosf
 
-/* INDENT OFF */
+
 /*
  * For |x| < pi/4, let z = x * x, and approximate sin(x) by
  *
@@ -52,12 +54,12 @@
  *
  * with error bounded by |cos(x) - C(x)| < 2**(-34.2).
  */
-/* INDENT ON */
 
 #include "libm.h"
 
 extern const int _TBL_ipio2_inf[];
 extern int __rem_pio2m(double *, double *, int, int, int, const int *);
+
 #if defined(__i386) && !defined(__amd64)
 extern int __swapRP(int);
 #endif
@@ -78,26 +80,26 @@
 	6.077100506506192601475e-11,	/* 2^-34  * 1.0B4611A626331 */
 };
 
-#define	S0	C[0]
-#define	S1	C[1]
-#define	S2	C[2]
-#define	S3	C[3]
-#define	C0	C[4]
-#define	C1	C[5]
-#define	C2	C[6]
-#define	C3	C[7]
-#define	C4	C[8]
-#define	invpio2	C[9]
-#define	half	C[10]
-#define	pio2_1  C[11]
-#define	pio2_t	C[12]
+#define	S0		C[0]
+#define	S1		C[1]
+#define	S2		C[2]
+#define	S3		C[3]
+#define	C0		C[4]
+#define	C1		C[5]
+#define	C2		C[6]
+#define	C3		C[7]
+#define	C4		C[8]
+#define	invpio2		C[9]
+#define	half		C[10]
+#define	pio2_1		C[11]
+#define	pio2_t		C[12]
 
 void
 sincosf(float x, float *s, float *c)
 {
-	double	y, z, w;
-	float	f, g;
-	int	n, ix, hx, hy;
+	double y, z, w;
+	float f, g;
+	int n, ix, hx, hy;
 	volatile int i __unused;
 
 	hx = *((int *)&x);
@@ -105,7 +107,7 @@
 
 	y = (double)x;
 
-	if (ix <= 0x4016cbe4) {		/* |x| < 3*pi/4 */
+	if (ix <= 0x4016cbe4) {			/* |x| < 3*pi/4 */
 		if (ix <= 0x3f490fdb) {		/* |x| < pi/4 */
 			if (ix <= 0x39800000) {	/* |x| <= 2**-12 */
 				i = (int)y;
@@ -116,38 +118,40 @@
 				*c = 1.0f;
 				return;
 			}
+
 			z = y * y;
-			*s = (float)((y * (S0 + z * S1)) *
-			    (S2 + z * (S3 + z)));
-			*c = (float)(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z)));
+			*s = (float)((y * (S0 + z * S1)) * (S2 + z * (S3 + z)));
+			*c = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z *
+			    (C4 + z)));
 		} else if (hx > 0) {
 			y = (y - pio2_1) - pio2_t;
 			z = y * y;
-			*s = (float)(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z)));
-			*c = (float)-((y * (S0 + z * S1)) *
-			    (S2 + z * (S3 + z)));
+			*s = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z *
+			    (C4 + z)));
+			*c = (float)-((y * (S0 + z * S1)) * (S2 + z * (S3 +
+			    z)));
 		} else {
 			y = (y + pio2_1) + pio2_t;
 			z = y * y;
-			*s = (float)-(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z)));
-			*c = (float)((y * (S0 + z * S1)) *
-			    (S2 + z * (S3 + z)));
+			*s = (float)-(((C0 + z * C1) + (z * z) * C2) * (C3 + z *
+			    (C4 + z)));
+			*c = (float)((y * (S0 + z * S1)) * (S2 + z * (S3 + z)));
 		}
+
 		return;
 	} else if (ix <= 0x49c90fdb) {	/* |x| < 2^19*pi */
 #if defined(__i386) && !defined(__amd64)
-		int	rp;
+		int rp;
 
 		rp = __swapRP(fp_extended);
 #endif
 		w = y * invpio2;
+
 		if (hx < 0)
 			n = (int)(w - half);
 		else
 			n = (int)(w + half);
+
 		y = (y - n * pio2_1) - n * pio2_t;
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
@@ -158,11 +162,13 @@
 			*s = *c = x / x;
 			return;
 		}
+
 		hy = ((int *)&y)[HIWORD];
 		n = ((hy >> 20) & 0x7ff) - 1046;
 		((int *)&w)[HIWORD] = (hy & 0xfffff) | 0x41600000;
 		((int *)&w)[LOWORD] = ((int *)&y)[LOWORD];
 		n = __rem_pio2m(&w, &y, n, 1, 0, _TBL_ipio2_inf);
+
 		if (hy < 0) {
 			y = -y;
 			n = -n;
@@ -171,12 +177,13 @@
 
 	z = y * y;
 	f = (float)((y * (S0 + z * S1)) * (S2 + z * (S3 + z)));
-	g = (float)(((C0 + z * C1) + (z * z) * C2) *
-	    (C3 + z * (C4 + z)));
+	g = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 + z)));
+
 	if (n & 2) {
 		f = -f;
 		g = -g;
 	}
+
 	if (n & 1) {
 		*s = g;
 		*c = -f;
--- old/usr/src/lib/libm/common/R/sincospif.c	2019-06-06 20:39:24.885025809 +0000
+++ new/usr/src/lib/libm/common/R/sincospif.c	2019-06-06 20:39:24.902710106 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,18 +33,19 @@
 extern void sincospi(double, double *, double *);
 
 void
-sincospif(float x, float *s, float *c) {
+sincospif(float x, float *s, float *c)
+{
 	double ds, dc;
 
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
-	if (isnanf(x))
+	if (isnanf(x)) {
 		*s = *c = x * x;
-	else {
+	} else {
 #endif
-	sincospi((double) x, &ds, &dc);
-	*s = (float) ds;
-	*c = (float) dc;
+	sincospi((double)x, &ds, &dc);
+	*s = (float)ds;
+	*c = (float)dc;
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
-	}
+}
 #endif
 }
--- old/usr/src/lib/libm/common/R/sinf.c	2019-06-06 20:39:25.368689386 +0000
+++ new/usr/src/lib/libm/common/R/sinf.c	2019-06-06 20:39:25.387771287 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,6 +38,7 @@
 
 extern const int _TBL_ipio2_inf[];
 extern int __rem_pio2m(double *, double *, int, int, int, const int *);
+
 #if defined(__i386) && !defined(__amd64)
 extern int __swapRP(int);
 #endif
@@ -56,26 +59,26 @@
 	6.077100506506192601475e-11,	/* 2^-34  * 1.0B4611A626331 */
 };
 
-#define	S0	C[0]
-#define	S1	C[1]
-#define	S2	C[2]
-#define	S3	C[3]
-#define	C0	C[4]
-#define	C1	C[5]
-#define	C2	C[6]
-#define	C3	C[7]
-#define	C4	C[8]
-#define	invpio2	C[9]
-#define	half	C[10]
-#define	pio2_1  C[11]
-#define	pio2_t	C[12]
+#define	S0		C[0]
+#define	S1		C[1]
+#define	S2		C[2]
+#define	S3		C[3]
+#define	C0		C[4]
+#define	C1		C[5]
+#define	C2		C[6]
+#define	C3		C[7]
+#define	C4		C[8]
+#define	invpio2		C[9]
+#define	half		C[10]
+#define	pio2_1		C[11]
+#define	pio2_t		C[12]
 
 float
 sinf(float x)
 {
-	double	y, z, w;
-	float	f;
-	int	n, ix, hx, hy;
+	double y, z, w;
+	float f;
+	int n, ix, hx, hy;
 	volatile int i __unused;
 
 	hx = *((int *)&x);
@@ -83,7 +86,7 @@
 
 	y = (double)x;
 
-	if (ix <= 0x4016cbe4) {		/* |x| < 3*pi/4 */
+	if (ix <= 0x4016cbe4) {			/* |x| < 3*pi/4 */
 		if (ix <= 0x3f490fdb) {		/* |x| < pi/4 */
 			if (ix <= 0x39800000) {	/* |x| <= 2**-12 */
 				i = (int)y;
@@ -92,31 +95,34 @@
 #endif
 				return (x);
 			}
+
 			z = y * y;
-			return ((float)((y * (S0 + z * S1)) *
-			    (S2 + z * (S3 + z))));
+			return ((float)((y * (S0 + z * S1)) * (S2 + z *
+			    (S3 + z))));
 		} else if (hx > 0) {
 			y = (y - pio2_1) - pio2_t;
 			z = y * y;
-			return ((float)(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z))));
+			return ((float)(((C0 + z * C1) + (z * z) * C2) * (C3 +
+			    z * (C4 + z))));
 		} else {
 			y = (y + pio2_1) + pio2_t;
 			z = y * y;
-			return ((float)-(((C0 + z * C1) + (z * z) * C2) *
-			    (C3 + z * (C4 + z))));
+			return ((float)-(((C0 + z * C1) + (z * z) * C2) * (C3 +
+			    z * (C4 + z))));
 		}
 	} else if (ix <= 0x49c90fdb) {	/* |x| < 2^19*pi */
 #if defined(__i386) && !defined(__amd64)
-		int	rp;
+		int rp;
 
 		rp = __swapRP(fp_extended);
 #endif
 		w = y * invpio2;
+
 		if (hx < 0)
 			n = (int)(w - half);
 		else
 			n = (int)(w + half);
+
 		y = (y - n * pio2_1) - n * pio2_t;
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
@@ -124,12 +130,14 @@
 #endif
 	} else {
 		if (ix >= 0x7f800000)
-			return (x / x);	/* sin(Inf or NaN) is NaN */
+			return (x / x);		/* sin(Inf or NaN) is NaN */
+
 		hy = ((int *)&y)[HIWORD];
 		n = ((hy >> 20) & 0x7ff) - 1046;
 		((int *)&w)[HIWORD] = (hy & 0xfffff) | 0x41600000;
 		((int *)&w)[LOWORD] = ((int *)&y)[LOWORD];
 		n = __rem_pio2m(&w, &y, n, 1, 0, _TBL_ipio2_inf);
+
 		if (hy < 0) {
 			y = -y;
 			n = -n;
@@ -139,13 +147,13 @@
 	if (n & 1) {
 		/* compute cos y */
 		z = y * y;
-		f = (float)(((C0 + z * C1) + (z * z) * C2) *
-		    (C3 + z * (C4 + z)));
+		f = (float)(((C0 + z * C1) + (z * z) * C2) * (C3 + z * (C4 +
+		    z)));
 	} else {
 		/* compute sin y */
 		z = y * y;
 		f = (float)((y * (S0 + z * S1)) * (S2 + z * (S3 + z)));
 	}
 
-	return ((n & 2)? -f : f);
+	return ((n & 2) ? -f : f);
 }
--- old/usr/src/lib/libm/common/R/sinhf.c	2019-06-06 20:39:25.875420761 +0000
+++ new/usr/src/lib/libm/common/R/sinhf.c	2019-06-06 20:39:25.893070864 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -31,21 +33,25 @@
 #include "libm.h"
 
 float
-sinhf(float x) {
-	double	s;
-	float	w;
-	int	hx, ix;
+sinhf(float x)
+{
+	double s;
+	float w;
+	int hx, ix;
 
 	hx = *(int *)&x;
 	ix = hx & ~0x80000000;
+
 	if (ix >= 0x7f800000) {
 		/* sinhf(x) is x if x is +-Inf or NaN */
 		return (x * 1.0f);
 	}
-	if (ix >= 0x43000000)	/* sinhf(x) trivially overflows */
-		s = (hx < 0)? -1.0e100 : 1.0e100;
+
+	if (ix >= 0x43000000)		/* sinhf(x) trivially overflows */
+		s = (hx < 0) ? -1.0e100 : 1.0e100;
 	else
 		s = sinh((double)x);
+
 	w = (float)s;
 	return (w);
 }
--- old/usr/src/lib/libm/common/R/sqrtf.c	2019-06-06 20:39:26.347614661 +0000
+++ new/usr/src/lib/libm/common/R/sqrtf.c	2019-06-06 20:39:26.365947084 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,11 +32,10 @@
 
 #include "libm.h"
 
-
 extern float __inline_sqrtf(float);
 
 float
-sqrtf(float x) {
+sqrtf(float x)
+{
 	return (__inline_sqrtf(x));
 }
-
--- old/usr/src/lib/libm/common/R/tanf.c	2019-06-06 20:39:26.846278222 +0000
+++ new/usr/src/lib/libm/common/R/tanf.c	2019-06-06 20:39:26.865736776 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,6 +34,7 @@
 
 extern const int _TBL_ipio2_inf[];
 extern int __rem_pio2m(double *, double *, int, int, int, const int *);
+
 #if defined(__i386) && !defined(__amd64)
 extern int __swapRP(int);
 #endif
@@ -54,28 +57,28 @@
 	6.077100506506192601475e-11,	/* 2^-34  * 1.0B4611A626331 */
 };
 
-#define	one	C[0]
-#define	P0	C[1]
-#define	P1	C[2]
-#define	P2	C[3]
-#define	P3	C[4]
-#define	P4	C[5]
-#define	P5	C[6]
-#define	P6	C[7]
-#define	P7	C[8]
-#define	T0	C[9]
-#define	T1	C[10]
-#define	invpio2	C[11]
-#define	half	C[12]
-#define	pio2_1  C[13]
-#define	pio2_t	C[14]
+#define	one		C[0]
+#define	P0		C[1]
+#define	P1		C[2]
+#define	P2		C[3]
+#define	P3		C[4]
+#define	P4		C[5]
+#define	P5		C[6]
+#define	P6		C[7]
+#define	P7		C[8]
+#define	T0		C[9]
+#define	T1		C[10]
+#define	invpio2		C[11]
+#define	half		C[12]
+#define	pio2_1		C[13]
+#define	pio2_t		C[14]
 
 float
 tanf(float x)
 {
-	double	y, z, w;
-	float	f;
-	int	n, ix, hx, hy;
+	double y, z, w;
+	float f;
+	int n, ix, hx, hy;
 	volatile int i __unused;
 
 	hx = *((int *)&x);
@@ -83,8 +86,8 @@
 
 	y = (double)x;
 
-	if (ix <= 0x4016cbe4) {		/* |x| < 3*pi/4 */
-		if (ix <= 0x3f490fdb) {		/* |x| < pi/4 */
+	if (ix <= 0x4016cbe4) {				/* |x| < 3*pi/4 */
+		if (ix <= 0x3f490fdb) {			/* |x| < pi/4 */
 			if (ix < 0x3c000000) {		/* |x| < 2**-7 */
 				if (ix <= 0x39800000) {	/* |x| < 2**-12 */
 					i = (int)y;
@@ -93,39 +96,47 @@
 #endif
 					return (x);
 				}
+
 				return ((float)((y * T0) * (T1 + y * y)));
 			}
+
 			z = y * y;
-			return ((float)(((P0 * y) * (P1 + z * (P2 + z)) *
-			    (P3 + z * (P4 + z))) *
-			    (P5 + z * (P6 + z * (P7 + z)))));
+			return ((float)(((P0 * y) * (P1 + z * (P2 + z)) * (P3 +
+			    z * (P4 + z))) * (P5 + z * (P6 + z *
+			    (P7 + z)))));
 		}
+
 		if (hx > 0)
 			y = (y - pio2_1) - pio2_t;
 		else
 			y = (y + pio2_1) + pio2_t;
+
 		hy = ((int *)&y)[HIWORD] & ~0x80000000;
-		if (hy < 0x3f800000) {		/* |y| < 2**-7 */
+
+		if (hy < 0x3f800000) {	/* |y| < 2**-7 */
 			z = (y * T0) * (T1 + y * y);
 			return ((float)(-one / z));
 		}
+
 		z = y * y;
 		w = ((P0 * y) * (P1 + z * (P2 + z)) * (P3 + z * (P4 + z))) *
 		    (P5 + z * (P6 + z * (P7 + z)));
 		return ((float)(-one / w));
 	}
 
-	if (ix <= 0x49c90fdb) {	/* |x| < 2^19*pi */
+	if (ix <= 0x49c90fdb) {		/* |x| < 2^19*pi */
 #if defined(__i386) && !defined(__amd64)
-		int	rp;
+		int rp;
 
 		rp = __swapRP(fp_extended);
 #endif
 		w = y * invpio2;
+
 		if (hx < 0)
 			n = (int)(w - half);
 		else
 			n = (int)(w + half);
+
 		y = (y - n * pio2_1) - n * pio2_t;
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
@@ -133,12 +144,14 @@
 #endif
 	} else {
 		if (ix >= 0x7f800000)
-			return (x / x);	/* sin(Inf or NaN) is NaN */
+			return (x / x);		/* sin(Inf or NaN) is NaN */
+
 		hy = ((int *)&y)[HIWORD];
 		n = ((hy >> 20) & 0x7ff) - 1046;
 		((int *)&w)[HIWORD] = (hy & 0xfffff) | 0x41600000;
 		((int *)&w)[LOWORD] = ((int *)&y)[LOWORD];
 		n = __rem_pio2m(&w, &y, n, 1, 0, _TBL_ipio2_inf);
+
 		if (hy < 0) {
 			y = -y;
 			n = -n;
@@ -146,14 +159,16 @@
 	}
 
 	hy = ((int *)&y)[HIWORD] & ~0x80000000;
+
 	if (hy < 0x3f800000) {		/* |y| < 2**-7 */
 		z = (y * T0) * (T1 + y * y);
-		f = ((n & 1) == 0)? (float)z : (float)(-one / z);
+		f = ((n & 1) == 0) ? (float)z : (float)(-one / z);
 		return (f);
 	}
+
 	z = y * y;
-	w = ((P0 * y) * (P1 + z * (P2 + z)) * (P3 + z * (P4 + z))) *
-	    (P5 + z * (P6 + z * (P7 + z)));
-	f = ((n & 1) == 0)? (float)w : (float)(-one / w);
+	w = ((P0 * y) * (P1 + z * (P2 + z)) * (P3 + z * (P4 + z))) * (P5 + z *
+	    (P6 + z * (P7 + z)));
+	f = ((n & 1) == 0) ? (float)w : (float)(-one / w);
 	return (f);
 }
--- old/usr/src/lib/libm/common/R/tanhf.c	2019-06-06 20:39:27.363680101 +0000
+++ new/usr/src/lib/libm/common/R/tanhf.c	2019-06-06 20:39:27.381430777 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,11 +33,12 @@
 #include "libm.h"
 
 float
-tanhf(float x) {
+tanhf(float x)
+{
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 	if (isnanf(x))
 		return (x * x);
 	else
 #endif
-	return ((float) tanh((double) x));
+	return ((float)tanh((double)x));
 }
--- old/usr/src/lib/libm/common/complex/cabs.c	2019-06-06 20:39:27.853865148 +0000
+++ new/usr/src/lib/libm/common/complex/cabs.c	2019-06-06 20:39:27.871974088 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -40,19 +42,18 @@
  * the hypot implementation here.  I've chosen to do the latter.
  */
 
-static const double
-	zero = 0.0,
+static const double zero = 0.0,
 	onep1u = 1.00000000000000022204e+00,	/* 0x3ff00000 1 = 1+2**-52 */
 	twom53 = 1.11022302462515654042e-16,	/* 0x3ca00000 0 = 2**-53 */
 	twom768 = 6.441148769597133308e-232,	/* 2^-768 */
-	two768  = 1.552518092300708935e+231;	/* 2^768 */
+	two768 = 1.552518092300708935e+231;	/* 2^768 */
 
 double
 cabs(dcomplex z)
 {
-	double		x, y, xh, yh, w, ax, ay;
-	int		i, j, nx, ny, ix, iy, iscale = 0;
-	unsigned	lx, ly;
+	double x, y, xh, yh, w, ax, ay;
+	int i, j, nx, ny, ix, iy, iscale = 0;
+	unsigned lx, ly;
 
 	x = D_RE(z);
 	y = D_IM(z);
@@ -76,27 +77,30 @@
 		ax = fabs(x);
 		ay = fabs(y);
 	}
+
 	nx = ix >> 20;
 	ny = iy >> 20;
-	j  = nx - ny;
+	j = nx - ny;
 
 	if (nx >= 0x5f3) {
 		/* x >= 2^500 (x*x or y*y may overflow) */
 		if (nx == 0x7ff) {
 			/* inf or NaN, signal of sNaN */
 			if (((ix - 0x7ff00000) | lx) == 0)
-				return ((ax == ay)? ay : ax);
+				return ((ax == ay) ? ay : ax);
 			else if (((iy - 0x7ff00000) | ly) == 0)
-				return ((ay == ax)? ax : ay);
+				return ((ay == ax) ? ax : ay);
 			else
 				return (ax * ay);
 		} else if (j > 32) {
 			/* x >> y */
 			if (j <= 53)
 				ay *= twom53;
+
 			ax += ay;
 			return (ax);
 		}
+
 		ax *= twom768;
 		ay *= twom768;
 		iscale = 2;
@@ -106,38 +110,49 @@
 		/* y < 2^-450 (x*x or y*y may underflow) */
 		if ((ix | lx) == 0)
 			return (ay);
+
 		if ((iy | ly) == 0)
 			return (ax);
-		if (j > 53) 		/* x >> y */
+
+		if (j > 53)		/* x >> y */
 			return (ax + ay);
+
 		iscale = 1;
 		ax *= two768;
 		ay *= two768;
+
 		if (nx == 0) {
 			if (ax == zero)	/* guard subnormal flush to zero */
 				return (ax);
+
 			ix = ((int *)&ax)[HIWORD];
 		} else {
 			ix += 768 << 20;
 		}
+
 		if (ny == 0) {
 			if (ay == zero)	/* guard subnormal flush to zero */
 				return (ax * twom768);
+
 			iy = ((int *)&ay)[HIWORD];
 		} else {
 			iy += 768 << 20;
 		}
+
 		j = (ix >> 20) - (iy >> 20);
+
 		if (j > 32) {
 			/* x >> y */
 			if (j <= 53)
 				ay *= twom53;
+
 			return ((ax + ay) * twom768);
 		}
 	} else if (j > 32) {
 		/* x >> y */
 		if (j <= 53)
 			ay *= twom53;
+
 		return (ax + ay);
 	}
 
@@ -150,13 +165,16 @@
 		ay = ay * ay;
 		ax += ay / (ax + sqrt(ax * ax + ay));
 	} else if (onep1u * onep1u != onep1u + twom53) {
-		/* round-to-zero, positive, negative mode */
-		/* magic formula with less than an ulp error */
+		/*
+		 * round-to-zero, positive, negative mode
+		 * magic formula with less than an ulp error
+		 */
 		w = sqrt(ax * ax + ay * ay);
 		ax += ay / ((ax + w) / ay);
 	} else {
 		/* round-to-nearest mode */
 		w = ax - ay;
+
 		if (w > ay) {
 			((int *)&xh)[HIWORD] = ix;
 			((int *)&xh)[LOWORD] = 0;
@@ -172,11 +190,13 @@
 			ax = sqrt(xh * yh + ay);
 		}
 	}
+
 	if (iscale > 0) {
 		if (iscale == 1)
 			ax *= twom768;
 		else
 			ax *= two768;	/* must generate side effect here */
 	}
+
 	return (ax);
 }
--- old/usr/src/lib/libm/common/complex/cabsf.c	2019-06-06 20:39:28.370661165 +0000
+++ new/usr/src/lib/libm/common/complex/cabsf.c	2019-06-06 20:39:28.388668096 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 float
-cabsf(fcomplex z) {
+cabsf(fcomplex z)
+{
 	return (hypotf(F_RE(z), F_IM(z)));
 }
--- old/usr/src/lib/libm/common/complex/cabsl.c	2019-06-06 20:39:28.863160780 +0000
+++ new/usr/src/lib/libm/common/complex/cabsl.c	2019-06-06 20:39:28.881122599 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 long double
-cabsl(ldcomplex z) {
+cabsl(ldcomplex z)
+{
 	return (hypotl(LD_RE(z), LD_IM(z)));
 }
--- old/usr/src/lib/libm/common/complex/cacos.c	2019-06-06 20:39:29.364492745 +0000
+++ new/usr/src/lib/libm/common/complex/cacos.c	2019-06-06 20:39:29.382854276 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __cacos = cacos
 
-/* INDENT OFF */
+
 /*
  * dcomplex cacos(dcomplex z);
  *
@@ -41,7 +42,7 @@
  * The principal value of complex inverse cosine function cacos(z),
  * where z = x+iy, can be defined by
  *
- * 	cacos(z) = acos(B) - i sign(y) log (A + sqrt(A*A-1)),
+ *      cacos(z) = acos(B) - i sign(y) log (A + sqrt(A*A-1)),
  *
  * where the log function is the natural log, and
  *             ____________           ____________
@@ -152,7 +153,7 @@
  *	   A = (sqrt(4+y*y)+y)/2 ~ 1 + y/2 + y^2/8 + ...
  *	and
  *	   B = 1/A = 1 - y/2 + y^2/8 + ...
- * 	Since
+ *      Since
  *         cos(sqrt(y)) ~ 1 - y/2 + ...
  *      we have, for the real part,
  *         acos(B) ~ acos(1 - y/2) ~ sqrt(y)
@@ -165,7 +166,7 @@
  *
  *  case 4. y >= (x+1)/ulp(0.5). In this case, A ~ y and B ~ x/y. Thus
  *	   real part = acos(B) ~ pi/2
- * 	and
+ *      and
  *	   imag part = log(y+sqrt(y*y-one))
  *
  *  case 5. Both x and y are large: x and y > sqrt(M)/8, where M = maximum x
@@ -188,18 +189,15 @@
  *	              = 0.5*log(1+2y(y+sqrt(1+y^2)));
  *	              = 0.5*log1p(2y(y+A));
  *
- * 	cacos(z) = acos(B) - i sign(y) log (A + sqrt(A*A-1)),
+ *      cacos(z) = acos(B) - i sign(y) log (A + sqrt(A*A-1)),
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
-static const double
-	zero = 0.0,
+static const double zero = 0.0,
 	one = 1.0,
-	E = 1.11022302462515654042e-16,			/* 2**-53 */
+	E = 1.11022302462515654042e-16,	/* 2**-53 */
 	ln2 = 6.93147180559945286227e-01,
 	pi = 3.1415926535897931159979634685,
 	pi_l = 1.224646799147353177e-16,
@@ -213,10 +211,11 @@
 	Acrossover = 1.5,
 	Bcrossover = 0.6417,
 	half = 0.5;
-/* INDENT ON */
+
 
 dcomplex
-cacos(dcomplex z) {
+cacos(dcomplex z)
+{
 	double x, y, t, R, S, A, Am1, B, y2, xm1, xp1, Apx;
 	int ix, iy, hx, hy;
 	unsigned lx, ly;
@@ -244,6 +243,7 @@
 	if (iy >= 0x7ff00000) {
 		if (ISINF(iy, ly)) {	/* cacos(x + i inf) = pi/2  - i inf */
 			D_IM(ans) = -y;
+
 			if (ix < 0x7ff00000) {
 				D_RE(ans) = pi_2 + pi_2_l;
 			} else if (ISINF(ix, lx)) {
@@ -256,11 +256,13 @@
 			}
 		} else {		/* cacos(x + i NaN) = NaN  + i NaN */
 			D_RE(ans) = y + x;
+
 			if (ISINF(ix, lx))
 				D_IM(ans) = -fabs(x);
 			else
 				D_IM(ans) = y;
 		}
+
 		return (ans);
 	}
 
@@ -268,71 +270,76 @@
 	y = fabs(y);
 
 	/* x is inf or NaN */
-	if (ix >= 0x7ff00000) {	/* x is inf or NaN */
+	if (ix >= 0x7ff00000) {		/* x is inf or NaN */
 		if (ISINF(ix, lx)) {	/* x is INF */
 			D_IM(ans) = -x;
+
 			if (iy >= 0x7ff00000) {
 				if (ISINF(iy, ly)) {
-					/* INDENT OFF */
-					/* cacos(inf + i inf) = pi/4 - i inf */
-					/* cacos(-inf+ i inf) =3pi/4 - i inf */
-					/* INDENT ON */
+					/*
+					 * cacos(inf + i inf) = pi/4 - i inf
+					 * cacos(-inf+ i inf) =3pi/4 - i inf
+					 */
 					if (hx >= 0)
 						D_RE(ans) = pi_4 + pi_4_l;
 					else
 						D_RE(ans) = pi3_4 + pi3_4_l;
-				} else
-					/* INDENT OFF */
-					/* cacos(inf + i NaN) = NaN  - i inf  */
-					/* INDENT ON */
+				} else {
+					/*
+					 * cacos(inf + i NaN) = NaN  - i inf
+					 */
 					D_RE(ans) = y + y;
+				}
 			} else
-				/* INDENT OFF */
-				/* cacos(inf + iy ) = 0  - i inf */
-				/* cacos(-inf+ iy  ) = pi - i inf */
-				/* INDENT ON */
-			if (hx >= 0)
+			/*
+			 * cacos(inf + iy ) = 0  - i inf
+			 * cacos(-inf+ iy  ) = pi - i inf
+			 */
+			if (hx >= 0) {
 				D_RE(ans) = zero;
-			else
+			} else {
 				D_RE(ans) = pi + pi_l;
+			}
 		} else {		/* x is NaN */
-			/* INDENT OFF */
+
 			/*
 			 * cacos(NaN + i inf) = NaN  - i inf
 			 * cacos(NaN + i y  ) = NaN  + i NaN
 			 * cacos(NaN + i NaN) = NaN  + i NaN
 			 */
-			/* INDENT ON */
 			D_RE(ans) = x + y;
-			if (iy >= 0x7ff00000) {
+
+			if (iy >= 0x7ff00000)
 				D_IM(ans) = -y;
-			} else {
+			else
 				D_IM(ans) = x;
-			}
 		}
+
 		if (hy < 0)
 			D_IM(ans) = -D_IM(ans);
+
 		return (ans);
 	}
 
-	if ((iy | ly) == 0) {	/* region 1: y=0 */
+	if ((iy | ly) == 0) {		/* region 1: y=0 */
 		if (ix < 0x3ff00000) {	/* |x| < 1 */
 			D_RE(ans) = acos(x);
 			D_IM(ans) = zero;
 		} else {
 			D_RE(ans) = zero;
-			if (ix >= 0x43500000)	/* |x| >= 2**54 */
+
+			if (ix >= 0x43500000) {		/* |x| >= 2**54 */
 				D_IM(ans) = ln2 + log(x);
-			else if (ix >= 0x3ff80000)	/* x > Acrossover */
+			} else if (ix >= 0x3ff80000) {	/* x > Acrossover */
 				D_IM(ans) = log(x + sqrt((x - one) * (x +
-					one)));
-			else {
+				    one)));
+			} else {
 				xm1 = x - one;
 				D_IM(ans) = log1p(xm1 + sqrt(xm1 * (x + one)));
 			}
 		}
 	} else if (y <= E * fabs(x - one)) {	/* region 2: y < tiny*|x-1| */
-		if (ix < 0x3ff00000) {	/* x < 1 */
+		if (ix < 0x3ff00000) {		/* x < 1 */
 			D_RE(ans) = acos(x);
 			D_IM(ans) = y / sqrt((one + x) * (one - x));
 		} else if (ix >= 0x43500000) {	/* |x| >= 2**54 */
@@ -341,6 +348,7 @@
 		} else {
 			t = sqrt((x - one) * (x + one));
 			D_RE(ans) = y / t;
+
 			if (ix >= 0x3ff80000)	/* x > Acrossover */
 				D_IM(ans) = log(x + t);
 			else
@@ -350,7 +358,7 @@
 		t = sqrt(y);
 		D_RE(ans) = t;
 		D_IM(ans) = t;
-	} else if (E * y - one >= x) {	/* region 4 */
+	} else if (E * y - one >= x) {				/* region 4 */
 		D_RE(ans) = pi_2;
 		D_IM(ans) = ln2 + log(y);
 	} else if (ix >= 0x5fc00000 || iy >= 0x5fc00000) {	/* x,y>2**509 */
@@ -362,11 +370,12 @@
 		/* region 6: x is very small, < 4sqrt(min) */
 		D_RE(ans) = pi_2;
 		A = sqrt(one + y * y);
+
 		if (iy >= 0x3ff80000)	/* if y > Acrossover */
 			D_IM(ans) = log(y + A);
 		else
 			D_IM(ans) = half * log1p((y + y) * (y + A));
-	} else {	/* safe region */
+	} else {			/* safe region */
 		y2 = y * y;
 		xp1 = x + one;
 		xm1 = x - one;
@@ -374,31 +383,38 @@
 		S = sqrt(xm1 * xm1 + y2);
 		A = half * (R + S);
 		B = x / A;
-		if (B <= Bcrossover)
+
+		if (B <= Bcrossover) {
 			D_RE(ans) = acos(B);
-		else {		/* use atan and an accurate approx to a-x */
+		} else {	/* use atan and an accurate approx to a-x */
 			Apx = A + x;
+
 			if (x <= one)
 				D_RE(ans) = atan(sqrt(half * Apx * (y2 / (R +
-					xp1) + (S - xm1))) / x);
+				    xp1) + (S - xm1))) / x);
 			else
 				D_RE(ans) = atan((y * sqrt(half * (Apx / (R +
-					xp1) + Apx / (S + xm1)))) / x);
+				    xp1) + Apx / (S + xm1)))) / x);
 		}
+
 		if (A <= Acrossover) {
 			/* use log1p and an accurate approx to A-1 */
 			if (x < one)
 				Am1 = half * (y2 / (R + xp1) + y2 / (S - xm1));
 			else
 				Am1 = half * (y2 / (R + xp1) + (S + xm1));
+
 			D_IM(ans) = log1p(Am1 + sqrt(Am1 * (A + one)));
 		} else {
 			D_IM(ans) = log(A + sqrt(A * A - one));
 		}
 	}
+
 	if (hx < 0)
 		D_RE(ans) = pi - D_RE(ans);
+
 	if (hy >= 0)
 		D_IM(ans) = -D_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cacosf.c	2019-06-06 20:39:29.916808137 +0000
+++ new/usr/src/lib/libm/common/complex/cacosf.c	2019-06-06 20:39:29.934770576 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,14 +34,15 @@
 #include "complex_wrapper.h"
 
 fcomplex
-cacosf(fcomplex z) {
+cacosf(fcomplex z)
+{
 	dcomplex dz, dans;
 	fcomplex ans;
 
-	D_RE(dz) = (double) (F_RE(z));
-	D_IM(dz) = (double) (F_IM(z));
+	D_RE(dz) = (double)(F_RE(z));
+	D_IM(dz) = (double)(F_IM(z));
 	dans = cacos(dz);
-	F_RE(ans) = (float) (D_RE(dans));
-	F_IM(ans) = (float) (D_IM(dans));
+	F_RE(ans) = (float)(D_RE(dans));
+	F_IM(ans) = (float)(D_IM(dans));
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cacosh.c	2019-06-06 20:39:30.436997642 +0000
+++ new/usr/src/lib/libm/common/complex/cacosh.c	2019-06-06 20:39:30.455246989 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __cacosh = cacosh
 
-/* INDENT OFF */
+
 /*
  * dcomplex cacosh(dcomplex z);
  *	cacosh z = +-i cacos z .
@@ -38,23 +39,25 @@
  *	cacosh z = sign(Im(z))*i cacos z .
  *
  */
-/* INDENT ON */
 
-#include "libm.h"	/* fabs/isnan/isinf/signbit */
+#include "libm.h"			/* fabs/isnan/isinf/signbit */
 #include "complex_wrapper.h"
 
 /* need to work on special cases according to spec */
 
 dcomplex
-cacosh(dcomplex z) {
+cacosh(dcomplex z)
+{
 	dcomplex w, ans;
 	double x, y;
 
 	w = cacos(z);
 	x = D_RE(z);
 	y = D_IM(z);
+
 	if (isnan(y)) {
 		D_IM(ans) = y + y;
+
 		if (isinf(x))
 			D_RE(ans) = fabs(x);
 		else
@@ -66,5 +69,6 @@
 		D_RE(ans) = D_IM(w);
 		D_IM(ans) = -D_RE(w);
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cacoshf.c	2019-06-06 20:39:30.952904894 +0000
+++ new/usr/src/lib/libm/common/complex/cacoshf.c	2019-06-06 20:39:30.971764927 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,14 +36,15 @@
 /* need to work on special cases according to spec */
 
 fcomplex
-cacoshf(fcomplex z) {
+cacoshf(fcomplex z)
+{
 	dcomplex dz, dans;
 	fcomplex ans;
 
-	D_RE(dz) = (double) (F_RE(z));
-	D_IM(dz) = (double) (F_IM(z));
+	D_RE(dz) = (double)(F_RE(z));
+	D_IM(dz) = (double)(F_IM(z));
 	dans = cacosh(dz);
-	F_RE(ans) = (float) (D_RE(dans));
-	F_IM(ans) = (float) (D_IM(dans));
+	F_RE(ans) = (float)(D_RE(dans));
+	F_IM(ans) = (float)(D_IM(dans));
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cacoshl.c	2019-06-06 20:39:31.484875301 +0000
+++ new/usr/src/lib/libm/common/complex/cacoshl.c	2019-06-06 20:39:31.502674840 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,11 +30,11 @@
 
 #pragma weak __cacoshl = cacoshl
 
-#include "libm.h"	/* fabsl/isnanl/isinfl/signbitl */
+#include "libm.h"			/* fabsl/isnanl/isinfl/signbitl */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
+
 /*
  * ldcomplex cacoshl(ldcomplex z);
  *	cacosh z = +-i cacos z .
@@ -42,18 +43,20 @@
  *	cacosh z = sign(Im(z))*i cacos z .
  *
  */
-/* INDENT ON */
 
 ldcomplex
-cacoshl(ldcomplex z) {
+cacoshl(ldcomplex z)
+{
 	ldcomplex w, ans;
 	long double x, y;
 
 	w = cacosl(z);
 	x = LD_RE(z);
 	y = LD_IM(z);
+
 	if (isnanl(y)) {
 		LD_IM(ans) = y + y;
+
 		if (isinfl(x))
 			LD_RE(ans) = fabsl(x);
 		else
@@ -65,5 +68,6 @@
 		LD_RE(ans) = LD_IM(w);
 		LD_IM(ans) = -LD_RE(w);
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cacosl.c	2019-06-06 20:39:32.000929223 +0000
+++ new/usr/src/lib/libm/common/complex/cacosl.c	2019-06-06 20:39:32.019562083 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,41 +30,40 @@
 
 #pragma weak __cacosl = cacosl
 
-#include "libm.h"		/* acosl/atanl/fabsl/isinfl/log1pl/logl/sqrtl */
+#include "libm.h"	/* acosl/atanl/fabsl/isinfl/log1pl/logl/sqrtl */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
-static const long double
-zero = 0.0L,
-one = 1.0L,
-Acrossover = 1.5L,
-Bcrossover = 0.6417L,
-half = 0.5L,
-ln2 = 6.931471805599453094172321214581765680755e-0001L,
-Foursqrtu = 7.3344154702193886624856495681939326638255e-2466L,	/* 2**-8189 */
+/* BEGIN CSTYLED */
+static const long double zero = 0.0L,
+	one = 1.0L,
+	Acrossover = 1.5L,
+	Bcrossover = 0.6417L,
+	half = 0.5L,
+	ln2 = 6.931471805599453094172321214581765680755e-0001L,
+	Foursqrtu = 7.3344154702193886624856495681939326638255e-2466L,	/* 2**-8189 */
 #if defined(__x86)
-E = 5.4210108624275221700372640043497085571289e-20L,		/* 2**-64 */
-pi = 3.141592653589793238295968524909085317631252110004425048828125L,
-pi_l = 1.666748583704175665659172893706807721468195923078e-19L,
-pi_2 = 1.5707963267948966191479842624545426588156260L,
-pi_2_l = 8.3337429185208783282958644685340386073409796e-20L,
-pi_4 = 0.78539816339744830957399213122727132940781302750110626220703125L,
-pi_4_l = 4.166871459260439164147932234267019303670489807695410e-20L,
-pi3_4 = 2.35619449019234492872197639368181398822343908250331878662109375L,
-pi3_4_l = 1.250061437778131749244379670280105791101146942308e-19L;
+	E = 5.4210108624275221700372640043497085571289e-20L,	/* 2**-64 */
+	pi = 3.141592653589793238295968524909085317631252110004425048828125L,
+	pi_l = 1.666748583704175665659172893706807721468195923078e-19L,
+	pi_2 = 1.5707963267948966191479842624545426588156260L,
+	pi_2_l = 8.3337429185208783282958644685340386073409796e-20L,
+	pi_4 = 0.78539816339744830957399213122727132940781302750110626220703125L,
+	pi_4_l = 4.166871459260439164147932234267019303670489807695410e-20L,
+	pi3_4 = 2.35619449019234492872197639368181398822343908250331878662109375L,
+	pi3_4_l = 1.250061437778131749244379670280105791101146942308e-19L;
 #else
-E = 9.6296497219361792652798897129246365926905e-35L,		/* 2**-113 */
-pi = 3.1415926535897932384626433832795027974790680981372955730045043318L,
-pi_l = 8.6718101301237810247970440260433519687623233462565303417759356862e-35L,
-pi_2 = 1.5707963267948966192313216916397513987395340L,
-pi_2_l = 4.3359050650618905123985220130216759843811616e-35L,
-pi_4 = 0.785398163397448309615660845819875699369767024534323893251126L,
-pi_4_l = 2.167952532530945256199261006510837992190580836564132585443e-35L,
-pi3_4 = 2.35619449019234492884698253745962709810930107360297167975337824L,
-pi3_4_l = 6.503857597592835768597783019532513976571742509692397756331e-35L;
+	E = 9.6296497219361792652798897129246365926905e-35L,	/* 2**-113 */
+	pi = 3.1415926535897932384626433832795027974790680981372955730045043318L,
+	pi_l = 8.6718101301237810247970440260433519687623233462565303417759356862e-35L,
+	pi_2 = 1.5707963267948966192313216916397513987395340L,
+	pi_2_l = 4.3359050650618905123985220130216759843811616e-35L,
+	pi_4 = 0.785398163397448309615660845819875699369767024534323893251126L,
+	pi_4_l = 2.167952532530945256199261006510837992190580836564132585443e-35L,
+	pi3_4 = 2.35619449019234492884698253745962709810930107360297167975337824L,
+	pi3_4_l = 6.503857597592835768597783019532513976571742509692397756331e-35L;
 #endif
-/* INDENT ON */
+/* END CSTYLED */
 
 #if defined(__x86)
 static const int ip1 = 0x40400000;	/* 2**65 */
@@ -72,7 +72,8 @@
 #endif
 
 ldcomplex
-cacosl(ldcomplex z) {
+cacosl(ldcomplex z)
+{
 	long double x, y, t, R, S, A, Am1, B, y2, xm1, xp1, Apx;
 	int ix, iy, hx, hy;
 	ldcomplex ans;
@@ -97,6 +98,7 @@
 	if (iy >= 0x7fff0000) {
 		if (isinfl(y)) {	/* cacos(x + i inf) =  pi/2 - i inf */
 			LD_IM(ans) = -y;
+
 			if (ix < 0x7fff0000) {
 				LD_RE(ans) = pi_2 + pi_2_l;
 			} else if (isinfl(x)) {
@@ -109,80 +111,86 @@
 			}
 		} else {		/* cacos(x + i NaN) = NaN  + i NaN */
 			LD_RE(ans) = y + x;
+
 			if (isinfl(x))
 				LD_IM(ans) = -fabsl(x);
 			else
 				LD_IM(ans) = y;
 		}
+
 		return (ans);
 	}
 
 	y = fabsl(y);
 
-	if (ix >= 0x7fff0000) {	/* x is inf or NaN */
+	if (ix >= 0x7fff0000) {		/* x is inf or NaN */
 		if (isinfl(x)) {	/* x is INF */
 			LD_IM(ans) = -fabsl(x);
+
 			if (iy >= 0x7fff0000) {
 				if (isinfl(y)) {
-					/* INDENT OFF */
-					/* cacos(inf + i inf) = pi/4 - i inf */
-					/* cacos(-inf+ i inf) =3pi/4 - i inf */
-					/* INDENT ON */
+					/*
+					 * cacos(inf + i inf) = pi/4 - i inf
+					 * cacos(-inf+ i inf) =3pi/4 - i inf
+					 */
 					if (hx >= 0)
 						LD_RE(ans) = pi_4 + pi_4_l;
 					else
 						LD_RE(ans) = pi3_4 + pi3_4_l;
-				} else
-					/* INDENT OFF */
-					/* cacos(inf + i NaN) = NaN  - i inf  */
-					/* INDENT ON */
+				} else {
+					/*
+					 * cacos(inf + i NaN) = NaN  - i inf
+					 */
 					LD_RE(ans) = y + y;
+				}
 			} else {
-				/* INDENT OFF */
-				/* cacos(inf + iy ) = 0  - i inf */
-				/* cacos(-inf+ iy  ) = pi - i inf */
-				/* INDENT ON */
+				/*
+				 * cacos(inf + iy ) = 0  - i inf
+				 * cacos(-inf+ iy  ) = pi - i inf
+				 */
 				if (hx >= 0)
 					LD_RE(ans) = zero;
 				else
 					LD_RE(ans) = pi + pi_l;
 			}
 		} else {		/* x is NaN */
-			/* INDENT OFF */
+
 			/*
 			 * cacos(NaN + i inf) = NaN  - i inf
 			 * cacos(NaN + i y  ) = NaN  + i NaN
 			 * cacos(NaN + i NaN) = NaN  + i NaN
 			 */
-			/* INDENT ON */
 			LD_RE(ans) = x + y;
-			if (iy >= 0x7fff0000) {
+
+			if (iy >= 0x7fff0000)
 				LD_IM(ans) = -y;
-			} else {
+			else
 				LD_IM(ans) = x;
-			}
 		}
+
 		if (hy < 0)
 			LD_IM(ans) = -LD_IM(ans);
+
 		return (ans);
 	}
 
-	if (y == zero) {	/* region 1: y=0 */
+	if (y == zero) {		/* region 1: y=0 */
 		if (ix < 0x3fff0000) {	/* |x| < 1 */
 			LD_RE(ans) = acosl(x);
 			LD_IM(ans) = zero;
 		} else {
 			LD_RE(ans) = zero;
 			x = fabsl(x);
-			if (ix >= ip1)	/* i386 ? 2**65 : 2**114 */
+
+			if (ix >= ip1) { /* i386 ? 2**65 : 2**114 */
 				LD_IM(ans) = ln2 + logl(x);
-			else if (ix >= 0x3fff8000)	/* x > Acrossover */
+			} else if (ix >= 0x3fff8000) {	/* x > Acrossover */
 				LD_IM(ans) = logl(x + sqrtl((x - one) * (x +
-					one)));
-			else {
+				    one)));
+			} else {
 				xm1 = x - one;
 				LD_IM(ans) = log1pl(xm1 + sqrtl(xm1 * (x +
-					one)));
+				    one)));
 			}
 		}
 	} else if (y <= E * fabsl(fabsl(x) - one)) {
@@ -192,21 +200,23 @@
 			x = fabsl(x);
 			LD_IM(ans) = y / sqrtl((one + x) * (one - x));
 		} else if (ix >= ip1) {	/* i386 ? 2**65 : 2**114 */
-			if (hx >= 0)
+			if (hx >= 0) {
 				LD_RE(ans) = y / x;
-			else {
-				if (ix >= ip1 + 0x00040000)
+			} else {
+				if (ix >= ip1 + 0x00040000) {
 					LD_RE(ans) = pi + pi_l;
-				else {
+				} else {
 					t = pi_l + y / x;
 					LD_RE(ans) = pi + t;
 				}
 			}
+
 			LD_IM(ans) = ln2 + logl(fabsl(x));
 		} else {
 			x = fabsl(x);
 			t = sqrtl((x - one) * (x + one));
-			LD_RE(ans) = (hx >= 0)? y / t : pi - (y / t - pi_l);
+			LD_RE(ans) = (hx >= 0) ? y / t : pi - (y / t - pi_l);
+
 			if (ix >= 0x3fff8000)	/* x > Acrossover */
 				LD_IM(ans) = logl(x + t);
 			else
@@ -214,7 +224,7 @@
 		}
 	} else if (y < Foursqrtu) {	/* region 3 */
 		t = sqrtl(y);
-		LD_RE(ans) = (hx >= 0)? t : pi + pi_l;
+		LD_RE(ans) = (hx >= 0) ? t : pi + pi_l;
 		LD_IM(ans) = t;
 	} else if (E * y - one >= fabsl(x)) {	/* region 4 */
 		LD_RE(ans) = pi_2 + pi_2_l;
@@ -228,11 +238,12 @@
 		/* region 6: x is very small, < 4sqrt(min) */
 		LD_RE(ans) = pi_2 + pi_2_l;
 		A = sqrtl(one + y * y);
+
 		if (iy >= 0x3fff8000)	/* if y > Acrossover */
 			LD_IM(ans) = logl(y + A);
 		else
 			LD_IM(ans) = half * log1pl((y + y) * (y + A));
-	} else {	/* safe region */
+	} else {			/* safe region */
 		t = fabsl(x);
 		y2 = y * y;
 		xp1 = t + one;
@@ -242,23 +253,26 @@
 		A = half * (R + S);
 		B = t / A;
 
-		if (B <= Bcrossover)
-			LD_RE(ans) = (hx >= 0)? acosl(B) : acosl(-B);
-		else {		/* use atan and an accurate approx to a-x */
+		if (B <= Bcrossover) {
+			LD_RE(ans) = (hx >= 0) ? acosl(B) : acosl(-B);
+		} else {	/* use atan and an accurate approx to a-x */
 			Apx = A + t;
+
 			if (t <= one)
 				LD_RE(ans) = atan2l(sqrtl(half * Apx * (y2 /
-					(R + xp1) + (S - xm1))), x);
+				    (R + xp1) + (S - xm1))), x);
 			else
 				LD_RE(ans) = atan2l((y * sqrtl(half * (Apx /
-					(R + xp1) + Apx / (S + xm1)))), x);
+				    (R + xp1) + Apx / (S + xm1)))), x);
 		}
+
 		if (A <= Acrossover) {
 			/* use log1p and an accurate approx to A-1 */
 			if (ix < 0x3fff0000)
 				Am1 = half * (y2 / (R + xp1) + y2 / (S - xm1));
 			else
 				Am1 = half * (y2 / (R + xp1) + (S + xm1));
+
 			LD_IM(ans) = log1pl(Am1 + sqrtl(Am1 * (A + one)));
 		} else {
 			LD_IM(ans) = logl(A + sqrtl(A * A - one));
--- old/usr/src/lib/libm/common/complex/carg.c	2019-06-06 20:39:32.523189206 +0000
+++ new/usr/src/lib/libm/common/complex/carg.c	2019-06-06 20:39:32.542502523 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,25 +30,28 @@
 
 #pragma weak __carg = carg
 
-#include <math.h>		/* atan2 */
+#include <math.h>			/* atan2 */
 #include "complex_wrapper.h"
 
-static const double
-	pi	= 3.14159265358979311600e+00,
-	pi_lo	= 1.22464679914735320717e-16;
+static const double pi = 3.14159265358979311600e+00,
+	pi_lo = 1.22464679914735320717e-16;
 
 double
-carg(dcomplex z) {
-	int	ix, iy;
+carg(dcomplex z)
+{
+	int ix, iy;
 
 	ix = ((int *)&(D_RE(z)))[HIWORD];
 	iy = ((int *)&(D_IM(z)))[HIWORD];
+
 	if ((((ix | iy) & ~0x80000000) | ((int *)&(D_RE(z)))[LOWORD] |
 	    ((int *)&(D_IM(z)))[LOWORD]) == 0) {
 		/* x and y are both zero */
 		if (ix == 0)
 			return (D_IM(z));
-		return ((iy == 0)? pi + pi_lo : -pi - pi_lo);
+
+		return ((iy == 0) ? pi + pi_lo : -pi - pi_lo);
 	}
+
 	return (atan2(D_IM(z), D_RE(z)));
 }
--- old/usr/src/lib/libm/common/complex/cargf.c	2019-06-06 20:39:33.016058624 +0000
+++ new/usr/src/lib/libm/common/complex/cargf.c	2019-06-06 20:39:33.033903649 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 float
-cargf(fcomplex z) {
+cargf(fcomplex z)
+{
 	return (atan2f(F_IM(z), F_RE(z)));
 }
--- old/usr/src/lib/libm/common/complex/cargl.c	2019-06-06 20:39:33.513887701 +0000
+++ new/usr/src/lib/libm/common/complex/cargl.c	2019-06-06 20:39:33.532379106 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 long double
-cargl(ldcomplex z) {
+cargl(ldcomplex z)
+{
 	return (atan2l(LD_IM(z), LD_RE(z)));
 }
--- old/usr/src/lib/libm/common/complex/casin.c	2019-06-06 20:39:34.025362313 +0000
+++ new/usr/src/lib/libm/common/complex/casin.c	2019-06-06 20:39:34.043726925 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __casin = casin
 
-/* INDENT OFF */
+
 /*
  * dcomplex casin(dcomplex z);
  *
@@ -41,7 +42,7 @@
  * The principal value of complex inverse sine function casin(z),
  * where z = x+iy, can be defined by
  *
- * 	casin(z) = asin(B) + i sign(y) log (A + sqrt(A*A-1)),
+ *      casin(z) = asin(B) + i sign(y) log (A + sqrt(A*A-1)),
  *
  * where the log function is the natural log, and
  *             ____________           ____________
@@ -150,7 +151,7 @@
  *	   A = (sqrt(4+y*y)+y)/2 ~ 1 + y/2 + y^2/8 + ...
  *	and
  *	   B = 1/A = 1 - y/2 + y^2/8 + ...
- * 	Since
+ *      Since
  *	   asin(x) = pi/2-2*asin(sqrt((1-x)/2))
  *	   asin(x) = x + x^3/6 + x^5*3/40 + x^7*15/336 + ...
  *	we have, for the real part asin(B),
@@ -165,7 +166,7 @@
  *
  *  case 4. y >= (x+1)ulp(0.5). In this case, A ~ y and B ~ x/y. Thus
  *	   real part = asin(B) ~ x/y (be careful, x/y may underflow)
- * 	and
+ *      and
  *	   imag part = log(y+sqrt(y*y-one))
  *
  *
@@ -189,30 +190,28 @@
  *	              = 0.5*log(1+2y(y+sqrt(1+y^2)));
  *	              = 0.5*log1p(2y(y+A));
  *
- * 	casin(z) = asin(B) + i sign(y) log (A + sqrt(A*A-1)),
+ *      casin(z) = asin(B) + i sign(y) log (A + sqrt(A*A-1)),
  */
-/* INDENT ON */
 
-#include "libm.h"		/* asin/atan/fabs/log/log1p/sqrt */
+#include "libm.h"			/* asin/atan/fabs/log/log1p/sqrt */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
-static const double
-	zero = 0.0,
+static const double zero = 0.0,
 	one = 1.0,
-	E = 1.11022302462515654042e-16,			/* 2**-53 */
+	E = 1.11022302462515654042e-16,	/* 2**-53 */
 	ln2 = 6.93147180559945286227e-01,
 	pi_2 = 1.570796326794896558e+00,
 	pi_2_l = 6.123233995736765886e-17,
 	pi_4 = 7.85398163397448278999e-01,
-	Foursqrtu = 5.96667258496016539463e-154,	/* 2**(-509) */
+	Foursqrtu = 5.96667258496016539463e-154, /* 2**(-509) */
 	Acrossover = 1.5,
 	Bcrossover = 0.6417,
 	half = 0.5;
-/* INDENT ON */
+
 
 dcomplex
-casin(dcomplex z) {
+casin(dcomplex z)
+{
 	double x, y, t, R, S, A, Am1, B, y2, xm1, xp1, Apx;
 	int ix, iy, hx, hy;
 	unsigned lx, ly;
@@ -232,25 +231,26 @@
 	/* special cases */
 
 	/* x is inf or NaN */
-	if (ix >= 0x7ff00000) {	/* x is inf or NaN */
+	if (ix >= 0x7ff00000) {		/* x is inf or NaN */
 		if (ISINF(ix, lx)) {	/* x is INF */
 			D_IM(ans) = x;
+
 			if (iy >= 0x7ff00000) {
 				if (ISINF(iy, ly))
 					/* casin(inf + i inf) = pi/4 + i inf */
 					D_RE(ans) = pi_4;
 				else	/* casin(inf + i NaN) = NaN  + i inf  */
 					D_RE(ans) = y + y;
-			} else	/* casin(inf + iy) = pi/2 + i inf */
+			} else { /* casin(inf + iy) = pi/2 + i inf */
 				D_RE(ans) = pi_2;
+			}
 		} else {		/* x is NaN */
 			if (iy >= 0x7ff00000) {
-				/* INDENT OFF */
+
 				/*
 				 * casin(NaN + i inf) = NaN + i inf
 				 * casin(NaN + i NaN) = NaN + i NaN
 				 */
-				/* INDENT ON */
 				D_IM(ans) = y + y;
 				D_RE(ans) = x + x;
 			} else {
@@ -258,10 +258,13 @@
 				D_IM(ans) = D_RE(ans) = x + y;
 			}
 		}
+
 		if (hx < 0)
 			D_RE(ans) = -D_RE(ans);
+
 		if (hy < 0)
 			D_IM(ans) = -D_IM(ans);
+
 		return (ans);
 	}
 
@@ -269,61 +272,67 @@
 	if ((ix | lx | iy | ly) == 0)
 		return (z);
 
-	if (iy >= 0x7ff00000) {	/* y is inf or NaN */
+	if (iy >= 0x7ff00000) {		/* y is inf or NaN */
 		if (ISINF(iy, ly)) {	/* casin(x + i inf) =  0   + i inf */
 			D_IM(ans) = y;
 			D_RE(ans) = zero;
 		} else {		/* casin(x + i NaN) = NaN  + i NaN */
 			D_IM(ans) = x + y;
+
 			if ((ix | lx) == 0)
 				D_RE(ans) = x;
 			else
 				D_RE(ans) = y;
 		}
+
 		if (hx < 0)
 			D_RE(ans) = -D_RE(ans);
+
 		if (hy < 0)
 			D_IM(ans) = -D_IM(ans);
+
 		return (ans);
 	}
 
-	if ((iy | ly) == 0) {	/* region 1: y=0 */
+	if ((iy | ly) == 0) {		/* region 1: y=0 */
 		if (ix < 0x3ff00000) {	/* |x| < 1 */
 			D_RE(ans) = asin(x);
 			D_IM(ans) = zero;
 		} else {
 			D_RE(ans) = pi_2;
-			if (ix >= 0x43500000)	/* |x| >= 2**54 */
+
+			if (ix >= 0x43500000) {		/* |x| >= 2**54 */
 				D_IM(ans) = ln2 + log(x);
-			else if (ix >= 0x3ff80000)	/* x > Acrossover */
+			} else if (ix >= 0x3ff80000) {	/* x > Acrossover */
 				D_IM(ans) = log(x + sqrt((x - one) * (x +
-					one)));
-			else {
+				    one)));
+			} else {
 				xm1 = x - one;
 				D_IM(ans) = log1p(xm1 + sqrt(xm1 * (x + one)));
 			}
 		}
 	} else if (y <= E * fabs(x - one)) {	/* region 2: y < tiny*|x-1| */
-		if (ix < 0x3ff00000) {	/* x < 1 */
+		if (ix < 0x3ff00000) {		/* x < 1 */
 			D_RE(ans) = asin(x);
 			D_IM(ans) = y / sqrt((one + x) * (one - x));
 		} else {
 			D_RE(ans) = pi_2;
-			if (ix >= 0x43500000) {	/* |x| >= 2**54 */
+
+			if (ix >= 0x43500000)		/* |x| >= 2**54 */
 				D_IM(ans) = ln2 + log(x);
-			} else if (ix >= 0x3ff80000)	/* x > Acrossover */
+			else if (ix >= 0x3ff80000)	/* x > Acrossover */
 				D_IM(ans) = log(x + sqrt((x - one) * (x +
-					one)));
+				    one)));
 			else
 				D_IM(ans) = log1p((x - one) + sqrt((x - one) *
-					(x + one)));
+				    (x + one)));
 		}
 	} else if (y < Foursqrtu) {	/* region 3 */
 		t = sqrt(y);
 		D_RE(ans) = pi_2 - (t - pi_2_l);
 		D_IM(ans) = t;
-	} else if (E * y - one >= x) {	/* region 4 */
-		D_RE(ans) = x / y;	/* need to fix underflow cases */
+	} else if (E * y - one >= x) { /* region 4 */
+		D_RE(ans) = x / y; /* need to fix underflow cases */
 		D_IM(ans) = ln2 + log(y);
 	} else if (ix >= 0x5fc00000 || iy >= 0x5fc00000) {	/* x,y>2**509 */
 		/* region 5: x+1 or y is very large (>= sqrt(max)/8) */
@@ -334,11 +343,12 @@
 		/* region 6: x is very small, < 4sqrt(min) */
 		A = sqrt(one + y * y);
 		D_RE(ans) = x / A;	/* may underflow */
+
 		if (iy >= 0x3ff80000)	/* if y > Acrossover */
 			D_IM(ans) = log(y + A);
 		else
 			D_IM(ans) = half * log1p((y + y) * (y + A));
-	} else {	/* safe region */
+	} else {			/* safe region */
 		y2 = y * y;
 		xp1 = x + one;
 		xm1 = x - one;
@@ -347,23 +357,26 @@
 		A = half * (R + S);
 		B = x / A;
 
-		if (B <= Bcrossover)
+		if (B <= Bcrossover) {
 			D_RE(ans) = asin(B);
-		else {		/* use atan and an accurate approx to a-x */
+		} else {	/* use atan and an accurate approx to a-x */
 			Apx = A + x;
+
 			if (x <= one)
 				D_RE(ans) = atan(x / sqrt(half * Apx * (y2 /
-					(R + xp1) + (S - xm1))));
+				    (R + xp1) + (S - xm1))));
 			else
 				D_RE(ans) = atan(x / (y * sqrt(half * (Apx /
-					(R + xp1) + Apx / (S + xm1)))));
+				    (R + xp1) + Apx / (S + xm1)))));
 		}
+
 		if (A <= Acrossover) {
 			/* use log1p and an accurate approx to A-1 */
 			if (x < one)
 				Am1 = half * (y2 / (R + xp1) + y2 / (S - xm1));
 			else
 				Am1 = half * (y2 / (R + xp1) + (S + xm1));
+
 			D_IM(ans) = log1p(Am1 + sqrt(Am1 * (A + one)));
 		} else {
 			D_IM(ans) = log(A + sqrt(A * A - one));
@@ -372,6 +385,7 @@
 
 	if (hx < 0)
 		D_RE(ans) = -D_RE(ans);
+
 	if (hy < 0)
 		D_IM(ans) = -D_IM(ans);
 
--- old/usr/src/lib/libm/common/complex/casinf.c	2019-06-06 20:39:34.577381036 +0000
+++ new/usr/src/lib/libm/common/complex/casinf.c	2019-06-06 20:39:34.595966384 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,14 +34,15 @@
 #include "complex_wrapper.h"
 
 fcomplex
-casinf(fcomplex z) {
+casinf(fcomplex z)
+{
 	dcomplex dz, dans;
 	fcomplex ans;
 
-	D_RE(dz) = (double) (F_RE(z));
-	D_IM(dz) = (double) (F_IM(z));
+	D_RE(dz) = (double)(F_RE(z));
+	D_IM(dz) = (double)(F_IM(z));
 	dans = casin(dz);
-	F_RE(ans) = (float) (D_RE(dans));
-	F_IM(ans) = (float) (D_IM(dans));
+	F_RE(ans) = (float)(D_RE(dans));
+	F_IM(ans) = (float)(D_IM(dans));
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/casinh.c	2019-06-06 20:39:35.074406179 +0000
+++ new/usr/src/lib/libm/common/complex/casinh.c	2019-06-06 20:39:35.092454999 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,18 +30,18 @@
 
 #pragma weak __casinh = casinh
 
-/* INDENT OFF */
+
 /*
  * dcomplex casinh(dcomplex z);
  * casinh z = -i casin iz .
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "complex_wrapper.h"
 
 dcomplex
-casinh(dcomplex z) {
+casinh(dcomplex z)
+{
 	dcomplex w, r, ans;
 
 	D_RE(w) = -D_IM(z);
--- old/usr/src/lib/libm/common/complex/casinhf.c	2019-06-06 20:39:35.549339245 +0000
+++ new/usr/src/lib/libm/common/complex/casinhf.c	2019-06-06 20:39:35.568133659 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 fcomplex
-casinhf(fcomplex z) {
+casinhf(fcomplex z)
+{
 	fcomplex w, r, ans;
 
 	F_RE(w) = -F_IM(z);
--- old/usr/src/lib/libm/common/complex/casinhl.c	2019-06-06 20:39:36.062517820 +0000
+++ new/usr/src/lib/libm/common/complex/casinhl.c	2019-06-06 20:39:36.080475443 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 ldcomplex
-casinhl(ldcomplex z) {
+casinhl(ldcomplex z)
+{
 	ldcomplex w, r, ans;
 
 	LD_RE(w) = -LD_IM(z);
--- old/usr/src/lib/libm/common/complex/casinl.c	2019-06-06 20:39:36.548732487 +0000
+++ new/usr/src/lib/libm/common/complex/casinl.c	2019-06-06 20:39:36.567909696 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,35 +30,32 @@
 
 #pragma weak __casinl = casinl
 
-#include "libm.h"		/* asinl/atanl/fabsl/isinfl/log1pl/logl/sqrtl */
+#include "libm.h"	/* asinl/atanl/fabsl/isinfl/log1pl/logl/sqrtl */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
-static const long double
-zero = 0.0L,
-one = 1.0L,
-Acrossover = 1.5L,
-Bcrossover = 0.6417L,
-half = 0.5L,
-ln2 = 6.931471805599453094172321214581765680755e-0001L,
-Foursqrtu = 7.3344154702193886624856495681939326638255e-2466L,	/* 2**-8189 */
+/* BEGIN CSTYLED */
+static const long double zero = 0.0L,
+	one = 1.0L,
+	Acrossover = 1.5L,
+	Bcrossover = 0.6417L,
+	half = 0.5L,
+	ln2 = 6.931471805599453094172321214581765680755e-0001L,
+	Foursqrtu = 7.3344154702193886624856495681939326638255e-2466L,	/* 2**-8189 */
 #if defined(__x86)
-E = 5.4210108624275221700372640043497085571289e-20L,	/* 2**-64 */
-pi_4 = 0.7853981633974483095739921312272713294078130L,
-pi_4_l = 4.1668714592604391641479322342670193036704898e-20L,
-pi_2 = 1.5707963267948966191479842624545426588156260L,
-pi_2_l = 8.3337429185208783282958644685340386073409796e-20L;
-
+	E = 5.4210108624275221700372640043497085571289e-20L,	/* 2**-64 */
+	pi_4 = 0.7853981633974483095739921312272713294078130L,
+	pi_4_l = 4.1668714592604391641479322342670193036704898e-20L,
+	pi_2 = 1.5707963267948966191479842624545426588156260L,
+	pi_2_l = 8.3337429185208783282958644685340386073409796e-20L;
 #else
-E = 9.6296497219361792652798897129246365926905e-35L,	/* 2**-113 */
-pi_4 = 0.7853981633974483096156608458198756993697670L,
-pi_4_l = 2.1679525325309452561992610065108379921905808e-35L,
-pi_2 = 1.5707963267948966192313216916397513987395340L,
-pi_2_l = 4.3359050650618905123985220130216759843811616e-35L;
-
+	E = 9.6296497219361792652798897129246365926905e-35L,	/* 2**-113 */
+	pi_4 = 0.7853981633974483096156608458198756993697670L,
+	pi_4_l = 2.1679525325309452561992610065108379921905808e-35L,
+	pi_2 = 1.5707963267948966192313216916397513987395340L,
+	pi_2_l = 4.3359050650618905123985220130216759843811616e-35L;
 #endif
-/* INDENT ON */
+/* END CSTYLED */
 
 #if defined(__x86)
 static const int ip1 = 0x40400000;	/* 2**65 */
@@ -66,7 +64,8 @@
 #endif
 
 ldcomplex
-casinl(ldcomplex z) {
+casinl(ldcomplex z)
+{
 	long double x, y, t, R, S, A, Am1, B, y2, xm1, xp1, Apx;
 	int ix, iy, hx, hy;
 	ldcomplex ans;
@@ -83,38 +82,42 @@
 	/* special cases */
 
 	/* x is inf or NaN */
-	if (ix >= 0x7fff0000) {	/* x is inf or NaN */
+	if (ix >= 0x7fff0000) {		/* x is inf or NaN */
 		if (isinfl(x)) {	/* x is INF */
 			LD_IM(ans) = x;
+
 			if (iy >= 0x7fff0000) {
 				if (isinfl(y))
 					/* casin(inf + i inf) = pi/4 + i inf */
 					LD_RE(ans) = pi_4 + pi_4_l;
 				else	/* casin(inf + i NaN) = NaN + i inf */
 					LD_RE(ans) = y + y;
-			} else	/* casin(inf + iy) = pi/2 + i inf */
+			} else { /* casin(inf + iy) = pi/2 + i inf */
 				LD_RE(ans) = pi_2 + pi_2_l;
+			}
 		} else {		/* x is NaN */
 			if (iy >= 0x7fff0000) {
-				/* INDENT OFF */
+
 				/*
 				 * casin(NaN + i inf) = NaN  + i inf
 				 * casin(NaN + i NaN) = NaN  + i NaN
 				 */
-				/* INDENT ON */
 				LD_IM(ans) = y + y;
 				LD_RE(ans) = x + x;
 			} else {
-				/* INDENT OFF */
-				/* casin(NaN + i y ) = NaN  + i NaN */
-				/* INDENT ON */
+				/*
+				 * casin(NaN + i y ) = NaN  + i NaN
+				 */
 				LD_IM(ans) = LD_RE(ans) = x + y;
 			}
 		}
+
 		if (hx < 0)
 			LD_RE(ans) = -LD_RE(ans);
+
 		if (hy < 0)
 			LD_IM(ans) = -LD_IM(ans);
+
 		return (ans);
 	}
 
@@ -122,55 +125,61 @@
 	if (x == zero && y == zero)
 		return (z);
 
-	if (iy >= 0x7fff0000) {	/* y is inf or NaN */
+	if (iy >= 0x7fff0000) {		/* y is inf or NaN */
 		if (isinfl(y)) {	/* casin(x + i inf) = 0 + i inf */
 			LD_IM(ans) = y;
 			LD_RE(ans) = zero;
 		} else {		/* casin(x + i NaN) = NaN + i NaN */
 			LD_IM(ans) = x + y;
+
 			if (x == zero)
 				LD_RE(ans) = x;
 			else
 				LD_RE(ans) = y;
 		}
+
 		if (hx < 0)
 			LD_RE(ans) = -LD_RE(ans);
+
 		if (hy < 0)
 			LD_IM(ans) = -LD_IM(ans);
+
 		return (ans);
 	}
 
-	if (y == zero) {	/* region 1: y=0 */
+	if (y == zero) {		/* region 1: y=0 */
 		if (ix < 0x3fff0000) {	/* |x| < 1 */
 			LD_RE(ans) = asinl(x);
 			LD_IM(ans) = zero;
 		} else {
 			LD_RE(ans) = pi_2 + pi_2_l;
-			if (ix >= ip1)	/* |x| >= i386 ? 2**65 : 2**114 */
+
+			if (ix >= ip1) { /* |x| >= i386 ? 2**65 : 2**114 */
 				LD_IM(ans) = ln2 + logl(x);
-			else if (ix >= 0x3fff8000)	/* x > Acrossover */
+			} else if (ix >= 0x3fff8000) {	/* x > Acrossover */
 				LD_IM(ans) = logl(x + sqrtl((x - one) * (x +
-					one)));
-			else {
+				    one)));
+			} else {
 				xm1 = x - one;
 				LD_IM(ans) = log1pl(xm1 + sqrtl(xm1 * (x +
-					one)));
+				    one)));
 			}
 		}
 	} else if (y <= E * fabsl(x - one)) {	/* region 2: y < tiny*|x-1| */
-		if (ix < 0x3fff0000) {	/* x < 1 */
+		if (ix < 0x3fff0000) {		/* x < 1 */
 			LD_RE(ans) = asinl(x);
 			LD_IM(ans) = y / sqrtl((one + x) * (one - x));
 		} else {
 			LD_RE(ans) = pi_2 + pi_2_l;
-			if (ix >= ip1)	/* i386 ? 2**65 : 2**114 */
+
+			if (ix >= ip1) /* i386 ? 2**65 : 2**114 */
 				LD_IM(ans) = ln2 + logl(x);
 			else if (ix >= 0x3fff8000)	/* x > Acrossover */
 				LD_IM(ans) = logl(x + sqrtl((x - one) * (x +
-					one)));
+				    one)));
 			else
 				LD_IM(ans) = log1pl((x - one) + sqrtl((x -
-					one) * (x + one)));
+				    one) * (x + one)));
 		}
 	} else if (y < Foursqrtu) {	/* region 3 */
 		t = sqrtl(y);
@@ -188,11 +197,12 @@
 		/* region 6: x is very small, < 4sqrt(min) */
 		A = sqrtl(one + y * y);
 		LD_RE(ans) = x / A;	/* may underflow */
+
 		if (iy >= 0x3fff8000)	/* if y > Acrossover */
 			LD_IM(ans) = logl(y + A);
 		else
 			LD_IM(ans) = half * log1pl((y + y) * (y + A));
-	} else {	/* safe region */
+	} else {			/* safe region */
 		y2 = y * y;
 		xp1 = x + one;
 		xm1 = x - one;
@@ -200,23 +210,27 @@
 		S = sqrtl(xm1 * xm1 + y2);
 		A = half * (R + S);
 		B = x / A;
-		if (B <= Bcrossover)
+
+		if (B <= Bcrossover) {
 			LD_RE(ans) = asinl(B);
-		else {		/* use atan and an accurate approx to a-x */
+		} else {	/* use atan and an accurate approx to a-x */
 			Apx = A + x;
+
 			if (x <= one)
 				LD_RE(ans) = atanl(x / sqrtl(half * Apx * (y2 /
-					(R + xp1) + (S - xm1))));
+				    (R + xp1) + (S - xm1))));
 			else
 				LD_RE(ans) = atanl(x / (y * sqrtl(half * (Apx /
-					(R + xp1) + Apx / (S + xm1)))));
+				    (R + xp1) + Apx / (S + xm1)))));
 		}
+
 		if (A <= Acrossover) {
 			/* use log1p and an accurate approx to A-1 */
 			if (x < one)
 				Am1 = half * (y2 / (R + xp1) + y2 / (S - xm1));
 			else
 				Am1 = half * (y2 / (R + xp1) + (S + xm1));
+
 			LD_IM(ans) = log1pl(Am1 + sqrtl(Am1 * (A + one)));
 		} else {
 			LD_IM(ans) = logl(A + sqrtl(A * A - one));
@@ -225,6 +239,7 @@
 
 	if (hx < 0)
 		LD_RE(ans) = -LD_RE(ans);
+
 	if (hy < 0)
 		LD_IM(ans) = -LD_IM(ans);
 
--- old/usr/src/lib/libm/common/complex/catan.c	2019-06-06 20:39:37.075284208 +0000
+++ new/usr/src/lib/libm/common/complex/catan.c	2019-06-06 20:39:37.094516601 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __catan = catan
 
-/* INDENT OFF */
+
 /*
  * dcomplex catan(dcomplex z);
  *
@@ -73,23 +74,21 @@
  *    catan( x  , NaN ) =  (NaN  ,  NaN ) with invalid for finite x
  *    catan( inf, NaN ) =  (pi/2 ,  +-0 )
  */
-/* INDENT ON */
 
-#include "libm.h"		/* atan/atan2/fabs/log/log1p */
+#include "libm.h"			/* atan/atan2/fabs/log/log1p */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
-static const double
-	pi_2 = 1.570796326794896558e+00,
+static const double pi_2 = 1.570796326794896558e+00,
 	zero = 0.0,
 	half = 0.5,
 	two = 2.0,
 	ln2 = 6.931471805599453094172321214581765680755e-0001,
 	one = 1.0;
-/* INDENT ON */
+
 
 dcomplex
-catan(dcomplex z) {
+catan(dcomplex z)
+{
 	dcomplex ans;
 	double x, y, ax, ay, t;
 	int hx, hy, ix, iy;
@@ -113,6 +112,7 @@
 			D_IM(ans) = zero;
 		} else {
 			D_RE(ans) = x + x;
+
 			if ((iy | ly) == 0 || (ISINF(iy, ly)))
 				D_IM(ans) = zero;
 			else
@@ -128,7 +128,7 @@
 			D_IM(ans) = y;
 		}
 	} else if ((ix | lx) == 0) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * x = 0
 		 *      1                            1
@@ -139,8 +139,9 @@
 		 * B = - log [ ------------ ] = - log (1+ ---) or - log(1+ ----)
 		 *     4     [  (y-1)*(y-1) ]   2         y-1     2         1-y
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		t = one - ay;
+
 		if (((iy - 0x3ff00000) | ly) == 0) {
 			/* y=1: catan(0,1)=(0,+inf) with 1/0 signal */
 			D_IM(ans) = ay / ax;
@@ -148,32 +149,33 @@
 		} else if (iy >= 0x3ff00000) {	/* y>1 */
 			D_IM(ans) = half * log1p(two / (-t));
 			D_RE(ans) = pi_2;
-		} else {		/* y<1 */
+		} else {			/* y<1 */
 			D_IM(ans) = half * log1p((ay + ay) / t);
 			D_RE(ans) = zero;
 		}
 	} else if (iy < 0x3e200000 || ((ix - iy) >> 20) >= 30) {
-	/* INDENT OFF */
-	/*
-	 * Tiny y (relative to 1+|x|)
-	 *     |y| < E*(1+|x|)
-	 * where E=2**-29, -35, -60 for double, double extended, quad precision
-	 *
-	 *      1                           [ x<=1:   atan(x)
-	 * A = --- * atan2(2x, 1-x*x-y*y) ~ [       1                 1+x
-	 *      2                           [ x>=1: - atan2(2,(1-x)*(-----))
-	 *                                          2                  x
-	 *
-	 *                               y/x
-	 * B ~ t*(1-2t), where t = ----------------- is tiny
-	 *                         x + (y-1)*(y-1)/x
-	 */
-		/* INDENT ON */
+		/* BEGIN CSTYLED */
+		/*
+		 * Tiny y (relative to 1+|x|)
+		 *     |y| < E*(1+|x|)
+		 * where E=2**-29, -35, -60 for double, double extended, quad precision
+		 *
+		 *      1                           [ x<=1:   atan(x)
+		 * A = --- * atan2(2x, 1-x*x-y*y) ~ [       1                 1+x
+		 *      2                           [ x>=1: - atan2(2,(1-x)*(-----))
+		 *                                          2                  x
+		 *
+		 *                               y/x
+		 * B ~ t*(1-2t), where t = ----------------- is tiny
+		 *                         x + (y-1)*(y-1)/x
+		 */
+		/* END CSTYLED */
 		if (ix < 0x3ff00000)
 			D_RE(ans) = atan(ax);
 		else
-			D_RE(ans) = half * atan2(two, (one - ax) * (one +
-				one / ax));
+			D_RE(ans) = half * atan2(two, (one - ax) * (one + one /
+			    ax));
+
 		if ((iy | ly) == 0) {
 			D_IM(ans) = ay;
 		} else {
@@ -183,10 +185,11 @@
 				t = (ay / ax) / ax;
 			else
 				t = ay / (ax * ax + (ay - one) * (ay - one));
+
 			D_IM(ans) = t * (one - (t + t));
 		}
 	} else if (iy >= 0x41c00000 && ((iy - ix) >> 20) >= 30) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * Huge y relative to 1+|x|
 		 *            |y| > Einv*(1+|x|), where Einv~2**(prec/2+3),
@@ -197,12 +200,12 @@
 		 *       B ~ t*(1-2t), where t = --------------- is tiny
 		 *                                (y-1)*(y-1)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		D_RE(ans) = pi_2;
 		t = (ay / (ay - one)) / (ay - one);
 		D_IM(ans) = t * (one - (t + t));
 	} else if (((iy - 0x3ff00000) | ly) == 0) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * y = 1
 		 *      1                       1
@@ -213,16 +216,17 @@
 		 * B = - log [-------] = - log (1+ ---) = [ |x|<E, else 0.25*
 		 *     4     [  x*x  ]   4         x*x    [ log1p((2/x)*(2/x))
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		D_RE(ans) = half * atan2(two, -ax);
-		if (ix < 0x3e200000)
+
+		if (ix < 0x3e200000) {
 			D_IM(ans) = half * (ln2 - log(ax));
-		else {
+		} else {
 			t = two / ax;
 			D_IM(ans) = 0.25 * log1p(t * t);
 		}
 	} else if (ix >= 0x43900000) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * Huge x:
 		 * when |x| > 1/E^2,
@@ -233,13 +237,13 @@
 		 * B ~ t*(1-2t), where t = --------------- = (-------------- )/x
 		 *                         x*x+(y-1)*(y-1)     1+((y-1)/x)^2
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		D_RE(ans) = pi_2;
 		t = ((ay / ax) / (one + ((ay - one) / ax) * ((ay - one) /
-			ax))) / ax;
+		    ax))) / ax;
 		D_IM(ans) = t * (one - (t + t));
 	} else if (ix < 0x38b00000) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * Tiny x:
 		 * when |x| < E^4,  (note that y != 1)
@@ -251,14 +255,15 @@
 		 * B = - log [-----------] = - log (1+ ---) or - log(1+ ----)
 		 *     4     [(y-1)*(y-1)]   2         y-1     2         1-y
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		D_RE(ans) = half * atan2(ax + ax, (one - ay) * (one + ay));
+
 		if (iy >= 0x3ff00000)
 			D_IM(ans) = half * log1p(two / (ay - one));
 		else
 			D_IM(ans) = half * log1p((ay + ay) / (one - ay));
 	} else {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * normal x,y
 		 *      1
@@ -269,24 +274,30 @@
 		 * B = - log [---------------] = - log (1+ -----------------)
 		 *     4     [x*x+(y-1)*(y-1)]   4         x*x + (y-1)*(y-1)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		t = one - ay;
+
 		if (iy >= 0x3fe00000 && iy < 0x40000000) {
 			/* y close to 1 */
 			D_RE(ans) = half * (atan2((ax + ax), (t * (one + ay) -
-				ax * ax)));
+			    ax * ax)));
 		} else if (ix >= 0x3fe00000 && ix < 0x40000000) {
 			/* x close to 1 */
-			D_RE(ans) = half * atan2((ax + ax), ((one - ax) *
-				(one + ax) - ay * ay));
-		} else
+			D_RE(ans) = half * atan2((ax + ax), ((one - ax) * (one +
+			    ax) - ay * ay));
+		} else {
 			D_RE(ans) = half * atan2((ax + ax), ((one - ax * ax) -
-				ay * ay));
+			    ay * ay));
+		}
+
 		D_IM(ans) = 0.25 * log1p((4.0 * ay) / (ax * ax + t * t));
 	}
+
 	if (hx < 0)
 		D_RE(ans) = -D_RE(ans);
+
 	if (hy < 0)
 		D_IM(ans) = -D_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/catanf.c	2019-06-06 20:39:37.598937084 +0000
+++ new/usr/src/lib/libm/common/complex/catanf.c	2019-06-06 20:39:37.616870096 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,19 +37,19 @@
 extern int __swapRP(int);
 #endif
 
-static const float
-	pi_2 = 1.570796326794896558e+00F,
+static const float pi_2 = 1.570796326794896558e+00F,
 	zero = 0.0F,
 	half = 0.5F,
 	two = 2.0F,
 	one = 1.0F;
 
 fcomplex
-catanf(fcomplex z) {
-	fcomplex	ans;
-	float		x, y, ax, ay, t;
-	double		dx, dy, dt;
-	int		hx, hy, ix, iy;
+catanf(fcomplex z)
+{
+	fcomplex ans;
+	float x, y, ax, ay, t;
+	double dx, dy, dt;
+	int hx, hy, ix, iy;
 
 	x = F_RE(z);
 	y = F_IM(z);
@@ -64,6 +66,7 @@
 			F_IM(ans) = zero;
 		} else {
 			F_RE(ans) = x * x;
+
 			if (iy == 0 || iy == 0x7f800000)
 				F_IM(ans) = zero;
 			else
@@ -78,7 +81,7 @@
 			F_IM(ans) = y * y;
 		}
 	} else if (ix == 0) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * x = 0
 		 *      1                            1
@@ -89,8 +92,9 @@
 		 * B = - log [ ----------- ] = - log (1+ ---) or - log(1+ ----)
 		 *     4     [ (y-1)*(y-1) ]   2         y-1     2         1-y
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		t = one - ay;
+
 		if (iy == 0x3f800000) {
 			/* y=1: catan(0,1)=(0,+inf) with 1/0 signal */
 			F_IM(ans) = ay / ax;
@@ -98,12 +102,12 @@
 		} else if (iy > 0x3f800000) {	/* y>1 */
 			F_IM(ans) = half * log1pf(two / (-t));
 			F_RE(ans) = pi_2;
-		} else {		/* y<1 */
+		} else {			/* y<1 */
 			F_IM(ans) = half * log1pf((ay + ay) / t);
 			F_RE(ans) = zero;
 		}
 	} else {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * use double precision x,y
 		 *      1
@@ -114,25 +118,30 @@
 		 * B = - log [ --------------- ] = - log (1+ -----------------)
 		 *     4     [ x*x+(y-1)*(y-1) ]   4         x*x + (y-1)*(y-1)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
+
 #if defined(__i386) && !defined(__amd64)
-		int	rp = __swapRP(fp_extended);
+		int rp = __swapRP(fp_extended);
 #endif
 		dx = (double)ax;
 		dy = (double)ay;
-		F_RE(ans) = (float)(0.5 * atan2(dx + dx,
-		    1.0 - dx * dx - dy * dy));
+		F_RE(ans) = (float)(0.5 * atan2(dx + dx, 1.0 - dx * dx - dy *
+		    dy));
 		dt = dy - 1.0;
-		F_IM(ans) = (float)(0.25 * log1p(4.0 * dy /
-		    (dx * dx + dt * dt)));
+		F_IM(ans) = (float)(0.25 * log1p(4.0 * dy / (dx * dx + dt *
+		    dt)));
+
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
 			(void) __swapRP(rp);
 #endif
 	}
+
 	if (hx < 0)
 		F_RE(ans) = -F_RE(ans);
+
 	if (hy < 0)
 		F_IM(ans) = -F_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/catanh.c	2019-06-06 20:39:38.122591732 +0000
+++ new/usr/src/lib/libm/common/complex/catanh.c	2019-06-06 20:39:38.141366097 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,20 +30,20 @@
 
 #pragma weak __catanh = catanh
 
-/* INDENT OFF */
+
 /*
  * z := x + iy
  * catanh(z)	= -i catan(iz)
  *		= -i catan(-y+ix)
  *		= (Im(catan(-y+ix)), -Re(catan(-y+ix)))
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "complex_wrapper.h"
 
 dcomplex
-catanh(dcomplex z) {
+catanh(dcomplex z)
+{
 	double x, y;
 	dcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/catanhf.c	2019-06-06 20:39:38.623752319 +0000
+++ new/usr/src/lib/libm/common/complex/catanhf.c	2019-06-06 20:39:38.642037667 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 fcomplex
-catanhf(fcomplex z) {
+catanhf(fcomplex z)
+{
 	float x, y;
 	fcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/catanhl.c	2019-06-06 20:39:39.136367086 +0000
+++ new/usr/src/lib/libm/common/complex/catanhl.c	2019-06-06 20:39:39.155675548 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 ldcomplex
-catanhl(ldcomplex z) {
+catanhl(ldcomplex z)
+{
 	long double x, y;
 	ldcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/catanl.c	2019-06-06 20:39:39.648111402 +0000
+++ new/usr/src/lib/libm/common/complex/catanl.c	2019-06-06 20:39:39.665639487 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __catanl = catanl
 
-/* INDENT OFF */
+
 /*
  * ldcomplex catanl(ldcomplex z);
  *
@@ -58,7 +59,7 @@
  *              1+y-ix    (1+y)**2 + x**2    (1+y)**2 + x**2
  *
  * Comparing the real and imaginary parts of (2) and (3), we have:
- * 	cos(2A) : 1-x*x-y*y = sin(2A) : 2x
+ *      cos(2A) : 1-x*x-y*y = sin(2A) : 2x
  * and hence
  *	tan(2A) = 2x/(1-x*x-y*y), or
  *	A = 0.5 * atan2(2x, 1-x*x-y*y)	                    ... (4)
@@ -99,31 +100,30 @@
  *    catan( x  , NaN ) =  (NaN  ,  NaN ) with invalid for finite x
  *    catan( inf, NaN ) =  (pi/2 ,  +-0 )
  */
-/* INDENT ON */
 
 #include "libm.h"	/* atan2l/atanl/fabsl/isinfl/iszerol/log1pl/logl */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
-static const long double
-zero = 0.0L,
-one = 1.0L,
-two = 2.0L,
-half = 0.5L,
-ln2 = 6.931471805599453094172321214581765680755e-0001L,
-pi_2 = 1.570796326794896619231321691639751442098584699687552910487472L,
+/* BEGIN CSTYLED */
+static const long double zero = 0.0L,
+	one = 1.0L,
+	two = 2.0L,
+	half = 0.5L,
+	ln2 = 6.931471805599453094172321214581765680755e-0001L,
+	pi_2 = 1.570796326794896619231321691639751442098584699687552910487472L,
 #if defined(__x86)
-E = 2.910383045673370361328125000000000000000e-11L,	/* 2**-35 */
-Einv = 3.435973836800000000000000000000000000000e+10L;	/* 2**+35 */
+	E = 2.910383045673370361328125000000000000000e-11L,		/* 2**-35 */
+	Einv = 3.435973836800000000000000000000000000000e+10L;	/* 2**+35 */
 #else
-E = 8.673617379884035472059622406959533691406e-19L,	/* 2**-60 */
-Einv = 1.152921504606846976000000000000000000000e18L;	/* 2**+60 */
+	E = 8.673617379884035472059622406959533691406e-19L,		/* 2**-60 */
+	Einv = 1.152921504606846976000000000000000000000e18L;		/* 2**+60 */
 #endif
-/* INDENT ON */
+/* END CSTYLED */
 
 ldcomplex
-catanl(ldcomplex z) {
+catanl(ldcomplex z)
+{
 	ldcomplex ans;
 	long double x, y, t1, ax, ay, t;
 	int hx, hy, ix, iy;
@@ -144,6 +144,7 @@
 			LD_IM(ans) = zero;
 		} else {
 			LD_RE(ans) = x + x;
+
 			if (iszerol(y) || (isinfl(y)))
 				LD_IM(ans) = zero;
 			else
@@ -159,7 +160,7 @@
 			LD_IM(ans) = y;
 		}
 	} else if (iszerol(x)) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * x = 0
 		 *      1                            1
@@ -170,8 +171,9 @@
 		 * B = - log [ ----------- ] = - log (1+ ---) or - log(1+ ----)
 		 *     4     [ (y-1)*(y-1) ]   2         y-1     2         1-y
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		t = one - ay;
+
 		if (ay == one) {
 			/* y=1: catan(0,1)=(0,+inf) with 1/0 signal */
 			LD_IM(ans) = ay / ax;
@@ -184,7 +186,7 @@
 			LD_RE(ans) = zero;
 		}
 	} else if (ay < E * (one + ax)) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * Tiny y (relative to 1+|x|)
 		 *     |y| < E*(1+|x|)
@@ -203,27 +205,29 @@
 		 * (when x < 2**-60, t = ----------- )
 		 *                       (y-1)*(y-1)
 		 */
-		/* INDENT ON */
-		if (ay == zero)
+		/* END CSTYLED */
+		if (ay == zero) {
 			LD_IM(ans) = ay;
-		else {
+		} else {
 			t1 = ay - one;
+
 			if (ix < 0x3fc30000)
 				t = ay / (t1 * t1);
 			else if (ix > 0x403b0000)
 				t = (ay / ax) / ax;
 			else
 				t = ay / (ax * ax + t1 * t1);
+
 			LD_IM(ans) = t * (one - two * t);
 		}
+
 		if (ix < 0x3fff0000)
 			LD_RE(ans) = atanl(ax);
 		else
 			LD_RE(ans) = half * atan2l(two, (one - ax) * (one +
-				one / ax));
-
+			    one / ax));
 	} else if (ay > Einv * (one + ax)) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * Huge y relative to 1+|x|
 		 *     |y| > Einv*(1+|x|), where Einv~2**(prec/2+3),
@@ -234,12 +238,12 @@
 		 * B ~ t*(1-2t), where t = --------------- is tiny
 		 *                          (y-1)*(y-1)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		LD_RE(ans) = pi_2;
 		t = (ay / (ay - one)) / (ay - one);
 		LD_IM(ans) = t * (one - (t + t));
 	} else if (ay == one) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * y=1
 		 *     1                      1
@@ -250,16 +254,17 @@
 		 * B = - log [ -----] = - log (1+ ---) = [ |x|<E, else 0.25*
 		 *     4     [  x*x ]   4         x*x    [ log1p((2/x)*(2/x))
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		LD_RE(ans) = half * atan2l(two, -ax);
-		if (ax < E)
+
+		if (ax < E) {
 			LD_IM(ans) = half * (ln2 - logl(ax));
-		else {
+		} else {
 			t = two / ax;
 			LD_IM(ans) = 0.25L * log1pl(t * t);
 		}
 	} else if (ax > Einv * Einv) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * Huge x:
 		 * when |x| > 1/E^2,
@@ -270,13 +275,13 @@
 		 * B ~ t*(1-2t), where t = --------------- = (-------------- )/x
 		 *                         x*x+(y-1)*(y-1)     1+((y-1)/x)^2
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		LD_RE(ans) = pi_2;
 		t = ((ay / ax) / (one + ((ay - one) / ax) * ((ay - one) /
-			ax))) / ax;
+		    ax))) / ax;
 		LD_IM(ans) = t * (one - (t + t));
 	} else if (ax < E * E * E * E) {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * Tiny x:
 		 * when |x| < E^4,  (note that y != 1)
@@ -288,14 +293,15 @@
 		 * B = - log [ ----------- ] = - log (1+ ---) or - log(1+ ----)
 		 *     4     [ (y-1)*(y-1) ]   2         y-1     2         1-y
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		LD_RE(ans) = half * atan2l(ax + ax, (one - ay) * (one + ay));
-		if (ay > one)	/* y>1 */
+
+		if (ay > one)		/* y>1 */
 			LD_IM(ans) = half * log1pl(two / (ay - one));
-		else		/* y<1 */
+		else			/* y<1 */
 			LD_IM(ans) = half * log1pl((ay + ay) / (one - ay));
 	} else {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 * normal x,y
 		 *      1
@@ -306,24 +312,30 @@
 		 * B = - log [ --------------- ] = - log (1+ -----------------)
 		 *     4     [ x*x+(y-1)*(y-1) ]   4         x*x + (y-1)*(y-1)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		t = one - ay;
+
 		if (iy >= 0x3ffe0000 && iy < 0x40000000) {
 			/* y close to 1 */
-			LD_RE(ans) = half * (atan2l((ax + ax), (t * (one +
-				ay) - ax * ax)));
+			LD_RE(ans) = half * (atan2l((ax + ax), (t * (one + ay) -
+			    ax * ax)));
 		} else if (ix >= 0x3ffe0000 && ix < 0x40000000) {
 			/* x close to 1 */
 			LD_RE(ans) = half * atan2l((ax + ax), ((one - ax) *
-				(one + ax) - ay * ay));
-		} else
-			LD_RE(ans) = half * atan2l((ax + ax), ((one - ax *
-				ax) - ay * ay));
+			    (one + ax) - ay * ay));
+		} else {
+			LD_RE(ans) = half * atan2l((ax + ax), ((one - ax * ax) -
+			    ay * ay));
+		}
+
 		LD_IM(ans) = 0.25L * log1pl((4.0L * ay) / (ax * ax + t * t));
 	}
+
 	if (hx < 0)
 		LD_RE(ans) = -LD_RE(ans);
+
 	if (hy < 0)
 		LD_IM(ans) = -LD_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ccos.c	2019-06-06 20:39:40.155416458 +0000
+++ new/usr/src/lib/libm/common/complex/ccos.c	2019-06-06 20:39:40.173161407 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __ccos = ccos
 
-/* INDENT OFF */
+
 /*
  * dcomplex ccos(dcomplex z);
  *
@@ -38,13 +39,13 @@
  *		= ccosh(i*(-z)) = ccosh(i*(-x-yi))
  *		= ccosh(y-ix)
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "complex_wrapper.h"
 
 dcomplex
-ccos(dcomplex z) {
+ccos(dcomplex z)
+{
 	double x, y;
 
 	x = D_RE(z);
--- old/usr/src/lib/libm/common/complex/ccosf.c	2019-06-06 20:39:40.655856809 +0000
+++ new/usr/src/lib/libm/common/complex/ccosf.c	2019-06-06 20:39:40.673076093 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 fcomplex
-ccosf(fcomplex z) {
+ccosf(fcomplex z)
+{
 	float x, y;
 
 	x = F_RE(z);
--- old/usr/src/lib/libm/common/complex/ccosh.c	2019-06-06 20:39:41.108685643 +0000
+++ new/usr/src/lib/libm/common/complex/ccosh.c	2019-06-06 20:39:41.124526196 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __ccosh = ccosh
 
-/* INDENT OFF */
+
 /*
  * dcomplex ccosh(dcomplex z);
  *
@@ -73,13 +74,13 @@
  *      ccosh(NaN,y) = (NaN,NaN) for non-zero y
  *      ccosh(NaN,NaN) = (NaN,NaN)
  */
-/* INDENT ON */
 
-#include "libm.h"		/* cosh/exp/fabs/scalbn/sinh/sincos/__k_cexp */
+#include "libm.h"	/* cosh/exp/fabs/scalbn/sinh/sincos/__k_cexp */
 #include "complex_wrapper.h"
 
 dcomplex
-ccosh(dcomplex z) {
+ccosh(dcomplex z)
+{
 	double t, x, y, S, C;
 	int hx, ix, lx, hy, iy, ly, n;
 	dcomplex ans;
@@ -96,7 +97,8 @@
 	y = fabs(y);
 
 	(void) sincos(y, &S, &C);
-	if (ix >= 0x403c0000) {	/* |x| > 28 = prec/2 (14,28,34,60) */
+
+	if (ix >= 0x403c0000) {		/* |x| > 28 = prec/2 (14,28,34,60) */
 		if (ix >= 0x40862E42) {	/* |x| > 709.78... ~ log(2**1024) */
 			if (ix >= 0x7ff00000) {	/* |x| is inf or NaN */
 				if ((iy | ly) == 0) {
@@ -111,7 +113,7 @@
 				}
 			} else {
 				t = __k_cexp(x, &n);
-						/* return exp(x)=t*2**n */
+				/* return exp(x)=t*2**n */
 				D_RE(ans) = scalbn(C * t, n - 1);
 				D_IM(ans) = scalbn(S * t, n - 1);
 			}
@@ -129,7 +131,9 @@
 			D_IM(ans) = S * sinh(x);
 		}
 	}
+
 	if ((hx ^ hy) < 0)
 		D_IM(ans) = -D_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ccoshf.c	2019-06-06 20:39:41.604369877 +0000
+++ new/usr/src/lib/libm/common/complex/ccoshf.c	2019-06-06 20:39:41.621756301 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,11 +40,12 @@
 static const float zero = 0.0F, half = 0.5F;
 
 fcomplex
-ccoshf(fcomplex z) {
-	float		t, x, y, S, C;
-	double		w;
-	int		hx, ix, hy, iy, n;
-	fcomplex	ans;
+ccoshf(fcomplex z)
+{
+	float t, x, y, S, C;
+	double w;
+	int hx, ix, hy, iy, n;
+	fcomplex ans;
 
 	x = F_RE(z);
 	y = F_IM(z);
@@ -54,7 +57,8 @@
 	y = fabsf(y);
 
 	sincosf(y, &S, &C);
-	if (ix >= 0x41600000) {	/* |x| > 14 = prec/2 (14,28,34,60) */
+
+	if (ix >= 0x41600000) {		/* |x| > 14 = prec/2 (14,28,34,60) */
 		if (ix >= 0x42B171AA) {	/* |x| > 88.722... ~ log(2**128) */
 			if (ix >= 0x7f800000) {	/* |x| is inf or NaN */
 				if (iy == 0) {
@@ -69,7 +73,7 @@
 				}
 			} else {
 #if defined(__i386) && !defined(__amd64)
-				int	rp = __swapRP(fp_extended);
+				int rp = __swapRP(fp_extended);
 #endif
 				/* return (C, S) * exp(x) / 2 */
 				w = __k_cexp((double)x, &n);
@@ -86,7 +90,7 @@
 			F_IM(ans) = S * t;
 		}
 	} else {
-		if (ix == 0) {	/* x = 0, return (C,0) */
+		if (ix == 0) {		/* x = 0, return (C,0) */
 			F_RE(ans) = C;
 			F_IM(ans) = zero;
 		} else {
@@ -94,7 +98,9 @@
 			F_IM(ans) = S * sinhf(x);
 		}
 	}
+
 	if ((hx ^ hy) < 0)
 		F_IM(ans) = -F_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ccoshl.c	2019-06-06 20:39:42.073023672 +0000
+++ new/usr/src/lib/libm/common/complex/ccoshl.c	2019-06-06 20:39:42.089656531 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,12 +33,12 @@
 #include "libm.h"	/* coshl/expl/fabsl/scalbnl/sincosl/sinhl/__k_cexpl */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
 static const long double zero = 0.0L, half = 0.5L;
-/* INDENT ON */
+
 
 ldcomplex
-ccoshl(ldcomplex z) {
+ccoshl(ldcomplex z)
+{
 	long double t, x, y, S, C;
 	int hx, ix, hy, iy, n;
 	ldcomplex ans;
@@ -52,7 +53,8 @@
 	y = fabsl(y);
 
 	(void) sincosl(y, &S, &C);
-	if (ix >= 0x4004e000) {	/* |x| > 60 = prec/2 (14,28,34,60) */
+
+	if (ix >= 0x4004e000) {		/* |x| > 60 = prec/2 (14,28,34,60) */
 		if (ix >= 0x400C62E4) {	/* |x| > 11356.52... ~ log(2**16384) */
 			if (ix >= 0x7fff0000) {	/* |x| is inf or NaN */
 				if (y == zero) {
@@ -67,7 +69,7 @@
 				}
 			} else {
 				t = __k_cexpl(x, &n);
-						/* return exp(x)=t*2**n */
+				/* return exp(x)=t*2**n */
 				LD_RE(ans) = scalbnl(C * t, n - 1);
 				LD_IM(ans) = scalbnl(S * t, n - 1);
 			}
@@ -85,7 +87,9 @@
 			LD_IM(ans) = S * sinhl(x);
 		}
 	}
+
 	if ((hx ^ hy) < 0)
 		LD_IM(ans) = -LD_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ccosl.c	2019-06-06 20:39:42.524716112 +0000
+++ new/usr/src/lib/libm/common/complex/ccosl.c	2019-06-06 20:39:42.541551165 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 ldcomplex
-ccosl(ldcomplex z) {
+ccosl(ldcomplex z)
+{
 	long double x, y;
 
 	x = LD_RE(z);
--- old/usr/src/lib/libm/common/complex/cexp.c	2019-06-06 20:39:42.992283073 +0000
+++ new/usr/src/lib/libm/common/complex/cexp.c	2019-06-06 20:39:43.008340910 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __cexp = cexp
 
-/* INDENT OFF */
+
 /*
  * dcomplex cexp(dcomplex z);
  *
@@ -56,15 +57,15 @@
  *	2. compute sincos(y,&s,&c)
  *	3. compute t*s+i*(t*c), then scale back to 2**n and return.
  */
-/* INDENT ON */
 
-#include "libm.h"		/* exp/scalbn/sincos/__k_cexp */
+#include "libm.h"			/* exp/scalbn/sincos/__k_cexp */
 #include "complex_wrapper.h"
 
 static const double zero = 0.0;
 
 dcomplex
-cexp(dcomplex z) {
+cexp(dcomplex z)
+{
 	dcomplex ans;
 	double x, y, t, c, s;
 	int n, ix, iy, hx, hy, lx, ly;
@@ -77,7 +78,8 @@
 	ly = LO_WORD(y);
 	ix = hx & 0x7fffffff;
 	iy = hy & 0x7fffffff;
-	if ((iy | ly) == 0) {	/* y = 0 */
+
+	if ((iy | ly) == 0) {		/* y = 0 */
 		D_RE(ans) = exp(x);
 		D_IM(ans) = y;
 	} else if (ISINF(ix, lx)) {	/* x is +-inf */
@@ -102,6 +104,7 @@
 		}
 	} else {
 		(void) sincos(y, &s, &c);
+
 		if (ix >= 0x40862E42) {	/* |x| > 709.78... ~ log(2**1024) */
 			t = __k_cexp(x, &n);
 			D_RE(ans) = scalbn(t * c, n);
@@ -112,5 +115,6 @@
 			D_IM(ans) = t * s;
 		}
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cexpf.c	2019-06-06 20:39:43.445835648 +0000
+++ new/usr/src/lib/libm/common/complex/cexpf.c	2019-06-06 20:39:43.463911427 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,11 +40,12 @@
 static const float zero = 0.0F;
 
 fcomplex
-cexpf(fcomplex z) {
-	fcomplex	ans;
-	float		x, y, c, s;
-	double		t;
-	int		n, ix, iy, hx, hy;
+cexpf(fcomplex z)
+{
+	fcomplex ans;
+	float x, y, c, s;
+	double t;
+	int n, ix, iy, hx, hy;
 
 	x = F_RE(z);
 	y = F_IM(z);
@@ -50,7 +53,8 @@
 	hy = THE_WORD(y);
 	ix = hx & 0x7fffffff;
 	iy = hy & 0x7fffffff;
-	if (iy == 0) {		/* y = 0 */
+
+	if (iy == 0) {			/* y = 0 */
 		F_RE(ans) = expf(x);
 		F_IM(ans) = y;
 	} else if (ix == 0x7f800000) {	/* x is +-inf */
@@ -75,9 +79,10 @@
 		}
 	} else {
 		sincosf(y, &s, &c);
+
 		if (ix >= 0x42B171AA) {	/* |x| > 88.722... ~ log(2**128) */
 #if defined(__i386) && !defined(__amd64)
-			int	rp = __swapRP(fp_extended);
+			int rp = __swapRP(fp_extended);
 #endif
 			t = __k_cexp(x, &n);
 			F_RE(ans) = (float)scalbn(t * (double)c, n);
@@ -92,5 +97,6 @@
 			F_IM(ans) = t * s;
 		}
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cexpl.c	2019-06-06 20:39:43.940900049 +0000
+++ new/usr/src/lib/libm/common/complex/cexpl.c	2019-06-06 20:39:43.958711232 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,18 +30,18 @@
 
 #pragma weak __cexpl = cexpl
 
-#include "libm.h"		/* expl/isinfl/iszerol/scalbnl/sincosl */
+#include "libm.h"	/* expl/isinfl/iszerol/scalbnl/sincosl */
 #include "complex_wrapper.h"
 
 extern int isinfl(long double);
 extern int iszerol(long double);
 
-/* INDENT OFF */
 static const long double zero = 0.0L;
-/* INDENT ON */
+
 
 ldcomplex
-cexpl(ldcomplex z) {
+cexpl(ldcomplex z)
+{
 	ldcomplex ans;
 	long double x, y, t, c, s;
 	int n, ix, iy, hx, hy;
@@ -51,10 +52,11 @@
 	hy = HI_XWORD(y);
 	ix = hx & 0x7fffffff;
 	iy = hy & 0x7fffffff;
-	if (iszerol(y)) {	/* y = 0 */
+
+	if (iszerol(y)) {		/* y = 0 */
 		LD_RE(ans) = expl(x);
 		LD_IM(ans) = y;
-	} else if (isinfl(x)) {	/* x is +-inf */
+	} else if (isinfl(x)) {		/* x is +-inf */
 		if (hx < 0) {
 			if (iy >= 0x7fff0000) {
 				LD_RE(ans) = zero;
@@ -76,6 +78,7 @@
 		}
 	} else {
 		(void) sincosl(y, &s, &c);
+
 		if (ix >= 0x400C62E4) {	/* |x| > 11356.52... ~ log(2**16384) */
 			t = __k_cexpl(x, &n);
 			LD_RE(ans) = scalbnl(t * c, n);
@@ -86,5 +89,6 @@
 			LD_IM(ans) = t * s;
 		}
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cimag.c	2019-06-06 20:39:44.460501521 +0000
+++ new/usr/src/lib/libm/common/complex/cimag.c	2019-06-06 20:39:44.479089828 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 double
-cimag(dcomplex z) {
+cimag(dcomplex z)
+{
 	return (D_IM(z));
 }
--- old/usr/src/lib/libm/common/complex/cimagf.c	2019-06-06 20:39:44.946839764 +0000
+++ new/usr/src/lib/libm/common/complex/cimagf.c	2019-06-06 20:39:44.964383680 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 float
-cimagf(fcomplex z) {
+cimagf(fcomplex z)
+{
 	return (F_IM(z));
 }
--- old/usr/src/lib/libm/common/complex/cimagl.c	2019-06-06 20:39:45.423852980 +0000
+++ new/usr/src/lib/libm/common/complex/cimagl.c	2019-06-06 20:39:45.440766681 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 long double
-cimagl(ldcomplex z) {
+cimagl(ldcomplex z)
+{
 	return (LD_IM(z));
 }
--- old/usr/src/lib/libm/common/complex/clog.c	2019-06-06 20:39:45.889884306 +0000
+++ new/usr/src/lib/libm/common/complex/clog.c	2019-06-06 20:39:45.907230750 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -28,7 +30,7 @@
 
 #pragma weak clog = __clog
 
-/* INDENT OFF */
+
 /*
  * dcomplex clog(dcomplex z);
  *
@@ -58,21 +60,20 @@
  *    clog(NaN  + i inf)=  inf  + i NaN
  *    clog(NaN  + i NaN)=  NaN  + i NaN
  */
-/* INDENT ON */
 
-#include <math.h>		/* atan2/fabs/log/log1p */
+#include <math.h>			/* atan2/fabs/log/log1p */
 #include "complex_wrapper.h"
-#include "libm_protos.h"	/* __k_clog_r */
-
+#include "libm_protos.h"		/* __k_clog_r */
 
 static const double half = 0.5, one = 1.0;
 
 dcomplex
-__clog(dcomplex z) {
-	dcomplex	ans;
-	double		x, y, t, ax, ay, w;
-	int		n, ix, iy, hx, hy;
-	unsigned	lx, ly;
+__clog(dcomplex z)
+{
+	dcomplex ans;
+	double x, y, t, ax, ay, w;
+	int n, ix, iy, hx, hy;
+	unsigned lx, ly;
 
 	x = D_RE(z);
 	y = D_IM(z);
@@ -85,6 +86,7 @@
 	ay = fabs(y);
 	ax = fabs(x);
 	D_IM(ans) = carg(z);
+
 	if (ix < iy || (ix == iy && lx < ly)) {
 		/* swap x and y to force ax >= ay */
 		t = ax;
@@ -95,8 +97,10 @@
 		n = lx, lx = ly;
 		ly = n;
 	}
+
 	n = (ix - iy) >> 20;
-	if (ix >= 0x7ff00000) {	/* x or y is Inf or NaN */
+
+	if (ix >= 0x7ff00000) {		/* x or y is Inf or NaN */
 		if (ISINF(ix, lx))
 			D_RE(ans) = ax;
 		else if (ISINF(iy, ly))
@@ -104,7 +108,7 @@
 		else
 			D_RE(ans) = ax * ay;
 	} else if ((iy | ly) == 0) {
-		D_RE(ans) = ((ix | lx) == 0)? -one / ax : log(ax);
+		D_RE(ans) = ((ix | lx) == 0) ? -one / ax : log(ax);
 	} else if (((0x3fffffff - ix) ^ (ix - 0x3fe00000)) >= 0) {
 		/* 0.5 <= x < 2 */
 		if (ix >= 0x3ff00000) {
@@ -113,8 +117,8 @@
 			else if (n >= 60)
 				D_RE(ans) = log(ax);
 			else
-				D_RE(ans) = half * (log1p(ay * ay + (ax -
-				    one) * (ax + one)));
+				D_RE(ans) = half * (log1p(ay * ay + (ax - one) *
+				    (ax + one)));
 		} else if (n >= 60) {
 			D_RE(ans) = log(ax);
 		} else {
@@ -129,5 +133,6 @@
 		t = ay / ax;
 		D_RE(ans) = log(ax) + half * log1p(t * t);
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/clogf.c	2019-06-06 20:39:46.403147513 +0000
+++ new/usr/src/lib/libm/common/complex/clogf.c	2019-06-06 20:39:46.420458613 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,11 +38,12 @@
 #endif
 
 fcomplex
-clogf(fcomplex z) {
-	fcomplex	ans;
-	float		x, y, ax, ay;
-	double		dx, dy;
-	int		ix, iy, hx, hy;
+clogf(fcomplex z)
+{
+	fcomplex ans;
+	float x, y, ax, ay;
+	double dx, dy;
+	int ix, iy, hx, hy;
 
 	x = F_RE(z);
 	y = F_IM(z);
@@ -51,6 +54,7 @@
 	ay = fabsf(y);
 	ax = fabsf(x);
 	F_IM(ans) = atan2f(y, x);
+
 	if (ix >= 0x7f800000 || iy >= 0x7f800000) {
 		/* x or y is Inf or NaN */
 		if (iy == 0x7f800000)
@@ -61,10 +65,11 @@
 			F_RE(ans) = ax + ay;
 	} else {
 #if defined(__i386) && !defined(__amd64)
-		int	rp = __swapRP(fp_extended);
+		int rp = __swapRP(fp_extended);
 #endif
 		dx = (double)ax;
 		dy = (double)ay;
+
 		if (ix == 0x3f800000)
 			F_RE(ans) = (float)(0.5 * log1p(dy * dy));
 		else if (iy == 0x3f800000)
@@ -73,10 +78,12 @@
 			F_RE(ans) = -1.0f / ax;
 		else
 			F_RE(ans) = (float)(0.5 * log(dx * dx + dy * dy));
+
 #if defined(__i386) && !defined(__amd64)
 		if (rp != fp_extended)
 			(void) __swapRP(rp);
 #endif
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/clogl.c	2019-06-06 20:39:46.898096655 +0000
+++ new/usr/src/lib/libm/common/complex/clogl.c	2019-06-06 20:39:46.915947194 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,19 +35,19 @@
 #include "longdouble.h"
 
 #if defined(__sparc)
-#define	SIGP7	120
-#define	HSIGP7	60
+#define	SIGP7		120
+#define	HSIGP7		60
 #elif defined(__x86)
-#define	SIGP7	70
-#define	HSIGP7	35
+#define	SIGP7		70
+#define	HSIGP7		35
 #endif
 
-/* INDENT OFF */
 static const long double zero = 0.0L, half = 0.5L, one = 1.0L;
-/* INDENT ON */
+
 
 ldcomplex
-clogl(ldcomplex z) {
+clogl(ldcomplex z)
+{
 	ldcomplex ans;
 	long double x, y, t, ax, ay;
 	int n, ix, iy, hx, hy;
@@ -60,26 +61,29 @@
 	ay = fabsl(y);
 	ax = fabsl(x);
 	LD_IM(ans) = atan2l(y, x);
+
 	if (ix < iy || (ix == iy && ix < 0x7fff0000 && ax < ay)) {
-			/* swap x and y to force ax>=ay */
+		/* swap x and y to force ax>=ay */
 		t = ax;
 		ax = ay;
 		ay = t;
 		n = ix, ix = iy;
 		iy = n;
 	}
+
 	n = (ix - iy) >> 16;
-	if (ix >= 0x7fff0000) {	/* x or y is Inf or NaN */
+
+	if (ix >= 0x7fff0000) {		/* x or y is Inf or NaN */
 		if (isinfl(ax))
 			LD_RE(ans) = ax;
 		else if (isinfl(ay))
 			LD_RE(ans) = ay;
 		else
 			LD_RE(ans) = ax + ay;
-	} else if (ay == zero)
+	} else if (ay == zero) {
 		LD_RE(ans) = logl(ax);
-	else if (((0x3fffffff - ix) ^ (ix - 0x3ffe0000)) >= 0) {
-							/* 0.5 <= x < 2 */
+	} else if (((0x3fffffff - ix) ^ (ix - 0x3ffe0000)) >= 0) {
+		/* 0.5 <= x < 2 */
 		if (ix >= 0x3fff0000) {
 			if (ax == one)
 				LD_RE(ans) = half * log1pl(ay * ay);
@@ -87,19 +91,21 @@
 				LD_RE(ans) = logl(ax);
 			else
 				LD_RE(ans) = half * (log1pl(ay * ay + (ax -
-					one) * (ax + one)));
-		} else if (n >= SIGP7)
+				    one) * (ax + one)));
+		} else if (n >= SIGP7) {
 			LD_RE(ans) = logl(ax);
-		else
+		} else {
 			LD_RE(ans) = __k_clog_rl(x, y, &t);
-	} else if (n >= HSIGP7)
+		}
+	} else if (n >= HSIGP7) {
 		LD_RE(ans) = logl(ax);
-	else if (ix < 0x5f3f0000 && iy >= 0x20bf0000)
+	} else if (ix < 0x5f3f0000 && iy >= 0x20bf0000) {
 		/* 2**-8000 < y < x < 2**8000 */
 		LD_RE(ans) = half * logl(ax * ax + ay * ay);
-	else {
+	} else {
 		t = ay / ax;
 		LD_RE(ans) = logl(ax) + half * log1pl(t * t);
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/complex_wrapper.h	2019-06-06 20:39:47.403452696 +0000
+++ new/usr/src/lib/libm/common/complex/complex_wrapper.h	2019-06-06 20:39:47.419949076 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,57 +34,55 @@
 #pragma ident	"@(#)complex_wrapper.h	1.7	06/01/31 SMI"
 
 #if defined(__GNUC__)
-#define dcomplex double _Complex
-#define fcomplex float _Complex
-#define ldcomplex long double _Complex
-#define D_RE(x) __real__ x
-#define D_IM(x) __imag__ x
-#define F_RE(x) __real__ x
-#define F_IM(x) __imag__ x
-#define LD_RE(x) __real__ x
-#define LD_IM(x) __imag__ x
+#define	dcomplex		double _Complex
+#define	fcomplex		float _Complex
+#define	ldcomplex		long double _Complex
+#define	D_RE(x)			__real__ x
+#define	D_IM(x)			__imag__ x
+#define	F_RE(x)			__real__ x
+#define	F_IM(x)			__imag__ x
+#define	LD_RE(x)		__real__ x
+#define	LD_IM(x)		__imag__ x
 
 #include <complex.h>
 #else
-
-#define	dcomplex	double complex
-#define	fcomplex	float complex
-#define	ldcomplex	long double complex
-#define	_X_RE(__t, __z)	((__t *) &__z)[0]
-#define	_X_IM(__t, __z)	((__t *) &__z)[1]
-#define	D_RE(__z)	_X_RE(double, __z)
-#define	D_IM(__z)	_X_IM(double, __z)
-#define	F_RE(__z)	_X_RE(float, __z)
-#define	F_IM(__z)	_X_IM(float, __z)
-#define	LD_RE(__z)	_X_RE(long double, __z)
-#define	LD_IM(__z)	_X_IM(long double, __z)
+#define	dcomplex		double complex
+#define	fcomplex		float complex
+#define	ldcomplex		long double complex
+#define	_X_RE(__t, __z)		((__t *)&__z)[0]
+#define	_X_IM(__t, __z)		((__t *)&__z)[1]
+#define	D_RE(__z)		_X_RE(double, __z)
+#define	D_IM(__z)		_X_IM(double, __z)
+#define	F_RE(__z)		_X_RE(float, __z)
+#define	F_IM(__z)		_X_IM(float, __z)
+#define	LD_RE(__z)		_X_RE(long double, __z)
+#define	LD_IM(__z)		_X_IM(long double, __z)
 
 #include <complex.h>
 #endif
 
 #if defined(__sparc)
-#define	HIWORD	0
-#define	LOWORD	1
-#define	HI_XWORD(x)	((unsigned *) &x)[0]
-#define	XFSCALE(x, n)	((unsigned *) &x)[0] += n << 16	/* signbitl(x) == 0 */
-#define	CHOPPED(x)	((long double) ((double) (x)))
+#define	HIWORD		0
+#define	LOWORD		1
+#define	HI_XWORD(x)	((unsigned *)&x)[0]
+#define	XFSCALE(x, n)	((unsigned *)&x)[0] += n << 16	/* signbitl(x) == 0 */
+#define	CHOPPED(x)	((long double)((double)(x)))
 #elif defined(__x86)
-#define	HIWORD	1
-#define	LOWORD	0
-#define	HI_XWORD(x)	((((int *) &x)[2] << 16) | \
-			(0xffff & ((unsigned *) &x)[1] >> 15))
-#define	XFSCALE(x, n)	((unsigned short *) &x)[4] += n	/* signbitl(x) == 0 */
-#define	CHOPPED(x)	((long double) ((float) (x)))
+#define	HIWORD		1
+#define	LOWORD		0
+#define	HI_XWORD(x)	((((int *)&x)[2] << 16) | (0xffff & \
+	((unsigned *)&x)[1] >> 15))
+#define	XFSCALE(x, n)	((unsigned short *)&x)[4] += n	/* signbitl(x) == 0 */
+#define	CHOPPED(x)	((long double)((float)(x)))
 #else
 #error Unknown architecture
 #endif
-#define	HI_WORD(x)	((int *) &x)[HIWORD]	/* for double */
-#define	LO_WORD(x)	((int *) &x)[LOWORD]	/* for double */
-#define	THE_WORD(x)	((int *) &x)[0]		/* for float */
+#define	HI_WORD(x)		((int *)&x)[HIWORD]	/* for double */
+#define	LO_WORD(x)		((int *)&x)[LOWORD]	/* for double */
+#define	THE_WORD(x)		((int *)&x)[0]		/* for float */
 
 /*
  * iy:ly must have the sign bit already cleared
  */
-#define	ISINF(iy, ly)	(((iy - 0x7ff00000) | ly) == 0)
-
-#endif	/* _COMPLEX_WRAPPER_H */
+#define	ISINF(iy, ly)		(((iy - 0x7ff00000) | ly) == 0)
+#endif /* _COMPLEX_WRAPPER_H */
--- old/usr/src/lib/libm/common/complex/conj.c	2019-06-06 20:39:47.877520747 +0000
+++ new/usr/src/lib/libm/common/complex/conj.c	2019-06-06 20:39:47.894239117 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 dcomplex
-conj(dcomplex z) {
+conj(dcomplex z)
+{
 	D_IM(z) = -D_IM(z);
 	return (z);
 }
--- old/usr/src/lib/libm/common/complex/conjf.c	2019-06-06 20:39:48.338949423 +0000
+++ new/usr/src/lib/libm/common/complex/conjf.c	2019-06-06 20:39:48.359812674 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 fcomplex
-conjf(fcomplex z) {
+conjf(fcomplex z)
+{
 	F_IM(z) = -F_IM(z);
 	return (z);
 }
--- old/usr/src/lib/libm/common/complex/conjl.c	2019-06-06 20:39:48.799399051 +0000
+++ new/usr/src/lib/libm/common/complex/conjl.c	2019-06-06 20:39:48.816006466 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 ldcomplex
-conjl(ldcomplex z) {
+conjl(ldcomplex z)
+{
 	LD_IM(z) = -LD_IM(z);
 	return (z);
 }
--- old/usr/src/lib/libm/common/complex/cpow.c	2019-06-06 20:39:49.250517148 +0000
+++ new/usr/src/lib/libm/common/complex/cpow.c	2019-06-06 20:39:49.266436895 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __cpow = cpow
 
-/* INDENT OFF */
+
 /*
  * dcomplex cpow(dcomplex z);
  *
@@ -86,23 +87,22 @@
  *                  r exp(q i) = r * cos(q) + r * sin(q) i,
  *      we regard r * 0 is 0 except when r is a NaN.
  */
-/* INDENT ON */
 
-#include "libm.h"	/* atan2/exp/fabs/hypot/log/pow/scalbn */
-			/* atan2pi/exp2/sincos/sincospi/__k_clog_r/__k_atan2 */
+/*
+ * atan2/exp/fabs/hypot/log/pow/scalbn
+ * atan2pi/exp2/sincos/sincospi/__k_clog_r/__k_atan2
+ */
+#include "libm.h"
 #include "complex_wrapper.h"
 
 extern void sincospi(double, double *, double *);
-
-static const double
-	huge = 1e300,
+static const double huge = 1e300,
 	tiny = 1e-300,
 	invln2 = 1.44269504088896338700e+00,
-	ln2hi = 6.93147180369123816490e-01,   /* 0x3fe62e42, 0xfee00000 */
-	ln2lo = 1.90821492927058770002e-10,   /* 0x3dea39ef, 0x35793c76 */
+	ln2hi = 6.93147180369123816490e-01,	/* 0x3fe62e42, 0xfee00000 */
+	ln2lo = 1.90821492927058770002e-10,	/* 0x3dea39ef, 0x35793c76 */
 	one = 1.0,
 	zero = 0.0;
-
 static const int hiinf = 0x7ff00000;
 extern double atan2pi(double, double);
 
@@ -111,37 +111,57 @@
  * compute t[0] + t[1] + t[2] + t[3] into two double fp numbers.
  */
 static double
-sum4fp(double ta[], double *w) {
+sum4fp(double ta[], double *w)
+{
 	double t1, t2, t3, t4, w1, w2, t;
-	t1 = ta[0]; t2 = ta[1]; t3 = ta[2]; t4 = ta[3];
+
+	t1 = ta[0];
+	t2 = ta[1];
+	t3 = ta[2];
+	t4 = ta[3];
+
 	/*
 	 * Rearrange ti so that |t1| >= |t2| >= |t3| >= |t4|
 	 */
 	if (fabs(t4) > fabs(t1)) {
-		t = t1; t1 = t3; t3 = t;
-		t = t2; t2 = t4; t4 = t;
+		t = t1;
+		t1 = t3;
+		t3 = t;
+		t = t2;
+		t2 = t4;
+		t4 = t;
 	} else if (fabs(t3) > fabs(t1)) {
-		t = t1; t1 = t3;
+		t = t1;
+		t1 = t3;
+
 		if (fabs(t4) > fabs(t2)) {
-			t3 = t4; t4 = t2; t2 = t;
+			t3 = t4;
+			t4 = t2;
+			t2 = t;
 		} else {
-			t3 = t2; t2 = t;
+			t3 = t2;
+			t2 = t;
 		}
 	} else if (fabs(t3) > fabs(t2)) {
-		t = t2; t2 = t3;
+		t = t2;
+		t2 = t3;
+
 		if (fabs(t4) > fabs(t2)) {
-			t3 = t4; t4 = t;
-		} else
+			t3 = t4;
+			t4 = t;
+		} else {
 			t3 = t;
+		}
 	}
+
 	/* summing r = t1 + t2 + t3 + t4 to w1 + w2 */
 	w1 = t3 + t4;
 	w2 = t4 - (w1 - t3);
-	t  = t2 + w1;
+	t = t2 + w1;
 	w2 += w1 - (t - t2);
 	w1 = t + w2;
 	w2 += t - w1;
-	t  = t1 + w1;
+	t = t1 + w1;
 	w2 += w1 - (t - t1);
 	w1 = t + w2;
 	*w = w2 - (w1 - t);
@@ -149,7 +169,8 @@
 }
 
 dcomplex
-cpow(dcomplex z, dcomplex w) {
+cpow(dcomplex z, dcomplex w)
+{
 	dcomplex ans;
 	double x, y, u, v, t, c, s, r, x2, y2;
 	double b[4], t1, t2, t3, t4, w1, w2, u1, v1, x1, y1;
@@ -160,59 +181,63 @@
 	y = D_IM(z);
 	u = D_RE(w);
 	v = D_IM(w);
-	hx = ((int *) &x)[HIWORD];
-	lx = ((int *) &x)[LOWORD];
-	hy = ((int *) &y)[HIWORD];
-	ly = ((int *) &y)[LOWORD];
-	hu = ((int *) &u)[HIWORD];
-	lu = ((int *) &u)[LOWORD];
-	hv = ((int *) &v)[HIWORD];
-	lv = ((int *) &v)[LOWORD];
+	hx = ((int *)&x)[HIWORD];
+	lx = ((int *)&x)[LOWORD];
+	hy = ((int *)&y)[HIWORD];
+	ly = ((int *)&y)[LOWORD];
+	hu = ((int *)&u)[HIWORD];
+	lu = ((int *)&u)[LOWORD];
+	hv = ((int *)&v)[HIWORD];
+	lv = ((int *)&v)[LOWORD];
 	ix = hx & 0x7fffffff;
 	iy = hy & 0x7fffffff;
 	iu = hu & 0x7fffffff;
 	iv = hv & 0x7fffffff;
 
 	j = 0;
-	if ((iv | lv) == 0) {	/* z**(real) */
+
+	if ((iv | lv) == 0) {				/* z**(real) */
 		if (((hu - 0x3ff00000) | lu) == 0) {	/* z ** 1 = z */
 			D_RE(ans) = x;
 			D_IM(ans) = y;
-		} else if ((iu | lu) == 0) {	/* z ** 0 = 1 */
+		} else if ((iu | lu) == 0) {		/* z ** 0 = 1 */
 			D_RE(ans) = one;
 			D_IM(ans) = zero;
-		} else if ((iy | ly) == 0) {	/* (real)**(real) */
+		} else if ((iy | ly) == 0) {		/* (real)**(real) */
 			D_IM(ans) = zero;
+
 			if (hx < 0 && ix < hiinf && iu < hiinf) {
 				/* -x ** u  is exp(i*pi*u)*pow(x,u) */
 				r = pow(-x, u);
 				sincospi(u, &s, &c);
-				D_RE(ans) = (c == zero)? c: c * r;
-				D_IM(ans) = (s == zero)? s: s * r;
-			} else
+				D_RE(ans) = (c == zero) ? c : c *r;
+				D_IM(ans) = (s == zero) ? s : s *r;
+			} else {
 				D_RE(ans) = pow(x, u);
+			}
 		} else if (((ix | lx) == 0) || ix >= hiinf || iy >= hiinf) {
-			if (isnan(x) || isnan(y) || isnan(u))
+			if (isnan(x) || isnan(y) || isnan(u)) {
 				D_RE(ans) = D_IM(ans) = x + y + u;
-			else {
+			} else {
 				if ((ix | lx) == 0)
 					r = fabs(y);
 				else
 					r = fabs(x) + fabs(y);
+
 				t = atan2pi(y, x);
 				sincospi(t * u, &s, &c);
-				D_RE(ans) = (c == zero)? c: c * r;
-				D_IM(ans) = (s == zero)? s: s * r;
+				D_RE(ans) = (c == zero) ? c : c *r;
+				D_IM(ans) = (s == zero) ? s : s *r;
 			}
-		} else if (((ix - iy) | (lx - ly)) == 0) {   /* |x| = |y| */
+		} else if (((ix - iy) | (lx - ly)) == 0) {	/* |x| = |y| */
 			if (hx >= 0) {
-				t = (hy >= 0)? 0.25 : -0.25;
+				t = (hy >= 0) ? 0.25 : -0.25;
 				sincospi(t * u, &s, &c);
 			} else if ((lu & 3) == 0) {
-				t = (hy >= 0)? 0.75 : -0.75;
+				t = (hy >= 0) ? 0.75 : -0.75;
 				sincospi(t * u, &s, &c);
 			} else {
-				r = (hy >= 0)? u : -u;
+				r = (hy >= 0) ? u : -u;
 				t = -0.25 * r;
 				w1 = r + t;
 				w2 = t - (w1 - r);
@@ -221,22 +246,27 @@
 				s = t1 * t4 + t3 * t2;
 				c = t2 * t4 - t1 * t3;
 			}
+
 			if (ix < 0x3fe00000)	/* |x| < 1/2 */
 				r = pow(fabs(x + x), u) * exp2(-0.5 * u);
 			else if (ix >= 0x3ff00000 || iu < 0x408ff800)
 				/* |x| >= 1 or |u| < 1023 */
 				r = pow(fabs(x), u) * exp2(0.5 * u);
-			else   /* special treatment */
+			else		/* special treatment */
 				j = 2;
+
 			if (j == 0) {
-				D_RE(ans) = (c == zero)? c: c * r;
-				D_IM(ans) = (s == zero)? s: s * r;
+				D_RE(ans) = (c == zero) ? c : c *r;
+				D_IM(ans) = (s == zero) ? s : s *r;
 			}
-		} else
+		} else {
 			j = 1;
+		}
+
 		if (j == 0)
 			return (ans);
 	}
+
 	if (iu >= hiinf || iv >= hiinf || ix >= hiinf || iy >= hiinf) {
 		/*
 		 * non-zero imag part(s) with inf component(s) yields NaN
@@ -244,12 +274,14 @@
 		t = fabs(x) + fabs(y) + fabs(u) + fabs(v);
 		D_RE(ans) = D_IM(ans) = t - t;
 	} else {
-		k = 0;	/* no scaling */
+		k = 0;				/* no scaling */
+
 		if (iu > 0x7f000000 || iv > 0x7f000000) {
 			u *= .0009765625; /* scale 2**-10 to avoid overflow */
 			v *= .0009765625;
-			k = 1;	/* scale by 2**-10 */
+			k = 1;			/* scale by 2**-10 */
 		}
+
 		/*
 		 * Use similated higher precision arithmetic to compute:
 		 * r = u * log(hypot(x, y)) - v * atan2(y, x)
@@ -261,16 +293,18 @@
 		y1 = t3;
 		u1 = u;
 		v1 = v;
-		((int *) &u1)[LOWORD] &= 0xf8000000;
-		((int *) &v1)[LOWORD] &= 0xf8000000;
-		((int *) &x1)[LOWORD] &= 0xf8000000;
-		((int *) &y1)[LOWORD] &= 0xf8000000;
+		((int *)&u1)[LOWORD] &= 0xf8000000;
+		((int *)&v1)[LOWORD] &= 0xf8000000;
+		((int *)&x1)[LOWORD] &= 0xf8000000;
+		((int *)&y1)[LOWORD] &= 0xf8000000;
 		x2 = t2 - (x1 - t1);	/* log(hypot(x,y)) = x1 + x2 */
 		y2 = t4 - (y1 - t3);	/* atan2(y,x) = y1 + y2 */
+
 		/* compute q = u * atan2(y, x) + v * log(hypot(x, y)) */
 		if (j != 2) {
 			b[0] = u1 * y1;
 			b[1] = (u - u1) * y1 + u * y2;
+
 			if (j == 1) {	/* v = 0 */
 				w1 = b[0] + b[1];
 				w2 = b[1] - (w1 - b[0]);
@@ -279,25 +313,30 @@
 				b[3] = (v - v1) * x1 + v * x2;
 				w1 = sum4fp(b, &w2);
 			}
+
 			sincos(w1, &t1, &t2);
 			sincos(w2, &t3, &t4);
 			s = t1 * t4 + t3 * t2;
 			c = t2 * t4 - t1 * t3;
-			if (k == 1)
-			/*
-			 * square (cos(q) + i sin(q)) k times to get
-			 * (cos(2^k * q + i sin(2^k * q)
-			 */
+
+			if (k == 1) {
+				/*
+				 * square (cos(q) + i sin(q)) k times to get
+				 * (cos(2^k * q + i sin(2^k * q)
+				 */
 				for (i = 0; i < 10; i++) {
 					t1 = s * c;
 					c = (c + s) * (c - s);
 					s = t1 + t1;
 				}
+			}
 		}
+
 		/* compute r = u * (t1, t2) - v * (t3, t4) */
 		b[0] = u1 * x1;
 		b[1] = (u - u1) * x1 + u * x2;
-		if (j == 1) {	/* v = 0 */
+
+		if (j == 1) {		/* v = 0 */
 			w1 = b[0] + b[1];
 			w2 = b[1] - (w1 - b[0]);
 		} else {
@@ -305,33 +344,45 @@
 			b[3] = (v1 - v) * y1 - v * y2;
 			w1 = sum4fp(b, &w2);
 		}
+
 		/* check over/underflow for exp(w1 + w2) */
 		if (k && fabs(w1) < 1000.0) {
-			w1 *= 1024; w2 *= 1024; k = 0;
+			w1 *= 1024;
+			w2 *= 1024;
+			k = 0;
 		}
-		hx = ((int *) &w1)[HIWORD];
-		lx = ((int *) &w1)[LOWORD];
+
+		hx = ((int *)&w1)[HIWORD];
+		lx = ((int *)&w1)[LOWORD];
 		ix = hx & 0x7fffffff;
+
 		/* compute exp(w1 + w2) */
-		if (ix < 0x3c900000) /* exp(tiny < 2**-54) = 1 */
+		if (ix < 0x3c900000) {		/* exp(tiny < 2**-54) = 1 */
 			r = one;
-		else if (ix >= 0x40880000) /* overflow/underflow */
-			r = (hx < 0)? tiny * tiny : huge * huge;
-		else {	/* compute exp(w1 + w2) */
-			k = (int) (invln2 * w1 + ((hx >= 0)? 0.5 : -0.5));
-			t1 = (double) k;
+		} else if (ix >= 0x40880000) {	/* overflow/underflow */
+			r = (hx < 0) ? tiny * tiny : huge * huge;
+		} else { /* compute exp(w1 + w2) */
+			k = (int)(invln2 * w1 + ((hx >= 0) ? 0.5 : -0.5));
+			t1 = (double)k;
 			t2 = w1 - t1 * ln2hi;
 			t3 = w2 - t1 * ln2lo;
 			r = exp(t2 + t3);
 		}
-		if (c != zero) c *= r;
-		if (s != zero) s *= r;
+
+		if (c != zero)
+			c *= r;
+
+		if (s != zero)
+			s *= r;
+
 		if (k != 0) {
 			c = scalbn(c, k);
 			s = scalbn(s, k);
 		}
+
 		D_RE(ans) = c;
 		D_IM(ans) = s;
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cpowf.c	2019-06-06 20:39:49.744694598 +0000
+++ new/usr/src/lib/libm/common/complex/cpowf.c	2019-06-06 20:39:49.760831929 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -40,9 +42,10 @@
 extern int __swapRP(int);
 #endif
 
-static const double
-	dpi = 3.1415926535897931160E0,	/* Hex 2^ 1 * 1.921FB54442D18 */
-	dhalf = 0.5,
+/* Hex 2^ 1 * 1.921FB54442D18 */
+static const double dpi = 3.1415926535897931160E0;
+
+static const double dhalf = 0.5,
 	dsqrt2 = 1.41421356237309514547,	/* 3FF6A09E 667F3BCD */
 	dinvpi = 0.3183098861837906715377675;
 
@@ -51,11 +54,12 @@
 #define	hiinf	0x7f800000
 
 fcomplex
-cpowf(fcomplex z, fcomplex w) {
-	fcomplex	ans;
-	float		x, y, u, v, t, c, s;
-	double		dx, dy, du, dv, dt, dc, ds, dp, dq, dr;
-	int		ix, iy, hx, hy, hv, hu, iu, iv, j;
+cpowf(fcomplex z, fcomplex w)
+{
+	fcomplex ans;
+	float x, y, u, v, t, c, s;
+	double dx, dy, du, dv, dt, dc, ds, dp, dq, dr;
+	int ix, iy, hx, hy, hv, hu, iu, iv, j;
 
 	x = F_RE(z);
 	y = F_IM(z);
@@ -71,7 +75,8 @@
 	iv = hv & 0x7fffffff;
 
 	j = 0;
-	if (iv == 0) {		/* z**(real) */
+
+	if (iv == 0) {			/* z**(real) */
 		if (hu == 0x3f800000) {	/* (anything) ** 1  is itself */
 			F_RE(ans) = x;
 			F_IM(ans) = y;
@@ -80,12 +85,13 @@
 			F_IM(ans) = zero;
 		} else if (iy == 0) {	/* (real)**(real) */
 			F_IM(ans) = zero;
+
 			if (hx < 0 && ix < hiinf && iu < hiinf) {
 				/* -x ** u  is exp(i*pi*u)*pow(x,u) */
 				t = powf(-x, u);
 				sincospif(u, &s, &c);
-				F_RE(ans) = (c == zero)? c: c * t;
-				F_IM(ans) = (s == zero)? s: s * t;
+				F_RE(ans) = (c == zero) ? c : c *t;
+				F_IM(ans) = (s == zero) ? s : s *t;
 			} else {
 				F_RE(ans) = powf(x, u);
 			}
@@ -94,22 +100,26 @@
 				F_RE(ans) = F_IM(ans) = x + y + u;
 			} else {
 				v = fabsf(y);
+
 				if (ix != 0)
 					v += fabsf(x);
+
 				t = atan2pif(y, x);
 				sincospif(t * u, &s, &c);
-				F_RE(ans) = (c == zero)? c: c * v;
-				F_IM(ans) = (s == zero)? s: s * v;
+				F_RE(ans) = (c == zero) ? c : c *v;
+				F_IM(ans) = (s == zero) ? s : s *v;
 			}
 		} else if (ix == iy) {	/* if |x| == |y| */
 #if defined(__i386) && !defined(__amd64)
-			int	rp = __swapRP(fp_extended);
+			int rp = __swapRP(fp_extended);
 #endif
 			dx = (double)x;
 			du = (double)u;
-			dt = (hx >= 0)? 0.25 : 0.75;
+			dt = (hx >= 0) ? 0.25 : 0.75;
+
 			if (hy < 0)
 				dt = -dt;
+
 			dr = pow(dsqrt2 * dx, du);
 			sincospi(dt * du, &ds, &dc);
 			F_RE(ans) = (float)(dr * dc);
@@ -121,9 +131,11 @@
 		} else {
 			j = 1;
 		}
+
 		if (j == 0)
 			return (ans);
 	}
+
 	if (iu >= hiinf || iv >= hiinf || ix >= hiinf || iy >= hiinf) {
 		/*
 		 * non-zero imaginery part(s) with inf component(s) yields NaN
@@ -132,9 +144,9 @@
 		F_RE(ans) = F_IM(ans) = t - t;
 	} else {
 #if defined(__i386) && !defined(__amd64)
-		int	rp = __swapRP(fp_extended);
+		int rp = __swapRP(fp_extended);
 #endif
-		/* INDENT OFF */
+
 		/*
 		 * r = u*log(hypot(x,y))-v*atan2(y,x),
 		 * q = u*atan2(y,x)+v*log(hypot(x,y))
@@ -143,25 +155,28 @@
 		 * q/pi = u*atan2pi(y,x)+v*log(hypot(x,y))/pi
 		 * ans = exp(r)*(cospi(q/pi)  + i sinpi(q/pi))
 		 */
-		/* INDENT ON */
 		dx = (double)x;
 		dy = (double)y;
 		du = (double)u;
 		dv = (double)v;
+
 		if (ix > 0x3f000000 && ix < 0x40000000)	/* .5 < |x| < 2 */
 			dt = dhalf * log1p((dx - 1.0) * (dx + 1.0) + dy * dy);
 		else if (iy > 0x3f000000 && iy < 0x40000000) /* .5 < |y| < 2 */
 			dt = dhalf * log1p((dy - 1.0) * (dy + 1.0) + dx * dx);
 		else
 			dt = dhalf * log(dx * dx + dy * dy);
+
 		dp = atan2pi(dy, dx);
-		if (iv == 0) {	/* dv = 0 */
+
+		if (iv == 0) {		/* dv = 0 */
 			dr = exp(du * dt);
 			dq = du * dp;
 		} else {
 			dr = exp(du * dt - dv * dp * dpi);
 			dq = du * dp + dv * dt * dinvpi;
 		}
+
 		sincospi(dq, &ds, &dc);
 		F_RE(ans) = (float)(dr * dc);
 		F_IM(ans) = (float)(dr * ds);
@@ -170,5 +185,6 @@
 			(void) __swapRP(rp);
 #endif
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cpowl.c	2019-06-06 20:39:50.237398620 +0000
+++ new/usr/src/lib/libm/common/complex/cpowl.c	2019-06-06 20:39:50.255051253 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,74 +30,91 @@
 
 #pragma weak __cpowl = cpowl
 
-#include "libm.h"				/* __k_clog_rl/__k_atan2l */
+#include "libm.h"			/* __k_clog_rl/__k_atan2l */
 /* atan2l/atan2pil/exp2l/expl/fabsl/hypotl/isinfl/logl/powl/sincosl/sincospil */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
 #if defined(__sparc)
-#define	HALF(x)  ((int *) &x)[3] = 0; ((int *) &x)[2] &= 0xfe000000
-#define	LAST(x)  ((int *) &x)[3]
+#define	HALF(x)		((int *)&x)[3] = 0; ((int *)&x)[2] &= 0xfe000000
+#define	LAST(x)		((int *)&x)[3]
 #elif defined(__x86)
-#define	HALF(x)  ((int *) &x)[0] = 0
-#define	LAST(x)  ((int *) &x)[0]
+#define	HALF(x)		((int *)&x)[0] = 0
+#define	LAST(x)		((int *)&x)[0]
 #endif
 
-/* INDENT OFF */
 static const int hiinf = 0x7fff0000;
-static const long double
-	tiny = 1.0e-4000L,
+static const long double tiny = 1.0e-4000L,
 	huge = 1.0e4000L,
 #if defined(__x86)
-		/* 43 significant bits, 21 trailing zeros */
+/* 43 significant bits, 21 trailing zeros */
 	ln2hil = 0.693147180559890330187045037746429443359375L,
 	ln2lol = 5.497923018708371174712471612513436025525412068e-14L,
-#else   /* sparc */
-		/* 0x3FF962E4 2FEFA39E F35793C7 00000000 */
+#else /* sparc */
+/* 0x3FF962E4 2FEFA39E F35793C7 00000000 */
 	ln2hil = 0.693147180559945309417231592858066493070671489074L,
 	ln2lol = 5.28600110075004828645286235820646730106802446566153e-25L,
 #endif
-	invln2  = 1.442695040888963407359924681001892137427e+0000L,
+	invln2 = 1.442695040888963407359924681001892137427e+0000L,
 	one = 1.0L,
 	zero = 0.0L;
-/* INDENT ON */
 
 /*
  * Assuming |t[0]| > |t[1]| and |t[2]| > |t[3]|, sum4fpl subroutine
  * compute t[0] + t[1] + t[2] + t[3] into two long double fp numbers.
  */
-static long double sum4fpl(long double ta[], long double *w)
+static long double
+sum4fpl(long double ta[], long double *w)
 {
 	long double t1, t2, t3, t4, w1, w2, t;
-	t1 = ta[0]; t2 = ta[1]; t3 = ta[2]; t4 = ta[3];
+
+	t1 = ta[0];
+	t2 = ta[1];
+	t3 = ta[2];
+	t4 = ta[3];
+
 	/*
 	 * Rearrange ti so that |t1| >= |t2| >= |t3| >= |t4|
 	 */
 	if (fabsl(t4) > fabsl(t1)) {
-		t = t1; t1 = t3; t3 = t;
-		t = t2; t2 = t4; t4 = t;
+		t = t1;
+		t1 = t3;
+		t3 = t;
+		t = t2;
+		t2 = t4;
+		t4 = t;
 	} else if (fabsl(t3) > fabsl(t1)) {
-		t = t1; t1 = t3;
+		t = t1;
+		t1 = t3;
+
 		if (fabsl(t4) > fabsl(t2)) {
-			t3 = t4; t4 = t2; t2 = t;
+			t3 = t4;
+			t4 = t2;
+			t2 = t;
 		} else {
-			t3 = t2; t2 = t;
+			t3 = t2;
+			t2 = t;
 		}
 	} else if (fabsl(t3) > fabsl(t2)) {
-		t = t2; t2 = t3;
+		t = t2;
+		t2 = t3;
+
 		if (fabsl(t4) > fabsl(t2)) {
-			t3 = t4; t4 = t;
-		} else
+			t3 = t4;
+			t4 = t;
+		} else {
 			t3 = t;
+		}
 	}
+
 	/* summing r = t1 + t2 + t3 + t4 to w1 + w2 */
 	w1 = t3 + t4;
 	w2 = t4 - (w1 - t3);
-	t  = t2 + w1;
+	t = t2 + w1;
 	w2 += w1 - (t - t2);
 	w1 = t + w2;
 	w2 += t - w1;
-	t  = t1 + w1;
+	t = t1 + w1;
 	w2 += w1 - (t - t1);
 	w1 = t + w2;
 	*w = w2 - (w1 - t);
@@ -104,7 +122,8 @@
 }
 
 ldcomplex
-cpowl(ldcomplex z, ldcomplex w) {
+cpowl(ldcomplex z, ldcomplex w)
+{
 	ldcomplex ans;
 	long double x, y, u, v, t, c, s, r;
 	long double t1, t2, t3, t4, x1, x2, y1, y2, u1, v1, b[4], w1, w2;
@@ -124,8 +143,9 @@
 	iv = hv & 0x7fffffff;
 
 	j = 0;
-	if (v == zero) {	/* z**(real) */
-		if (u == one) {	/* (anything) ** 1  is itself */
+
+	if (v == zero) {		/* z**(real) */
+		if (u == one) {		/* (anything) ** 1  is itself */
 			LD_RE(ans) = x;
 			LD_IM(ans) = y;
 		} else if (u == zero) {	/* (anything) ** 0  is 1 */
@@ -133,36 +153,39 @@
 			LD_IM(ans) = zero;
 		} else if (y == zero) {	/* real ** real */
 			LD_IM(ans) = zero;
+
 			if (hx < 0 && ix < hiinf && iu < hiinf) {
-			/* -x ** u  is exp(i*pi*u)*pow(x,u) */
+				/* -x ** u  is exp(i*pi*u)*pow(x,u) */
 				r = powl(-x, u);
 				sincospil(u, &s, &c);
-				LD_RE(ans) = (c == zero)? c: c * r;
-				LD_IM(ans) = (s == zero)? s: s * r;
-			} else
+				LD_RE(ans) = (c == zero) ? c : c *r;
+				LD_IM(ans) = (s == zero) ? s : s *r;
+			} else {
 				LD_RE(ans) = powl(x, u);
+			}
 		} else if (x == zero || ix >= hiinf || iy >= hiinf) {
-			if (isnanl(x) || isnanl(y) || isnanl(u))
+			if (isnanl(x) || isnanl(y) || isnanl(u)) {
 				LD_RE(ans) = LD_IM(ans) = x + y + u;
-			else {
+			} else {
 				if (x == zero)
 					r = fabsl(y);
 				else
 					r = fabsl(x) + fabsl(y);
+
 				t = atan2pil(y, x);
 				sincospil(t * u, &s, &c);
-				LD_RE(ans) = (c == zero)? c: c * r;
-				LD_IM(ans) = (s == zero)? s: s * r;
+				LD_RE(ans) = (c == zero) ? c : c *r;
+				LD_IM(ans) = (s == zero) ? s : s *r;
 			}
-		} else if (fabsl(x) == fabsl(y)) {    /* |x| = |y| */
+		} else if (fabsl(x) == fabsl(y)) {	/* |x| = |y| */
 			if (hx >= 0) {
-				t = (hy >= 0)? 0.25L : -0.25L;
+				t = (hy >= 0) ? 0.25L : -0.25L;
 				sincospil(t * u, &s, &c);
 			} else if ((LAST(u) & 3) == 0) {
-				t = (hy >= 0)? 0.75L : -0.75L;
+				t = (hy >= 0) ? 0.75L : -0.75L;
 				sincospil(t * u, &s, &c);
 			} else {
-				r = (hy >= 0)? u : -u;
+				r = (hy >= 0) ? u : -u;
 				t = -0.25L * r;
 				w1 = r + t;
 				w2 = t - (w1 - r);
@@ -171,22 +194,27 @@
 				s = t1 * t4 + t3 * t2;
 				c = t2 * t4 - t1 * t3;
 			}
+
 			if (ix < 0x3ffe0000)	/* |x| < 1/2 */
 				r = powl(fabsl(x + x), u) * exp2l(-0.5L * u);
 			else if (ix >= 0x3fff0000 || iu < 0x400cfff8)
 				/* |x| >= 1 or |u| < 16383 */
 				r = powl(fabsl(x), u) * exp2l(0.5L * u);
-			else   /* special treatment */
+			else		/* special treatment */
 				j = 2;
+
 			if (j == 0) {
-				LD_RE(ans) = (c == zero)? c: c * r;
-				LD_IM(ans) = (s == zero)? s: s * r;
+				LD_RE(ans) = (c == zero) ? c : c *r;
+				LD_IM(ans) = (s == zero) ? s : s *r;
 			}
-		} else
+		} else {
 			j = 1;
+		}
+
 		if (j == 0)
 			return (ans);
 	}
+
 	if (iu >= hiinf || iv >= hiinf || ix >= hiinf || iy >= hiinf) {
 		/*
 		 * non-zero imag part(s) with inf component(s) yields NaN
@@ -194,12 +222,14 @@
 		t = fabsl(x) + fabsl(y) + fabsl(u) + fabsl(v);
 		LD_RE(ans) = LD_IM(ans) = t - t;
 	} else {
-		k = 0;	/* no scaling */
+		k = 0;			/* no scaling */
+
 		if (iu > 0x7ffe0000 || iv > 0x7ffe0000) {
 			u *= 1.52587890625000000000e-05L;
 			v *= 1.52587890625000000000e-05L;
-			k = 1;	/* scale u and v by 2**-16 */
+			k = 1;		/* scale u and v by 2**-16 */
 		}
+
 		/*
 		 * Use similated higher precision arithmetic to compute:
 		 * r = u * log(hypot(x, y)) - v * atan2(y, x)
@@ -208,16 +238,22 @@
 
 		t1 = __k_clog_rl(x, y, &t2);
 		t3 = __k_atan2l(y, x, &t4);
-		x1 = t1; HALF(x1);
-		y1 = t3; HALF(y1);
-		u1 = u; HALF(u1);
-		v1 = v; HALF(v1);
-		x2 = t2 - (x1 - t1);    /* log(hypot(x,y)) = x1 + x2 */
-		y2 = t4 - (y1 - t3);    /* atan2(y,x) = y1 + y2 */
+		x1 = t1;
+		HALF(x1);
+		y1 = t3;
+		HALF(y1);
+		u1 = u;
+		HALF(u1);
+		v1 = v;
+		HALF(v1);
+		x2 = t2 - (x1 - t1);	/* log(hypot(x,y)) = x1 + x2 */
+		y2 = t4 - (y1 - t3);	/* atan2(y,x) = y1 + y2 */
+
 		/* compute q = u * atan2(y, x) + v * log(hypot(x, y)) */
 		if (j != 2) {
 			b[0] = u1 * y1;
 			b[1] = (u - u1) * y1 + u * y2;
+
 			if (j == 1) {	/* v = 0 */
 				w1 = b[0] + b[1];
 				w2 = b[1] - (w1 - b[0]);
@@ -226,21 +262,26 @@
 				b[3] = (v - v1) * x1 + v * x2;
 				w1 = sum4fpl(b, &w2);
 			}
+
 			sincosl(w1, &t1, &t2);
 			sincosl(w2, &t3, &t4);
 			s = t1 * t4 + t3 * t2;
 			c = t2 * t4 - t1 * t3;
-			if (k == 1)	/* square j times */
+
+			if (k == 1) {	/* square j times */
 				for (i = 0; i < 10; i++) {
 					t1 = s * c;
 					c = (c + s) * (c - s);
 					s = t1 + t1;
 				}
+			}
 		}
+
 		/* compute r = u * (t1, t2) - v * (t3, t4) */
 		b[0] = u1 * x1;
 		b[1] = (u - u1) * x1 + u * x2;
-		if (j == 1) {   /* v = 0 */
+
+		if (j == 1) {		/* v = 0 */
 			w1 = b[0] + b[1];
 			w2 = b[1] - (w1 - b[0]);
 		} else {
@@ -248,33 +289,44 @@
 			b[3] = (v1 - v) * y1 - v * y2;
 			w1 = sum4fpl(b, &w2);
 		}
+
 		/* scale back unless w1 is large enough to cause exception */
 		if (k != 0 && fabsl(w1) < 20000.0L) {
-			w1 *= 65536.0L; w2 *= 65536.0L;
+			w1 *= 65536.0L;
+			w2 *= 65536.0L;
 		}
+
 		hx = HI_XWORD(w1);
 		ix = hx & 0x7fffffff;
 		/* compute exp(w1 + w2) */
 		k = 0;
-		if (ix < 0x3f8c0000) /* exp(tiny < 2**-115) = 1 */
+
+		if (ix < 0x3f8c0000) {		/* exp(tiny < 2**-115) = 1 */
 			r = one;
-		else if (ix >= 0x400c6760) /* overflow/underflow */
-			r = (hx < 0)? tiny * tiny : huge * huge;
-		else {  /* compute exp(w1 + w2) */
-			k = (int) (invln2 * w1 + ((hx >= 0)? 0.5L : -0.5L));
-			t1 = (long double) k;
+		} else if (ix >= 0x400c6760) {	/* overflow/underflow */
+			r = (hx < 0) ? tiny * tiny : huge * huge;
+		} else { /* compute exp(w1 + w2) */
+			k = (int)(invln2 * w1 + ((hx >= 0) ? 0.5L : -0.5L));
+			t1 = (long double)k;
 			t2 = w1 - t1 * ln2hil;
 			t3 = w2 - t1 * ln2lol;
 			r = expl(t2 + t3);
 		}
-		if (c != zero) c *= r;
-		if (s != zero) s *= r;
+
+		if (c != zero)
+			c *= r;
+
+		if (s != zero)
+			s *= r;
+
 		if (k != 0) {
 			c = scalbnl(c, k);
 			s = scalbnl(s, k);
 		}
+
 		LD_RE(ans) = c;
 		LD_IM(ans) = s;
 	}
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/cproj.c	2019-06-06 20:39:50.756213004 +0000
+++ new/usr/src/lib/libm/common/complex/cproj.c	2019-06-06 20:39:50.774697478 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __cproj = cproj
 
-/* INDENT OFF */
+
 /*
  * dcomplex cproj(dcomplex z);
  *
@@ -38,7 +39,6 @@
  * otherwise,
  *	cproj(z) = z
  */
-/* INDENT ON */
 
 #include "libm.h"			/* fabs */
 #include "complex_wrapper.h"
@@ -46,7 +46,8 @@
 static const double zero = 0.0;
 
 dcomplex
-cproj(dcomplex z) {
+cproj(dcomplex z)
+{
 	double x, y;
 	int ix, iy, hx, hy, lx, ly;
 
@@ -58,6 +59,7 @@
 	ly = LO_WORD(y);
 	ix = hx & 0x7fffffff;
 	iy = hy & 0x7fffffff;
+
 	if (ISINF(iy, ly)) {
 		D_RE(z) = fabs(y);
 		D_IM(z) = hy >= 0 ? zero : -zero;
@@ -65,5 +67,6 @@
 		D_RE(z) = fabs(x);
 		D_IM(z) = hy >= 0 ? zero : -zero;
 	}
+
 	return (z);
 }
--- old/usr/src/lib/libm/common/complex/cprojf.c	2019-06-06 20:39:51.267214124 +0000
+++ new/usr/src/lib/libm/common/complex/cprojf.c	2019-06-06 20:39:51.285607061 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,12 +33,12 @@
 #include "libm.h"
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
 static const float zero = 0.0F;
-/* INDENT ON */
+
 
 fcomplex
-cprojf(fcomplex z) {
+cprojf(fcomplex z)
+{
 	float x, y;
 	int ix, iy, hx, hy;
 
@@ -47,6 +48,7 @@
 	hy = THE_WORD(y);
 	ix = hx & 0x7fffffff;
 	iy = hy & 0x7fffffff;
+
 	if (iy == 0x7f800000) {
 		F_RE(z) = fabsf(y);
 		F_IM(z) = hy >= 0 ? zero : -zero;
@@ -54,5 +56,6 @@
 		F_RE(z) = fabsf(x);
 		F_IM(z) = hy >= 0 ? zero : -zero;
 	}
+
 	return (z);
 }
--- old/usr/src/lib/libm/common/complex/cprojl.c	2019-06-06 20:39:51.763281966 +0000
+++ new/usr/src/lib/libm/common/complex/cprojl.c	2019-06-06 20:39:51.781247144 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,26 +30,27 @@
 
 #pragma weak __cprojl = cprojl
 
-#include "libm.h"		/* fabsl */
+#include "libm.h"			/* fabsl */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
 static const long double zero = 0.0L;
-/* INDENT ON */
+
 
 ldcomplex
-cprojl(ldcomplex z) {
+cprojl(ldcomplex z)
+{
 	long double x, y;
 	int hy;
 
 	x = LD_RE(z);
 	y = LD_IM(z);
 #if defined(__x86)
-	hy = ((int *) &y)[2] << 16;
+	hy = ((int *)&y)[2] << 16;
 #else
-	hy = ((int *) &y)[0];
+	hy = ((int *)&y)[0];
 #endif
+
 	if (isinfl(y)) {
 		LD_RE(z) = fabsl(y);
 		LD_IM(z) = hy >= 0 ? zero : -zero;
@@ -56,5 +58,6 @@
 		LD_RE(z) = fabsl(x);
 		LD_IM(z) = hy >= 0 ? zero : -zero;
 	}
+
 	return (z);
 }
--- old/usr/src/lib/libm/common/complex/creal.c	2019-06-06 20:39:52.255968424 +0000
+++ new/usr/src/lib/libm/common/complex/creal.c	2019-06-06 20:39:52.273443345 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 double
-creal(dcomplex z) {
+creal(dcomplex z)
+{
 	return (D_RE(z));
 }
--- old/usr/src/lib/libm/common/complex/crealf.c	2019-06-06 20:39:52.750357368 +0000
+++ new/usr/src/lib/libm/common/complex/crealf.c	2019-06-06 20:39:52.769984142 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 float
-crealf(fcomplex z) {
+crealf(fcomplex z)
+{
 	return (F_RE(z));
 }
--- old/usr/src/lib/libm/common/complex/creall.c	2019-06-06 20:39:53.272421479 +0000
+++ new/usr/src/lib/libm/common/complex/creall.c	2019-06-06 20:39:53.290161972 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,6 +34,7 @@
 #include "complex_wrapper.h"
 
 long double
-creall(ldcomplex z) {
+creall(ldcomplex z)
+{
 	return (LD_RE(z));
 }
--- old/usr/src/lib/libm/common/complex/csin.c	2019-06-06 20:39:53.770985203 +0000
+++ new/usr/src/lib/libm/common/complex/csin.c	2019-06-06 20:39:53.791120228 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __csin = csin
 
-/* INDENT OFF */
+
 /*
  * dcomplex csin(dcomplex z);
  *
@@ -40,13 +41,13 @@
  *		= i*csinh(y-ix)
  *		= -Im(csinh(y-ix))+i*Re(csinh(y-ix))
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "complex_wrapper.h"
 
 dcomplex
-csin(dcomplex z) {
+csin(dcomplex z)
+{
 	double x, y;
 	dcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/csinf.c	2019-06-06 20:39:54.286924810 +0000
+++ new/usr/src/lib/libm/common/complex/csinf.c	2019-06-06 20:39:54.304794548 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 fcomplex
-csinf(fcomplex z) {
+csinf(fcomplex z)
+{
 	float x, y;
 	fcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/csinh.c	2019-06-06 20:39:54.795158120 +0000
+++ new/usr/src/lib/libm/common/complex/csinh.c	2019-06-06 20:39:54.812249357 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __csinh = csinh
 
-/* INDENT OFF */
+
 /*
  * dcomplex csinh(dcomplex z);
  *
@@ -73,13 +74,13 @@
  *      csinh(NaN,y) = (NaN,NaN) for non-zero y
  *      csinh(NaN,NaN) = (NaN,NaN)
  */
-/* INDENT ON */
 
-#include "libm.h"		/* cosh/exp/fabs/scalbn/sinh/sincos/__k_cexp */
+#include "libm.h"	/* cosh/exp/fabs/scalbn/sinh/sincos/__k_cexp */
 #include "complex_wrapper.h"
 
 dcomplex
-csinh(dcomplex z) {
+csinh(dcomplex z)
+{
 	double t, x, y, S, C;
 	int hx, ix, lx, hy, iy, ly, n;
 	dcomplex ans;
@@ -96,7 +97,8 @@
 	y = fabs(y);
 
 	(void) sincos(y, &S, &C);
-	if (ix >= 0x403c0000) {	/* |x| > 28 = prec/2 (14,28,34,60) */
+
+	if (ix >= 0x403c0000) {		/* |x| > 28 = prec/2 (14,28,34,60) */
 		if (ix >= 0x40862E42) {	/* |x| > 709.78... ~ log(2**1024) */
 			if (ix >= 0x7ff00000) {	/* |x| is inf or NaN */
 				if ((iy | ly) == 0) {
@@ -129,9 +131,12 @@
 			D_IM(ans) = S * cosh(x);
 		}
 	}
+
 	if (hx < 0)
 		D_RE(ans) = -D_RE(ans);
+
 	if (hy < 0)
 		D_IM(ans) = -D_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/csinhf.c	2019-06-06 20:39:55.294528734 +0000
+++ new/usr/src/lib/libm/common/complex/csinhf.c	2019-06-06 20:39:55.312381216 +0000
@@ -18,9 +18,11 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,11 +40,12 @@
 static const float zero = 0.0F, half = 0.5F;
 
 fcomplex
-csinhf(fcomplex z) {
-	float		x, y, S, C;
-	double		t;
-	int		hx, ix, hy, iy, n;
-	fcomplex	ans;
+csinhf(fcomplex z)
+{
+	float x, y, S, C;
+	double t;
+	int hx, ix, hy, iy, n;
+	fcomplex ans;
 
 	x = F_RE(z);
 	y = F_IM(z);
@@ -54,7 +57,8 @@
 	y = fabsf(y);
 
 	sincosf(y, &S, &C);
-	if (ix >= 0x41600000) {	/* |x| > 14 = prec/2 (14,28,34,60) */
+
+	if (ix >= 0x41600000) {		/* |x| > 14 = prec/2 (14,28,34,60) */
 		if (ix >= 0x42B171AA) {	/* |x| > 88.722... ~ log(2**128) */
 			if (ix >= 0x7f800000) {	/* |x| is inf or NaN */
 				if (iy == 0) {
@@ -69,7 +73,7 @@
 				}
 			} else {
 #if defined(__i386) && !defined(__amd64)
-				int	rp = __swapRP(fp_extended);
+				int rp = __swapRP(fp_extended);
 #endif
 				/* return (C, S) * exp(x) / 2 */
 				t = __k_cexp((double)x, &n);
@@ -86,7 +90,7 @@
 			F_IM(ans) = S * t;
 		}
 	} else {
-		if (ix == 0) {	/* x = 0, return (0,S) */
+		if (ix == 0) {		/* x = 0, return (0,S) */
 			F_RE(ans) = zero;
 			F_IM(ans) = S;
 		} else {
@@ -94,9 +98,12 @@
 			F_IM(ans) = S * coshf(x);
 		}
 	}
+
 	if (hx < 0)
 		F_RE(ans) = -F_RE(ans);
+
 	if (hy < 0)
 		F_IM(ans) = -F_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/csinhl.c	2019-06-06 20:39:55.804406252 +0000
+++ new/usr/src/lib/libm/common/complex/csinhl.c	2019-06-06 20:39:55.822378961 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,12 +33,12 @@
 #include "libm.h"	/* coshl/expl/fabsl/scalbnl/sincosl/sinhl/__k_cexpl */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
 static const long double zero = 0.0L, half = 0.5L;
-/* INDENT ON */
+
 
 ldcomplex
-csinhl(ldcomplex z) {
+csinhl(ldcomplex z)
+{
 	long double t, x, y, S, C;
 	int hx, ix, hy, iy, n;
 	ldcomplex ans;
@@ -52,7 +53,8 @@
 	y = fabsl(y);
 
 	(void) sincosl(y, &S, &C);
-	if (ix >= 0x4004e000) {	/* |x| > 60 = prec/2 (14,28,34,60) */
+
+	if (ix >= 0x4004e000) {		/* |x| > 60 = prec/2 (14,28,34,60) */
 		if (ix >= 0x400C62E4) {	/* |x| > 11356.52... ~ log(2**16384) */
 			if (ix >= 0x7fff0000) {	/* |x| is inf or NaN */
 				if (y == zero) {
@@ -85,9 +87,12 @@
 			LD_IM(ans) = S * coshl(x);
 		}
 	}
+
 	if (hx < 0)
 		LD_RE(ans) = -LD_RE(ans);
+
 	if (hy < 0)
 		LD_IM(ans) = -LD_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/csinl.c	2019-06-06 20:39:56.320916394 +0000
+++ new/usr/src/lib/libm/common/complex/csinl.c	2019-06-06 20:39:56.338352726 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 ldcomplex
-csinl(ldcomplex z) {
+csinl(ldcomplex z)
+{
 	long double x, y;
 	ldcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/csqrt.c	2019-06-06 20:39:56.846225292 +0000
+++ new/usr/src/lib/libm/common/complex/csqrt.c	2019-06-06 20:39:56.865639621 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __csqrt = csqrt
 
-/* INDENT OFF */
+
 /*
  * dcomplex csqrt(dcomplex z);
  *
@@ -100,24 +101,22 @@
  *    csqrt(NaN + i y  ) =  NaN  + i NaN for finite y
  *    csqrt(NaN + i NaN) =  NaN  + i NaN
  */
-/* INDENT ON */
 
-#include "libm.h"		/* fabs/sqrt */
+#include "libm.h"			/* fabs/sqrt */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
-static const double
-	two300 = 2.03703597633448608627e+90,
+static const double two300 = 2.03703597633448608627e+90,
 	twom300 = 4.90909346529772655310e-91,
 	two599 = 2.07475778444049647926e+180,
 	twom601 = 1.20495993255144205887e-181,
 	two = 2.0,
 	zero = 0.0,
 	half = 0.5;
-/* INDENT ON */
+
 
 dcomplex
-csqrt(dcomplex z) {
+csqrt(dcomplex z)
+{
 	dcomplex ans;
 	double x, y, t, ax, ay;
 	int n, ix, iy, hx, hy, lx, ly;
@@ -132,11 +131,12 @@
 	iy = hy & 0x7fffffff;
 	ay = fabs(y);
 	ax = fabs(x);
+
 	if (ix >= 0x7ff00000 || iy >= 0x7ff00000) {
 		/* x or y is Inf or NaN */
-		if (ISINF(iy, ly))
+		if (ISINF(iy, ly)) {
 			D_IM(ans) = D_RE(ans) = ay;
-		else if (ISINF(ix, lx)) {
+		} else if (ISINF(ix, lx)) {
 			if (hx > 0) {
 				D_RE(ans) = ax;
 				D_IM(ans) = ay * zero;
@@ -144,8 +144,9 @@
 				D_RE(ans) = ay * zero;
 				D_IM(ans) = ax;
 			}
-		} else
+		} else {
 			D_IM(ans) = D_RE(ans) = ax + ay;
+		}
 	} else if ((iy | ly) == 0) {	/* y = 0 */
 		if (hx >= 0) {
 			D_RE(ans) = sqrt(ax);
@@ -156,7 +157,8 @@
 		}
 	} else if (ix >= iy) {
 		n = (ix - iy) >> 20;
-		if (n >= 30) {	/* x >> y or y=0 */
+
+		if (n >= 30) {			/* x >> y or y=0 */
 			t = sqrt(ax);
 		} else if (ix >= 0x5f300000) {	/* x > 2**500 */
 			ax *= twom601;
@@ -166,8 +168,10 @@
 			ax *= two599;
 			y *= two599;
 			t = twom300 * sqrt(ax + sqrt(ax * ax + y * y));
-		} else
+		} else {
 			t = sqrt(half * (ax + sqrt(ax * ax + ay * ay)));
+		}
+
 		if (hx >= 0) {
 			D_RE(ans) = t;
 			D_IM(ans) = ay / (t + t);
@@ -177,7 +181,8 @@
 		}
 	} else {
 		n = (iy - ix) >> 20;
-		if (n >= 30) {	/* y >> x */
+
+		if (n >= 30) {		/* y >> x */
 			if (n >= 60)
 				t = sqrt(half * ay);
 			else if (iy >= 0x7fe00000)
@@ -194,8 +199,10 @@
 			ax *= two599;
 			y *= two599;
 			t = twom300 * sqrt(ax + sqrt(ax * ax + y * y));
-		} else
+		} else {
 			t = sqrt(half * (ax + sqrt(ax * ax + ay * ay)));
+		}
+
 		if (hx >= 0) {
 			D_RE(ans) = t;
 			D_IM(ans) = ay / (t + t);
@@ -204,7 +211,9 @@
 			D_RE(ans) = ay / (t + t);
 		}
 	}
+
 	if (hy < 0)
 		D_IM(ans) = -D_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/csqrtf.c	2019-06-06 20:39:57.376474774 +0000
+++ new/usr/src/lib/libm/common/complex/csqrtf.c	2019-06-06 20:39:57.394153045 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,15 +30,15 @@
 
 #pragma weak __csqrtf = csqrtf
 
-#include "libm.h"		/* sqrt/fabsf/sqrtf */
+#include "libm.h"			/* sqrt/fabsf/sqrtf */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
 static const float zero = 0.0F;
-/* INDENT ON */
+
 
 fcomplex
-csqrtf(fcomplex z) {
+csqrtf(fcomplex z)
+{
 	fcomplex ans;
 	double dt, dx, dy;
 	float x, y, t, ax, ay, w;
@@ -51,11 +52,12 @@
 	iy = hy & 0x7fffffff;
 	ay = fabsf(y);
 	ax = fabsf(x);
+
 	if (ix >= 0x7f800000 || iy >= 0x7f800000) {
 		/* x or y is Inf or NaN */
-		if (iy == 0x7f800000)
+		if (iy == 0x7f800000) {
 			F_IM(ans) = F_RE(ans) = ay;
-		else if (ix == 0x7f800000) {
+		} else if (ix == 0x7f800000) {
 			if (hx > 0) {
 				F_RE(ans) = ax;
 				F_IM(ans) = ay * zero;
@@ -63,8 +65,9 @@
 				F_RE(ans) = ay * zero;
 				F_IM(ans) = ax;
 			}
-		} else
+		} else {
 			F_IM(ans) = F_RE(ans) = ax + ay;
+		}
 	} else if (iy == 0) {
 		if (hx >= 0) {
 			F_RE(ans) = sqrtf(ax);
@@ -74,11 +77,12 @@
 			F_RE(ans) = zero;
 		}
 	} else {
-		dx = (double) ax;
-		dy = (double) ay;
+		dx = (double)ax;
+		dy = (double)ay;
 		dt = sqrt(0.5 * (sqrt(dx * dx + dy * dy) + dx));
-		t = (float) dt;
-		w = (float) (dy / (dt + dt));
+		t = (float)dt;
+		w = (float)(dy / (dt + dt));
+
 		if (hx >= 0) {
 			F_RE(ans) = t;
 			F_IM(ans) = w;
@@ -87,7 +91,9 @@
 			F_RE(ans) = w;
 		}
 	}
+
 	if (hy < 0)
 		F_IM(ans) = -F_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/csqrtl.c	2019-06-06 20:39:57.839286359 +0000
+++ new/usr/src/lib/libm/common/complex/csqrtl.c	2019-06-06 20:39:57.856692419 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,11 +30,10 @@
 
 #pragma weak __csqrtl = csqrtl
 
-#include "libm.h"		/* fabsl/isinfl/sqrtl */
+#include "libm.h"			/* fabsl/isinfl/sqrtl */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
 static const long double
 	twom9001 = 2.6854002716003034957421765100615693043656e-2710L,
 	twom4500 = 2.3174987687592429423263242862381544149252e-1355L,
@@ -42,10 +42,11 @@
 	zero = 0.0L,
 	half = 0.5L,
 	two = 2.0L;
-/* INDENT ON */
+
 
 ldcomplex
-csqrtl(ldcomplex z) {
+csqrtl(ldcomplex z)
+{
 	ldcomplex ans;
 	long double x, y, t, ax, ay;
 	int n, ix, iy, hx, hy;
@@ -58,11 +59,12 @@
 	iy = hy & 0x7fffffff;
 	ay = fabsl(y);
 	ax = fabsl(x);
+
 	if (ix >= 0x7fff0000 || iy >= 0x7fff0000) {
 		/* x or y is Inf or NaN */
-		if (isinfl(y))
+		if (isinfl(y)) {
 			LD_IM(ans) = LD_RE(ans) = ay;
-		else if (isinfl(x)) {
+		} else if (isinfl(x)) {
 			if (hx > 0) {
 				LD_RE(ans) = ax;
 				LD_IM(ans) = ay * zero;
@@ -70,8 +72,9 @@
 				LD_RE(ans) = ay * zero;
 				LD_IM(ans) = ax;
 			}
-		} else
+		} else {
 			LD_IM(ans) = LD_RE(ans) = ax + ay;
+		}
 	} else if (y == zero) {
 		if (hx >= 0) {
 			LD_RE(ans) = sqrtl(ax);
@@ -82,13 +85,14 @@
 		}
 	} else if (ix >= iy) {
 		n = (ix - iy) >> 16;
-#if defined(__x86)		/* 64 significant bits */
+#if defined(__x86)			/* 64 significant bits */
 		if (n >= 35)
-#else				/* 113 significant bits  */
+#else /* 113 significant bits  */
 		if (n >= 60)
 #endif
+		{
 			t = sqrtl(ax);
-		else if (ix >= 0x5f3f0000) {	/* x > 2**8000 */
+		} else if (ix >= 0x5f3f0000) {	/* x > 2**8000 */
 			ax *= twom9001;
 			y *= twom9001;
 			t = two4500 * sqrtl(ax + sqrtl(ax * ax + y * y));
@@ -96,8 +100,9 @@
 			ax *= two8999;
 			y *= two8999;
 			t = twom4500 * sqrtl(ax + sqrtl(ax * ax + y * y));
-		} else
+		} else {
 			t = sqrtl(half * (ax + sqrtl(ax * ax + y * y)));
+		}
 
 		if (hx >= 0) {
 			LD_RE(ans) = t;
@@ -108,11 +113,12 @@
 		}
 	} else {
 		n = (iy - ix) >> 16;
-#if defined(__x86)		/* 64 significant bits */
-		if (n >= 35) {	/* } */
-#else				/* 113 significant bits  */
+#if defined(__x86)			/* 64 significant bits */
+		if (n >= 35) {		/* } */
+#else /* 113 significant bits  */
 		if (n >= 60) {
 #endif
+
 			if (n >= 120)
 				t = sqrtl(half * ay);
 			else if (iy >= 0x7ffe0000)
@@ -129,8 +135,9 @@
 			ax *= two8999;
 			y *= two8999;
 			t = twom4500 * sqrtl(ax + sqrtl(ax * ax + y * y));
-		} else
+		} else {
 			t = sqrtl(half * (ax + sqrtl(ax * ax + y * y)));
+		}
 
 		if (hx >= 0) {
 			LD_RE(ans) = t;
@@ -140,7 +147,9 @@
 			LD_RE(ans) = ay / (t + t);
 		}
 	}
+
 	if (hy < 0)
 		LD_IM(ans) = -LD_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ctan.c	2019-06-06 20:39:58.310341043 +0000
+++ new/usr/src/lib/libm/common/complex/ctan.c	2019-06-06 20:39:58.328534533 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __ctan = ctan
 
-/* INDENT OFF */
+
 /*
  * dcomplex ctan(dcomplex z);
  *
@@ -40,13 +41,13 @@
  *		= i*ctanh(y-ix)
  *		= -Im(ctanh(y-ix))+i*Re(ctanh(y-ix))
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "complex_wrapper.h"
 
 dcomplex
-ctan(dcomplex z) {
+ctan(dcomplex z)
+{
 	double x, y;
 	dcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/ctanf.c	2019-06-06 20:39:58.812308443 +0000
+++ new/usr/src/lib/libm/common/complex/ctanf.c	2019-06-06 20:39:58.832031189 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 fcomplex
-ctanf(fcomplex z) {
+ctanf(fcomplex z)
+{
 	float x, y;
 	fcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/ctanh.c	2019-06-06 20:39:59.328570501 +0000
+++ new/usr/src/lib/libm/common/complex/ctanh.c	2019-06-06 20:39:59.347169595 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __ctanh = ctanh
 
-/* INDENT OFF */
+
 /*
  * dcomplex ctanh(dcomplex z);
  *
@@ -87,15 +88,15 @@
  *      ctanh(NaN,y) = (NaN,NaN) for non-zero y
  *      ctanh(NaN,NaN) = (NaN,NaN)
  */
-/* INDENT ON */
 
-#include "libm.h"		/* exp/expm1/fabs/sin/tanh/sincos */
+#include "libm.h"			/* exp/expm1/fabs/sin/tanh/sincos */
 #include "complex_wrapper.h"
 
 static const double four = 4.0, two = 2.0, one = 1.0, zero = 0.0;
 
 dcomplex
-ctanh(dcomplex z) {
+ctanh(dcomplex z)
+{
 	double t, r, v, u, x, y, S, C;
 	int hx, ix, lx, hy, iy, ly;
 	dcomplex ans;
@@ -114,10 +115,10 @@
 	if ((iy | ly) == 0) {	/* ctanh(x,0) = (x,0) for x = 0 or NaN */
 		D_RE(ans) = tanh(x);
 		D_IM(ans) = zero;
-	} else if (iy >= 0x7ff00000) {	/* y is inf or NaN */
-		if (ix < 0x7ff00000)	/* catanh(finite x,inf/nan) is nan */
+	} else if (iy >= 0x7ff00000) { /* y is inf or NaN */
+		if (ix < 0x7ff00000) { /* catanh(finite x,inf/nan) is nan */
 			D_RE(ans) = D_IM(ans) = y - y;
-		else if (((ix - 0x7ff00000) | lx) == 0) {	/* x is inf */
+		} else if (((ix - 0x7ff00000) | lx) == 0) {	/* x is inf */
 			D_RE(ans) = one;
 			D_IM(ans) = zero;
 		} else {
@@ -130,26 +131,31 @@
 		 * ctanh z ~ 1 + i (sin2y)/(exp(2x))
 		 */
 		D_RE(ans) = one;
-		if (iy < 0x7fe00000)	/* t = sin(2y) */
+
+		if (iy < 0x7fe00000) {	/* t = sin(2y) */
 			S = sin(y + y);
-		else {
+		} else {
 			(void) sincos(y, &S, &C);
 			S = (S + S) * C;
 		}
-		if (ix >= 0x7fe00000) {	/* |x| > max/2 */
+
+		if (ix >= 0x7fe00000) {		/* |x| > max/2 */
 			if (ix >= 0x7ff00000) {	/* |x| is inf or NaN */
 				if (((ix - 0x7ff00000) | lx) != 0)
 					D_RE(ans) = D_IM(ans) = x + y;
-								/* x is NaN */
+				/* x is NaN */
 				else
 					D_IM(ans) = zero * S;	/* x is inf */
-			} else
+			} else {
 				D_IM(ans) = S * exp(-x);	/* underflow */
-		} else
+			}
+		} else {
 			D_IM(ans) = (S + S) * exp(-(x + x));
-							/* 2 sin 2y / exp(2x) */
+		}
+
+		/* 2 sin 2y / exp(2x) */
 	} else {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 *                        t*t+2t
 		 *    ctanh z = --------------------------- +
@@ -159,7 +165,7 @@
 		 *              i --------------------------
 		 *                t*t+[4(t+1)(cos y)](cos y)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		(void) sincos(y, &S, &C);
 		t = expm1(x + x);
 		r = (four * C) * (t + one);
@@ -168,9 +174,12 @@
 		D_RE(ans) = (u + two * t) * v;
 		D_IM(ans) = (r * S) * v;
 	}
+
 	if (hx < 0)
 		D_RE(ans) = -D_RE(ans);
+
 	if (hy < 0)
 		D_IM(ans) = -D_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ctanhf.c	2019-06-06 20:39:59.844146871 +0000
+++ new/usr/src/lib/libm/common/complex/ctanhf.c	2019-06-06 20:39:59.864945531 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,15 +30,15 @@
 
 #pragma weak __ctanhf = ctanhf
 
-#include "libm.h"		/* expf/expm1f/fabsf/sincosf/sinf/tanhf */
+#include "libm.h"	/* expf/expm1f/fabsf/sincosf/sinf/tanhf */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
 static const float four = 4.0F, two = 2.0F, one = 1.0F, zero = 0.0F;
-/* INDENT ON */
+
 
 fcomplex
-ctanhf(fcomplex z) {
+ctanhf(fcomplex z)
+{
 	float r, u, v, t, x, y, S, C;
 	int hx, ix, hy, iy;
 	fcomplex ans;
@@ -54,10 +55,10 @@
 	if (iy == 0) {		/* ctanh(x,0) = (x,0) for x = 0 or NaN */
 		F_RE(ans) = tanhf(x);
 		F_IM(ans) = zero;
-	} else if (iy >= 0x7f800000) {	/* y is inf or NaN */
-		if (ix < 0x7f800000)	/* catanh(finite x,inf/nan) is nan */
+	} else if (iy >= 0x7f800000) { /* y is inf or NaN */
+		if (ix < 0x7f800000) { /* catanh(finite x,inf/nan) is nan */
 			F_RE(ans) = F_IM(ans) = y - y;
-		else if (ix == 0x7f800000) {	/* x is inf */
+		} else if (ix == 0x7f800000) {	/* x is inf */
 			F_RE(ans) = one;
 			F_IM(ans) = zero;
 		} else {
@@ -70,25 +71,30 @@
 		 * ctanh z ~ 1 + i (sin2y)/(exp(2x))
 		 */
 		F_RE(ans) = one;
-		if (iy < 0x7f000000)	/* t = sin(2y) */
+
+		if (iy < 0x7f000000) {	/* t = sin(2y) */
 			S = sinf(y + y);
-		else {
+		} else {
 			(void) sincosf(y, &S, &C);
 			S = (S + S) * C;
 		}
-		if (ix >= 0x7f000000) {	/* |x| > max/2 */
+
+		if (ix >= 0x7f000000) {		/* |x| > max/2 */
 			if (ix >= 0x7f800000) {	/* |x| is inf or NaN */
-				if (ix > 0x7f800000)	/* x is NaN */
+				if (ix > 0x7f800000)		/* x is NaN */
 					F_RE(ans) = F_IM(ans) = x + y;
 				else
 					F_IM(ans) = zero * S;	/* x is inf */
-			} else
+			} else {
 				F_IM(ans) = S * expf(-x);	/* underflow */
-		} else
+			}
+		} else {
 			F_IM(ans) = (S + S) * expf(-(x + x));
-							/* 2 sin 2y / exp(2x) */
+		}
+
+		/* 2 sin 2y / exp(2x) */
 	} else {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 *                        t*t+2t
 		 *    ctanh z = ---------------------------
@@ -98,7 +104,7 @@
 		 *              i --------------------------
 		 *                t*t+[4(t+1)(cos y)](cos y)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		(void) sincosf(y, &S, &C);
 		t = expm1f(x + x);
 		r = (four * C) * (t + one);
@@ -107,9 +113,12 @@
 		F_RE(ans) = (u + two * t) * v;
 		F_IM(ans) = (r * S) * v;
 	}
+
 	if (hx < 0)
 		F_RE(ans) = -F_RE(ans);
+
 	if (hy < 0)
 		F_IM(ans) = -F_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ctanhl.c	2019-06-06 20:40:00.364455106 +0000
+++ new/usr/src/lib/libm/common/complex/ctanhl.c	2019-06-06 20:40:00.383794297 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,12 +34,12 @@
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
 static const long double four = 4.0L, two = 2.0L, one = 1.0L, zero = 0.0L;
-/* INDENT ON */
+
 
 ldcomplex
-ctanhl(ldcomplex z) {
+ctanhl(ldcomplex z)
+{
 	long double r, u, v, t, x, y, S, C;
 	int hx, ix, hy, iy;
 	ldcomplex ans;
@@ -56,9 +57,9 @@
 		LD_RE(ans) = tanhl(x);
 		LD_IM(ans) = zero;
 	} else if (iy >= 0x7fff0000) {	/* y is inf or NaN */
-		if (ix < 0x7fff0000)	/* catanh(finite x,inf/nan) is nan */
+		if (ix < 0x7fff0000) {	/* catanh(finite x,inf/nan) is nan */
 			LD_RE(ans) = LD_IM(ans) = y - y;
-		else if (isinfl(x)) {	/* x is inf */
+		} else if (isinfl(x)) {	/* x is inf */
 			LD_RE(ans) = one;
 			LD_IM(ans) = zero;
 		} else {
@@ -66,32 +67,36 @@
 			LD_IM(ans) = y - y;
 		}
 	} else if (ix >= 0x4004e000) {
-		/* INDENT OFF */
+
 		/*
 		 * |x| > 60 = prec/2 (14,28,34,60)
 		 * ctanh z ~ 1 + i (sin2y)/(exp(2x))
 		 */
-		/* INDENT ON */
 		LD_RE(ans) = one;
-		if (iy < 0x7ffe0000)	/* t = sin(2y) */
+
+		if (iy < 0x7ffe0000) {	/* t = sin(2y) */
 			S = sinl(y + y);
-		else {
+		} else {
 			(void) sincosl(y, &S, &C);
 			S = (S + S) * C;
 		}
-		if (ix >= 0x7ffe0000) {	/* |x| > max/2 */
+
+		if (ix >= 0x7ffe0000) {		/* |x| > max/2 */
 			if (ix >= 0x7fff0000) {	/* |x| is inf or NaN */
 				if (isnanl(x))	/* x is NaN */
 					LD_RE(ans) = LD_IM(ans) = x + y;
 				else
 					LD_IM(ans) = zero * S;	/* x is inf */
-			} else
+			} else {
 				LD_IM(ans) = S * expl(-x);	/* underflow */
-		} else
+			}
+		} else {
 			LD_IM(ans) = (S + S) * expl(-(x + x));
-							/* 2 sin 2y / exp(2x) */
+		}
+
+		/* 2 sin 2y / exp(2x) */
 	} else {
-		/* INDENT OFF */
+		/* BEGIN CSTYLED */
 		/*
 		 *                        t*t+2t
 		 *    ctanh z = ---------------------------
@@ -101,7 +106,7 @@
 		 *              i --------------------------
 		 *                t*t+[4(t+1)(cos y)](cos y)
 		 */
-		/* INDENT ON */
+		/* END CSTYLED */
 		sincosl(y, &S, &C);
 		t = expm1l(x + x);
 		r = (four * C) * (t + one);
@@ -110,9 +115,12 @@
 		LD_RE(ans) = (u + two * t) * v;
 		LD_IM(ans) = (r * S) * v;
 	}
+
 	if (hx < 0)
 		LD_RE(ans) = -LD_RE(ans);
+
 	if (hy < 0)
 		LD_IM(ans) = -LD_IM(ans);
+
 	return (ans);
 }
--- old/usr/src/lib/libm/common/complex/ctanl.c	2019-06-06 20:40:00.890257301 +0000
+++ new/usr/src/lib/libm/common/complex/ctanl.c	2019-06-06 20:40:00.906484587 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,7 +34,8 @@
 #include "complex_wrapper.h"
 
 ldcomplex
-ctanl(ldcomplex z) {
+ctanl(ldcomplex z)
+{
 	long double x, y;
 	ldcomplex ans, ct;
 
--- old/usr/src/lib/libm/common/complex/k_atan2.c	2019-06-06 20:40:01.357651863 +0000
+++ new/usr/src/lib/libm/common/complex/k_atan2.c	2019-06-06 20:40:01.375318739 +0000
@@ -18,15 +18,17 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-#include "libm.h"		/* __k_atan2 */
+#include "libm.h"			/* __k_atan2 */
 #include "complex_wrapper.h"
 
 /*
@@ -69,40 +71,42 @@
  *	For ai, the first one contian the leading 53 bits rounded, and the
  *	second is the remaining 53 bits (total 106 bits accuracy).
  * 2.	z is an array of three doubles.
- * 	z[0] :	the rounded value of Z (the intended value of z)
- * 	z[1] :	the leading 24 bits of Z rounded
- * 	z[2] :	the remaining 53 bits of Z
+ *      z[0] :	the rounded value of Z (the intended value of z)
+ *      z[1] :	the leading 24 bits of Z rounded
+ *      z[2] :	the remaining 53 bits of Z
  *		Note that z[0] = z[1]+z[2] rounded.
  *
  */
-
 static void
-mx_poly(const double *z, const double *a, double *e, int n) {
+mx_poly(const double *z, const double *a, double *e, int n)
+{
 	double r, s, t, p_h, p_l, z_h, z_l, p;
 	int i;
 
 	n = n + n;
 	p = e[0] + a[n];
 	p_l = a[n + 1];
-	p_h = (double) ((float) p);
-	p   = a[n - 2] + z[0] * p;
-	z_h = z[1]; z_l = z[2];
+	p_h = (double)((float)p);
+	p = a[n - 2] + z[0] * p;
+	z_h = z[1];
+	z_l = z[2];
 	p_l += e[0] - (p_h - a[n]);
 
 	for (i = n - 2; i >= 2; i -= 2) {
-	/* compute p = ai + z * p */
-		t   = z_h * p_h;
-		s   = z[0] * p_l + p_h * z_l;
-		p_h = (double) ((float) p);
-		s  += a[i + 1];
-		r   = t - (p_h - a[i]);
-		p   = a[i - 2] + z[0] * p;
+		/* compute p = ai + z * p */
+		t = z_h * p_h;
+		s = z[0] * p_l + p_h * z_l;
+		p_h = (double)((float)p);
+		s += a[i + 1];
+		r = t - (p_h - a[i]);
+		p = a[i - 2] + z[0] * p;
 		p_l = r + s;
 	}
-	e[0] = (double)((float) p);
-	t   = z_h * p_h;
-	s   = z[0] * p_l + p_h * z_l;
-	r   = t - (e[0] - a[0]);
+
+	e[0] = (double)((float)p);
+	t = z_h * p_h;
+	s = z[0] * p_l + p_h * z_l;
+	r = t - (e[0] - a[0]);
 	e[1] = r + s;
 }
 
@@ -118,75 +122,107 @@
  */
 
 static const double TBL_atan_hi[] = {
-1.243549945467614382e-01, 1.320397616146387620e-01, 1.397088742891636204e-01,
-1.473614810886516302e-01, 1.549967419239409727e-01, 1.626138285979485676e-01,
-1.702119252854744080e-01, 1.777902289926760471e-01, 1.853479499956947607e-01,
-1.928843122579746439e-01, 2.003985538258785115e-01, 2.078899272022629863e-01,
-2.153576996977380476e-01, 2.228011537593945213e-01, 2.302195872768437179e-01,
-2.376123138654712419e-01, 2.449786631268641435e-01, 2.596296294082575118e-01,
-2.741674511196587893e-01, 2.885873618940774099e-01, 3.028848683749714166e-01,
-3.170557532091470287e-01, 3.310960767041321029e-01, 3.450021772071051318e-01,
-3.587706702705721895e-01, 3.723984466767542023e-01, 3.858826693980737521e-01,
-3.992207695752525431e-01, 4.124104415973872673e-01, 4.254496373700422662e-01,
-4.383365598579578304e-01, 4.510696559885234436e-01, 4.636476090008060935e-01,
-4.883339510564055352e-01, 5.123894603107377321e-01, 5.358112379604637043e-01,
-5.585993153435624414e-01, 5.807563535676704136e-01, 6.022873461349641522e-01,
-6.231993299340659043e-01, 6.435011087932843710e-01, 6.632029927060932861e-01,
-6.823165548747480713e-01, 7.008544078844501923e-01, 7.188299996216245269e-01,
-7.362574289814280970e-01, 7.531512809621944138e-01, 7.695264804056582975e-01,
-7.853981633974482790e-01, 8.156919233162234217e-01, 8.441539861131710509e-01,
-8.709034570756529758e-01, 8.960553845713439269e-01, 9.197196053504168578e-01,
-9.420000403794636101e-01, 9.629943306809362058e-01, 9.827937232473290541e-01,
-1.001483135694234639e+00, 1.019141344266349725e+00, 1.035841253008800145e+00,
-1.051650212548373764e+00, 1.066630365315743623e+00, 1.080839000541168327e+00,
-1.094328907321189925e+00, 1.107148717794090409e+00, 1.130953743979160375e+00,
-1.152571997215667610e+00, 1.172273881128476303e+00, 1.190289949682531656e+00,
-1.206817370285252489e+00, 1.222025323210989667e+00, 1.236059489478081863e+00,
-1.249045772398254428e+00, 1.261093382252440387e+00, 1.272297395208717319e+00,
-1.282740879744270757e+00, 1.292496667789785336e+00, 1.301628834009196156e+00,
-1.310193935047555547e+00, 1.318242051016837113e+00, 1.325817663668032553e+00,
-1.339705659598999565e+00, 1.352127380920954636e+00, 1.363300100359693845e+00,
-1.373400766945015894e+00, 1.382574821490125894e+00, 1.390942827002418447e+00,
-1.398605512271957618e+00, 1.405647649380269870e+00, 1.412141064608495311e+00,
-1.418146998399631542e+00, 1.423717971406494032e+00, 1.428899272190732761e+00,
-1.433730152484709031e+00, 1.438244794498222623e+00, 1.442473099109101931e+00,
-1.446441332248135092e+00,
+	1.243549945467614382e-01, 1.320397616146387620e-01,
+	1.397088742891636204e-01, 1.473614810886516302e-01,
+	1.549967419239409727e-01, 1.626138285979485676e-01,
+	1.702119252854744080e-01, 1.777902289926760471e-01,
+	1.853479499956947607e-01, 1.928843122579746439e-01,
+	2.003985538258785115e-01, 2.078899272022629863e-01,
+	2.153576996977380476e-01, 2.228011537593945213e-01,
+	2.302195872768437179e-01, 2.376123138654712419e-01,
+	2.449786631268641435e-01, 2.596296294082575118e-01,
+	2.741674511196587893e-01, 2.885873618940774099e-01,
+	3.028848683749714166e-01, 3.170557532091470287e-01,
+	3.310960767041321029e-01, 3.450021772071051318e-01,
+	3.587706702705721895e-01, 3.723984466767542023e-01,
+	3.858826693980737521e-01, 3.992207695752525431e-01,
+	4.124104415973872673e-01, 4.254496373700422662e-01,
+	4.383365598579578304e-01, 4.510696559885234436e-01,
+	4.636476090008060935e-01, 4.883339510564055352e-01,
+	5.123894603107377321e-01, 5.358112379604637043e-01,
+	5.585993153435624414e-01, 5.807563535676704136e-01,
+	6.022873461349641522e-01, 6.231993299340659043e-01,
+	6.435011087932843710e-01, 6.632029927060932861e-01,
+	6.823165548747480713e-01, 7.008544078844501923e-01,
+	7.188299996216245269e-01, 7.362574289814280970e-01,
+	7.531512809621944138e-01, 7.695264804056582975e-01,
+	7.853981633974482790e-01, 8.156919233162234217e-01,
+	8.441539861131710509e-01, 8.709034570756529758e-01,
+	8.960553845713439269e-01, 9.197196053504168578e-01,
+	9.420000403794636101e-01, 9.629943306809362058e-01,
+	9.827937232473290541e-01, 1.001483135694234639e+00,
+	1.019141344266349725e+00, 1.035841253008800145e+00,
+	1.051650212548373764e+00, 1.066630365315743623e+00,
+	1.080839000541168327e+00, 1.094328907321189925e+00,
+	1.107148717794090409e+00, 1.130953743979160375e+00,
+	1.152571997215667610e+00, 1.172273881128476303e+00,
+	1.190289949682531656e+00, 1.206817370285252489e+00,
+	1.222025323210989667e+00, 1.236059489478081863e+00,
+	1.249045772398254428e+00, 1.261093382252440387e+00,
+	1.272297395208717319e+00, 1.282740879744270757e+00,
+	1.292496667789785336e+00, 1.301628834009196156e+00,
+	1.310193935047555547e+00, 1.318242051016837113e+00,
+	1.325817663668032553e+00, 1.339705659598999565e+00,
+	1.352127380920954636e+00, 1.363300100359693845e+00,
+	1.373400766945015894e+00, 1.382574821490125894e+00,
+	1.390942827002418447e+00, 1.398605512271957618e+00,
+	1.405647649380269870e+00, 1.412141064608495311e+00,
+	1.418146998399631542e+00, 1.423717971406494032e+00,
+	1.428899272190732761e+00, 1.433730152484709031e+00,
+	1.438244794498222623e+00, 1.442473099109101931e+00,
+	1.446441332248135092e+00,
 };
 
 static const double TBL_atan_lo[] = {
--3.125324142453938311e-18, -1.276925400709959526e-17, 2.479758919089733066e-17,
-5.409599147666297957e-18, 9.585415594114323829e-18, 7.784470643106252464e-18,
--3.541164079802125137e-18, 2.372599351477449041e-17, 4.180692268843078977e-18,
-2.034098543938166622e-17, 3.139954287184449286e-18, 7.333160666520898500e-18,
-4.738160130078732886e-19, -5.498822172446843173e-18, 1.231340452914270316e-17,
-1.058231431371112987e-17, 1.069875561873445139e-17, 1.923875492461530410e-17,
-8.261353575163771936e-18, -1.428369957377257085e-17, -1.101082790300136900e-17,
--1.893928924292642146e-17, -7.952610375793798701e-18, -2.293880475557830393e-17,
-3.088733564861919217e-17, 1.961231150484565340e-17, 2.378822732491940868e-17,
-2.246598105617042065e-17, 3.963462895355093301e-17, 2.331553074189288466e-17,
--2.494277030626540909e-17, 3.280735600183735558e-17, 2.269877745296168709e-17,
--1.137323618932958456e-17, -2.546278147285580353e-17, -4.063795683482557497e-18,
--5.455630548591626394e-18, -1.441464378193066908e-17, 2.950430737228402307e-17,
-2.672403885140095079e-17, 1.583478505144428617e-17, -3.076054864429649001e-17,
-6.943223671560007740e-18, -1.987626234335816123e-17, -2.147838844445698302e-17,
-3.473937648299456719e-17, -2.425693465918206812e-17, -3.704991905602721293e-17,
-3.061616997868383018e-17, -1.071456562778743077e-17, -4.841337011934916763e-17,
--2.269823590747287052e-17, 2.923876285774304890e-17, -4.057439412852767923e-17,
-5.460837485846687627e-17, -3.986660595210752445e-18, 1.390331103123099845e-17,
-9.438308023545392000e-17, 1.000401886936679889e-17, 3.194313981784503706e-17,
--9.650564731467513515e-17, -5.956589637160374564e-17, -1.567632251135907253e-17,
--5.490676155022364226e-18, 9.404471373566379412e-17, 7.123833804538446299e-17,
--9.159738508900378819e-17, 8.385188614028674371e-17, 7.683333629842068806e-17,
-4.172467638861439118e-17, -2.979162864892849274e-17, 7.879752739459421280e-17,
--2.196203799612310905e-18, 3.242139621534960503e-17, 2.245875015034507026e-17,
--9.283188754266129476e-18, -6.830804768926660334e-17, -1.236918499824626670e-17,
-8.745413734780278834e-17, -6.319394031144676258e-17, -8.824429373951136321e-17,
--2.599011860304134377e-17, 2.147674250751150961e-17, 1.093246171526936217e-16,
--3.307710355769516504e-17, -3.561490438648230100e-17, -9.843712133488842595e-17,
--2.324061182591627982e-17, -8.922630138234492386e-17, -9.573807110557223276e-17,
--8.263883782511013632e-17, 8.721870922223967507e-17, -6.457134743238754385e-17,
--4.396204466767636187e-17, -2.493019910264565554e-17, -1.105119435430315713e-16,
-9.211323971545051565e-17,
+	-3.125324142453938311e-18, -1.276925400709959526e-17,
+	2.479758919089733066e-17, 5.409599147666297957e-18,
+	9.585415594114323829e-18, 7.784470643106252464e-18,
+	-3.541164079802125137e-18, 2.372599351477449041e-17,
+	4.180692268843078977e-18, 2.034098543938166622e-17,
+	3.139954287184449286e-18, 7.333160666520898500e-18,
+	4.738160130078732886e-19, -5.498822172446843173e-18,
+	1.231340452914270316e-17, 1.058231431371112987e-17,
+	1.069875561873445139e-17, 1.923875492461530410e-17,
+	8.261353575163771936e-18, -1.428369957377257085e-17,
+	-1.101082790300136900e-17, -1.893928924292642146e-17,
+	-7.952610375793798701e-18, -2.293880475557830393e-17,
+	3.088733564861919217e-17, 1.961231150484565340e-17,
+	2.378822732491940868e-17, 2.246598105617042065e-17,
+	3.963462895355093301e-17, 2.331553074189288466e-17,
+	-2.494277030626540909e-17, 3.280735600183735558e-17,
+	2.269877745296168709e-17, -1.137323618932958456e-17,
+	-2.546278147285580353e-17, -4.063795683482557497e-18,
+	-5.455630548591626394e-18, -1.441464378193066908e-17,
+	2.950430737228402307e-17, 2.672403885140095079e-17,
+	1.583478505144428617e-17, -3.076054864429649001e-17,
+	6.943223671560007740e-18, -1.987626234335816123e-17,
+	-2.147838844445698302e-17, 3.473937648299456719e-17,
+	-2.425693465918206812e-17, -3.704991905602721293e-17,
+	3.061616997868383018e-17, -1.071456562778743077e-17,
+	-4.841337011934916763e-17, -2.269823590747287052e-17,
+	2.923876285774304890e-17, -4.057439412852767923e-17,
+	5.460837485846687627e-17, -3.986660595210752445e-18,
+	1.390331103123099845e-17, 9.438308023545392000e-17,
+	1.000401886936679889e-17, 3.194313981784503706e-17,
+	-9.650564731467513515e-17, -5.956589637160374564e-17,
+	-1.567632251135907253e-17, -5.490676155022364226e-18,
+	9.404471373566379412e-17, 7.123833804538446299e-17,
+	-9.159738508900378819e-17, 8.385188614028674371e-17,
+	7.683333629842068806e-17, 4.172467638861439118e-17,
+	-2.979162864892849274e-17, 7.879752739459421280e-17,
+	-2.196203799612310905e-18, 3.242139621534960503e-17,
+	2.245875015034507026e-17, -9.283188754266129476e-18,
+	-6.830804768926660334e-17, -1.236918499824626670e-17,
+	8.745413734780278834e-17, -6.319394031144676258e-17,
+	-8.824429373951136321e-17, -2.599011860304134377e-17,
+	2.147674250751150961e-17, 1.093246171526936217e-16,
+	-3.307710355769516504e-17, -3.561490438648230100e-17,
+	-9.843712133488842595e-17, -2.324061182591627982e-17,
+	-8.922630138234492386e-17, -9.573807110557223276e-17,
+	-8.263883782511013632e-17, 8.721870922223967507e-17,
+	-6.457134743238754385e-17, -4.396204466767636187e-17,
+	-2.493019910264565554e-17, -1.105119435430315713e-16,
+	9.211323971545051565e-17,
 };
 
 /*
@@ -199,7 +235,7 @@
  * The algorithm is based on atan(x)=atan(y)+atan((x-y)/(1+x*y)).
  * We use poly1(x) to approximate atan(x) for x in [0,1/8] with
  * error (relative)
- * 	|(atan(x)-poly1(x))/x|<= 2^-83.41
+ *      |(atan(x)-poly1(x))/x|<= 2^-83.41
  *
  * and use poly2(x) to approximate atan(x) for x in [0,1/65] with
  * error
@@ -235,13 +271,14 @@
  *
  */
 
-#define	P1 p[2]
-#define	P4 p[8]
-#define	P5 p[9]
-#define	P6 p[10]
-#define	P7 p[11]
-#define	P8 p[12]
-#define	P9 p[13]
+#define	P1		p[2]
+#define	P4		p[8]
+#define	P5		p[9]
+#define	P6		p[10]
+#define	P7		p[11]
+#define	P8		p[12]
+#define	P9		p[13]
+
 static const double p[] = {
 	1.0,
 	0.0,
@@ -258,58 +295,62 @@
 	5.87081768778560317279e-02,	/* p8   = 3FAE0EFF 87657733 */
 	-4.90818147456113240690e-02,	/* p9   = BFA92140 6A524B5C */
 };
-#define	Q1 q[2]
-#define	Q3 q[6]
-#define	Q4 q[7]
-#define	Q5 q[8]
+
+#define	Q1		q[2]
+#define	Q3		q[6]
+#define	Q4		q[7]
+#define	Q5		q[8]
+
 static const double q[] = {
 	1.0,
 	0.0,
 	-3.33333333333333314830e-01,	/* q1   = BFD55555 55555555 */
-	-1.85022941571278638733e-17,	/* q1_l = BC7554E9 D20EFA66 */
-	1.99999999999999927836e-01,	/* q2   = 3FC99999 99999997 */
-	-1.28782564407438833398e-17,	/* q2_l = BC6DB1FB 17217417 */
-	-1.42857142855492280642e-01,	/* q3   = BFC24924 92483C46 */
-	1.11111097130183356096e-01,	/* q4   = 3FBC71C6 E06595CC */
-	-9.08553303569109294013e-02,	/* q5   = BFB7424B 808CDA76 */
+	-1.85022941571278638733e-17,		/* q1_l = BC7554E9 D20EFA66 */
+	1.99999999999999927836e-01,		/* q2   = 3FC99999 99999997 */
+	-1.28782564407438833398e-17,		/* q2_l = BC6DB1FB 17217417 */
+	-1.42857142855492280642e-01,		/* q3   = BFC24924 92483C46 */
+	1.11111097130183356096e-01,		/* q4   = 3FBC71C6 E06595CC */
+	-9.08553303569109294013e-02,		/* q5   = BFB7424B 808CDA76 */
 };
-static const double
-one = 1.0,
-pio2hi = 1.570796326794896558e+00,
-pio2lo = 6.123233995736765886e-17;
+
+static const double one = 1.0,
+	pio2hi = 1.570796326794896558e+00,
+	pio2lo = 6.123233995736765886e-17;
 
 static double
-mx_atan(double x, double *err) {
-	double y, z, r, s, t, w, s_h, s_l, x_h, x_l, zz[3], ee[2], z_h,
-		z_l, r_h, r_l, u, v;
+mx_atan(double x, double *err)
+{
+	double y, z, r, s, t, w, s_h, s_l, x_h, x_l, zz[3], ee[2], z_h, z_l,
+	    r_h, r_l, u, v;
 	int ix, iy, sign, j;
 
-	ix = ((int *) &x)[HIWORD];
+	ix = ((int *)&x)[HIWORD];
 	sign = ix & 0x80000000;
 	ix ^= sign;
 
 	/* for |x| < 1/8 */
 	if (ix < 0x3fc00000) {
-		if (ix < 0x3f300000) {	/* when |x| < 2**-12 */
+		if (ix < 0x3f300000) {		/* when |x| < 2**-12 */
 			if (ix < 0x3d800000) {	/* if |x| < 2**-39 */
-				*err = (double) ((int) x);
+				*err = (double)((int)x);
 				return (x);
 			}
+
 			z = x * x;
 			t = x * z * (q[2] + z * (q[4] + z * q[6]));
 			r = x + t;
 			*err = t - (r - x);
 			return (r);
 		}
+
 		z = x * x;
 
 		/* use double precision at p4 and on */
-		ee[0] = z *
-			(P4 + z *
-			(P5 + z * (P6 + z * (P7 + z * (P8 + z * P9)))));
+		ee[0] = z * (P4 + z * (P5 + z * (P6 + z * (P7 + z * (P8 + z *
+		    P9)))));
 
-		x_h = (double) ((float) x);
-		z_h = (double) ((float) z);
+		x_h = (double)((float)x);
+		z_h = (double)((float)z);
 		x_l = x - x_h;
 		z_l = (x_h * x_h - z_h);
 		zz[0] = z;
@@ -330,14 +371,17 @@
 		*err = t - (s - r);
 		return (s);
 	}
+
 	/* for |x| >= 8.0 */
-	if (ix >= 0x40200000) {	/* x >=  8 */
+	if (ix >= 0x40200000) {			/* x >=  8 */
 		x = fabs(x);
-		if (ix >= 0x42600000) {	/* x >=  2**39 */
-			if (ix >= 0x44c00000) {	/* x >=  2**77 */
+
+		if (ix >= 0x42600000) {		/* x >=  2**39 */
+			if (ix >= 0x44c00000)	/* x >=  2**77 */
 				y = -pio2lo;
-			} else
+			else
 				y = one / x - pio2lo;
+
 			if (sign == 0) {
 				t = pio2hi - y;
 				*err = -(y - (pio2hi - t));
@@ -345,51 +389,54 @@
 				t = y - pio2hi;
 				*err = y - (pio2hi + t);
 			}
+
 			return (t);
 		} else {
 			/* compute r = 1/x */
 			r = one / x;
 			z = r * r;
-			if (ix < 0x40504000) {	/* 8 <  x <  65 */
 
+			if (ix < 0x40504000) {	/* 8 <  x <  65 */
 				/* use double precision at p4 and on */
-				ee[0] = z *
-					(P4 + z *
-					(P5 + z *
-					(P6 + z * (P7 + z * (P8 + z * P9)))));
-				x_h = (double) ((float) x);
-				r_h = (double) ((float) r);
-				z_h = (double) ((float) z);
+				ee[0] = z * (P4 + z * (P5 + z * (P6 + z * (P7 +
+				    z * (P8 + z * P9)))));
+				x_h = (double)((float)x);
+				r_h = (double)((float)r);
+				z_h = (double)((float)z);
 				r_l = r * ((x_h - x) * r_h - (x_h * r_h - one));
 				z_l = (r_h * r_h - z_h);
 				zz[0] = z;
 				zz[1] = z_h;
 				zz[2] = z_l + r_l * (r + r_h);
+
 				/*
 				 * compute (1+z*(p1+z*(p2+z*(p3+e)))) by call
 				 * mx_poly
 				 */
 				mx_poly(zz, p, ee, 3);
-			} else { /* x < 65 < 2**39 */
+			} else {	/* x < 65 < 2**39 */
 				/* use double precision at q3 and on */
 				ee[0] = z * (Q3 + z * (Q4 + z * Q5));
-				x_h = (double) ((float) x);
-				r_h = (double) ((float) r);
-				z_h = (double) ((float) z);
+				x_h = (double)((float)x);
+				r_h = (double)((float)r);
+				z_h = (double)((float)z);
 				r_l = r * ((x_h - x) * r_h - (x_h * r_h - one));
 				z_l = (r_h * r_h - z_h);
 				zz[0] = z;
 				zz[1] = z_h;
 				zz[2] = z_l + r_l * (r + r_h);
+
 				/*
 				 * compute (1+z*(q1+z*(q2+e))) by call
 				 * mx_poly
 				 */
 				mx_poly(zz, q, ee, 2);
 			}
+
 			/* pio2 - r*(1+...) */
 			v = r_h * ee[0];
 			t = pio2lo - (r * ee[1] + r_l * ee[0]);
+
 			if (sign == 0) {
 				s = pio2hi - v;
 				t -= (v - (pio2hi - s));
@@ -397,16 +444,18 @@
 				s = v - pio2hi;
 				t = -(t - (v - (s + pio2hi)));
 			}
+
 			w = s + t;
 			*err = t - (w - s);
 			return (w);
 		}
 	}
+
 	/* now x is between 1/8 and 8 */
-	((int *) &x)[HIWORD] = ix;
+	((int *)&x)[HIWORD] = ix;
 	iy = (ix + 0x00008000) & 0x7fff0000;
-	((int *) &y)[HIWORD] = iy;
-	((int *) &y)[LOWORD] = 0;
+	((int *)&y)[HIWORD] = iy;
+	((int *)&y)[LOWORD] = 0;
 	j = (iy - 0x3fc00000) >> 16;
 
 	w = (x - y);
@@ -415,10 +464,10 @@
 	z = s * s;
 	/* use double precision at q3 and on */
 	ee[0] = z * (Q3 + z * (Q4 + z * Q5));
-	s_h = (double) ((float) s);
-	z_h = (double) ((float) z);
-	x_h = (double) ((float) x);
-	t = (double) ((float) (one + x * y));
+	s_h = (double)((float)s);
+	z_h = (double)((float)z);
+	x_h = (double)((float)x);
+	t = (double)((float)(one + x * y));
 	r = -((x_h - x) * y - (x_h * y - (t - one)));
 	s_l = -v * (s_h * r - (w - s_h * t));
 	z_l = (s_h * s_h - z_h);
@@ -434,16 +483,17 @@
 	t += (v - (s - u));
 	w = s + t;
 	*err = t - (w - s);
+
 	if (sign != 0) {
 		w = -w;
 		*err = -*err;
 	}
+
 	return (w);
 }
 
-static const double
-	twom768 = 6.441148769597133308e-232,    /* 2^-768 */
-	two768  = 1.552518092300708935e+231,    /* 2^768 */
+static const double twom768 = 6.441148769597133308e-232,	/* 2^-768 */
+	two768 = 1.552518092300708935e+231,			/* 2^768 */
 	pi = 3.1415926535897931159979634685,
 	pi_lo = 1.224646799147353177e-16,
 	pio2 = 1.570796326794896558e+00,
@@ -454,23 +504,25 @@
 	pi3o4_lo = 9.184850993605148829195e-17;
 
 double
-__k_atan2(double y, double x, double *w) {
+__k_atan2(double y, double x, double *w)
+{
 	double t, xh, th, t1, t2, w1, w2;
 	int ix, iy, hx, hy, lx, ly;
 
-	hy = ((int *) &y)[HIWORD];
-	ly = ((int *) &y)[LOWORD];
+	hy = ((int *)&y)[HIWORD];
+	ly = ((int *)&y)[LOWORD];
 	iy = hy & ~0x80000000;
 
-	hx = ((int *) &x)[HIWORD];
-	lx = ((int *) &x)[LOWORD];
+	hx = ((int *)&x)[HIWORD];
+	lx = ((int *)&x)[LOWORD];
 	ix = hx & ~0x80000000;
 
 	*w = 0.0;
+
 	if (ix >= 0x7ff00000 || iy >= 0x7ff00000) {	/* ignore inexact */
-		if (isnan(x) || isnan(y))
+		if (isnan(x) || isnan(y)) {
 			return (x * y);
-		else if (iy < 0x7ff00000) {
+		} else if (iy < 0x7ff00000) {
 			if (hx >= 0) {	/* ATAN2(+-finite, +inf) is +-0 */
 				*w *= y;
 				return (*w);
@@ -479,41 +531,41 @@
 				return (copysign(pi, y));
 			}
 		} else if (ix < 0x7ff00000) {
-					/* ATAN2(+-inf, finite) is +-pi/2 */
-			*w = (hy >= 0)? pio2_lo : -pio2_lo;
-			return ((hy >= 0)? pio2 : -pio2);
+			/* ATAN2(+-inf, finite) is +-pi/2 */
+			*w = (hy >= 0) ? pio2_lo : -pio2_lo;
+			return ((hy >= 0) ? pio2 : -pio2);
 		} else if (hx > 0) {	/* ATAN2(+-INF,+INF) = +-pi/4 */
-			*w = (hy >= 0)? pio4_lo : -pio4_lo;
-			return ((hy >= 0)? pio4 : -pio4);
+			*w = (hy >= 0) ? pio4_lo : -pio4_lo;
+			return ((hy >= 0) ? pio4 : -pio4);
 		} else {		/* ATAN2(+-INF,-INF) = +-3pi/4 */
-			*w = (hy >= 0)? pi3o4_lo : -pi3o4_lo;
-			return ((hy >= 0)? pi3o4 : -pi3o4);
+			*w = (hy >= 0) ? pi3o4_lo : -pi3o4_lo;
+			return ((hy >= 0) ? pi3o4 : -pi3o4);
 		}
 	} else if ((ix | lx) == 0 || (iy | ly) == 0) {
 		if ((iy | ly) == 0) {
-			if (hx >= 0) /* ATAN2(+-0, +(0 <= x <= inf)) is +-0 */
+			if (hx >= 0) { /* ATAN2(+-0, +(0 <= x <= inf)) is +-0 */
 				return (y);
-			else { 	/* ATAN2(+-0, -(0 <= x <= inf)) is +-pi */
-				*w = (hy >= 0)? pi_lo : -pi_lo;
-				return ((hy >= 0)? pi : -pi);
+			} else { /* ATAN2(+-0, -(0 <= x <= inf)) is +-pi */
+				*w = (hy >= 0) ? pi_lo : -pi_lo;
+				return ((hy >= 0) ? pi : -pi);
 			}
-		} else { /* ATAN2(+-(anything but 0 and NaN), 0) is +-pi/2 */
-			*w = (hy >= 0)? pio2_lo : -pio2_lo;
-			return ((hy >= 0)? pio2 : -pio2);
+		} else {  /* ATAN2(+-(anything but 0 and NaN), 0) is +-pi/2 */
+			*w = (hy >= 0) ? pio2_lo : -pio2_lo;
+			return ((hy >= 0) ? pio2 : -pio2);
 		}
-	} else if (iy - ix > 0x06400000) { /* |x/y| < 2 ** -100 */
-		*w = (hy >= 0)? pio2_lo : -pio2_lo;
-		return ((hy >= 0)? pio2 : -pio2);
-	} else if (ix - iy > 0x06400000) { /* |y/x| < 2 ** -100 */
+	} else if (iy - ix > 0x06400000) {	/* |x/y| < 2 ** -100 */
+		*w = (hy >= 0) ? pio2_lo : -pio2_lo;
+		return ((hy >= 0) ? pio2 : -pio2);
+	} else if (ix - iy > 0x06400000) {	/* |y/x| < 2 ** -100 */
 		if (hx < 0) {
-			*w = (hy >= 0)? pi_lo : -pi_lo;
-			return ((hy >= 0)? pi : -pi);
+			*w = (hy >= 0) ? pi_lo : -pi_lo;
+			return ((hy >= 0) ? pi : -pi);
 		} else {
 			t = y / x;
 			th = t;
-			((int *) &th)[LOWORD] &= 0xf8000000;
+			((int *)&th)[LOWORD] &= 0xf8000000;
 			xh = x;
-			((int *) &xh)[LOWORD] &= 0xf8000000;
+			((int *)&xh)[LOWORD] &= 0xf8000000;
 			t1 = (x - xh) * t + xh * (t - th);
 			t2 = y - xh * th;
 			*w = (t2 - t1) / x;
@@ -527,24 +579,27 @@
 			x *= two768;
 			y *= two768;
 		}
+
 		y = fabs(y);
 		x = fabs(x);
 		t = y / x;
 		th = t;
-		((int *) &th)[LOWORD] &= 0xf8000000;
+		((int *)&th)[LOWORD] &= 0xf8000000;
 		xh = x;
-		((int *) &xh)[LOWORD] &= 0xf8000000;
+		((int *)&xh)[LOWORD] &= 0xf8000000;
 		t1 = (x - xh) * t + xh * (t - th);
 		t2 = y - xh * th;
 		w1 = mx_atan(t, &w2);
 		w2 += (t2 - t1) / (x + y * t);
+
 		if (hx < 0) {
 			t1 = pi - w1;
 			t2 = pi - t1;
 			w2 = (pi_lo - w2) - (w1 - t2);
 			w1 = t1;
 		}
-		*w = (hy >= 0)? w2 : -w2;
-		return ((hy >= 0)? w1 : -w1);
+
+		*w = (hy >= 0) ? w2 : -w2;
+		return ((hy >= 0) ? w1 : -w1);
 	}
 }
--- old/usr/src/lib/libm/common/complex/k_atan2l.c	2019-06-06 20:40:01.870673392 +0000
+++ new/usr/src/lib/libm/common/complex/k_atan2l.c	2019-06-06 20:40:01.886946600 +0000
@@ -18,21 +18,23 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-#include "libm.h"		/* __k_atan2l */
+#include "libm.h"			/* __k_atan2l */
 #include "complex_wrapper.h"
 
 #if defined(__sparc)
-#define	HALF(x)  ((int *) &x)[3] = 0; ((int *) &x)[2] &= 0xfe000000
+#define	HALF(x)		((int *)&x)[3] = 0; ((int *)&x)[2] &= 0xfe000000
 #elif defined(__x86)
-#define	HALF(x)  ((int *) &x)[0] = 0
+#define	HALF(x)		((int *)&x)[0] = 0
 #endif
 
 /*
@@ -63,7 +65,6 @@
  * __k_atan2l call static functions mx_polyl, mx_atanl
  */
 
-
 /*
  * (void) mx_polyl (long double *z, long double *a, long double *e, int n)
  * return
@@ -76,43 +77,48 @@
  *	For ai, the first one contian the leading 53 bits (or 30 for x86)
  *      rounded, and the second is the remaining 113 bits (or 64 for x86).
  * 2.	z is an array of three doubles.
- * 	z[0] :	the rounded value of Z (the intended value of z)
- * 	z[1] :	the leading 32 (or 56) bits of Z rounded
- * 	z[2] :	the remaining 113 (or 64) bits of Z
+ *      z[0] :	the rounded value of Z (the intended value of z)
+ *      z[1] :	the leading 32 (or 56) bits of Z rounded
+ *      z[2] :	the remaining 113 (or 64) bits of Z
  *		Note that z[0] = z[1]+z[2] rounded.
  *
  */
-
 static void
-mx_polyl(const long double *z, const long double *a, long double *e, int n) {
+mx_polyl(const long double *z, const long double *a, long double *e, int n)
+{
 	long double r, s, t, p_h, p_l, z_h, z_l, p, w;
 	int i;
+
 	n = n + n;
 	p = e[0] + a[n];
 	p_l = a[n + 1];
-	w = p; HALF(w);
+	w = p;
+	HALF(w);
 	p_h = w;
-	p   = a[n - 2] + z[0] * p;
-	z_h = z[1]; z_l = z[2];
+	p = a[n - 2] + z[0] * p;
+	z_h = z[1];
+	z_l = z[2];
 	p_l += e[0] - (p_h - a[n]);
 
 	for (i = n - 2; i >= 2; i -= 2) {
-
-	/* compute p = ai + z * p */
+		/* compute p = ai + z * p */
 		t = z_h * p_h;
 		s = z[0] * p_l + p_h * z_l;
-		w = p;  HALF(w);
+		w = p;
+		HALF(w);
 		p_h = w;
-		s  += a[i + 1];
-		r   = t - (p_h - a[i]);
-		p   = a[i - 2] + z[0] * p;
+		s += a[i + 1];
+		r = t - (p_h - a[i]);
+		p = a[i - 2] + z[0] * p;
 		p_l = r + s;
 	}
-	w = p; HALF(w);
+
+	w = p;
+	HALF(w);
 	e[0] = w;
-	t   = z_h * p_h;
-	s   = z[0] * p_l + p_h * z_l;
-	r   = t - (e[0] - a[0]);
+	t = z_h * p_h;
+	s = z[0] * p_l + p_h * z_l;
+	r = t - (e[0] - a[0]);
 	e[1] = r + s;
 }
 
@@ -128,304 +134,401 @@
 
 static const long double TBL_atan_hil[] = {
 #if defined(__sparc)
-1.2435499454676143503135484916387102416568e-01L,
-1.3203976161463874927468440652656953226250e-01L,
-1.3970887428916364518336777673909505681607e-01L,
-1.4736148108865163560980276039684551821066e-01L,
-1.5499674192394098230371437493349219133371e-01L,
-1.6261382859794857537364156376155780062019e-01L,
-1.7021192528547440449049660709976171369543e-01L,
-1.7779022899267607079662479921582468899456e-01L,
-1.8534794999569476488602596122854464667261e-01L,
-1.9288431225797466419705871069022730349878e-01L,
-2.0039855382587851465394578503437838446153e-01L,
-2.0788992720226299360533498310299432475629e-01L,
-2.1535769969773804802445962716648964165745e-01L,
-2.2280115375939451577103212214043255525024e-01L,
-2.3021958727684373024017095967980299065551e-01L,
-2.3761231386547125247388363432563777919892e-01L,
-2.4497866312686415417208248121127580641959e-01L,
-2.5962962940825753102994644318397190560106e-01L,
-2.7416745111965879759937189834217578592444e-01L,
-2.8858736189407739562361141995821834504332e-01L,
-3.0288486837497140556055609450555821812277e-01L,
-3.1705575320914700980901557667446732975852e-01L,
-3.3109607670413209494433878775694455421259e-01L,
-3.4500217720710510886768128690005168408290e-01L,
-3.5877067027057222039592006392646052215363e-01L,
-3.7239844667675422192365503828370182641413e-01L,
-3.8588266939807377589769548460723139638186e-01L,
-3.9922076957525256561471669615886476491104e-01L,
-4.1241044159738730689979128966712694260920e-01L,
-4.2544963737004228954226360518079233013817e-01L,
-4.3833655985795780544561604921477130895882e-01L,
-4.5106965598852347637563925728219344073798e-01L,
-4.6364760900080611621425623146121439713344e-01L,
-4.8833395105640552386716496074706484459644e-01L,
-5.1238946031073770666660102058425923805558e-01L,
-5.3581123796046370026908506870769144698471e-01L,
-5.5859931534356243597150821640166122875873e-01L,
-5.8075635356767039920327447500150082375122e-01L,
-6.0228734613496418168212269420423291922459e-01L,
-6.2319932993406593099247534906037459367793e-01L,
-6.4350110879328438680280922871732260447265e-01L,
-6.6320299270609325536325431023827583417226e-01L,
-6.8231655487474807825642998171115298784729e-01L,
-7.0085440788445017245795128178675127318623e-01L,
-7.1882999962162450541701415152590469891043e-01L,
-7.3625742898142813174283527108914662479274e-01L,
-7.5315128096219438952473937026902888600575e-01L,
-7.6952648040565826040682003598565401726598e-01L,
-7.8539816339744830961566084581987569936977e-01L,
-8.1569192331622341102146083874564582672284e-01L,
-8.4415398611317100251784414827164746738632e-01L,
-8.7090345707565295314017311259781407291650e-01L,
-8.9605538457134395617480071802993779546602e-01L,
-9.1971960535041681722860345482108940969311e-01L,
-9.4200004037946366473793717053459362115891e-01L,
-9.6299433068093620181519583599709989677298e-01L,
-9.8279372324732906798571061101466603762572e-01L,
-1.0014831356942347329183295953014374896343e+00L,
-1.0191413442663497346383429170230636212354e+00L,
-1.0358412530088001765846944703254440735476e+00L,
-1.0516502125483736674598673120862999026920e+00L,
-1.0666303653157435630791763474202799086015e+00L,
-1.0808390005411683108871567292171997859003e+00L,
-1.0943289073211899198927883146102352763033e+00L,
-1.1071487177940905030170654601785370497543e+00L,
-1.1309537439791604464709335155363277560026e+00L,
-1.1525719972156675180401498626127514672834e+00L,
-1.1722738811284763866005949441337046006865e+00L,
-1.1902899496825317329277337748293182803384e+00L,
-1.2068173702852525303955115800565576625682e+00L,
-1.2220253232109896370417417439225704120294e+00L,
-1.2360594894780819419094519711090786146210e+00L,
-1.2490457723982544258299170772810900483550e+00L,
-1.2610933822524404193139408812473357640124e+00L,
-1.2722973952087173412961937498224805746463e+00L,
-1.2827408797442707473628852511364955164072e+00L,
-1.2924966677897852679030914214070816723528e+00L,
-1.3016288340091961438047858503666855024453e+00L,
-1.3101939350475556342564376891719053437537e+00L,
-1.3182420510168370498593302023271363040427e+00L,
-1.3258176636680324650592392104284756886164e+00L,
-1.3397056595989995393283037525895557850243e+00L,
-1.3521273809209546571891479413898127598774e+00L,
-1.3633001003596939542892985278250991560269e+00L,
-1.3734007669450158608612719264449610604836e+00L,
-1.3825748214901258580599674177685685163955e+00L,
-1.3909428270024183486427686943836432395486e+00L,
-1.3986055122719575950126700816114282727858e+00L,
-1.4056476493802697809521934019958080664406e+00L,
-1.4121410646084952153676136718584890852820e+00L,
-1.4181469983996314594038603039700988632607e+00L,
-1.4237179714064941189018190466107297108905e+00L,
-1.4288992721907326964184700745371984001389e+00L,
-1.4337301524847089866404719096698873880264e+00L,
-1.4382447944982225979614042479354816039669e+00L,
-1.4424730991091018200252920599377291810352e+00L,
-1.4464413322481351841999668424758803866109e+00L,
+	1.2435499454676143503135484916387102416568e-01L,
+	1.3203976161463874927468440652656953226250e-01L,
+	1.3970887428916364518336777673909505681607e-01L,
+	1.4736148108865163560980276039684551821066e-01L,
+	1.5499674192394098230371437493349219133371e-01L,
+	1.6261382859794857537364156376155780062019e-01L,
+	1.7021192528547440449049660709976171369543e-01L,
+	1.7779022899267607079662479921582468899456e-01L,
+	1.8534794999569476488602596122854464667261e-01L,
+	1.9288431225797466419705871069022730349878e-01L,
+	2.0039855382587851465394578503437838446153e-01L,
+	2.0788992720226299360533498310299432475629e-01L,
+	2.1535769969773804802445962716648964165745e-01L,
+	2.2280115375939451577103212214043255525024e-01L,
+	2.3021958727684373024017095967980299065551e-01L,
+	2.3761231386547125247388363432563777919892e-01L,
+	2.4497866312686415417208248121127580641959e-01L,
+	2.5962962940825753102994644318397190560106e-01L,
+	2.7416745111965879759937189834217578592444e-01L,
+	2.8858736189407739562361141995821834504332e-01L,
+	3.0288486837497140556055609450555821812277e-01L,
+	3.1705575320914700980901557667446732975852e-01L,
+	3.3109607670413209494433878775694455421259e-01L,
+	3.4500217720710510886768128690005168408290e-01L,
+	3.5877067027057222039592006392646052215363e-01L,
+	3.7239844667675422192365503828370182641413e-01L,
+	3.8588266939807377589769548460723139638186e-01L,
+	3.9922076957525256561471669615886476491104e-01L,
+	4.1241044159738730689979128966712694260920e-01L,
+	4.2544963737004228954226360518079233013817e-01L,
+	4.3833655985795780544561604921477130895882e-01L,
+	4.5106965598852347637563925728219344073798e-01L,
+	4.6364760900080611621425623146121439713344e-01L,
+	4.8833395105640552386716496074706484459644e-01L,
+	5.1238946031073770666660102058425923805558e-01L,
+	5.3581123796046370026908506870769144698471e-01L,
+	5.5859931534356243597150821640166122875873e-01L,
+	5.8075635356767039920327447500150082375122e-01L,
+	6.0228734613496418168212269420423291922459e-01L,
+	6.2319932993406593099247534906037459367793e-01L,
+	6.4350110879328438680280922871732260447265e-01L,
+	6.6320299270609325536325431023827583417226e-01L,
+	6.8231655487474807825642998171115298784729e-01L,
+	7.0085440788445017245795128178675127318623e-01L,
+	7.1882999962162450541701415152590469891043e-01L,
+	7.3625742898142813174283527108914662479274e-01L,
+	7.5315128096219438952473937026902888600575e-01L,
+	7.6952648040565826040682003598565401726598e-01L,
+	7.8539816339744830961566084581987569936977e-01L,
+	8.1569192331622341102146083874564582672284e-01L,
+	8.4415398611317100251784414827164746738632e-01L,
+	8.7090345707565295314017311259781407291650e-01L,
+	8.9605538457134395617480071802993779546602e-01L,
+	9.1971960535041681722860345482108940969311e-01L,
+	9.4200004037946366473793717053459362115891e-01L,
+	9.6299433068093620181519583599709989677298e-01L,
+	9.8279372324732906798571061101466603762572e-01L,
+	1.0014831356942347329183295953014374896343e+00L,
+	1.0191413442663497346383429170230636212354e+00L,
+	1.0358412530088001765846944703254440735476e+00L,
+	1.0516502125483736674598673120862999026920e+00L,
+	1.0666303653157435630791763474202799086015e+00L,
+	1.0808390005411683108871567292171997859003e+00L,
+	1.0943289073211899198927883146102352763033e+00L,
+	1.1071487177940905030170654601785370497543e+00L,
+	1.1309537439791604464709335155363277560026e+00L,
+	1.1525719972156675180401498626127514672834e+00L,
+	1.1722738811284763866005949441337046006865e+00L,
+	1.1902899496825317329277337748293182803384e+00L,
+	1.2068173702852525303955115800565576625682e+00L,
+	1.2220253232109896370417417439225704120294e+00L,
+	1.2360594894780819419094519711090786146210e+00L,
+	1.2490457723982544258299170772810900483550e+00L,
+	1.2610933822524404193139408812473357640124e+00L,
+	1.2722973952087173412961937498224805746463e+00L,
+	1.2827408797442707473628852511364955164072e+00L,
+	1.2924966677897852679030914214070816723528e+00L,
+	1.3016288340091961438047858503666855024453e+00L,
+	1.3101939350475556342564376891719053437537e+00L,
+	1.3182420510168370498593302023271363040427e+00L,
+	1.3258176636680324650592392104284756886164e+00L,
+	1.3397056595989995393283037525895557850243e+00L,
+	1.3521273809209546571891479413898127598774e+00L,
+	1.3633001003596939542892985278250991560269e+00L,
+	1.3734007669450158608612719264449610604836e+00L,
+	1.3825748214901258580599674177685685163955e+00L,
+	1.3909428270024183486427686943836432395486e+00L,
+	1.3986055122719575950126700816114282727858e+00L,
+	1.4056476493802697809521934019958080664406e+00L,
+	1.4121410646084952153676136718584890852820e+00L,
+	1.4181469983996314594038603039700988632607e+00L,
+	1.4237179714064941189018190466107297108905e+00L,
+	1.4288992721907326964184700745371984001389e+00L,
+	1.4337301524847089866404719096698873880264e+00L,
+	1.4382447944982225979614042479354816039669e+00L,
+	1.4424730991091018200252920599377291810352e+00L,
+	1.4464413322481351841999668424758803866109e+00L,
 #elif defined(__x86)
-1.243549945356789976358413696289e-01L,  1.320397615781985223293304443359e-01L,
-1.397088742814958095550537109375e-01L,  1.473614810383878648281097412109e-01L,
-1.549967419123277068138122558594e-01L,  1.626138285500928759574890136719e-01L,
-1.702119252295233309268951416016e-01L,  1.777902289759367704391479492188e-01L,
-1.853479499695822596549987792969e-01L,  1.928843122441321611404418945312e-01L,
-2.003985538030974566936492919922e-01L,  2.078899272019043564796447753906e-01L,
-2.153576996643096208572387695312e-01L,  2.228011537226848304271697998047e-01L,
-2.302195872762240469455718994141e-01L,  2.376123138237744569778442382812e-01L,
-2.449786631041206419467926025391e-01L,  2.596296293195337057113647460938e-01L,
-2.741674510762095451354980468750e-01L,  2.885873618070036172866821289062e-01L,
-3.028848683461546897888183593750e-01L,  3.170557531993836164474487304688e-01L,
-3.310960766393691301345825195312e-01L,  3.450021771714091300964355468750e-01L,
-3.587706702528521418571472167969e-01L,  3.723984466632828116416931152344e-01L,
-3.858826693613082170486450195312e-01L,  3.992207695264369249343872070312e-01L,
-4.124104415532201528549194335938e-01L,  4.254496373469009995460510253906e-01L,
-4.383365598041564226150512695312e-01L,  4.510696559445932507514953613281e-01L,
-4.636476089945062994956970214844e-01L,  4.883339509833604097366333007812e-01L,
-5.123894601128995418548583984375e-01L,  5.358112377580255270004272460938e-01L,
-5.585993151180446147918701171875e-01L,  5.807563534472137689590454101562e-01L,
-6.022873460315167903900146484375e-01L,  6.231993297114968299865722656250e-01L,
-6.435011087451130151748657226562e-01L,  6.632029926404356956481933593750e-01L,
-6.823165547102689743041992187500e-01L,  7.008544078562408685684204101562e-01L,
-7.188299994450062513351440429688e-01L,  7.362574287690222263336181640625e-01L,
-7.531512808054685592651367187500e-01L,  7.695264802314341068267822265625e-01L,
-7.853981633670628070831298828125e-01L,  8.156919232569634914398193359375e-01L,
-8.441539860796183347702026367188e-01L,  8.709034570492804050445556640625e-01L,
-8.960553845390677452087402343750e-01L,  9.197196052409708499908447265625e-01L,
-9.420000403188169002532958984375e-01L,  9.629943305626511573791503906250e-01L,
-9.827937232330441474914550781250e-01L,  1.001483135391026735305786132812e+00L,
-1.019141343887895345687866210938e+00L,  1.035841252654790878295898437500e+00L,
-1.051650212146341800689697265625e+00L,  1.066630364861339330673217773438e+00L,
-1.080839000176638364791870117188e+00L,  1.094328907318413257598876953125e+00L,
-1.107148717623203992843627929688e+00L,  1.130953743588179349899291992188e+00L,
-1.152571997139602899551391601562e+00L,  1.172273880802094936370849609375e+00L,
-1.190289949532598257064819335938e+00L,  1.206817369908094406127929687500e+00L,
-1.222025323193520307540893554688e+00L,  1.236059489194303750991821289062e+00L,
-1.249045772012323141098022460938e+00L,  1.261093381792306900024414062500e+00L,
-1.272297394927591085433959960938e+00L,  1.282740879338234663009643554688e+00L,
-1.292496667709201574325561523438e+00L,  1.301628833636641502380371093750e+00L,
-1.310193934943526983261108398438e+00L,  1.318242050707340240478515625000e+00L,
-1.325817663222551345825195312500e+00L,  1.339705659542232751846313476562e+00L,
-1.352127380669116973876953125000e+00L,  1.363300099968910217285156250000e+00L,
-1.373400766868144273757934570312e+00L,  1.382574821356683969497680664062e+00L,
-1.390942826867103576660156250000e+00L,  1.398605511989444494247436523438e+00L,
-1.405647648964077234268188476562e+00L,  1.412141064181923866271972656250e+00L,
-1.418146998155862092971801757812e+00L,  1.423717970959842205047607421875e+00L,
-1.428899271879345178604125976562e+00L,  1.433730152435600757598876953125e+00L,
-1.438244794495403766632080078125e+00L,  1.442473099101334810256958007812e+00L,
-1.446441331878304481506347656250e+00L,
+	1.243549945356789976358413696289e-01L,
+	1.320397615781985223293304443359e-01L,
+	1.397088742814958095550537109375e-01L,
+	1.473614810383878648281097412109e-01L,
+	1.549967419123277068138122558594e-01L,
+	1.626138285500928759574890136719e-01L,
+	1.702119252295233309268951416016e-01L,
+	1.777902289759367704391479492188e-01L,
+	1.853479499695822596549987792969e-01L,
+	1.928843122441321611404418945312e-01L,
+	2.003985538030974566936492919922e-01L,
+	2.078899272019043564796447753906e-01L,
+	2.153576996643096208572387695312e-01L,
+	2.228011537226848304271697998047e-01L,
+	2.302195872762240469455718994141e-01L,
+	2.376123138237744569778442382812e-01L,
+	2.449786631041206419467926025391e-01L,
+	2.596296293195337057113647460938e-01L,
+	2.741674510762095451354980468750e-01L,
+	2.885873618070036172866821289062e-01L,
+	3.028848683461546897888183593750e-01L,
+	3.170557531993836164474487304688e-01L,
+	3.310960766393691301345825195312e-01L,
+	3.450021771714091300964355468750e-01L,
+	3.587706702528521418571472167969e-01L,
+	3.723984466632828116416931152344e-01L,
+	3.858826693613082170486450195312e-01L,
+	3.992207695264369249343872070312e-01L,
+	4.124104415532201528549194335938e-01L,
+	4.254496373469009995460510253906e-01L,
+	4.383365598041564226150512695312e-01L,
+	4.510696559445932507514953613281e-01L,
+	4.636476089945062994956970214844e-01L,
+	4.883339509833604097366333007812e-01L,
+	5.123894601128995418548583984375e-01L,
+	5.358112377580255270004272460938e-01L,
+	5.585993151180446147918701171875e-01L,
+	5.807563534472137689590454101562e-01L,
+	6.022873460315167903900146484375e-01L,
+	6.231993297114968299865722656250e-01L,
+	6.435011087451130151748657226562e-01L,
+	6.632029926404356956481933593750e-01L,
+	6.823165547102689743041992187500e-01L,
+	7.008544078562408685684204101562e-01L,
+	7.188299994450062513351440429688e-01L,
+	7.362574287690222263336181640625e-01L,
+	7.531512808054685592651367187500e-01L,
+	7.695264802314341068267822265625e-01L,
+	7.853981633670628070831298828125e-01L,
+	8.156919232569634914398193359375e-01L,
+	8.441539860796183347702026367188e-01L,
+	8.709034570492804050445556640625e-01L,
+	8.960553845390677452087402343750e-01L,
+	9.197196052409708499908447265625e-01L,
+	9.420000403188169002532958984375e-01L,
+	9.629943305626511573791503906250e-01L,
+	9.827937232330441474914550781250e-01L,
+	1.001483135391026735305786132812e+00L,
+	1.019141343887895345687866210938e+00L,
+	1.035841252654790878295898437500e+00L,
+	1.051650212146341800689697265625e+00L,
+	1.066630364861339330673217773438e+00L,
+	1.080839000176638364791870117188e+00L,
+	1.094328907318413257598876953125e+00L,
+	1.107148717623203992843627929688e+00L,
+	1.130953743588179349899291992188e+00L,
+	1.152571997139602899551391601562e+00L,
+	1.172273880802094936370849609375e+00L,
+	1.190289949532598257064819335938e+00L,
+	1.206817369908094406127929687500e+00L,
+	1.222025323193520307540893554688e+00L,
+	1.236059489194303750991821289062e+00L,
+	1.249045772012323141098022460938e+00L,
+	1.261093381792306900024414062500e+00L,
+	1.272297394927591085433959960938e+00L,
+	1.282740879338234663009643554688e+00L,
+	1.292496667709201574325561523438e+00L,
+	1.301628833636641502380371093750e+00L,
+	1.310193934943526983261108398438e+00L,
+	1.318242050707340240478515625000e+00L,
+	1.325817663222551345825195312500e+00L,
+	1.339705659542232751846313476562e+00L,
+	1.352127380669116973876953125000e+00L,
+	1.363300099968910217285156250000e+00L,
+	1.373400766868144273757934570312e+00L,
+	1.382574821356683969497680664062e+00L,
+	1.390942826867103576660156250000e+00L,
+	1.398605511989444494247436523438e+00L,
+	1.405647648964077234268188476562e+00L,
+	1.412141064181923866271972656250e+00L,
+	1.418146998155862092971801757812e+00L,
+	1.423717970959842205047607421875e+00L,
+	1.428899271879345178604125976562e+00L,
+	1.433730152435600757598876953125e+00L,
+	1.438244794495403766632080078125e+00L,
+	1.442473099101334810256958007812e+00L,
+	1.446441331878304481506347656250e+00L,
 #endif
 };
+
 static const long double TBL_atan_lol[] = {
 #if defined(__sparc)
-1.4074869197628063802317202820414310039556e-36L,
--4.9596961594739925555730439437999675295505e-36L,
-8.9527745625194648873931213446361849472788e-36L,
-1.1880437423207895718180765843544965589427e-35L,
--2.7810278112045145378425375128234365381448e-37L,
-1.4797220377023800327295536234315147262387e-36L,
--4.2169561400548198732870384801849639863829e-36L,
-7.2431229666913484649930323656316023494680e-36L,
--2.1573430089839170299895679353790663182462e-36L,
--9.9515745405126723554452367298128605186305e-36L,
--3.9065558992324838181617569730397882363067e-36L,
-5.5260292271793726813211980664661124518807e-36L,
-8.8415722215914321807682254318036452043689e-36L,
--8.1767728791586179254193323628285599800711e-36L,
--1.3344123034656142243797113823028330070762e-36L,
--4.4927331207813382908930733924681325892188e-36L,
-4.4945511471812490393201824336762495687730e-36L,
--1.6688081504279223555776724459648440567274e-35L,
-1.5629757586107955769461086568937329684113e-35L,
--2.2389835563308078552507970385331510848109e-35L,
--4.8312321745547311551870450671182151367050e-36L,
--1.4336172352905832876958926610980698844309e-35L,
--8.7440181998899932802989174170960593316080e-36L,
-5.9284636008529837445780360785464550143016e-36L,
--2.2376651248436241276061055295043514993630e-35L,
-6.0745837599336105414280310756677442136480e-36L,
-1.5372187110451949677792344762029967023093e-35L,
-2.0976068056751156241657121582478790247159e-35L,
--5.5623956405495438060726862202622807523700e-36L,
-1.9697366707832471841858411934897351901523e-35L,
-2.1070311964479488509034733639424887543697e-35L,
--2.3027356362982001602256518510854229844561e-35L,
-4.8950964225733349266861843522029764772843e-36L,
--7.2380143477794458213872723050820253166391e-36L,
-1.6365648865703614031637443396049568858105e-35L,
--3.9885811958234530793729129919803234197399e-35L,
-4.1587722120912613510417783923227421336929e-35L,
-3.8347421454556472153684687377337135027394e-35L,
--9.2251178933638721723515896465489002497864e-36L,
-1.4094619690455989526175736741854656192178e-36L,
-3.3568857805472235270612851425810803679451e-35L,
-3.9090991055522552395018106803232118803401e-35L,
-5.2956416979654208140521862707297033857956e-36L,
--5.0960846819945514367847063923662507136721e-36L,
--4.4959014425277615858329680393918315204998e-35L,
-3.8039226544551634266566857615962609653834e-35L,
--4.4056522872895512108308642196611689657618e-36L,
-1.6025024192482161076223807753425619076948e-36L,
-2.1679525325309452561992610065108380635264e-35L,
-1.9844038013515422125715362925736754104066e-35L,
-3.9139619471799746834505227353568432457241e-35L,
-2.1113443807975453505518453436799561854730e-35L,
-3.1558557277444692755039816944392770185432e-35L,
-1.6295044520355461408265585619500238335614e-35L,
--3.5087245209270305856151230356171213582305e-35L,
-2.9041041864282855679591055270946117300088e-35L,
--2.3128843453818356590931995209806627233282e-35L,
--7.7124923181471578439967973820714857839953e-35L,
-2.7539027829886922429092063590445808781462e-35L,
--9.4500899453181308951084545990839335972452e-35L,
--7.3061755302032092337594946001641651543473e-35L,
--4.1736144813953752193952770157406952602798e-35L,
-3.4369948356256407045344855262863733571105e-35L,
--6.3790243492298090907302084924276831116460e-35L,
--9.6842943816353261291004127866079538980649e-36L,
-4.8746757539138870909275958326700072821615e-35L,
--8.7533886477084190884511601368582548254655e-35L,
-1.4284743992327918892692551138086727754845e-35L,
-5.7262776211073389542565625693479173445042e-35L,
--3.2254883148780411245594822270747948565684e-35L,
-7.8853548190609877325965525252380833808405e-35L,
-8.4081736739037194097515038365370730251333e-35L,
-7.4722870357563683815078242981933587273670e-35L,
-7.9977202825793435289434813600890494256112e-36L,
--8.0577840773362139054848492346292673645405e-35L,
-1.4217746753670583065490040209048757624336e-35L,
-1.2232486914221205004109743560319090913328e-35L,
-8.9696055070830036447361957217943988339065e-35L,
--3.1480394435081884410686066739846269858951e-35L,
--5.0927146040715345013240642517608928352977e-35L,
--5.7431997715924136568133859432702789493569e-35L,
--4.3920451405083770279099766080476485439987e-35L,
-9.1106753984907715563018666776308759323326e-35L,
--3.7032569014272841009512400773061537538358e-35L,
-8.8167419429746714276909825405131416764489e-35L,
--3.8389341696028352503752312861740895209678e-36L,
--3.3462959341960891546340895508017603408404e-35L,
--3.9212626776786074383916188498955828634947e-35L,
--7.8340397396377867255864494568594088378648e-35L,
-7.4681018632456986520600640340627309824469e-35L,
-8.9110918618956918451135594876165314884113e-35L,
-3.9418160632271890530431797145664308529115e-35L,
--4.1048114088580104820193435638327617443913e-35L,
--2.3165419451582153326383944756220900454330e-35L,
--1.8428312581525319409399330203703211113843e-35L,
-7.1477316546709482345411712017906842769961e-35L,
-2.9914501578435874662153637707016094237004e-35L,
+	1.4074869197628063802317202820414310039556e-36L,
+	-4.9596961594739925555730439437999675295505e-36L,
+	8.9527745625194648873931213446361849472788e-36L,
+	1.1880437423207895718180765843544965589427e-35L,
+	-2.7810278112045145378425375128234365381448e-37L,
+	1.4797220377023800327295536234315147262387e-36L,
+	-4.2169561400548198732870384801849639863829e-36L,
+	7.2431229666913484649930323656316023494680e-36L,
+	-2.1573430089839170299895679353790663182462e-36L,
+	-9.9515745405126723554452367298128605186305e-36L,
+	-3.9065558992324838181617569730397882363067e-36L,
+	5.5260292271793726813211980664661124518807e-36L,
+	8.8415722215914321807682254318036452043689e-36L,
+	-8.1767728791586179254193323628285599800711e-36L,
+	-1.3344123034656142243797113823028330070762e-36L,
+	-4.4927331207813382908930733924681325892188e-36L,
+	4.4945511471812490393201824336762495687730e-36L,
+	-1.6688081504279223555776724459648440567274e-35L,
+	1.5629757586107955769461086568937329684113e-35L,
+	-2.2389835563308078552507970385331510848109e-35L,
+	-4.8312321745547311551870450671182151367050e-36L,
+	-1.4336172352905832876958926610980698844309e-35L,
+	-8.7440181998899932802989174170960593316080e-36L,
+	5.9284636008529837445780360785464550143016e-36L,
+	-2.2376651248436241276061055295043514993630e-35L,
+	6.0745837599336105414280310756677442136480e-36L,
+	1.5372187110451949677792344762029967023093e-35L,
+	2.0976068056751156241657121582478790247159e-35L,
+	-5.5623956405495438060726862202622807523700e-36L,
+	1.9697366707832471841858411934897351901523e-35L,
+	2.1070311964479488509034733639424887543697e-35L,
+	-2.3027356362982001602256518510854229844561e-35L,
+	4.8950964225733349266861843522029764772843e-36L,
+	-7.2380143477794458213872723050820253166391e-36L,
+	1.6365648865703614031637443396049568858105e-35L,
+	-3.9885811958234530793729129919803234197399e-35L,
+	4.1587722120912613510417783923227421336929e-35L,
+	3.8347421454556472153684687377337135027394e-35L,
+	-9.2251178933638721723515896465489002497864e-36L,
+	1.4094619690455989526175736741854656192178e-36L,
+	3.3568857805472235270612851425810803679451e-35L,
+	3.9090991055522552395018106803232118803401e-35L,
+	5.2956416979654208140521862707297033857956e-36L,
+	-5.0960846819945514367847063923662507136721e-36L,
+	-4.4959014425277615858329680393918315204998e-35L,
+	3.8039226544551634266566857615962609653834e-35L,
+	-4.4056522872895512108308642196611689657618e-36L,
+	1.6025024192482161076223807753425619076948e-36L,
+	2.1679525325309452561992610065108380635264e-35L,
+	1.9844038013515422125715362925736754104066e-35L,
+	3.9139619471799746834505227353568432457241e-35L,
+	2.1113443807975453505518453436799561854730e-35L,
+	3.1558557277444692755039816944392770185432e-35L,
+	1.6295044520355461408265585619500238335614e-35L,
+	-3.5087245209270305856151230356171213582305e-35L,
+	2.9041041864282855679591055270946117300088e-35L,
+	-2.3128843453818356590931995209806627233282e-35L,
+	-7.7124923181471578439967973820714857839953e-35L,
+	2.7539027829886922429092063590445808781462e-35L,
+	-9.4500899453181308951084545990839335972452e-35L,
+	-7.3061755302032092337594946001641651543473e-35L,
+	-4.1736144813953752193952770157406952602798e-35L,
+	3.4369948356256407045344855262863733571105e-35L,
+	-6.3790243492298090907302084924276831116460e-35L,
+	-9.6842943816353261291004127866079538980649e-36L,
+	4.8746757539138870909275958326700072821615e-35L,
+	-8.7533886477084190884511601368582548254655e-35L,
+	1.4284743992327918892692551138086727754845e-35L,
+	5.7262776211073389542565625693479173445042e-35L,
+	-3.2254883148780411245594822270747948565684e-35L,
+	7.8853548190609877325965525252380833808405e-35L,
+	8.4081736739037194097515038365370730251333e-35L,
+	7.4722870357563683815078242981933587273670e-35L,
+	7.9977202825793435289434813600890494256112e-36L,
+	-8.0577840773362139054848492346292673645405e-35L,
+	1.4217746753670583065490040209048757624336e-35L,
+	1.2232486914221205004109743560319090913328e-35L,
+	8.9696055070830036447361957217943988339065e-35L,
+	-3.1480394435081884410686066739846269858951e-35L,
+	-5.0927146040715345013240642517608928352977e-35L,
+	-5.7431997715924136568133859432702789493569e-35L,
+	-4.3920451405083770279099766080476485439987e-35L,
+	9.1106753984907715563018666776308759323326e-35L,
+	-3.7032569014272841009512400773061537538358e-35L,
+	8.8167419429746714276909825405131416764489e-35L,
+	-3.8389341696028352503752312861740895209678e-36L,
+	-3.3462959341960891546340895508017603408404e-35L,
+	-3.9212626776786074383916188498955828634947e-35L,
+	-7.8340397396377867255864494568594088378648e-35L,
+	7.4681018632456986520600640340627309824469e-35L,
+	8.9110918618956918451135594876165314884113e-35L,
+	3.9418160632271890530431797145664308529115e-35L,
+	-4.1048114088580104820193435638327617443913e-35L,
+	-2.3165419451582153326383944756220900454330e-35L,
+	-1.8428312581525319409399330203703211113843e-35L,
+	7.1477316546709482345411712017906842769961e-35L,
+	2.9914501578435874662153637707016094237004e-35L,
 #elif defined(__x86)
-1.108243739551347953496477557317e-11L,  3.644022694535396219063202730280e-11L,
-7.667835628314065801595065768845e-12L,  5.026377078169301918590803009109e-11L,
-1.161327548990211907411719105561e-11L,  4.785569941615255008968280209991e-11L,
-5.595107356360146549819920947848e-11L,  1.673930035747684999707469623769e-11L,
-2.611250523102718193166964451527e-11L,  1.384250305661681615897729354721e-11L,
-2.278105796029649304219088055497e-11L,  3.586371256902077123693302823191e-13L,
-3.342842716722085763523965049902e-11L,  3.670968534386232233574504707347e-11L,
-6.196832945990602657404893210974e-13L,  4.169679549603939604438777470618e-11L,
-2.274351222528987867221331091414e-11L,  8.872382531858169709022188891298e-11L,
-4.344925246387385146717580155420e-11L,  8.707377833692929105196832265348e-11L,
-2.881671577173773513055821329154e-11L,  9.763393361566846205717315422347e-12L,
-6.476296480975626822569454546857e-11L,  3.569597877124574002505169001136e-11L,
-1.772007853877284712958549977698e-11L,  1.347141028196192304932683248872e-11L,
-3.676555884905046507598141175404e-11L,  4.881564068032948912761478588710e-11L,
-4.416715404487185607337693704681e-11L,  2.314128999621257979016734983553e-11L,
-5.380138283056477968352133002913e-11L,  4.393022562414389595406841771063e-11L,
-6.299816718559209976839402028537e-12L,  7.304511413053165996581483735843e-11L,
-1.978381648117426221467592544212e-10L,  2.024381732686578226139414070989e-10L,
-2.255178211796380992141612703464e-10L,  1.204566302442290648452508620986e-10L,
-1.034473912921080457667329099995e-10L,  2.225691010059030834353745950874e-10L,
-4.817137162794350606107263804151e-11L,  6.565755971506095086327587326326e-11L,
-1.644791039522307629611529931429e-10L,  2.820930388953087163050126809014e-11L,
-1.766182540818701085571546539514e-10L,  2.124059054092171070266466628320e-10L,
-1.567258302596026515190288816001e-10L,  1.742241535800378094231540188685e-10L,
-3.038550253253096300737572104929e-11L,  5.925991958164150280814584656688e-11L,
-3.355266774764151155289750652594e-11L,  2.637254809561744853531409402995e-11L,
-3.227621096606048365493782702458e-11L,  1.094459672377587282585894259882e-10L,
-6.064676448464127209709358607166e-11L,  1.182850444360454453720999258140e-10L,
-1.428492049425553288966601449688e-11L,  3.032079976125434624889374125094e-10L,
-3.784543889504767060855636487744e-10L,  3.540092982887960328254439790467e-10L,
-4.020318667701700464612998296302e-10L,  4.544042324059585739827798668654e-10L,
-3.645299460952866120296998202703e-10L,  2.776662293911361485235212513020e-12L,
-1.708865101734375304910370400700e-10L,  3.909810965716415233488278047493e-10L,
-7.606461848875826105025137974947e-11L,  3.263814502297453347587046149712e-10L,
-1.499334758629144388918183376012e-10L,  3.771581242675818925565576303133e-10L,
-1.746932950084818923507049088298e-11L,  2.837781909176306820465786987027e-10L,
-3.859312847318946163435901230778e-10L,  4.601335192895268187473357720101e-10L,
-2.811262558622337888849804940684e-10L,  4.060360843532416964489955306249e-10L,
-8.058369357752989796958168458531e-11L,  3.725546414244147566166855921414e-10L,
-1.040286509953292907344053122733e-10L,  3.094968093808145773271362531155e-10L,
-4.454811192340438979284756311844e-10L,  5.676678748199027602705574110388e-11L,
-2.518376833121948163898128509842e-10L,  3.907837370041422778250991189943e-10L,
-7.687158710333735613246114865100e-11L,  1.334418885622867537060685125566e-10L,
-1.353147719826124443836432060856e-10L,  2.825131007652335581739282335732e-10L,
-4.161925466840049254333079881002e-10L,  4.265713490956410156084891599630e-10L,
-2.437693664320585461575989523716e-10L,  4.466519138542116247357297503086e-10L,
-3.113875178143440979746983590908e-10L,  4.910822904159495654488736486097e-11L,
-2.818831329324169810481585538618e-12L,  7.767009768334052125229252512543e-12L,
-3.698307026936191862258804165254e-10L,
+	1.108243739551347953496477557317e-11L,
+	3.644022694535396219063202730280e-11L,
+	7.667835628314065801595065768845e-12L,
+	5.026377078169301918590803009109e-11L,
+	1.161327548990211907411719105561e-11L,
+	4.785569941615255008968280209991e-11L,
+	5.595107356360146549819920947848e-11L,
+	1.673930035747684999707469623769e-11L,
+	2.611250523102718193166964451527e-11L,
+	1.384250305661681615897729354721e-11L,
+	2.278105796029649304219088055497e-11L,
+	3.586371256902077123693302823191e-13L,
+	3.342842716722085763523965049902e-11L,
+	3.670968534386232233574504707347e-11L,
+	6.196832945990602657404893210974e-13L,
+	4.169679549603939604438777470618e-11L,
+	2.274351222528987867221331091414e-11L,
+	8.872382531858169709022188891298e-11L,
+	4.344925246387385146717580155420e-11L,
+	8.707377833692929105196832265348e-11L,
+	2.881671577173773513055821329154e-11L,
+	9.763393361566846205717315422347e-12L,
+	6.476296480975626822569454546857e-11L,
+	3.569597877124574002505169001136e-11L,
+	1.772007853877284712958549977698e-11L,
+	1.347141028196192304932683248872e-11L,
+	3.676555884905046507598141175404e-11L,
+	4.881564068032948912761478588710e-11L,
+	4.416715404487185607337693704681e-11L,
+	2.314128999621257979016734983553e-11L,
+	5.380138283056477968352133002913e-11L,
+	4.393022562414389595406841771063e-11L,
+	6.299816718559209976839402028537e-12L,
+	7.304511413053165996581483735843e-11L,
+	1.978381648117426221467592544212e-10L,
+	2.024381732686578226139414070989e-10L,
+	2.255178211796380992141612703464e-10L,
+	1.204566302442290648452508620986e-10L,
+	1.034473912921080457667329099995e-10L,
+	2.225691010059030834353745950874e-10L,
+	4.817137162794350606107263804151e-11L,
+	6.565755971506095086327587326326e-11L,
+	1.644791039522307629611529931429e-10L,
+	2.820930388953087163050126809014e-11L,
+	1.766182540818701085571546539514e-10L,
+	2.124059054092171070266466628320e-10L,
+	1.567258302596026515190288816001e-10L,
+	1.742241535800378094231540188685e-10L,
+	3.038550253253096300737572104929e-11L,
+	5.925991958164150280814584656688e-11L,
+	3.355266774764151155289750652594e-11L,
+	2.637254809561744853531409402995e-11L,
+	3.227621096606048365493782702458e-11L,
+	1.094459672377587282585894259882e-10L,
+	6.064676448464127209709358607166e-11L,
+	1.182850444360454453720999258140e-10L,
+	1.428492049425553288966601449688e-11L,
+	3.032079976125434624889374125094e-10L,
+	3.784543889504767060855636487744e-10L,
+	3.540092982887960328254439790467e-10L,
+	4.020318667701700464612998296302e-10L,
+	4.544042324059585739827798668654e-10L,
+	3.645299460952866120296998202703e-10L,
+	2.776662293911361485235212513020e-12L,
+	1.708865101734375304910370400700e-10L,
+	3.909810965716415233488278047493e-10L,
+	7.606461848875826105025137974947e-11L,
+	3.263814502297453347587046149712e-10L,
+	1.499334758629144388918183376012e-10L,
+	3.771581242675818925565576303133e-10L,
+	1.746932950084818923507049088298e-11L,
+	2.837781909176306820465786987027e-10L,
+	3.859312847318946163435901230778e-10L,
+	4.601335192895268187473357720101e-10L,
+	2.811262558622337888849804940684e-10L,
+	4.060360843532416964489955306249e-10L,
+	8.058369357752989796958168458531e-11L,
+	3.725546414244147566166855921414e-10L,
+	1.040286509953292907344053122733e-10L,
+	3.094968093808145773271362531155e-10L,
+	4.454811192340438979284756311844e-10L,
+	5.676678748199027602705574110388e-11L,
+	2.518376833121948163898128509842e-10L,
+	3.907837370041422778250991189943e-10L,
+	7.687158710333735613246114865100e-11L,
+	1.334418885622867537060685125566e-10L,
+	1.353147719826124443836432060856e-10L,
+	2.825131007652335581739282335732e-10L,
+	4.161925466840049254333079881002e-10L,
+	4.265713490956410156084891599630e-10L,
+	2.437693664320585461575989523716e-10L,
+	4.466519138542116247357297503086e-10L,
+	3.113875178143440979746983590908e-10L,
+	4.910822904159495654488736486097e-11L,
+	2.818831329324169810481585538618e-12L,
+	7.767009768334052125229252512543e-12L,
+	3.698307026936191862258804165254e-10L,
 #endif
 };
 
@@ -439,7 +542,7 @@
  * The algorithm is based on atan(x)=atan(y)+atan((x-y)/(1+x*y)).
  * We use poly1(x) to approximate atan(x) for x in [0,1/8] with
  * error (relative)
- * 	|(atan(x)-poly1(x))/x|<= 2^-140
+ *      |(atan(x)-poly1(x))/x|<= 2^-140
  *
  * and use poly2(x) to approximate atan(x) for x in [0,1/65] with
  * error
@@ -475,6 +578,7 @@
  *
  */
 
+/* BEGIN CSTYLED */
 /*
  * p[0] - p[16] for atan(x) =
  *		x + x^3*(p1+x^2*(p2+...))
@@ -499,7 +603,7 @@
 #endif
 };
 
-static const long double p[] = { /* p[0] - p[16] */
+static const long double p[] = {	/* p[0] - p[16] */
 	1.0L,
 	-3.33333333333333333333333333333333333319278775586e-0001L,
 	1.99999999999999999999999999999999894961390937601e-0001L,
@@ -548,31 +652,32 @@
 	-5.25754959898164576495303840687699583228444695685e-0002L,
 };
 
-static const long double
-two8700  = 9.140338438955067659002088492701e+2618L, /* 2^8700 */
-twom8700 = 1.094051392821643668051436593760e-2619L, /* 2^-8700 */
-one   = 1.0L,
-zero  = 0.0L,
-pi    = 3.1415926535897932384626433832795028841971693993751L,
-pio2  = 1.57079632679489661923132169163975144209858469968755L,
-pio4  = 0.785398163397448309615660845819875721049292349843776L,
-pi3o4 = 2.356194490192344928846982537459627163147877049531329L,
+static const long double two8700 = 9.140338438955067659002088492701e+2618L,	/* 2^8700 */
+	twom8700 = 1.094051392821643668051436593760e-2619L, /* 2^-8700 */
+	one = 1.0L,
+	zero = 0.0L,
+	pi = 3.1415926535897932384626433832795028841971693993751L,
+	pio2 = 1.57079632679489661923132169163975144209858469968755L,
+	pio4 = 0.785398163397448309615660845819875721049292349843776L,
+	pi3o4 = 2.356194490192344928846982537459627163147877049531329L,
 #if defined(__sparc)
-pi_lo    = 8.67181013012378102479704402604335196876232e-35L,
-pio2_lo  = 4.33590506506189051239852201302167598438116e-35L,
-pio4_lo  = 2.16795253253094525619926100651083799219058e-35L,
-pi3o4_lo = 6.50385759759283576859778301953251397657174e-35L;
+	pi_lo = 8.67181013012378102479704402604335196876232e-35L,
+	pio2_lo = 4.33590506506189051239852201302167598438116e-35L,
+	pio4_lo = 2.16795253253094525619926100651083799219058e-35L,
+	pi3o4_lo = 6.50385759759283576859778301953251397657174e-35L;
 #elif defined(__x86)
-pi_lo    = -5.01655761266833202355732708e-20L,
-pio2_lo  = -2.50827880633416601177866354e-20L,
-pio4_lo  = -1.25413940316708300588933177e-20L,
-pi3o4_lo = -9.18342907192877118770525931e-20L;
+	pi_lo = -5.01655761266833202355732708e-20L,
+	pio2_lo = -2.50827880633416601177866354e-20L,
+	pio4_lo = -1.25413940316708300588933177e-20L,
+	pi3o4_lo = -9.18342907192877118770525931e-20L;
 #endif
+/* END CSTYLED */
 
 static long double
-mx_atanl(long double x, long double *err) {
+mx_atanl(long double x, long double *err)
+{
 	long double y, z, r, s, t, w, s_h, s_l, x_h, x_l, zz[3], ee[2], z_h,
-		z_l, r_h, r_l, u, v;
+	    z_l, r_h, r_l, u, v;
 	int ix, iy, hx, i, j;
 	float fx;
 
@@ -581,28 +686,38 @@
 
 	/* for |x| < 1/8 */
 	if (ix < 0x3ffc0000) {
-		if (ix < 0x3ff30000) {	/* when |x| < 2**-12 */
+		if (ix < 0x3ff30000) {		/* when |x| < 2**-12 */
 			if (ix < 0x3fc60000) {	/* if |x| < 2**-prec/2 */
-				*err = (long double) ((int) x);
+				*err = (long double)((int)x);
 				return (x);
 			}
+
 			z = x * x;
 			t = q[8];
-			for (i = 7; i >= 0; i--) t = q[i] + z * t;
+
+			for (i = 7; i >= 0; i--)
+				t = q[i] + z * t;
+
 			t *= x * z;
 			r = x + t;
 			*err = t - (r - x);
 			return (r);
 		}
+
 		z = x * x;
 
 		/* use long double precision at p4 and on */
 		t = p[16];
-		for (i = 15; i >= 4; i--) t = p[i] + z * t;
+
+		for (i = 15; i >= 4; i--)
+			t = p[i] + z * t;
+
 		ee[0] = z * t;
 
-		x_h = x;  HALF(x_h);
-		z_h = z;  HALF(z_h);
+		x_h = x;
+		HALF(x_h);
+		z_h = z;
+		HALF(z_h);
 		x_l = x - x_h;
 		z_l = (x_h * x_h - z_h);
 		zz[0] = z;
@@ -620,14 +735,17 @@
 		*err = t - (s - r);
 		return (s);
 	}
+
 	/* for |x| >= 8.0 */
-	if (ix >= 0x40020000) {	/* x >=  8 */
+	if (ix >= 0x40020000) {			/* x >=  8 */
 		x = fabsl(x);
-		if (ix >= 0x402e0000) {	/* x >=  2**47 */
-			if (ix >= 0x408b0000) {	/* x >=  2**140 */
+
+		if (ix >= 0x402e0000) {		/* x >=  2**47 */
+			if (ix >= 0x408b0000)	/* x >=  2**140 */
 				y = -pio2_lo;
-			} else
+			else
 				y = one / x - pio2_lo;
+
 			if (hx >= 0) {
 				t = pio2 - y;
 				*err = -(y - (pio2 - t));
@@ -635,37 +753,50 @@
 				t = y - pio2;
 				*err = y - (pio2 + t);
 			}
+
 			return (t);
 		} else {
 			/* compute r = 1/x */
 			r = one / x;
 			z = r * r;
-			x_h = x; HALF(x_h);
-			r_h = r; HALF(r_h);
-			z_h = z; HALF(z_h);
+			x_h = x;
+			HALF(x_h);
+			r_h = r;
+			HALF(r_h);
+			z_h = z;
+			HALF(z_h);
 			r_l = r * ((x_h - x) * r_h - (x_h * r_h - one));
 			z_l = (r_h * r_h - z_h);
 			zz[0] = z;
 			zz[1] = z_h;
 			zz[2] = z_l + r_l * (r + r_h);
+
 			if (ix < 0x40050400) {	/* 8 <  x <  65 */
 				/* use double precision at p4 and on */
 				t = p[16];
-				for (i = 15; i >= 4; i--) t = p[i] + z * t;
+
+				for (i = 15; i >= 4; i--)
+					t = p[i] + z * t;
+
 				ee[0] = z * t;
 				/* compute (1+z*(p1+z*(p2+z*(p3+e)))) */
 				mx_polyl(zz, pe, ee, 3);
-			} else { /* x < 65 < 2**47 */
+			} else {	/* x < 65 < 2**47 */
 				/* use long double at q3 and on */
 				t = q[8];
-				for (i = 7; i >= 2; i--) t = q[i] + z * t;
+
+				for (i = 7; i >= 2; i--)
+					t = q[i] + z * t;
+
 				ee[0] = z * t;
 				/* compute (1+z*(q1+z*(q2+e))) */
 				mx_polyl(zz, qe, ee, 2);
 			}
+
 			/* pio2 - r*(1+...) */
 			v = r_h * ee[0];
 			t = pio2_lo - (r * ee[1] + r_l * ee[0]);
+
 			if (hx >= 0) {
 				s = pio2 - v;
 				t -= (v - (pio2 - s));
@@ -673,16 +804,18 @@
 				s = v - pio2;
 				t = -(t - (v - (s + pio2)));
 			}
+
 			w = s + t;
 			*err = t - (w - s);
 			return (w);
 		}
 	}
+
 	/* now x is between 1/8 and 8 */
 	iy = (ix + 0x00000800) & 0x7ffff000;
 	j = (iy - 0x3ffc0000) >> 12;
-	((int *) &fx)[0] = 0x3e000000 + (j << 19);
-	y = (long double) fx;
+	((int *)&fx)[0] = 0x3e000000 + (j << 19);
+	y = (long double)fx;
 	x = fabsl(x);
 
 	w = (x - y);
@@ -691,12 +824,19 @@
 	z = s * s;
 	/* use long double precision at q3 and on */
 	t = q[8];
-	for (i = 7; i >= 2; i--) t = q[i] + z * t;
+
+	for (i = 7; i >= 2; i--)
+		t = q[i] + z * t;
+
 	ee[0] = z * t;
-	s_h = s; HALF(s_h);
-	z_h = z; HALF(z_h);
-	x_h = x; HALF(x_h);
-	t = one + x * y; HALF(t);
+	s_h = s;
+	HALF(s_h);
+	z_h = z;
+	HALF(z_h);
+	x_h = x;
+	HALF(x_h);
+	t = one + x * y;
+	HALF(t);
 	r = -((x_h - x) * y - (x_h * y - (t - one)));
 	s_l = -v * (s_h * r - (w - s_h * t));
 	z_l = (s_h * s_h - z_h);
@@ -712,15 +852,18 @@
 	t += (v - (s - u));
 	w = s + t;
 	*err = t - (w - s);
+
 	if (hx < 0) {
 		w = -w;
 		*err = -*err;
 	}
+
 	return (w);
 }
 
 long double
-__k_atan2l(long double y, long double x, long double *w) {
+__k_atan2l(long double y, long double x, long double *w)
+{
 	long double t, xh, th, t1, t2, w1, w2;
 	int ix, iy, hx, hy;
 
@@ -730,10 +873,11 @@
 	ix = hx & ~0x80000000;
 
 	*w = 0.0;
+
 	if (ix >= 0x7fff0000 || iy >= 0x7fff0000) {	/* ignore inexact */
-		if (isnanl(x) || isnanl(y))
+		if (isnanl(x) || isnanl(y)) {
 			return (x * y);
-		else if (iy < 0x7fff0000) {
+		} else if (iy < 0x7fff0000) {
 			if (hx >= 0) {	/* ATAN2(+-finite, +inf) is +-0 */
 				*w *= y;
 				return (*w);
@@ -742,39 +886,41 @@
 				return (copysignl(pi, y));
 			}
 		} else if (ix < 0x7fff0000) {
-					/* ATAN2(+-inf, finite) is +-pi/2 */
-			*w = (hy >= 0)? pio2_lo : -pio2_lo;
-			return ((hy >= 0)? pio2 : -pio2);
+			/* ATAN2(+-inf, finite) is +-pi/2 */
+			*w = (hy >= 0) ? pio2_lo : -pio2_lo;
+			return ((hy >= 0) ? pio2 : -pio2);
 		} else if (hx > 0) {	/* ATAN2(+-INF,+INF) = +-pi/4 */
-			*w = (hy >= 0)? pio4_lo : -pio4_lo;
-			return ((hy >= 0)? pio4 : -pio4);
+			*w = (hy >= 0) ? pio4_lo : -pio4_lo;
+			return ((hy >= 0) ? pio4 : -pio4);
 		} else {		/* ATAN2(+-INF,-INF) = +-3pi/4 */
-			*w = (hy >= 0)? pi3o4_lo : -pi3o4_lo;
-			return ((hy >= 0)? pi3o4 : -pi3o4);
+			*w = (hy >= 0) ? pi3o4_lo : -pi3o4_lo;
+			return ((hy >= 0) ? pi3o4 : -pi3o4);
 		}
 	} else if (x == zero || y == zero) {
 		if (y == zero) {
-			if (hx >= 0) /* ATAN2(+-0, +(0 <= x <= inf)) is +-0 */
+			if (hx >= 0) { /* ATAN2(+-0, +(0 <= x <= inf)) is +-0 */
 				return (y);
-			else { 	/* ATAN2(+-0, -(0 <= x <= inf)) is +-pi */
-				*w = (hy >= 0)? pi_lo : -pi_lo;
-				return ((hy >= 0)? pi : -pi);
+			} else { /* ATAN2(+-0, -(0 <= x <= inf)) is +-pi */
+				*w = (hy >= 0) ? pi_lo : -pi_lo;
+				return ((hy >= 0) ? pi : -pi);
 			}
-		} else { /* ATAN2(+-(anything but 0 and NaN), 0) is +-pi/2 */
-			*w = (hy >= 0)? pio2_lo : -pio2_lo;
-			return ((hy >= 0)? pio2 : -pio2);
+		} else {  /* ATAN2(+-(anything but 0 and NaN), 0) is +-pi/2 */
+			*w = (hy >= 0) ? pio2_lo : -pio2_lo;
+			return ((hy >= 0) ? pio2 : -pio2);
 		}
-	} else if (iy - ix > 0x00640000) { /* |x/y| < 2 ** -100 */
-		*w = (hy >= 0)? pio2_lo : -pio2_lo;
-		return ((hy >= 0)? pio2 : -pio2);
-	} else if (ix - iy > 0x00640000) { /* |y/x| < 2 ** -100 */
+	} else if (iy - ix > 0x00640000) {	/* |x/y| < 2 ** -100 */
+		*w = (hy >= 0) ? pio2_lo : -pio2_lo;
+		return ((hy >= 0) ? pio2 : -pio2);
+	} else if (ix - iy > 0x00640000) {	/* |y/x| < 2 ** -100 */
 		if (hx < 0) {
-			*w = (hy >= 0)? pi_lo : -pi_lo;
-			return ((hy >= 0)? pi : -pi);
+			*w = (hy >= 0) ? pi_lo : -pi_lo;
+			return ((hy >= 0) ? pi : -pi);
 		} else {
 			t = y / x;
-			th = t; HALF(th);
-			xh = x; HALF(xh);
+			th = t;
+			HALF(th);
+			xh = x;
+			HALF(xh);
 			t1 = (x - xh) * t + xh * (t - th);
 			t2 = y - xh * th;
 			*w = (t2 - t1) / x;
@@ -788,22 +934,27 @@
 			x *= two8700;
 			y *= two8700;
 		}
+
 		y = fabsl(y);
 		x = fabsl(x);
 		t = y / x;
-		th = t; HALF(th);
-		xh = x; HALF(xh);
+		th = t;
+		HALF(th);
+		xh = x;
+		HALF(xh);
 		t1 = (x - xh) * t + xh * (t - th);
 		t2 = y - xh * th;
 		w1 = mx_atanl(t, &w2);
 		w2 += (t2 - t1) / (x + y * t);
+
 		if (hx < 0) {
 			t1 = pi - w1;
 			t2 = pi - t1;
 			w2 = (pi_lo - w2) - (w1 - t2);
 			w1 = t1;
 		}
-		*w = (hy >= 0)? w2 : -w2;
-		return ((hy >= 0)? w1 : -w1);
+
+		*w = (hy >= 0) ? w2 : -w2;
+		return ((hy >= 0) ? w1 : -w1);
 	}
 }
--- old/usr/src/lib/libm/common/complex/k_cexp.c	2019-06-06 20:40:02.427281124 +0000
+++ new/usr/src/lib/libm/common/complex/k_cexp.c	2019-06-06 20:40:02.443560352 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * double __k_cexp(double x, int *n);
  * Returns the exponential of x in the form of 2**n * y, y=__k_cexp(x,&n).
@@ -47,11 +48,11 @@
  *	Write
  *	    R(r**2) = r*(exp(r)+1)/(exp(r)-1) = 2 + r*r/6 - r**4/360 + ...
  *      We use a special Remez algorithm on [0,0.34658] to generate
- * 	a polynomial of degree 5 to approximate R. The maximum error
+ *      a polynomial of degree 5 to approximate R. The maximum error
  *	of this polynomial approximation is bounded by 2**-59. In
  *	other words,
  *	    R(z) ~ 2.0 + P1*z + P2*z**2 + P3*z**3 + P4*z**4 + P5*z**5
- *  	(where z=r*r, and the values of P1 to P5 are listed below)
+ *      (where z=r*r, and the values of P1 to P5 are listed below)
  *	and
  *	    |                  5          |     -59
  *	    | 2.0+P1*z+...+P5*z   -  R(z) | <= 2
@@ -87,87 +88,96 @@
  * compiler will convert from decimal to binary accurately enough
  * to produce the hexadecimal values shown.
  */
-/* INDENT ON */
 
-#include "libm.h"		/* __k_cexp */
-#include "complex_wrapper.h"	/* HI_WORD/LO_WORD */
+#include "libm.h"			/* __k_cexp */
+#include "complex_wrapper.h"		/* HI_WORD/LO_WORD */
 
-/* INDENT OFF */
-static const double
-one = 1.0,
-two128 = 3.40282366920938463463e+38,
-halF[2]	= {
-	0.5, -0.5,
-},
-ln2HI[2] = {
+static const double one = 1.0,
+	two128 = 3.40282366920938463463e+38;
+
+static const double halF[2] = { 0.5, -0.5, };
+
+static const double ln2HI[2] = {
 	6.93147180369123816490e-01,	/* 0x3fe62e42, 0xfee00000 */
 	-6.93147180369123816490e-01,	/* 0xbfe62e42, 0xfee00000 */
-},
-ln2LO[2] = {
+};
+
+static const double ln2LO[2] = {
 	1.90821492927058770002e-10,	/* 0x3dea39ef, 0x35793c76 */
 	-1.90821492927058770002e-10,	/* 0xbdea39ef, 0x35793c76 */
-},
-invln2 = 1.44269504088896338700e+00,	/* 0x3ff71547, 0x652b82fe */
-P1 = 1.66666666666666019037e-01,	/* 0x3FC55555, 0x5555553E */
-P2 = -2.77777777770155933842e-03,	/* 0xBF66C16C, 0x16BEBD93 */
-P3 = 6.61375632143793436117e-05,	/* 0x3F11566A, 0xAF25DE2C */
-P4 = -1.65339022054652515390e-06,	/* 0xBEBBBD41, 0xC5D26BF1 */
-P5 = 4.13813679705723846039e-08;	/* 0x3E663769, 0x72BEA4D0 */
-/* INDENT ON */
+};
+
+static const double
+	invln2 = 1.44269504088896338700e+00,	/* 0x3ff71547, 0x652b82fe */
+	P1 = 1.66666666666666019037e-01,	/* 0x3FC55555, 0x5555553E */
+	P2 = -2.77777777770155933842e-03,	/* 0xBF66C16C, 0x16BEBD93 */
+	P3 = 6.61375632143793436117e-05,	/* 0x3F11566A, 0xAF25DE2C */
+	P4 = -1.65339022054652515390e-06,	/* 0xBEBBBD41, 0xC5D26BF1 */
+	P5 = 4.13813679705723846039e-08;	/* 0x3E663769, 0x72BEA4D0 */
+
 
 double
-__k_cexp(double x, int *n) {
+__k_cexp(double x, int *n)
+{
 	double hi = 0.0L, lo = 0.0L, c, t;
 	int k, xsb;
 	unsigned hx, lx;
 
-	hx = HI_WORD(x);	/* high word of x */
-	lx = LO_WORD(x);	/* low word of x */
-	xsb = (hx >> 31) & 1;	/* sign bit of x */
-	hx &= 0x7fffffff;	/* high word of |x| */
+	hx = HI_WORD(x);		/* high word of x */
+	lx = LO_WORD(x);		/* low word of x */
+	xsb = (hx >> 31) & 1;		/* sign bit of x */
+	hx &= 0x7fffffff;		/* high word of |x| */
 
 	/* filter out non-finite argument */
-	if (hx >= 0x40e86a00) {	/* if |x| > 50000 */
+	if (hx >= 0x40e86a00) {		/* if |x| > 50000 */
 		if (hx >= 0x7ff00000) {
 			*n = 1;
+
 			if (((hx & 0xfffff) | lx) != 0)
-				return (x + x);	/* NaN */
+				return (x + x);		/* NaN */
 			else
 				return ((xsb == 0) ? x : 0.0);
-							/* exp(+-inf)={inf,0} */
+
+			/* exp(+-inf)={inf,0} */
 		}
+
 		*n = (xsb == 0) ? 50000 : -50000;
 		return (one + ln2LO[1] * ln2LO[1]);	/* generate inexact */
 	}
 
 	*n = 0;
+
 	/* argument reduction */
-	if (hx > 0x3fd62e42) {	/* if  |x| > 0.5 ln2 */
+	if (hx > 0x3fd62e42) {		/* if  |x| > 0.5 ln2 */
 		if (hx < 0x3FF0A2B2) {	/* and |x| < 1.5 ln2 */
 			hi = x - ln2HI[xsb];
 			lo = ln2LO[xsb];
 			k = 1 - xsb - xsb;
 		} else {
-			k = (int) (invln2 * x + halF[xsb]);
+			k = (int)(invln2 * x + halF[xsb]);
 			t = k;
 			hi = x - t * ln2HI[0];
-					/* t*ln2HI is exact for t<2**20 */
+			/* t*ln2HI is exact for t<2**20 */
 			lo = t * ln2LO[0];
 		}
+
 		x = hi - lo;
 		*n = k;
 	} else if (hx < 0x3e300000) {	/* when |x|<2**-28 */
 		return (one + x);
-	} else
+	} else {
 		k = 0;
+	}
 
 	/* x is now in primary range */
 	t = x * x;
 	c = x - t * (P1 + t * (P2 + t * (P3 + t * (P4 + t * P5))));
-	if (k == 0)
+
+	if (k == 0) {
 		return (one - ((x * c) / (c - 2.0) - x));
-	else {
+	} else {
 		t = one - ((lo - (x * c) / (2.0 - c)) - hi);
+
 		if (k > 128) {
 			t *= two128;
 			*n = k - 128;
@@ -175,6 +185,7 @@
 			HI_WORD(t) += (k << 20);
 			*n = 0;
 		}
+
 		return (t);
 	}
 }
--- old/usr/src/lib/libm/common/complex/k_cexpl.c	2019-06-06 20:40:02.885607338 +0000
+++ new/usr/src/lib/libm/common/complex/k_cexpl.c	2019-06-06 20:40:02.903122661 +0000
@@ -22,12 +22,13 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-/* INDENT OFF */
+
 /*
  * long double __k_cexpl(long double x, int *n);
  * Returns the exponential of x in the form of 2**n * y, y=__k_cexpl(x,&n).
@@ -66,92 +67,62 @@
  * from decimal to binary accurately enough to produce the correct
  * hexadecimal values.
  */
-/* INDENT ON */
 
-#include "libm.h"		/* __k_cexpl */
-#include "complex_wrapper.h"	/* HI_XWORD */
+#include "libm.h"			/* __k_cexpl */
+#include "complex_wrapper.h"		/* HI_XWORD */
 
-/* INDENT OFF */
-/* ln2/32 = 0.0216608493924982909192885037955680177523593791987579766912713 */
+/*
+ * ln2/32 = 0.0216608493924982909192885037955680177523593791987579766912713
+ */
 #if defined(__x86)
 static const long double
-			/* 43 significant bits, 21 trailing zeros */
-ln2_32hi = 2.166084939249657281834515742957592010498046875e-2L,
-ln2_32lo = 1.7181009433463659920976473789104487579766912713e-15L;
-static const long double exp2_32_hi[] = {  	/* exp2_32[j] = 2^(j/32) */
-	1.0000000000000000000000000e+00L,
-	1.0218971486541166782081522e+00L,
-	1.0442737824274138402382006e+00L,
-	1.0671404006768236181297224e+00L,
-	1.0905077326652576591003302e+00L,
-	1.1143867425958925362894369e+00L,
-	1.1387886347566916536971221e+00L,
-	1.1637248587775775137938619e+00L,
-	1.1892071150027210666875674e+00L,
-	1.2152473599804688780476325e+00L,
-	1.2418578120734840485256747e+00L,
-	1.2690509571917332224885722e+00L,
-	1.2968395546510096659215822e+00L,
-	1.3252366431597412945939118e+00L,
-	1.3542555469368927282668852e+00L,
-	1.3839098819638319548151403e+00L,
-	1.4142135623730950487637881e+00L,
-	1.4451808069770466200253470e+00L,
-	1.4768261459394993113155431e+00L,
-	1.5091644275934227397133885e+00L,
-	1.5422108254079408235859630e+00L,
-	1.5759808451078864864006862e+00L,
-	1.6104903319492543080837174e+00L,
-	1.6457554781539648445110730e+00L,
-	1.6817928305074290860378350e+00L,
-	1.7186192981224779156032914e+00L,
-	1.7562521603732994831094730e+00L,
-	1.7947090750031071864148413e+00L,
-	1.8340080864093424633989166e+00L,
-	1.8741676341102999013002103e+00L,
-	1.9152065613971472938202589e+00L,
-	1.9571441241754002689657438e+00L,
+	/* 43 significant bits, 21 trailing zeros */
+	ln2_32hi = 2.166084939249657281834515742957592010498046875e-2L,
+	ln2_32lo = 1.7181009433463659920976473789104487579766912713e-15L;
+
+static const long double exp2_32_hi[] = {	/* exp2_32[j] = 2^(j/32) */
+	1.0000000000000000000000000e+00L, 1.0218971486541166782081522e+00L,
+	1.0442737824274138402382006e+00L, 1.0671404006768236181297224e+00L,
+	1.0905077326652576591003302e+00L, 1.1143867425958925362894369e+00L,
+	1.1387886347566916536971221e+00L, 1.1637248587775775137938619e+00L,
+	1.1892071150027210666875674e+00L, 1.2152473599804688780476325e+00L,
+	1.2418578120734840485256747e+00L, 1.2690509571917332224885722e+00L,
+	1.2968395546510096659215822e+00L, 1.3252366431597412945939118e+00L,
+	1.3542555469368927282668852e+00L, 1.3839098819638319548151403e+00L,
+	1.4142135623730950487637881e+00L, 1.4451808069770466200253470e+00L,
+	1.4768261459394993113155431e+00L, 1.5091644275934227397133885e+00L,
+	1.5422108254079408235859630e+00L, 1.5759808451078864864006862e+00L,
+	1.6104903319492543080837174e+00L, 1.6457554781539648445110730e+00L,
+	1.6817928305074290860378350e+00L, 1.7186192981224779156032914e+00L,
+	1.7562521603732994831094730e+00L, 1.7947090750031071864148413e+00L,
+	1.8340080864093424633989166e+00L, 1.8741676341102999013002103e+00L,
+	1.9152065613971472938202589e+00L, 1.9571441241754002689657438e+00L,
 };
+
 static const long double exp2_32_lo[] = {
-	0.0000000000000000000000000e+00L,
-	2.6327965667180882569382524e-20L,
-	8.3765863521895191129661899e-20L,
-	3.9798705777454504249209575e-20L,
-	1.0668046596651558640993042e-19L,
-	1.9376009847285360448117114e-20L,
-	6.7081819456112953751277576e-21L,
-	1.9711680502629186462729727e-20L,
-	2.9932584438449523689104569e-20L,
-	6.8887754153039109411061914e-20L,
-	6.8002718741225378942847820e-20L,
-	6.5846917376975403439742349e-20L,
-	1.2171958727511372194876001e-20L,
-	3.5625253228704087115438260e-20L,
-	3.1129551559077560956309179e-20L,
-	5.7519192396164779846216492e-20L,
-	3.7900651177865141593101239e-20L,
-	1.1659262405698741798080115e-20L,
-	7.1364385105284695967172478e-20L,
-	5.2631003710812203588788949e-20L,
-	2.6328853788732632868460580e-20L,
-	5.4583950085438242788190141e-20L,
-	9.5803254376938269960718656e-20L,
-	7.6837733983874245823512279e-21L,
-	2.4415965910835093824202087e-20L,
-	2.6052966871016580981769728e-20L,
-	2.6876456344632553875309579e-21L,
-	1.2861930155613700201703279e-20L,
-	8.8166633394037485606572294e-20L,
-	2.9788615389580190940837037e-20L,
-	5.2352341619805098677422139e-20L,
-	5.2578463064010463732242363e-20L,
+	0.0000000000000000000000000e+00L, 2.6327965667180882569382524e-20L,
+	8.3765863521895191129661899e-20L, 3.9798705777454504249209575e-20L,
+	1.0668046596651558640993042e-19L, 1.9376009847285360448117114e-20L,
+	6.7081819456112953751277576e-21L, 1.9711680502629186462729727e-20L,
+	2.9932584438449523689104569e-20L, 6.8887754153039109411061914e-20L,
+	6.8002718741225378942847820e-20L, 6.5846917376975403439742349e-20L,
+	1.2171958727511372194876001e-20L, 3.5625253228704087115438260e-20L,
+	3.1129551559077560956309179e-20L, 5.7519192396164779846216492e-20L,
+	3.7900651177865141593101239e-20L, 1.1659262405698741798080115e-20L,
+	7.1364385105284695967172478e-20L, 5.2631003710812203588788949e-20L,
+	2.6328853788732632868460580e-20L, 5.4583950085438242788190141e-20L,
+	9.5803254376938269960718656e-20L, 7.6837733983874245823512279e-21L,
+	2.4415965910835093824202087e-20L, 2.6052966871016580981769728e-20L,
+	2.6876456344632553875309579e-21L, 1.2861930155613700201703279e-20L,
+	8.8166633394037485606572294e-20L, 2.9788615389580190940837037e-20L,
+	5.2352341619805098677422139e-20L, 5.2578463064010463732242363e-20L,
 };
-#else	/* sparc */
+#else /* sparc */
 static const long double
-			/* 0x3FF962E4 2FEFA39E F35793C7 00000000 */
-ln2_32hi = 2.166084939249829091928849858592451515688e-2L,
-ln2_32lo = 5.209643502595475652782654157501186731779e-27L;
-static const long double exp2_32_hi[] = {  	/* exp2_32[j] = 2^(j/32) */
+	/* 0x3FF962E4 2FEFA39E F35793C7 00000000 */
+	ln2_32hi = 2.166084939249829091928849858592451515688e-2L,
+	ln2_32lo = 5.209643502595475652782654157501186731779e-27L;
+static const long double exp2_32_hi[] = {	/* exp2_32[j] = 2^(j/32) */
 	1.000000000000000000000000000000000000000e+0000L,
 	1.021897148654116678234480134783299439782e+0000L,
 	1.044273782427413840321966478739929008785e+0000L,
@@ -222,56 +193,62 @@
 };
 #endif
 
-static const long double
-	one = 1.0L,
+static const long double one = 1.0L,
 	two = 2.0L,
 	ln2_64 = 1.083042469624914545964425189778400898568e-2L,
 	invln2_32 = 4.616624130844682903551758979206054839765e+1L;
 
 /* rational approximation coeffs for [-(ln2)/64,(ln2)/64] */
-static const long double
-	t1 =  1.666666666666666666666666666660876387437e-1L,
+static const long double t1 = 1.666666666666666666666666666660876387437e-1L,
 	t2 = -2.777777777777777777777707812093173478756e-3L,
-	t3 =  6.613756613756613482074280932874221202424e-5L,
+	t3 = 6.613756613756613482074280932874221202424e-5L,
 	t4 = -1.653439153392139954169609822742235851120e-6L,
-	t5 =  4.175314851769539751387852116610973796053e-8L;
-/* INDENT ON */
+	t5 = 4.175314851769539751387852116610973796053e-8L;
 
 long double
-__k_cexpl(long double x, int *n) {
+__k_cexpl(long double x, int *n)
+{
 	int hx, ix, j, k;
 	long double t, r;
 
 	*n = 0;
 	hx = HI_XWORD(x);
 	ix = hx & 0x7fffffff;
+
 	if (hx >= 0x7fff0000)
-		return (x + x);	/* NaN of +inf */
-	if (((unsigned) hx) >= 0xffff0000)
+		return (x + x);		/* NaN of +inf */
+
+	if (((unsigned)hx) >= 0xffff0000)
 		return (-one / x);	/* NaN or -inf */
+
 	if (ix < 0x3fc30000)
 		return (one + x);	/* |x|<2^-60 */
+
 	if (hx > 0) {
 		if (hx > 0x401086a0) {	/* x > 200000 */
 			*n = 200000;
 			return (one);
 		}
-		k = (int) (invln2_32 * (x + ln2_64));
+
+		k = (int)(invln2_32 * (x + ln2_64));
 	} else {
 		if (ix > 0x401086a0) {	/* x < -200000 */
 			*n = -200000;
 			return (one);
 		}
-		k = (int) (invln2_32 * (x - ln2_64));
+
+		k = (int)(invln2_32 * (x - ln2_64));
 	}
+
 	j = k & 0x1f;
 	*n = k >> 5;
-	t = (long double) k;
+	t = (long double)k;
 	x = (x - t * ln2_32hi) - t * ln2_32lo;
 	t = x * x;
 	r = (x - t * (t1 + t * (t2 + t * (t3 + t * (t4 + t * t5))))) - two;
 	x = exp2_32_hi[j] - ((exp2_32_hi[j] * (x + x)) / r - exp2_32_lo[j]);
 	k >>= 5;
+
 	if (k > 240) {
 		XFSCALE(x, 240);
 		*n -= 240;
@@ -279,5 +256,6 @@
 		XFSCALE(x, k);
 		*n = 0;
 	}
+
 	return (x);
 }
--- old/usr/src/lib/libm/common/complex/k_clog_r.c	2019-06-06 20:40:03.353971177 +0000
+++ new/usr/src/lib/libm/common/complex/k_clog_r.c	2019-06-06 20:40:03.370168682 +0000
@@ -18,18 +18,20 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-#include "libm.h"		/* __k_clog_r */
+#include "libm.h"			/* __k_clog_r */
 #include "complex_wrapper.h"
 
-/* INDENT OFF */
+
 /*
  * double __k_clog_r(double x, double y, double *e);
  *
@@ -70,165 +72,163 @@
  *	   s2h = s2 rounded to float;  v = 0.5*s2h;
  *	   s2t = r*((((zh-s2h*(1+zk))-v*zh)+zt)-v*zt)
  */
-/* INDENT ON */
 
-static const double
-zero  = 0.0,
-half  = 0.5,
-two   = 2.0,
-two120 = 1.32922799578491587290e+36,  /* 2^120 */
-ln2_h  = 6.93147180369123816490e-01,  /* 3fe62e42 fee00000 */
-ln2_t  = 1.90821492927058770002e-10,  /* 3dea39ef 35793c76 */
-P1 =  .083333333333333351554108717377986202224765262191125,
-P2 =  .01249999999819227552330700574633767185896464873834375,
-P3 =  .0022321938458645656605471559987512516234702284287265625;
-
-/*
-* T[2k, 2k+1] = log(1+k*2^-7) for k = 0, ..., 2^7 - 1,
-* with T[2k] * 2^40 is an int
-*/
+static const double zero = 0.0,
+	half = 0.5,
+	two = 2.0,
+	two120 = 1.32922799578491587290e+36,		/* 2^120 */
+	ln2_h = 6.93147180369123816490e-01,	/* 3fe62e42 fee00000 */
+	ln2_t = 1.90821492927058770002e-10,	/* 3dea39ef 35793c76 */
+	P1 = .083333333333333351554108717377986202224765262191125,
+	P2 = .01249999999819227552330700574633767185896464873834375,
+	P3 = .0022321938458645656605471559987512516234702284287265625;
 
+/*
+ * T[2k, 2k+1] = log(1+k*2^-7) for k = 0, ..., 2^7 - 1,
+ * with T[2k] * 2^40 is an int
+ */
 static const double TBL_log1k[] = {
-0.00000000000000000000e+00,  0.00000000000000000000e+00,
-7.78214044203195953742e-03,  2.29894100462035112076e-14,
-1.55041865355087793432e-02,  4.56474807636434698847e-13,
-2.31670592811497044750e-02,  3.84673753843363762372e-13,
-3.07716586667083902285e-02,  4.52981425779092882775e-14,
-3.83188643018002039753e-02,  3.36395218465265063278e-13,
-4.58095360309016541578e-02,  3.92549008891706208826e-13,
-5.32445145181554835290e-02,  6.56799336898521766515e-13,
-6.06246218158048577607e-02,  6.29984819938331143924e-13,
-6.79506619080711971037e-02,  4.36552290856295281946e-13,
-7.52234212368421140127e-02,  7.45411685916941618656e-13,
-8.24436692109884461388e-02,  8.61451293608781447223e-14,
-8.96121586893059429713e-02,  3.81189648692113819551e-13,
-9.67296264579999842681e-02,  5.51128027471986918274e-13,
-1.03796793680885457434e-01,  7.58107392301637643358e-13,
-1.10814366339582193177e-01,  7.07921017612766061755e-13,
-1.17783035655520507134e-01,  8.62947404296943765415e-13,
-1.24703478500123310369e-01,  8.33925494898414856118e-13,
-1.31576357788617315236e-01,  1.01957352237084734958e-13,
-1.38402322858382831328e-01,  7.36304357708705134617e-13,
-1.45182009843665582594e-01,  8.32314688404647202319e-13,
-1.51916042025732167531e-01,  1.09807540998552379211e-13,
-1.58605030175749561749e-01,  8.89022343972466269900e-13,
-1.65249572894936136436e-01,  3.71026439894104998399e-13,
-1.71850256926518341061e-01,  1.40881279371111350341e-13,
-1.78407657472234859597e-01,  5.83437522462346671423e-13,
-1.84922338493379356805e-01,  6.32635858668445232946e-13,
-1.91394852999110298697e-01,  5.19155912393432989209e-13,
-1.97825743329303804785e-01,  6.16075577558872326221e-13,
-2.04215541428311553318e-01,  3.79338185766902218086e-13,
-2.10564769106895255391e-01,  4.54382278998146218219e-13,
-2.16873938300523150247e-01,  9.12093724991498410553e-14,
-2.23143551314024080057e-01,  1.85675709597960106615e-13,
-2.29374101064422575291e-01,  4.23254700234549300166e-13,
-2.35566071311950508971e-01,  8.16400106820959292914e-13,
-2.41719936886511277407e-01,  6.33890736899755317832e-13,
-2.47836163904139539227e-01,  4.41717553713155466566e-13,
-2.53915209980732470285e-01,  2.30973852175869394892e-13,
-2.59957524436686071567e-01,  2.39995404842117353465e-13,
-2.65963548496984003577e-01,  1.53937761744554075681e-13,
-2.71933715483100968413e-01,  5.40790418614551497411e-13,
-2.77868451003087102436e-01,  3.69203750820800887027e-13,
-2.83768173129828937817e-01,  8.15660529536291275782e-13,
-2.89633292582948342897e-01,  9.43339818951269030846e-14,
-2.95464212893421063200e-01,  4.14813187042585679830e-13,
-3.01261330577290209476e-01,  8.71571536970835103739e-13,
-3.07025035294827830512e-01,  8.40315630479242455758e-14,
-3.12755710003330023028e-01,  5.66865358290073900922e-13,
-3.18453731118097493891e-01,  4.37121919574291444278e-13,
-3.24119468653407238889e-01,  8.04737201185162774515e-13,
-3.29753286371669673827e-01,  7.98307987877335024112e-13,
-3.35355541920762334485e-01,  3.75495772572598557174e-13,
-3.40926586970454081893e-01,  1.39128412121975659358e-13,
-3.46466767346100823488e-01,  1.07757430375726404546e-13,
-3.51976423156884266064e-01,  2.93918591876480007730e-13,
-3.57455888921322184615e-01,  4.81589611172320539489e-13,
-3.62905493689140712377e-01,  2.27740761140395561986e-13,
-3.68325561158599157352e-01,  1.08495696229679121506e-13,
-3.73716409792905324139e-01,  6.78756682315870616582e-13,
-3.79078352934811846353e-01,  1.57612037739694350287e-13,
-3.84411698910298582632e-01,  3.34571026954408237380e-14,
-3.89716751139530970249e-01,  4.94243121138567024911e-13,
-3.94993808240542421117e-01,  3.26556988969071456956e-13,
-4.00243164126550254878e-01,  4.62452051668403792833e-13,
-4.05465108107819105498e-01,  3.45276479520397708744e-13,
-4.10659924984429380856e-01,  8.39005077851830734139e-13,
-4.15827895143593195826e-01,  1.17769787513692141889e-13,
-4.20969294643327884842e-01,  8.01751287156832458079e-13,
-4.26084395310681429692e-01,  2.18633432932159103190e-13,
-4.31173464818130014464e-01,  2.41326394913331314894e-13,
-4.36236766774527495727e-01,  3.90574622098307022265e-13,
-4.41274560804231441580e-01,  6.43787909737320689684e-13,
-4.46287102628048160113e-01,  3.71351419195920213229e-13,
-4.51274644138720759656e-01,  7.37825488412103968058e-13,
-4.56237433480964682531e-01,  6.22911850193784704748e-13,
-4.61175715121498797089e-01,  6.71369279138460114513e-13,
-4.66089729924533457961e-01,  6.57665976858006147528e-14,
-4.70979715218163619284e-01,  6.27393263311115598424e-13,
-4.75845904869856894948e-01,  1.07019317621142549209e-13,
-4.80688529345570714213e-01,  1.81193463664411114729e-13,
-4.85507815781602403149e-01,  9.84046527823262695501e-14,
-4.90303988044615834951e-01,  5.78003198945402769376e-13,
-4.95077266797125048470e-01,  7.26466128212511528295e-13,
-4.99827869555701909121e-01,  7.47420700205478712293e-13,
-5.04556010751912253909e-01,  4.83033149495532022300e-13,
-5.09261901789614057634e-01,  1.93889170049107088943e-13,
-5.13945751101346104406e-01,  8.88212395185718544720e-13,
-5.18607764207445143256e-01,  6.00488896640545761201e-13,
-5.23248143764249107335e-01,  2.98729182044413286731e-13,
-5.27867089620485785417e-01,  3.56599696633478298092e-13,
-5.32464798869114019908e-01,  3.57823965912763837621e-13,
-5.37041465896436420735e-01,  4.47233831757482468946e-13,
-5.41597282432121573947e-01,  6.22797629172251525649e-13,
-5.46132437597407260910e-01,  7.28389472720657362987e-13,
-5.50647117952394182794e-01,  2.68096466152116723636e-13,
-5.55141507539701706264e-01,  7.99886451312335479470e-13,
-5.59615787935399566777e-01,  2.31194938380053776320e-14,
-5.64070138284478161950e-01,  3.24804121719935740729e-13,
-5.68504735351780254859e-01,  8.88457219261483317716e-13,
-5.72919753561109246220e-01,  6.76262872317054154667e-13,
-5.77315365034337446559e-01,  4.86157758891509033842e-13,
-5.81691739634152327199e-01,  4.70155322075549811780e-13,
-5.86049045003164792433e-01,  4.13416470738355643357e-13,
-5.90387446602107957006e-01,  6.84176364159146659095e-14,
-5.94707107746216934174e-01,  4.75855340044306376333e-13,
-5.99008189645246602595e-01,  8.36796786747576938145e-13,
-6.03290851438032404985e-01,  5.18573553063418286042e-14,
-6.07555250224322662689e-01,  2.19132812293400917731e-13,
-6.11801541105705837253e-01,  2.87066276408616768331e-13,
-6.16029877214714360889e-01,  7.99658758518543977451e-13,
-6.20240409751204424538e-01,  6.53104313776336534177e-13,
-6.24433288011459808331e-01,  4.33692711555820529733e-13,
-6.28608659421843185555e-01,  5.30952189118357790115e-13,
-6.32766669570628437214e-01,  4.09392332186786656392e-13,
-6.36907462236194987781e-01,  8.74243839148582888557e-13,
-6.41031179420679109171e-01,  2.52181884568428814231e-13,
-6.45137961372711288277e-01,  8.73413388168702670246e-13,
-6.49227946624705509748e-01,  4.04309142530119209805e-13,
-6.53301272011958644725e-01,  7.86994033233553225797e-13,
-6.57358072708120744210e-01,  2.39285932153437645135e-13,
-6.61398482245203922503e-01,  1.61085757539324585156e-13,
-6.65422632544505177066e-01,  5.85271884362515112697e-13,
-6.69430653942072240170e-01,  5.57027128793880294600e-13,
-6.73422675211440946441e-01,  7.25773856816637653180e-13,
-6.77398823590920073912e-01,  8.86066898134949155668e-13,
-6.81359224807238206267e-01,  6.64862680714687006264e-13,
-6.85304003098281100392e-01,  6.38316151706465171657e-13,
-6.89233281238557538018e-01,  2.51442307283760746611e-13,
+	0.00000000000000000000e+00, 0.00000000000000000000e+00,
+	7.78214044203195953742e-03, 2.29894100462035112076e-14,
+	1.55041865355087793432e-02, 4.56474807636434698847e-13,
+	2.31670592811497044750e-02, 3.84673753843363762372e-13,
+	3.07716586667083902285e-02, 4.52981425779092882775e-14,
+	3.83188643018002039753e-02, 3.36395218465265063278e-13,
+	4.58095360309016541578e-02, 3.92549008891706208826e-13,
+	5.32445145181554835290e-02, 6.56799336898521766515e-13,
+	6.06246218158048577607e-02, 6.29984819938331143924e-13,
+	6.79506619080711971037e-02, 4.36552290856295281946e-13,
+	7.52234212368421140127e-02, 7.45411685916941618656e-13,
+	8.24436692109884461388e-02, 8.61451293608781447223e-14,
+	8.96121586893059429713e-02, 3.81189648692113819551e-13,
+	9.67296264579999842681e-02, 5.51128027471986918274e-13,
+	1.03796793680885457434e-01, 7.58107392301637643358e-13,
+	1.10814366339582193177e-01, 7.07921017612766061755e-13,
+	1.17783035655520507134e-01, 8.62947404296943765415e-13,
+	1.24703478500123310369e-01, 8.33925494898414856118e-13,
+	1.31576357788617315236e-01, 1.01957352237084734958e-13,
+	1.38402322858382831328e-01, 7.36304357708705134617e-13,
+	1.45182009843665582594e-01, 8.32314688404647202319e-13,
+	1.51916042025732167531e-01, 1.09807540998552379211e-13,
+	1.58605030175749561749e-01, 8.89022343972466269900e-13,
+	1.65249572894936136436e-01, 3.71026439894104998399e-13,
+	1.71850256926518341061e-01, 1.40881279371111350341e-13,
+	1.78407657472234859597e-01, 5.83437522462346671423e-13,
+	1.84922338493379356805e-01, 6.32635858668445232946e-13,
+	1.91394852999110298697e-01, 5.19155912393432989209e-13,
+	1.97825743329303804785e-01, 6.16075577558872326221e-13,
+	2.04215541428311553318e-01, 3.79338185766902218086e-13,
+	2.10564769106895255391e-01, 4.54382278998146218219e-13,
+	2.16873938300523150247e-01, 9.12093724991498410553e-14,
+	2.23143551314024080057e-01, 1.85675709597960106615e-13,
+	2.29374101064422575291e-01, 4.23254700234549300166e-13,
+	2.35566071311950508971e-01, 8.16400106820959292914e-13,
+	2.41719936886511277407e-01, 6.33890736899755317832e-13,
+	2.47836163904139539227e-01, 4.41717553713155466566e-13,
+	2.53915209980732470285e-01, 2.30973852175869394892e-13,
+	2.59957524436686071567e-01, 2.39995404842117353465e-13,
+	2.65963548496984003577e-01, 1.53937761744554075681e-13,
+	2.71933715483100968413e-01, 5.40790418614551497411e-13,
+	2.77868451003087102436e-01, 3.69203750820800887027e-13,
+	2.83768173129828937817e-01, 8.15660529536291275782e-13,
+	2.89633292582948342897e-01, 9.43339818951269030846e-14,
+	2.95464212893421063200e-01, 4.14813187042585679830e-13,
+	3.01261330577290209476e-01, 8.71571536970835103739e-13,
+	3.07025035294827830512e-01, 8.40315630479242455758e-14,
+	3.12755710003330023028e-01, 5.66865358290073900922e-13,
+	3.18453731118097493891e-01, 4.37121919574291444278e-13,
+	3.24119468653407238889e-01, 8.04737201185162774515e-13,
+	3.29753286371669673827e-01, 7.98307987877335024112e-13,
+	3.35355541920762334485e-01, 3.75495772572598557174e-13,
+	3.40926586970454081893e-01, 1.39128412121975659358e-13,
+	3.46466767346100823488e-01, 1.07757430375726404546e-13,
+	3.51976423156884266064e-01, 2.93918591876480007730e-13,
+	3.57455888921322184615e-01, 4.81589611172320539489e-13,
+	3.62905493689140712377e-01, 2.27740761140395561986e-13,
+	3.68325561158599157352e-01, 1.08495696229679121506e-13,
+	3.73716409792905324139e-01, 6.78756682315870616582e-13,
+	3.79078352934811846353e-01, 1.57612037739694350287e-13,
+	3.84411698910298582632e-01, 3.34571026954408237380e-14,
+	3.89716751139530970249e-01, 4.94243121138567024911e-13,
+	3.94993808240542421117e-01, 3.26556988969071456956e-13,
+	4.00243164126550254878e-01, 4.62452051668403792833e-13,
+	4.05465108107819105498e-01, 3.45276479520397708744e-13,
+	4.10659924984429380856e-01, 8.39005077851830734139e-13,
+	4.15827895143593195826e-01, 1.17769787513692141889e-13,
+	4.20969294643327884842e-01, 8.01751287156832458079e-13,
+	4.26084395310681429692e-01, 2.18633432932159103190e-13,
+	4.31173464818130014464e-01, 2.41326394913331314894e-13,
+	4.36236766774527495727e-01, 3.90574622098307022265e-13,
+	4.41274560804231441580e-01, 6.43787909737320689684e-13,
+	4.46287102628048160113e-01, 3.71351419195920213229e-13,
+	4.51274644138720759656e-01, 7.37825488412103968058e-13,
+	4.56237433480964682531e-01, 6.22911850193784704748e-13,
+	4.61175715121498797089e-01, 6.71369279138460114513e-13,
+	4.66089729924533457961e-01, 6.57665976858006147528e-14,
+	4.70979715218163619284e-01, 6.27393263311115598424e-13,
+	4.75845904869856894948e-01, 1.07019317621142549209e-13,
+	4.80688529345570714213e-01, 1.81193463664411114729e-13,
+	4.85507815781602403149e-01, 9.84046527823262695501e-14,
+	4.90303988044615834951e-01, 5.78003198945402769376e-13,
+	4.95077266797125048470e-01, 7.26466128212511528295e-13,
+	4.99827869555701909121e-01, 7.47420700205478712293e-13,
+	5.04556010751912253909e-01, 4.83033149495532022300e-13,
+	5.09261901789614057634e-01, 1.93889170049107088943e-13,
+	5.13945751101346104406e-01, 8.88212395185718544720e-13,
+	5.18607764207445143256e-01, 6.00488896640545761201e-13,
+	5.23248143764249107335e-01, 2.98729182044413286731e-13,
+	5.27867089620485785417e-01, 3.56599696633478298092e-13,
+	5.32464798869114019908e-01, 3.57823965912763837621e-13,
+	5.37041465896436420735e-01, 4.47233831757482468946e-13,
+	5.41597282432121573947e-01, 6.22797629172251525649e-13,
+	5.46132437597407260910e-01, 7.28389472720657362987e-13,
+	5.50647117952394182794e-01, 2.68096466152116723636e-13,
+	5.55141507539701706264e-01, 7.99886451312335479470e-13,
+	5.59615787935399566777e-01, 2.31194938380053776320e-14,
+	5.64070138284478161950e-01, 3.24804121719935740729e-13,
+	5.68504735351780254859e-01, 8.88457219261483317716e-13,
+	5.72919753561109246220e-01, 6.76262872317054154667e-13,
+	5.77315365034337446559e-01, 4.86157758891509033842e-13,
+	5.81691739634152327199e-01, 4.70155322075549811780e-13,
+	5.86049045003164792433e-01, 4.13416470738355643357e-13,
+	5.90387446602107957006e-01, 6.84176364159146659095e-14,
+	5.94707107746216934174e-01, 4.75855340044306376333e-13,
+	5.99008189645246602595e-01, 8.36796786747576938145e-13,
+	6.03290851438032404985e-01, 5.18573553063418286042e-14,
+	6.07555250224322662689e-01, 2.19132812293400917731e-13,
+	6.11801541105705837253e-01, 2.87066276408616768331e-13,
+	6.16029877214714360889e-01, 7.99658758518543977451e-13,
+	6.20240409751204424538e-01, 6.53104313776336534177e-13,
+	6.24433288011459808331e-01, 4.33692711555820529733e-13,
+	6.28608659421843185555e-01, 5.30952189118357790115e-13,
+	6.32766669570628437214e-01, 4.09392332186786656392e-13,
+	6.36907462236194987781e-01, 8.74243839148582888557e-13,
+	6.41031179420679109171e-01, 2.52181884568428814231e-13,
+	6.45137961372711288277e-01, 8.73413388168702670246e-13,
+	6.49227946624705509748e-01, 4.04309142530119209805e-13,
+	6.53301272011958644725e-01, 7.86994033233553225797e-13,
+	6.57358072708120744210e-01, 2.39285932153437645135e-13,
+	6.61398482245203922503e-01, 1.61085757539324585156e-13,
+	6.65422632544505177066e-01, 5.85271884362515112697e-13,
+	6.69430653942072240170e-01, 5.57027128793880294600e-13,
+	6.73422675211440946441e-01, 7.25773856816637653180e-13,
+	6.77398823590920073912e-01, 8.86066898134949155668e-13,
+	6.81359224807238206267e-01, 6.64862680714687006264e-13,
+	6.85304003098281100392e-01, 6.38316151706465171657e-13,
+	6.89233281238557538018e-01, 2.51442307283760746611e-13,
 };
 
 /*
  * Compute N*log2 + log(1+zk+zh+zt) in extra precision
  */
-static double k_log_NKz(int N, int K, double zh, double *zt)
+static double
+k_log_NKz(int N, int K, double zh, double *zt)
 {
 	double y, r, w, s2, s2h, s2t, t, zk, v, P;
 
 	((int *)&zk)[HIWORD] = 0x3ff00000 + (K << 13);
 	((int *)&zk)[LOWORD] = 0;
-	t  = zh + (*zt);
+	t = zh + (*zt);
 	r = two / (t + two * zk);
 	s2h = s2 = r * t;
 	((int *)&s2h)[LOWORD] &= 0xe0000000;
@@ -237,7 +237,7 @@
 	s2t = r * ((((zh - s2h * zk) - v * zh) + (*zt)) - v * (*zt));
 	P = s2t + (w * s2) * ((P1 + w * P2) + (w * w) * P3);
 	P += N * ln2_t + TBL_log1k[K + K + 1];
-	t = N*ln2_h + TBL_log1k[K+K];
+	t = N * ln2_h + TBL_log1k[K + K];
 	y = t + (P + s2h);
 	P -= ((y - t) - s2h);
 	*zt = P;
@@ -255,42 +255,55 @@
 	lx = ((unsigned *)&x)[LOWORD];
 	iy = (((int *)&y)[HIWORD]) & ~0x80000000;
 	ly = ((unsigned *)&y)[LOWORD];
-	y = fabs(y); x = fabs(x);
-	if (ix < iy || (ix == iy && lx < ly)) {		/* force x >= y */
-		tk = x;  x = y;   y = tk;
-		n = ix, ix = iy; iy = n;
-		n = lx, lx = ly; ly = n;
+	y = fabs(y);
+	x = fabs(x);
+
+	if (ix < iy || (ix == iy && lx < ly)) {	/* force x >= y */
+		tk = x;
+		x = y;
+		y = tk;
+		n = ix, ix = iy;
+		iy = n;
+		n = lx, lx = ly;
+		ly = n;
 	}
+
 	*er = zero;
-	nx = ix >> 20; ny = iy >> 20;
-	if (nx >= 0x7ff) {   	/* x or y is Inf or NaN */
+	nx = ix >> 20;
+	ny = iy >> 20;
+
+	if (nx >= 0x7ff) {		/* x or y is Inf or NaN */
 		if (ISINF(ix, lx))
 			return (x);
 		else if (ISINF(iy, ly))
 			return (y);
 		else
-			return (x+y);
+			return (x + y);
 	}
+
 /*
  * for tiny y (double y < 2^-35, extended y < 2^-46, quad y < 2^-70):
- * 	log(sqrt(1+y^2)) = (y^2)/2 - (y^4)/8 + ... ~= (y^2)/2
+ *      log(sqrt(1+y^2)) = (y^2)/2 - (y^4)/8 + ... ~= (y^2)/2
  */
-	if ((((ix - 0x3ff00000) | lx) == 0) && ny < (0x3ff - 35))  {
+	if ((((ix - 0x3ff00000) | lx) == 0) && ny < (0x3ff - 35)) {
 		t2 = y * y;
+
 		if (ny >= 565) {	/* compute er = tail of t2 */
-			((int *)&wh)[HIWORD] =  iy;
+			((int *)&wh)[HIWORD] = iy;
 			((unsigned *)&wh)[LOWORD] = ly & 0xf8000000;
 			*er = half * ((y - wh) * (y + wh) - (t2 - wh * wh));
 		}
+
 		return (half * t2);
 	}
+
 /*
  * x or y is subnormal or zero
  */
 	if (nx == 0) {
-		if ((ix | lx) == 0)
+		if ((ix | lx) == 0) {
 			return (-1.0 / x);
-		else {
+		} else {
 			x *= two120;
 			y *= two120;
 			ix = ((int *)&x)[HIWORD];
@@ -299,17 +312,20 @@
 			ly = ((unsigned *)&y)[LOWORD];
 			nx = (ix >> 20) - 120;
 			ny = (iy >> 20) - 120;
+
 			/* guard subnormal flush to 0 */
 			if ((ix | lx) == 0)
 				return (-1.0 / x);
 		}
-	} else if (ny == 0) {	/* y subnormal, scale it */
+	} else if (ny == 0) {		/* y subnormal, scale it */
 		y *= two120;
 		iy = ((int *)&y)[HIWORD];
 		ly = ((unsigned *)&y)[LOWORD];
 		ny = (iy >> 20) - 120;
 	}
+
 	n = nx - ny;
+
 /*
  * return log(x) when y is zero or x >> y so that
  * log(x) ~ log(sqrt(x*x+y*y)) to 27 extra bits
@@ -320,17 +336,20 @@
 		((int *)&x)[HIWORD] = i;
 		i += 0x1000;
 		((int *)&zk)[HIWORD] = i & 0xffffe000;
-		((int *)&zk)[LOWORD] = 0;  /* zk matches 7.5 bits of x */
+		((int *)&zk)[LOWORD] = 0;	/* zk matches 7.5 bits of x */
 		z = x - zk;
 		zh = (double)((float)z);
 		i >>= 13;
-		k = i & 0x7f;	/* index of zk */
+		k = i & 0x7f;		/* index of zk */
 		n = nx - 0x3ff;
 		*er = z - zh;
-		if (i >> 17) {	/* if zk = 2.0, adjust scaling */
+
+		if (i >> 17) {		/* if zk = 2.0, adjust scaling */
 			n += 1;
-			zh *= 0.5;  *er *= 0.5;
+			zh *= 0.5;
+			*er *= 0.5;
 		}
+
 		w = k_log_NKz(n, k, zh, er);
 	} else {
 /*
@@ -338,12 +357,15 @@
  */
 		ix = (ix & 0xfffff) | 0x3ff00000;
 		iy = (iy & 0xfffff) | (0x3ff00000 - (n << 20));
-		((int *)&x)[HIWORD] = ix; ((int *)&y)[HIWORD] = iy;
-		t1 = x * x; t2 = y * y;
+		((int *)&x)[HIWORD] = ix;
+		((int *)&y)[HIWORD] = iy;
+		t1 = x * x;
+		t2 = y * y;
 		j = ((lx >> 26) + 1) >> 1;
 		((int *)&wh)[HIWORD] = ix + (j >> 5);
 		((unsigned *)&wh)[LOWORD] = (j << 27);
-		z = t1+t2;
+		z = t1 + t2;
+
 /*
  * higher precision simulation x*x = t1 + t3, y*y = t2 + t4
  */
@@ -354,6 +376,7 @@
 		((unsigned *)&wh)[LOWORD] = (j << 27);
 		tk = wh - y;
 		t4 = tk * tk - (two * wh * tk - (wh * wh - t2));
+
 /*
  * find zk matches z to 7.5 bits
  */
@@ -363,16 +386,22 @@
 		nz = (iz >> 20) - 0x3ff;
 		((int *)&zk)[HIWORD] = iz & 0xffffe000;
 		((int *)&zk)[LOWORD] = 0;
+
 /*
  * order t1,t2,t3,t4 according to their size
  */
 		if (t2 >= fabs(t3)) {
 			if (fabs(t3) < fabs(t4)) {
-				wh = t3;  t3 = t4; t4 = wh;
+				wh = t3;
+				t3 = t4;
+				t4 = wh;
 			}
 		} else {
-			wh = t2; t2 = t3; t3 = wh;
+			wh = t2;
+			t2 = t3;
+			t3 = wh;
 		}
+
 /*
  * higher precision simulation: x * x + y * y = t1 + t2 + t3 + t4
  * = zk (7 bits) + zh (24 bits) + *er (tail) and call k_log_NKz
@@ -381,32 +410,50 @@
 		zh = ((tk + t2) + t3) + t4;
 		((int *)&zh)[LOWORD] &= 0xe0000000;
 		w = fabs(zh);
-		if (w >= fabs(t2))
+
+		if (w >= fabs(t2)) {
 			*er = (((tk - zh) + t2) + t3) + t4;
-		else {
+		} else {
 			if (n == 0) {
 				wh = half * zk;
 				wh = (t1 - wh) - (wh - t2);
-			} else
+			} else {
 				wh = tk + t2;
-			if (w >= fabs(t3))
+			}
+
+			if (w >= fabs(t3)) {
 				*er = ((wh - zh) + t3) + t4;
-			else {
+			} else {
 				z = t3;
 				t3 += t4;
 				t4 -= t3 - z;
+
 				if (w >= fabs(t3))
 					*er = ((wh - zh) + t3) + t4;
 				else
 					*er = ((wh + t3) - zh) + t4;
 			}
 		}
-		if (nz == 3) {zh *= 0.125; *er *= 0.125; }
-		if (nz == 2) {zh *= 0.25; *er *= 0.25; }
-		if (nz == 1) {zh *= half; *er *= half; }
+
+		if (nz == 3) {
+			zh *= 0.125;
+			*er *= 0.125;
+		}
+
+		if (nz == 2) {
+			zh *= 0.25;
+			*er *= 0.25;
+		}
+
+		if (nz == 1) {
+			zh *= half;
+			*er *= half;
+		}
+
 		nz += nx + nx;
 		w = half * k_log_NKz(nz, k, zh, er);
 		*er *= half;
 	}
+
 	return (w);
 }
--- old/usr/src/lib/libm/common/complex/k_clog_rl.c	2019-06-06 20:40:03.835982817 +0000
+++ new/usr/src/lib/libm/common/complex/k_clog_rl.c	2019-06-06 20:40:03.854744861 +0000
@@ -18,19 +18,21 @@
  *
  * CDDL HEADER END
  */
+
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
  */
 
-#include "libm.h"		/* __k_clog_rl */
+#include "libm.h"			/* __k_clog_rl */
 #include "complex_wrapper.h"
 #include "longdouble.h"
 
-/* INDENT OFF */
+
 /*
  * long double __k_clog_rl(long double x, long double y, long double *e);
  *
@@ -74,293 +76,292 @@
  *	  s2h = s2 rounded to double;  v = 0.5*s2h;
  *	  s2t = r*((((zh-s2h*(1+zk))-v*zh)+zt)-v*zt)
  */
-/* INDENT ON */
 
-static const long double
-zero  = 0.0L,
-half  = 0.5L,
-two   = 2.0L,
-two240 = 1.7668470647783843295832975007429185158274839e+72L, /* 2^240 */
+static const long double zero = 0.0L,
+	half = 0.5L,
+	two = 2.0L,
+	two240 = 1.7668470647783843295832975007429185158274839e+72L; /* 2^240 */
 
 /* first 48 bits of ln2 */
-ln2_h  = 0.693147180559943620892227045260369777679443359375L,
-ln2_t  = 1.68852500507619780679039605677498525525412068e-15L,
-P1 = .083333333333333333333333333333333333341023785768375L,
-P2 = .01249999999999999999999999999999679085402075766159375L,
-P3 = .002232142857142857142857143310092047621284490564671875L,
-P4 = .00043402777777777777774746781319264872413156956512109375L,
-P5 = .0000887784090909101756336594019277185263940665468935546875L,
-P6 = .000018780048055589639895360927834628371268354778446533203125L,
-P7 = .000004069227854328982921366736003458838031087153635406494140625L;
+static const long double
+	ln2_h = 0.693147180559943620892227045260369777679443359375L,
+	ln2_t = 1.68852500507619780679039605677498525525412068e-15L,
+	P1 = .083333333333333333333333333333333333341023785768375L,
+	P2 = .01249999999999999999999999999999679085402075766159375L,
+	P3 = .002232142857142857142857143310092047621284490564671875L,
+	P4 = .00043402777777777777774746781319264872413156956512109375L,
+	P5 = .0000887784090909101756336594019277185263940665468935546875L,
+	P6 = .000018780048055589639895360927834628371268354778446533203125L,
+	P7 = .000004069227854328982921366736003458838031087153635406494140625L;
 
 /*
  * T[2k, 2k+1] = log(1+k*2**-7) for k = 0, ..., 2**7 - 1,
  * with T[2k] * 2^48 is an int
  */
-
 static const long double TBL_log1k[] = {
-0.0000000000000000000000000000000000000000e+00L,
-0.0000000000000000000000000000000000000000e+00L,
-7.7821404420532758194894995540380477905273e-03L,
-1.6731279734005070987158875984584325351222e-15L,
-1.5504186535963526694104075431823730468750e-02L,
-1.7274567499706106231054091184928671990316e-15L,
-2.3167059281533397552266251295804977416992e-02L,
-9.8067653290966648493916241687661877474892e-16L,
-3.0771658666751022792595904320478439331055e-02L,
-2.6655784323032762937247606420524589813624e-15L,
-3.8318864302134159061097307130694389343262e-02L,
-2.4401326580179931029010027013316092332340e-15L,
-4.5809536031292452662455616518855094909668e-02L,
-1.7505042236510958082472042641283104263139e-15L,
-5.3244514518809182845870964229106903076172e-02L,
-3.1000199992295574218738634002122149891138e-15L,
-6.0624621816433688081815489567816257476807e-02L,
-1.1544987906424726040058093958345197512800e-15L,
-6.7950661908504628172522643581032752990723e-02L,
-3.1212220426341915966610439115772728417386e-15L,
-7.5223421237584631171557703055441379547119e-02L,
-2.8945270476369282210350897509258766743153e-15L,
-8.2443669211073711267090402543544769287109e-02L,
-8.8000106966612476303662698634483335676886e-16L,
-8.9612158689686083334891009144484996795654e-02L,
-1.0492850604602339995319895311151740799226e-15L,
-9.6729626458550654888313147239387035369873e-02L,
-4.5740725790924807640164516707244620870662e-16L,
-1.0379679368164218544734467286616563796997e-01L,
-1.3793787171308978090503366050174239822054e-15L,
-1.1081436634028918319927470292896032333374e-01L,
-9.3099553146639425160476473362380086036919e-16L,
-1.1778303565638026384476688690483570098877e-01L,
-3.1906940272225656860040797111813146690890e-15L,
-1.2470347850095464536934741772711277008057e-01L,
-2.5904940590976537504984110469214193890052e-15L,
-1.3157635778871679121948545798659324645996e-01L,
-2.4813692306707028899159917911012100567219e-15L,
-1.3840232285911824305912887211889028549194e-01L,
-8.9262619700148275890190121571708972000380e-16L,
-1.4518200984449691759436973370611667633057e-01L,
-9.7968756533003444764719201050911636480025e-16L,
-1.5191604202583874894116888754069805145264e-01L,
-3.2261306345373561864598749471119213018106e-15L,
-1.5860503017663774016909883357584476470947e-01L,
-8.4392427234104999681053621980394827998735e-16L,
-1.6524957289530561865831259638071060180664e-01L,
-1.5442172988528965297119225948270579746101e-15L,
-1.7185025692665689689420105423778295516968e-01L,
-2.3254458978918173643097657009894831132739e-15L,
-1.7840765747281750464026117697358131408691e-01L,
-7.9247913906453736065426776912520942036896e-16L,
-1.8492233849401173984006163664162158966064e-01L,
-2.5282384195601762803134514624610774126020e-16L,
-1.9139485299962899489401024766266345977783e-01L,
-4.5971528855989864541366920731297729269228e-16L,
-1.9782574332991842425144568551331758499146e-01L,
-1.4561111263856836438840838027526567191527e-15L,
-2.0421554142868814096800633706152439117432e-01L,
-2.7505358140491347148810394262840919337709e-15L,
-2.1056476910734645002776233013719320297241e-01L,
-3.1876417904825951583107481283088861928977e-15L,
-2.1687393830061196808856038842350244522095e-01L,
-2.3915305291373208450532580201045871599499e-15L,
-2.2314355131420882116799475625157356262207e-01L,
-9.3459830033405826094075253077304795996257e-16L,
-2.2937410106484534821902343537658452987671e-01L,
-4.8177245728966955534167425511952551974164e-16L,
-2.3556607131276408040321257431060075759888e-01L,
-2.8286743756446304426525380844720043381780e-15L,
-2.4171993688714366044223424978554248809814e-01L,
-1.5077020732661279714120052415509585052975e-15L,
-2.4783616390458007572306087240576744079590e-01L,
-1.1810575418933407573072030113600980623171e-15L,
-2.5391520998096339667426946107298135757446e-01L,
-4.7463053836833625309891834934881898560705e-17L,
-2.5995752443692410338371701072901487350464e-01L,
-1.9635883624838132961710716735786266795913e-15L,
-2.6596354849713677026556979399174451828003e-01L,
-1.1710735561325457988709887923652142233351e-15L,
-2.7193371548364098089223261922597885131836e-01L,
-7.7793943687530702031066421537496360004376e-16L,
-2.7786845100345303194444568362087011337280e-01L,
-3.2742419043493025311197092322146237692165e-15L,
-2.8376817313064250924981024581938982009888e-01L,
-2.0890970909765308649465619266075677112425e-15L,
-2.8963329258304071345264674164354801177979e-01L,
-1.9634262463138821209582240742801727823629e-15L,
-2.9546421289383317798638017848134040832520e-01L,
-2.6984003017275736237868564402005801750600e-15L,
-3.0126133057816062432721082586795091629028e-01L,
-1.1566856647123658045763670687640673680383e-15L,
-3.0702503529490954292668902780860662460327e-01L,
-2.3191484355127267712770857311812090801833e-15L,
-3.1275571000389490450288576539605855941772e-01L,
-1.9838833607942922604727420618882220398852e-15L,
-3.1845373111853447767316538374871015548706e-01L,
-1.3813708182984188944010814590398164268227e-16L,
-3.2411946865421015218089451082050800323486e-01L,
-1.8239097762496144793489474731253815376404e-15L,
-3.2975328637246548169059678912162780761719e-01L,
-2.5001238260227991620033344720809714552230e-15L,
-3.3535554192113536942088103387504816055298e-01L,
-2.4608362985459391180385214539620341910962e-15L,
-3.4092658697059263772644044365733861923218e-01L,
-5.7257864875612301758921090406373771458003e-16L,
-3.4646676734620740489845047704875469207764e-01L,
-1.1760200117113770182586341947822306069951e-15L,
-3.5197642315717558858523261733353137969971e-01L,
-2.5960702148389259075462896448369304790506e-15L,
-3.5745588892180180096147523727267980575562e-01L,
-1.9732645342528682246686790561260072184839e-15L,
-3.6290549368936808605212718248367309570312e-01L,
-3.6708569716349381675043725477739939978160e-16L,
-3.6832556115870573876236448995769023895264e-01L,
-1.9142858656640927085879445412821643247628e-15L,
-3.7371640979358389245135185774415731430054e-01L,
-1.8836966497497166619234389157276681281343e-16L,
-3.7907835293496816575498087331652641296387e-01L,
-1.2926358724723144934459175417385013725801e-15L,
-3.8441169891033055705520382616668939590454e-01L,
-1.4826795862363146014726140088145939341729e-15L,
-3.8971675114002479745067830663174390792847e-01L,
-4.1591978529737177695912258866565331189698e-16L,
-3.9499380824086571806219581048935651779175e-01L,
-3.2600441982258756252505182317625310732365e-15L,
-4.0024316412701210765590076334774494171143e-01L,
-5.9927342433864738622836851475469574662703e-16L,
-4.0546510810816371872533636633306741714478e-01L,
-6.6325267674913128171942721503283748008372e-16L,
-4.1065992498526782128465129062533378601074e-01L,
-5.6464965491255048900165082436455718077885e-16L,
-4.1582789514371043537721561733633279800415e-01L,
-5.3023611327561856950735176370587227509442e-16L,
-4.2096929464412724541944044176489114761353e-01L,
-2.3907094267197419048248363335257046791153e-15L,
-4.2608439531089814522601955104619264602661e-01L,
-1.9178985253285492839728700574592375309985e-15L,
-4.3117346481836804628073878120630979537964e-01L,
-3.2945784336977492852031005044499611665595e-15L,
-4.3623676677491474151793227065354585647583e-01L,
-3.3288311090524075754441878570852962903891e-15L,
-4.4127456080487448275562201160937547683716e-01L,
-7.4673387443005192574852544613692268411229e-16L,
-4.4628710262841764233598951250314712524414e-01L,
-1.8691966006681165218815050615460959199251e-15L,
-4.5127464413945617138779198285192251205444e-01L,
-2.4137569004002270899666314791611479063976e-15L,
-4.5623743348158640742440184112638235092163e-01L,
-1.1869564036970375473975162509216610120281e-15L,
-4.6117571512216670726047595962882041931152e-01L,
-3.4591075239659690349392915732654828400811e-15L,
-4.6608972992459740680715185590088367462158e-01L,
-1.8177514673916038857252366108673570603067e-15L,
-4.7097971521878889689105562865734100341797e-01L,
-2.1156558422273990182479555421331461933366e-15L,
-4.7584590486996347635795245878398418426514e-01L,
-4.3790725712752039722791012358345927696967e-16L,
-4.8068852934575190261057286988943815231323e-01L,
-5.0660455855585733988956280680891477171499e-18L,
-4.8550781578169832641833636444061994552612e-01L,
-2.4813834547127501689550526444948043590905e-15L,
-4.9030398804519137456736643798649311065674e-01L,
-2.4635829797216592537498738468934647345741e-15L,
-4.9507726679784980206022737547755241394043e-01L,
-1.7125377372093652812514167461480115600063e-15L,
-4.9982786955644797899367404170334339141846e-01L,
-1.3508276573735437007500942002018098437396e-15L,
-5.0455601075239187025545106735080480575562e-01L,
-3.4168028574643873701242268618467347998876e-15L,
-5.0926190178980590417268103919923305511475e-01L,
-2.0426313938800290907697638200502614622891e-15L,
-5.1394575110223428282552049495279788970947e-01L,
-3.3975485593321419703400672813719873194659e-17L,
-5.1860776420804555186805373523384332656860e-01L,
-8.0284923261130955371987633083003284697416e-17L,
-5.2324814376454753528378205373883247375488e-01L,
-3.0123302517119603836788558832352723470118e-16L,
-5.2786708962084105678513878956437110900879e-01L,
-1.3283287534282139298545497336570406582397e-15L,
-5.3246479886946929127589100971817970275879e-01L,
-2.5525980327137419625398485590148417041921e-15L,
-5.3704146589688050994482182431966066360474e-01L,
-3.1446219074198341716354190061340477078626e-15L,
-5.4159728243274329884116014000028371810913e-01L,
-1.0727353821639001503808606766770295812627e-15L,
-5.4613243759813556721383065450936555862427e-01L,
-8.3168566554721843605240702438699163825794e-17L,
-5.5064711795266063631970610003918409347534e-01L,
-1.6429402420791657293666192255419538448840e-15L,
-5.5514150754050106684189813677221536636353e-01L,
-5.2587358222274368868380660194332415847228e-16L,
-5.5961578793542088305912329815328121185303e-01L,
-1.8032117652023735453816330571171114110385e-15L,
-5.6407013828480145889443519990891218185425e-01L,
-1.5071769490901812785299634348367857600711e-15L,
-5.6850473535266843327917740680277347564697e-01L,
-2.7879956135806418878792935692629147550413e-16L,
-5.7291975356178426181941176764667034149170e-01L,
-1.2472733449589795907271346997596471822345e-15L,
-5.7731536503482061561953742057085037231445e-01L,
-2.9886985746409486460291929160223207644146e-15L,
-5.8169173963462128540413687005639076232910e-01L,
-1.1971164738836689815783808674399742176950e-15L,
-5.8604904500357690722012193873524665832520e-01L,
-1.3016839974975520776911897855504474452726e-15L,
-5.9038744660217545856539800297468900680542e-01L,
-9.1607651870514890975077236127894522134392e-16L,
-5.9470710774668944509357970673590898513794e-01L,
-3.3444207638397932963480545729233567201211e-15L,
-5.9900818964608149030937056522816419601440e-01L,
-1.9090722294592334873060460706130642200729e-15L,
-6.0329085143808214297678205184638500213623e-01L,
-2.1193638031348149256035110177854940281795e-15L,
-6.0755525022453937822319858241826295852661e-01L,
-2.4172778865703728624133665395876418941354e-15L,
-6.1180154110599005434778518974781036376953e-01L,
-2.8491821045766810044199163148675291775782e-15L,
-6.1602987721551372146677749697118997573853e-01L,
-2.9818078843122551067455400545109858745295e-16L,
-6.2024040975185457114093878772109746932983e-01L,
-2.9577105558448461493874424529516311623184e-15L,
-6.2443328801189323939979658462107181549072e-01L,
-2.6164274215943360130441858075903119505815e-16L,
-6.2860865942237253989333112258464097976685e-01L,
-1.5978509770831895426601797458058854400463e-15L,
-6.3276666957103699928666173946112394332886e-01L,
-8.3025912472904245581515990140161946934461e-16L,
-6.3690746223706895534633076749742031097412e-01L,
-2.7627416365968377888021629180796328536455e-16L,
-6.4103117942092779912854894064366817474365e-01L,
-3.4919270523937617243719652995048419893186e-15L,
-6.4513796137358170312836591619998216629028e-01L,
-2.9985368625799347497396478978681548584217e-15L,
-6.4922794662510696639401430729776620864868e-01L,
-2.8524968256626075449136225882322854909611e-15L,
-6.5330127201274379444839723873883485794067e-01L,
-1.8443102186424720390266302263929355424008e-15L,
-6.5735807270835877602621621917933225631714e-01L,
-1.2541156738040666039091970075936624723645e-15L,
-6.6139848224536379461824253667145967483521e-01L,
-1.2136419933020381912633127333149145382797e-15L,
-6.6542263254508782210905337706208229064941e-01L,
-2.6268410392329445778904988886114643307320e-15L,
-6.6943065394262646350398426875472068786621e-01L,
-2.8037949010021747828222575923191438798877e-15L,
-6.7342267521216570003161905333399772644043e-01L,
-1.0202663413354670195383104149875619397268e-15L,
-6.7739882359180469961756898555904626846313e-01L,
-1.4411921136244383020300914304078010801275e-15L,
-6.8135922480790256372529256623238325119019e-01L,
-5.0522277899333570619054540068138110661023e-16L,
-6.8530400309891703614084690343588590621948e-01L,
-2.3804032011755313470802014258958896193599e-15L,
-6.8923328123880622797514661215245723724365e-01L,
-2.7523497677256621466659891416404053623832e-15L,
+	0.0000000000000000000000000000000000000000e+00L,
+	0.0000000000000000000000000000000000000000e+00L,
+	7.7821404420532758194894995540380477905273e-03L,
+	1.6731279734005070987158875984584325351222e-15L,
+	1.5504186535963526694104075431823730468750e-02L,
+	1.7274567499706106231054091184928671990316e-15L,
+	2.3167059281533397552266251295804977416992e-02L,
+	9.8067653290966648493916241687661877474892e-16L,
+	3.0771658666751022792595904320478439331055e-02L,
+	2.6655784323032762937247606420524589813624e-15L,
+	3.8318864302134159061097307130694389343262e-02L,
+	2.4401326580179931029010027013316092332340e-15L,
+	4.5809536031292452662455616518855094909668e-02L,
+	1.7505042236510958082472042641283104263139e-15L,
+	5.3244514518809182845870964229106903076172e-02L,
+	3.1000199992295574218738634002122149891138e-15L,
+	6.0624621816433688081815489567816257476807e-02L,
+	1.1544987906424726040058093958345197512800e-15L,
+	6.7950661908504628172522643581032752990723e-02L,
+	3.1212220426341915966610439115772728417386e-15L,
+	7.5223421237584631171557703055441379547119e-02L,
+	2.8945270476369282210350897509258766743153e-15L,
+	8.2443669211073711267090402543544769287109e-02L,
+	8.8000106966612476303662698634483335676886e-16L,
+	8.9612158689686083334891009144484996795654e-02L,
+	1.0492850604602339995319895311151740799226e-15L,
+	9.6729626458550654888313147239387035369873e-02L,
+	4.5740725790924807640164516707244620870662e-16L,
+	1.0379679368164218544734467286616563796997e-01L,
+	1.3793787171308978090503366050174239822054e-15L,
+	1.1081436634028918319927470292896032333374e-01L,
+	9.3099553146639425160476473362380086036919e-16L,
+	1.1778303565638026384476688690483570098877e-01L,
+	3.1906940272225656860040797111813146690890e-15L,
+	1.2470347850095464536934741772711277008057e-01L,
+	2.5904940590976537504984110469214193890052e-15L,
+	1.3157635778871679121948545798659324645996e-01L,
+	2.4813692306707028899159917911012100567219e-15L,
+	1.3840232285911824305912887211889028549194e-01L,
+	8.9262619700148275890190121571708972000380e-16L,
+	1.4518200984449691759436973370611667633057e-01L,
+	9.7968756533003444764719201050911636480025e-16L,
+	1.5191604202583874894116888754069805145264e-01L,
+	3.2261306345373561864598749471119213018106e-15L,
+	1.5860503017663774016909883357584476470947e-01L,
+	8.4392427234104999681053621980394827998735e-16L,
+	1.6524957289530561865831259638071060180664e-01L,
+	1.5442172988528965297119225948270579746101e-15L,
+	1.7185025692665689689420105423778295516968e-01L,
+	2.3254458978918173643097657009894831132739e-15L,
+	1.7840765747281750464026117697358131408691e-01L,
+	7.9247913906453736065426776912520942036896e-16L,
+	1.8492233849401173984006163664162158966064e-01L,
+	2.5282384195601762803134514624610774126020e-16L,
+	1.9139485299962899489401024766266345977783e-01L,
+	4.5971528855989864541366920731297729269228e-16L,
+	1.9782574332991842425144568551331758499146e-01L,
+	1.4561111263856836438840838027526567191527e-15L,
+	2.0421554142868814096800633706152439117432e-01L,
+	2.7505358140491347148810394262840919337709e-15L,
+	2.1056476910734645002776233013719320297241e-01L,
+	3.1876417904825951583107481283088861928977e-15L,
+	2.1687393830061196808856038842350244522095e-01L,
+	2.3915305291373208450532580201045871599499e-15L,
+	2.2314355131420882116799475625157356262207e-01L,
+	9.3459830033405826094075253077304795996257e-16L,
+	2.2937410106484534821902343537658452987671e-01L,
+	4.8177245728966955534167425511952551974164e-16L,
+	2.3556607131276408040321257431060075759888e-01L,
+	2.8286743756446304426525380844720043381780e-15L,
+	2.4171993688714366044223424978554248809814e-01L,
+	1.5077020732661279714120052415509585052975e-15L,
+	2.4783616390458007572306087240576744079590e-01L,
+	1.1810575418933407573072030113600980623171e-15L,
+	2.5391520998096339667426946107298135757446e-01L,
+	4.7463053836833625309891834934881898560705e-17L,
+	2.5995752443692410338371701072901487350464e-01L,
+	1.9635883624838132961710716735786266795913e-15L,
+	2.6596354849713677026556979399174451828003e-01L,
+	1.1710735561325457988709887923652142233351e-15L,
+	2.7193371548364098089223261922597885131836e-01L,
+	7.7793943687530702031066421537496360004376e-16L,
+	2.7786845100345303194444568362087011337280e-01L,
+	3.2742419043493025311197092322146237692165e-15L,
+	2.8376817313064250924981024581938982009888e-01L,
+	2.0890970909765308649465619266075677112425e-15L,
+	2.8963329258304071345264674164354801177979e-01L,
+	1.9634262463138821209582240742801727823629e-15L,
+	2.9546421289383317798638017848134040832520e-01L,
+	2.6984003017275736237868564402005801750600e-15L,
+	3.0126133057816062432721082586795091629028e-01L,
+	1.1566856647123658045763670687640673680383e-15L,
+	3.0702503529490954292668902780860662460327e-01L,
+	2.3191484355127267712770857311812090801833e-15L,
+	3.1275571000389490450288576539605855941772e-01L,
+	1.9838833607942922604727420618882220398852e-15L,
+	3.1845373111853447767316538374871015548706e-01L,
+	1.3813708182984188944010814590398164268227e-16L,
+	3.2411946865421015218089451082050800323486e-01L,
+	1.8239097762496144793489474731253815376404e-15L,
+	3.2975328637246548169059678912162780761719e-01L,
+	2.5001238260227991620033344720809714552230e-15L,
+	3.3535554192113536942088103387504816055298e-01L,
+	2.4608362985459391180385214539620341910962e-15L,
+	3.4092658697059263772644044365733861923218e-01L,
+	5.7257864875612301758921090406373771458003e-16L,
+	3.4646676734620740489845047704875469207764e-01L,
+	1.1760200117113770182586341947822306069951e-15L,
+	3.5197642315717558858523261733353137969971e-01L,
+	2.5960702148389259075462896448369304790506e-15L,
+	3.5745588892180180096147523727267980575562e-01L,
+	1.9732645342528682246686790561260072184839e-15L,
+	3.6290549368936808605212718248367309570312e-01L,
+	3.6708569716349381675043725477739939978160e-16L,
+	3.6832556115870573876236448995769023895264e-01L,
+	1.9142858656640927085879445412821643247628e-15L,
+	3.7371640979358389245135185774415731430054e-01L,
+	1.8836966497497166619234389157276681281343e-16L,
+	3.7907835293496816575498087331652641296387e-01L,
+	1.2926358724723144934459175417385013725801e-15L,
+	3.8441169891033055705520382616668939590454e-01L,
+	1.4826795862363146014726140088145939341729e-15L,
+	3.8971675114002479745067830663174390792847e-01L,
+	4.1591978529737177695912258866565331189698e-16L,
+	3.9499380824086571806219581048935651779175e-01L,
+	3.2600441982258756252505182317625310732365e-15L,
+	4.0024316412701210765590076334774494171143e-01L,
+	5.9927342433864738622836851475469574662703e-16L,
+	4.0546510810816371872533636633306741714478e-01L,
+	6.6325267674913128171942721503283748008372e-16L,
+	4.1065992498526782128465129062533378601074e-01L,
+	5.6464965491255048900165082436455718077885e-16L,
+	4.1582789514371043537721561733633279800415e-01L,
+	5.3023611327561856950735176370587227509442e-16L,
+	4.2096929464412724541944044176489114761353e-01L,
+	2.3907094267197419048248363335257046791153e-15L,
+	4.2608439531089814522601955104619264602661e-01L,
+	1.9178985253285492839728700574592375309985e-15L,
+	4.3117346481836804628073878120630979537964e-01L,
+	3.2945784336977492852031005044499611665595e-15L,
+	4.3623676677491474151793227065354585647583e-01L,
+	3.3288311090524075754441878570852962903891e-15L,
+	4.4127456080487448275562201160937547683716e-01L,
+	7.4673387443005192574852544613692268411229e-16L,
+	4.4628710262841764233598951250314712524414e-01L,
+	1.8691966006681165218815050615460959199251e-15L,
+	4.5127464413945617138779198285192251205444e-01L,
+	2.4137569004002270899666314791611479063976e-15L,
+	4.5623743348158640742440184112638235092163e-01L,
+	1.1869564036970375473975162509216610120281e-15L,
+	4.6117571512216670726047595962882041931152e-01L,
+	3.4591075239659690349392915732654828400811e-15L,
+	4.6608972992459740680715185590088367462158e-01L,
+	1.8177514673916038857252366108673570603067e-15L,
+	4.7097971521878889689105562865734100341797e-01L,
+	2.1156558422273990182479555421331461933366e-15L,
+	4.7584590486996347635795245878398418426514e-01L,
+	4.3790725712752039722791012358345927696967e-16L,
+	4.8068852934575190261057286988943815231323e-01L,
+	5.0660455855585733988956280680891477171499e-18L,
+	4.8550781578169832641833636444061994552612e-01L,
+	2.4813834547127501689550526444948043590905e-15L,
+	4.9030398804519137456736643798649311065674e-01L,
+	2.4635829797216592537498738468934647345741e-15L,
+	4.9507726679784980206022737547755241394043e-01L,
+	1.7125377372093652812514167461480115600063e-15L,
+	4.9982786955644797899367404170334339141846e-01L,
+	1.3508276573735437007500942002018098437396e-15L,
+	5.0455601075239187025545106735080480575562e-01L,
+	3.4168028574643873701242268618467347998876e-15L,
+	5.0926190178980590417268103919923305511475e-01L,
+	2.0426313938800290907697638200502614622891e-15L,
+	5.1394575110223428282552049495279788970947e-01L,
+	3.3975485593321419703400672813719873194659e-17L,
+	5.1860776420804555186805373523384332656860e-01L,
+	8.0284923261130955371987633083003284697416e-17L,
+	5.2324814376454753528378205373883247375488e-01L,
+	3.0123302517119603836788558832352723470118e-16L,
+	5.2786708962084105678513878956437110900879e-01L,
+	1.3283287534282139298545497336570406582397e-15L,
+	5.3246479886946929127589100971817970275879e-01L,
+	2.5525980327137419625398485590148417041921e-15L,
+	5.3704146589688050994482182431966066360474e-01L,
+	3.1446219074198341716354190061340477078626e-15L,
+	5.4159728243274329884116014000028371810913e-01L,
+	1.0727353821639001503808606766770295812627e-15L,
+	5.4613243759813556721383065450936555862427e-01L,
+	8.3168566554721843605240702438699163825794e-17L,
+	5.5064711795266063631970610003918409347534e-01L,
+	1.6429402420791657293666192255419538448840e-15L,
+	5.5514150754050106684189813677221536636353e-01L,
+	5.2587358222274368868380660194332415847228e-16L,
+	5.5961578793542088305912329815328121185303e-01L,
+	1.8032117652023735453816330571171114110385e-15L,
+	5.6407013828480145889443519990891218185425e-01L,
+	1.5071769490901812785299634348367857600711e-15L,
+	5.6850473535266843327917740680277347564697e-01L,
+	2.7879956135806418878792935692629147550413e-16L,
+	5.7291975356178426181941176764667034149170e-01L,
+	1.2472733449589795907271346997596471822345e-15L,
+	5.7731536503482061561953742057085037231445e-01L,
+	2.9886985746409486460291929160223207644146e-15L,
+	5.8169173963462128540413687005639076232910e-01L,
+	1.1971164738836689815783808674399742176950e-15L,
+	5.8604904500357690722012193873524665832520e-01L,
+	1.3016839974975520776911897855504474452726e-15L,
+	5.9038744660217545856539800297468900680542e-01L,
+	9.1607651870514890975077236127894522134392e-16L,
+	5.9470710774668944509357970673590898513794e-01L,
+	3.3444207638397932963480545729233567201211e-15L,
+	5.9900818964608149030937056522816419601440e-01L,
+	1.9090722294592334873060460706130642200729e-15L,
+	6.0329085143808214297678205184638500213623e-01L,
+	2.1193638031348149256035110177854940281795e-15L,
+	6.0755525022453937822319858241826295852661e-01L,
+	2.4172778865703728624133665395876418941354e-15L,
+	6.1180154110599005434778518974781036376953e-01L,
+	2.8491821045766810044199163148675291775782e-15L,
+	6.1602987721551372146677749697118997573853e-01L,
+	2.9818078843122551067455400545109858745295e-16L,
+	6.2024040975185457114093878772109746932983e-01L,
+	2.9577105558448461493874424529516311623184e-15L,
+	6.2443328801189323939979658462107181549072e-01L,
+	2.6164274215943360130441858075903119505815e-16L,
+	6.2860865942237253989333112258464097976685e-01L,
+	1.5978509770831895426601797458058854400463e-15L,
+	6.3276666957103699928666173946112394332886e-01L,
+	8.3025912472904245581515990140161946934461e-16L,
+	6.3690746223706895534633076749742031097412e-01L,
+	2.7627416365968377888021629180796328536455e-16L,
+	6.4103117942092779912854894064366817474365e-01L,
+	3.4919270523937617243719652995048419893186e-15L,
+	6.4513796137358170312836591619998216629028e-01L,
+	2.9985368625799347497396478978681548584217e-15L,
+	6.4922794662510696639401430729776620864868e-01L,
+	2.8524968256626075449136225882322854909611e-15L,
+	6.5330127201274379444839723873883485794067e-01L,
+	1.8443102186424720390266302263929355424008e-15L,
+	6.5735807270835877602621621917933225631714e-01L,
+	1.2541156738040666039091970075936624723645e-15L,
+	6.6139848224536379461824253667145967483521e-01L,
+	1.2136419933020381912633127333149145382797e-15L,
+	6.6542263254508782210905337706208229064941e-01L,
+	2.6268410392329445778904988886114643307320e-15L,
+	6.6943065394262646350398426875472068786621e-01L,
+	2.8037949010021747828222575923191438798877e-15L,
+	6.7342267521216570003161905333399772644043e-01L,
+	1.0202663413354670195383104149875619397268e-15L,
+	6.7739882359180469961756898555904626846313e-01L,
+	1.4411921136244383020300914304078010801275e-15L,
+	6.8135922480790256372529256623238325119019e-01L,
+	5.0522277899333570619054540068138110661023e-16L,
+	6.8530400309891703614084690343588590621948e-01L,
+	2.3804032011755313470802014258958896193599e-15L,
+	6.8923328123880622797514661215245723724365e-01L,
+	2.7523497677256621466659891416404053623832e-15L,
 };
 
 /*
  * Compute N*log2 + log(1+zk+zh+zt) in extra precision
  */
-static long double k_log_NKzl(int N, int K, long double zh, long double *zt)
+static long double
+k_log_NKzl(int N, int K, long double zh, long double *zt)
 {
 	long double y, r, w, s2, s2h, s2t, t, zk, v, P;
 	double dzk;
@@ -372,33 +373,32 @@
 
 	((int *)&dzk)[HIWORD] = 0x3ff00000 + (K << 13);
 	((int *)&dzk)[LOWORD] = 0;
-	t  = zh + (*zt);
-	zk = (long double) dzk;
+	t = zh + (*zt);
+	zk = (long double)dzk;
 	r = two / (t + two * zk);
 	s2h = s2 = r * t;
 /* split s2 into correctly rounded half */
 
 #if defined(__x86)
-		((unsigned *)&s2h)[0] = 0;	/* 32 bits chopped */
+	((unsigned *)&s2h)[0] = 0;	/* 32 bits chopped */
 #else
-
-		lx = ((unsigned *)&s2h)[2];	/* 56 bits rounded */
-		j  = ((lx >> 24) + 1) >> 1;
-		((unsigned *)&s2h)[2] = (j << 25);
-		lx = ((unsigned *)&s2h)[1];
-		ly = lx + (j >> 7);
-		((unsigned *)&s2h)[1] = ly;
-		((unsigned *)&s2h)[0] += (ly == 0 && lx != 0);
-		((unsigned *)&s2h)[3] = 0;
+	lx = ((unsigned *)&s2h)[2];	/* 56 bits rounded */
+	j = ((lx >> 24) + 1) >> 1;
+	((unsigned *)&s2h)[2] = (j << 25);
+	lx = ((unsigned *)&s2h)[1];
+	ly = lx + (j >> 7);
+	((unsigned *)&s2h)[1] = ly;
+	((unsigned *)&s2h)[0] += (ly == 0 && lx != 0);
+	((unsigned *)&s2h)[3] = 0;
 #endif
 
 	v = half * s2h;
 	w = s2 * s2;
 	s2t = r * ((((zh - s2h * zk) - v * zh) + (*zt)) - v * (*zt));
-	P = s2t + (w * s2) * ((P1 + w * P2) + (w * w) * ((P3 + w * P4)
-		+ (w * w) * (P5 + w * P6 + (w * w) * P7)));
+	P = s2t + (w * s2) * ((P1 + w * P2) + (w * w) * ((P3 + w * P4) + (w *
+	    w) * (P5 + w * P6 + (w * w) * P7)));
 	P += N * ln2_t + TBL_log1k[K + K + 1];
-	t = N*ln2_h + TBL_log1k[K+K];
+	t = N * ln2_h + TBL_log1k[K + K];
 	y = t + (P + s2h);
 	P -= ((y - t) - s2h);
 	*zt = P;
@@ -419,22 +419,31 @@
 
 	ix = HI_XWORD(x) & ~0x80000000;
 	iy = HI_XWORD(y) & ~0x80000000;
-	y = fabsl(y); x = fabsl(x);
+	y = fabsl(y);
+	x = fabsl(x);
+
 	if (ix < iy || (ix < 0x7fff0000 && ix == iy && x < y)) {
 		/* force x >= y */
-		tk = x;  x = y;   y = tk;
-		n = ix, ix = iy; iy = n;
+		tk = x;
+		x = y;
+		y = tk;
+		n = ix, ix = iy;
+		iy = n;
 	}
+
 	*er = zero;
-	nx = ix >> 16; ny = iy >> 16;
-	if (nx >= 0x7fff) {   	/* x or y is Inf or NaN */
+	nx = ix >> 16;
+	ny = iy >> 16;
+
+	if (nx >= 0x7fff) {		/* x or y is Inf or NaN */
 		if (isinfl(x))
 			return (x);
 		else if (isinfl(y))
 			return (y);
 		else
-			return (x+y);
+			return (x + y);
 	}
+
 /*
  * for tiny y:(double y < 2^-35, extended y < 2^-46, quad y < 2^-70)
  *
@@ -447,41 +456,47 @@
 #endif
 
 		t2 = y * y;
+
 		if (ny >= 8305) {	/* compute er = tail of t2 */
-			dk = (double) y;
+			dk = (double)y;
 
 #if defined(__x86)
 			((unsigned *)&dk)[LOWORD] &= 0xfffe0000;
 #endif
 
-			wh = (long double) dk;
+			wh = (long double)dk;
 			*er = half * ((y - wh) * (y + wh) - (t2 - wh * wh));
 		}
+
 		return (half * t2);
 	}
+
 /*
  * x or y is subnormal or zero
  */
 	if (nx == 0) {
-		if (x == 0.0L)
+		if (x == 0.0L) {
 			return (-1.0L / x);
-		else {
+		} else {
 			x *= two240;
 			y *= two240;
 			ix = HI_XWORD(x);
 			iy = HI_XWORD(y);
 			nx = (ix >> 16) - 240;
 			ny = (iy >> 16) - 240;
+
 			/* guard subnormal flush to 0 */
 			if (x == 0.0L)
 				return (-1.0L / x);
 		}
-	} else if (ny == 0) {	/* y subnormal, scale it */
+	} else if (ny == 0) {		/* y subnormal, scale it */
 		y *= two240;
 		iy = HI_XWORD(y);
 		ny = (iy >> 16) - 240;
 	}
+
 	n = nx - ny;
+
 /*
  * When y is zero or when x >> y, i.e.,  n > 62, 78, 122 for DBLE,
  * EXTENDED, QUAD respectively,
@@ -495,8 +510,8 @@
 #endif
 
 		XFSCALE(x, (0x3fff - (ix >> 16)));
-		i = ((ix & 0xffff) + 0x100) >> 9;  /* 7.5 bits of x */
-		zk = 1.0L + ((long double) i) * 0.0078125L;
+		i = ((ix & 0xffff) + 0x100) >> 9;	/* 7.5 bits of x */
+		zk = 1.0L + ((long double)i) * 0.0078125L;
 		z = x - zk;
 		dk = (double)z;
 
@@ -505,13 +520,16 @@
 #endif
 
 		zh = (long double)dk;
-		k = i & 0x7f;	/* index of zk */
+		k = i & 0x7f;		/* index of zk */
 		n = nx - 0x3fff;
 		*er = z - zh;
+
 		if (i == 0x80) {	/* if zk = 2.0, adjust scaling */
 			n += 1;
-			zh *= 0.5L;  *er *= 0.5L;
+			zh *= 0.5L;
+			*er *= 0.5L;
 		}
+
 		w = k_log_NKzl(n, k, zh, er);
 	} else {
 /*
@@ -522,7 +540,8 @@
 		ix = (ix & 0xffff) | 0x3fff0000;
 		iy = (iy & 0xffff) | (0x3fff0000 - (n << 16));
 		nx -= 0x3fff;
-		t1 = x * x; t2 = y * y;
+		t1 = x * x;
+		t2 = y * y;
 		wh = x;
 
 /* split x into correctly rounded half */
@@ -530,7 +549,7 @@
 		((unsigned *)&wh)[0] = 0;	/* 32 bits chopped */
 #else
 		lx = ((unsigned *)&wh)[2];	/* 56 rounded */
-		j  = ((lx >> 24) + 1) >> 1;
+		j = ((lx >> 24) + 1) >> 1;
 		((unsigned *)&wh)[2] = (j << 25);
 		lx = ((unsigned *)&wh)[1];
 		ly = lx + (j >> 7);
@@ -539,7 +558,8 @@
 		((unsigned *)&wh)[3] = 0;
 #endif
 
-		z = t1+t2;
+		z = t1 + t2;
+
 /*
  * higher precision simulation x*x = t1 + t3, y*y = t2 + t4
  */
@@ -552,7 +572,7 @@
 		((unsigned *)&wh)[0] = 0;	/* 32 bits chopped */
 #else
 		ly = ((unsigned *)&wh)[2];	/* 56 bits rounded */
-		j  = ((ly >> 24) + 1) >> 1;
+		j = ((ly >> 24) + 1) >> 1;
 		((unsigned *)&wh)[2] = (j << 25);
 		lx = ((unsigned *)&wh)[1];
 		ly = lx + (j >> 7);
@@ -563,27 +583,38 @@
 
 		tk = wh - y;
 		t4 = tk * tk - (two * wh * tk - (wh * wh - t2));
+
 /*
  * find zk matches z to 7.5 bits
  */
 		iz = HI_XWORD(z);
-		k = ((iz & 0xffff) + 0x100) >> 9;  /* 7.5 bits of x */
+		k = ((iz & 0xffff) + 0x100) >> 9;	/* 7.5 bits of x */
 		nz = (iz >> 16) - 0x3fff + (k >> 7);
 		k &= 0x7f;
-		zk = 1.0L + ((long double) k) * 0.0078125L;
-		if (nz == 1) zk += zk;
-		else if (nz == 2) zk *= 4.0L;
-		else if (nz == 3) zk *= 8.0L;
+		zk = 1.0L + ((long double)k) * 0.0078125L;
+
+		if (nz == 1)
+			zk += zk;
+		else if (nz == 2)
+			zk *= 4.0L;
+		else if (nz == 3)
+			zk *= 8.0L;
+
 /*
  * order t1, t2, t3, t4 according to their size
  */
 		if (t2 >= fabsl(t3)) {
 			if (fabsl(t3) < fabsl(t4)) {
-				wh = t3;  t3 = t4; t4 = wh;
+				wh = t3;
+				t3 = t4;
+				t4 = wh;
 			}
 		} else {
-			wh = t2; t2 = t3; t3 = wh;
+			wh = t2;
+			t2 = t3;
+			t3 = wh;
 		}
+
 /*
  * higher precision simulation: x * x + y * y = t1 + t2 + t3 + t4
  * = zk(7 bits) + zh(24 bits) + *er(tail) and call k_log_NKz
@@ -596,7 +627,7 @@
 		((unsigned *)&zh)[0] = 0;
 #else
 		ly = ((unsigned *)&zh)[2];
-		j  = ((ly >> 24) + 1) >> 1;
+		j = ((ly >> 24) + 1) >> 1;
 		((unsigned *)&zh)[2] = (j << 25);
 		lx = ((unsigned *)&zh)[1];
 		ly = lx + (j >> 7);
@@ -606,40 +637,46 @@
 #endif
 
 		w = fabsl(zh);
-		if (w >= fabsl(t2))
-{
-			*er = (((tk - zh) + t2) + t3) + t4;
-}
-
-		else {
 
+		if (w >= fabsl(t2)) {
+			*er = (((tk - zh) + t2) + t3) + t4;
+		} else {
 			if (n == 0) {
 				wh = half * zk;
 				wh = (t1 - wh) - (wh - t2);
-			} else
+			} else {
 				wh = tk + t2;
-			if (w >= fabsl(t3))
+			}
+
+			if (w >= fabsl(t3)) {
 				*er = ((wh - zh) + t3) + t4;
-			else {
+			} else {
 				z = t3;
 				t3 += t4;
 				t4 -= t3 - z;
+
 				if (w >= fabsl(t3))
 					*er = ((wh - zh) + t3) + t4;
 				else
 					*er = ((wh + t3) - zh) + t4;
 			}
 		}
+
 		if (nz == 3) {
-			zh *= 0.125L; *er *= 0.125L;
+			zh *= 0.125L;
+			*er *= 0.125L;
 		} else if (nz == 2) {
-			zh *= 0.25L; *er *= 0.25L;
+			zh *= 0.25L;
+			*er *= 0.25L;
 		} else if (nz == 1) {
-			zh *= half; *er *= half;
+			zh *= half;
+			*er *= half;
 		}
+
 		nz += nx + nx;
 		w = half * k_log_NKzl(nz, k, zh, er);
 		*er *= half;
 	}
+
 	return (w);
 }
--- old/usr/src/lib/libm/common/m9x/__fex_hdlr.c	2019-06-06 20:40:04.347409979 +0000
+++ new/usr/src/lib/libm/common/m9x/__fex_hdlr.c	2019-06-06 20:40:04.368085549 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -47,16 +48,18 @@
 #include <sys/procfs.h>
 #endif
 
-/* 2.x signal.h doesn't declare sigemptyset or sigismember
-   if they're #defined (see sys/signal.h) */
+/*
+ * 2.x signal.h doesn't declare sigemptyset or sigismember
+ * if they're #define'd (see sys/signal.h)
+ */
 extern int sigemptyset(sigset_t *);
 extern int sigismember(const sigset_t *, int);
 
 /* external globals */
-void (*__mt_fex_sync)() = NULL; /* for synchronization with libmtsk */
+void (*__mt_fex_sync)() = NULL;		/* for synchronization with libmtsk */
 #pragma weak __mt_fex_sync
 
-void (*__libm_mt_fex_sync)() = NULL; /* new, improved version of above */
+void (*__libm_mt_fex_sync)() = NULL;	/* new, improved version of above */
 #pragma weak __libm_mt_fex_sync
 
 /* private variables */
@@ -64,63 +67,61 @@
 static int handlers_initialized = 0;
 static thread_key_t handlers_key;
 static mutex_t handlers_key_lock = DEFAULTMUTEX;
-
 static struct sigaction oact = { 0, SIG_DFL };
 static mutex_t hdlr_lock = DEFAULTMUTEX;
 static int hdlr_installed = 0;
 
 /* private const data */
 static const int te_bit[FEX_NUM_EXC] = {
-	1 << fp_trap_inexact,
-	1 << fp_trap_division,
-	1 << fp_trap_underflow,
-	1 << fp_trap_overflow,
-	1 << fp_trap_invalid,
-	1 << fp_trap_invalid,
-	1 << fp_trap_invalid,
-	1 << fp_trap_invalid,
-	1 << fp_trap_invalid,
-	1 << fp_trap_invalid,
-	1 << fp_trap_invalid,
-	1 << fp_trap_invalid
+	1 << fp_trap_inexact, 1 << fp_trap_division, 1 << fp_trap_underflow,
+	1 << fp_trap_overflow, 1 << fp_trap_invalid, 1 << fp_trap_invalid,
+	1 << fp_trap_invalid, 1 << fp_trap_invalid, 1 << fp_trap_invalid,
+	1 << fp_trap_invalid, 1 << fp_trap_invalid, 1 << fp_trap_invalid
 };
 
 /*
-*  Return the traps to be enabled given the current handling modes
-*  and flags
-*/
+ *  Return the traps to be enabled given the current handling modes
+ *  and flags
+ */
 static int
 __fex_te_needed(struct fex_handler_data *thr_handlers, unsigned long fsr)
 {
-	int		i, ex, te;
+	int i, ex, te;
 
 	/* set traps for handling modes */
 	te = 0;
+
 	for (i = 0; i < FEX_NUM_EXC; i++)
 		if (thr_handlers[i].__mode != FEX_NONSTOP)
 			te |= te_bit[i];
 
 	/* add traps for retrospective diagnostics */
+
 	if (fex_get_log()) {
 		ex = (int)__fenv_get_ex(fsr);
+
 		if (!(ex & FE_INEXACT))
 			te |= (1 << fp_trap_inexact);
+
 		if (!(ex & FE_UNDERFLOW))
 			te |= (1 << fp_trap_underflow);
+
 		if (!(ex & FE_OVERFLOW))
 			te |= (1 << fp_trap_overflow);
+
 		if (!(ex & FE_DIVBYZERO))
 			te |= (1 << fp_trap_division);
+
 		if (!(ex & FE_INVALID))
 			te |= (1 << fp_trap_invalid);
 	}
 
-	return te;
+	return (te);
 }
 
 /*
-*  The following function synchronizes with libmtsk (SPARC only, for now)
-*/
+ *  The following function synchronizes with libmtsk (SPARC only, for now)
+ */
 static void
 __fex_sync_with_libmtsk(int begin, int master)
 {
@@ -130,38 +131,38 @@
 
 	if (begin) {
 		mutex_lock(&env_lock);
+
 		if (master) {
 			(void) fegetenv(&master_env);
 			env_initialized = 1;
-		}
-		else if (env_initialized)
+		} else if (env_initialized) {
 			(void) fesetenv(&master_env);
+		}
+
 		mutex_unlock(&env_lock);
-	}
-	else if (master && fex_get_log())
+	} else if (master && fex_get_log()) {
 		__fex_update_te();
+	}
 }
 
 /*
-*  The following function may be used for synchronization with any
-*  internal project that manages multiple threads
-*/
+ *  The following function may be used for synchronization with any
+ *  internal project that manages multiple threads
+ */
 enum __libm_mt_fex_sync_actions {
-	__libm_mt_fex_start_master = 0,
-	__libm_mt_fex_start_slave,
-	__libm_mt_fex_finish_master,
-	__libm_mt_fex_finish_slave
+	__libm_mt_fex_start_master = 0, __libm_mt_fex_start_slave,
+	__libm_mt_fex_finish_master, __libm_mt_fex_finish_slave
 };
 
 struct __libm_mt_fex_sync_data {
-	fenv_t	master_env;
-	int		initialized;
-	mutex_t	lock;
+	fenv_t master_env;
+	int initialized;
+	mutex_t lock;
 };
 
 static void
-__fex_sync_with_threads(enum __libm_mt_fex_sync_actions action,
-	struct __libm_mt_fex_sync_data *thr_env)
+__fex_sync_with_threads(enum __libm_mt_fex_sync_actions action, struct
+    __libm_mt_fex_sync_data *thr_env)
 {
 	switch (action) {
 	case __libm_mt_fex_start_master:
@@ -173,8 +174,10 @@
 
 	case __libm_mt_fex_start_slave:
 		mutex_lock(&thr_env->lock);
+
 		if (thr_env->initialized)
 			(void) fesetenv(&thr_env->master_env);
+
 		mutex_unlock(&thr_env->lock);
 		break;
 
@@ -189,9 +192,13 @@
 
 	case __libm_mt_fex_finish_slave:
 #if defined(__x86)
-		/* clear traps, making all accrued flags visible in status word */
+		/*
+		 * clear traps, making all accrued flags visible in status
+		 * word
+		 */
 		{
-			unsigned long   fsr;
+			unsigned long fsr;
+
 			__fenv_getfsr(&fsr);
 			__fenv_set_te(fsr, 0);
 			__fenv_setfsr(&fsr);
@@ -202,37 +209,38 @@
 }
 
 #if defined(__sparc)
-
 /*
-*  Code for setting or clearing interval mode on US-III and above.
-*  This is embedded as data so we don't have to mark the library
-*  as a v8plusb/v9b object.  (I could have just used one entry and
-*  modified the second word to set the bits I want, but that would
-*  have required another mutex.)
-*/
+ *  Code for setting or clearing interval mode on US-III and above.
+ *  This is embedded as data so we don't have to mark the library
+ *  as a v8plusb/v9b object.  (I could have just used one entry and
+ *  modified the second word to set the bits I want, but that would
+ *  have required another mutex.)
+ */
 static const unsigned int siam[][2] = {
-	{ 0x81c3e008, 0x81b01020 }, /* retl, siam 0 */
-	{ 0x81c3e008, 0x81b01024 }, /* retl, siam 4 */
-	{ 0x81c3e008, 0x81b01025 }, /* retl, siam 5 */
-	{ 0x81c3e008, 0x81b01026 }, /* retl, siam 6 */
-	{ 0x81c3e008, 0x81b01027 }  /* retl, siam 7 */
+	{ 0x81c3e008, 0x81b01020 },	/* retl, siam 0 */
+	{ 0x81c3e008, 0x81b01024 },	/* retl, siam 4 */
+	{ 0x81c3e008, 0x81b01025 },	/* retl, siam 5 */
+	{ 0x81c3e008, 0x81b01026 },	/* retl, siam 6 */
+	{ 0x81c3e008, 0x81b01027 }	/* retl, siam 7 */
 };
 
 /*
-*  If a handling mode is in effect, apply it; otherwise invoke the
-*  saved handler
-*/
+ *  If a handling mode is in effect, apply it; otherwise invoke the
+ *  saved handler
+ */
 static void
 __fex_hdlr(int sig, siginfo_t *sip, ucontext_t *uap)
 {
-	struct fex_handler_data	*thr_handlers;
-	struct sigaction	act;
-	void			(*handler)(), (*siamp)();
-	int			mode, i;
-	enum fex_exception	e;
-	fex_info_t		info;
-	unsigned long		fsr, tmpfsr, addr;
-	unsigned int		gsr;
+	struct fex_handler_data *thr_handlers;
+	struct sigaction act;
+
+	void (*handler)(), (*siamp)();
+
+	int mode, i;
+	enum fex_exception e;
+	fex_info_t info;
+	unsigned long fsr, tmpfsr, addr;
+	unsigned int gsr;
 
 	/* determine which exception occurred */
 	switch (sip->si_code) {
@@ -249,8 +257,10 @@
 		e = fex_inexact;
 		break;
 	case FPE_FLTINV:
+
 		if ((int)(e = __fex_get_invalid_type(sip, uap)) < 0)
 			goto not_ieee;
+
 		break;
 	default:
 		/* not an IEEE exception */
@@ -261,6 +271,7 @@
 	mode = FEX_NOHANDLER;
 	handler = oact.sa_handler; /* for log; just looking, no need to lock */
 	thr_handlers = __fex_get_thr_handlers();
+
 	if (thr_handlers && thr_handlers[(int)e].__mode != FEX_NOHANDLER) {
 		mode = thr_handlers[(int)e].__mode;
 		handler = thr_handlers[(int)e].__handler;
@@ -271,11 +282,11 @@
 	__fex_mklog(uap, (char *)sip->si_addr, i, e, mode, (void *)handler);
 
 	/* handle the exception based on the mode */
-	if (mode == FEX_NOHANDLER)
+	if (mode == FEX_NOHANDLER) {
 		goto not_ieee;
-	else if (mode == FEX_ABORT)
+	} else if (mode == FEX_ABORT) {
 		abort();
-	else if (mode == FEX_SIGNAL) {
+	} else if (mode == FEX_SIGNAL) {
 		handler(sig, sip, uap);
 		return;
 	}
@@ -285,23 +296,29 @@
 	__fenv_set_te(fsr, 0);
 	__fenv_set_ex(fsr, 0);
 
-	/* if interval mode was set, clear it, then substitute the
-	   interval rounding direction and clear ns mode in the fsr */
+	/*
+	 * if interval mode was set, clear it, then substitute the interval
+	 * rounding direction and clear ns mode in the fsr
+	 */
 #ifdef __sparcv9
 	gsr = uap->uc_mcontext.asrs[3];
 #else
 	gsr = 0;
+
 	if (uap->uc_mcontext.xrs.xrs_id == XRS_ID)
-		gsr = (*(unsigned long long*)((prxregset_t*)uap->uc_mcontext.
-		    xrs.xrs_ptr)->pr_un.pr_v8p.pr_filler);
+		gsr = (*(unsigned long long *)
+		    ((prxregset_t *)uap->uc_mcontext.xrs.xrs_ptr)->pr_un.
+		    pr_v8p.pr_filler);
 #endif
 	gsr = (gsr >> 25) & 7;
+
 	if (gsr & 4) {
-		siamp = (void (*)()) siam[0];
+		siamp = (void (*)())siam[0];
 		siamp();
 		tmpfsr = fsr;
 		fsr = (fsr & ~0xc0400000ul) | ((gsr & 3) << 30);
 	}
+
 	__fenv_setfsr(&fsr);
 
 	/* decode the operation */
@@ -311,18 +328,21 @@
 	if (mode == FEX_CUSTOM) {
 		/* if we got here from feraiseexcept, pass dummy info */
 		addr = (unsigned long)sip->si_addr;
-		if (addr >= (unsigned long)feraiseexcept &&
-		    addr < (unsigned long)fetestexcept) {
+
+		if (addr >= (unsigned long)feraiseexcept && addr < (unsigned
+		    long)fetestexcept) {
 			info.op = fex_other;
 			info.op1.type = info.op2.type = info.res.type =
 			    fex_nodata;
 		}
 
-		/* restore interval mode if it was set, and put the original
-		   rounding direction and ns mode back in the fsr */
+		/*
+		 * restore interval mode if it was set, and put the original
+		 * rounding direction and ns mode back in the fsr
+		 */
 		if (gsr & 4) {
 			__fenv_setfsr(&tmpfsr);
-			siamp = (void (*)()) siam[1 + (gsr & 3)];
+			siamp = (void (*)())siam[1 + (gsr & 3)];
 			siamp();
 		}
 
@@ -330,9 +350,10 @@
 
 		/* restore modes in case the user's handler changed them */
 		if (gsr & 4) {
-			siamp = (void (*)()) siam[0];
+			siamp = (void (*)())siam[0];
 			siamp();
 		}
+
 		__fenv_setfsr(&fsr);
 	}
 
@@ -352,6 +373,7 @@
 	mutex_lock(&hdlr_lock);
 	act = oact;
 	mutex_unlock(&hdlr_lock);
+
 	switch ((unsigned long)act.sa_handler) {
 	case (unsigned long)SIG_DFL:
 		/* simulate trap with no handler installed */
@@ -366,41 +388,43 @@
 		act.sa_handler(sig, sip, uap);
 	}
 }
-
 #elif defined(__x86)
-
 #if defined(__amd64)
-#define test_sse_hw	1
+#define	test_sse_hw		1
 #else
 extern int _sse_hw;
-#define test_sse_hw	_sse_hw
+
+#define	test_sse_hw		_sse_hw
 #endif
 
 #if !defined(REG_PC)
-#define REG_PC	EIP
+#define	REG_PC			EIP
 #endif
 
 /*
-*  If a handling mode is in effect, apply it; otherwise invoke the
-*  saved handler
-*/
+ *  If a handling mode is in effect, apply it; otherwise invoke the
+ *  saved handler
+ */
 static void
 __fex_hdlr(int sig, siginfo_t *sip, ucontext_t *uap)
 {
-	struct fex_handler_data	*thr_handlers;
-	struct sigaction	act;
-	void			(*handler)() = NULL, (*simd_handler[4])();
-	int			mode, simd_mode[4], i, len, accrued, *ap;
-	unsigned int		cwsw, oldcwsw, mxcsr, oldmxcsr;
-	enum fex_exception	e, simd_e[4];
-	fex_info_t		info, simd_info[4];
-	unsigned long		addr;
-	siginfo_t		osip = *sip;
-	sseinst_t		inst;
+	struct fex_handler_data *thr_handlers;
+	struct sigaction act;
+
+	void (*handler)() = NULL, (*simd_handler[4])();
+
+	int mode, simd_mode[4], i, len, accrued, *ap;
+	unsigned int cwsw, oldcwsw, mxcsr, oldmxcsr;
+	enum fex_exception e, simd_e[4];
+	fex_info_t info, simd_info[4];
+	unsigned long addr;
+	siginfo_t osip = *sip;
+	sseinst_t inst;
 
 	/* check for an exception caused by an SSE instruction */
 	if (!(uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.status & 0x80)) {
 		len = __fex_parse_sse(uap, &inst);
+
 		if (len == 0)
 			goto not_ieee;
 
@@ -417,11 +441,13 @@
 
 			thr_handlers = __fex_get_thr_handlers();
 			addr = (unsigned long)uap->uc_mcontext.gregs[REG_PC];
-			accrued = uap->uc_mcontext.fpregs.fp_reg_set.
-			    fpchip_state.mxcsr;
+			accrued =
+			    uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+			    mxcsr;
 
 			e = (enum fex_exception)-1;
 			mode = FEX_NONSTOP;
+
 			for (i = 0; i < 4; i++) {
 				if ((int)simd_e[i] < 0)
 					continue;
@@ -429,6 +455,7 @@
 				e = simd_e[i];
 				simd_mode[i] = FEX_NOHANDLER;
 				simd_handler[i] = oact.sa_handler;
+
 				if (thr_handlers &&
 				    thr_handlers[(int)e].__mode !=
 				    FEX_NOHANDLER) {
@@ -437,30 +464,39 @@
 					simd_handler[i] =
 					    thr_handlers[(int)e].__handler;
 				}
+
 				accrued &= ~te_bit[(int)e];
+
 				switch (simd_mode[i]) {
 				case FEX_ABORT:
 					mode = FEX_ABORT;
 					break;
 				case FEX_SIGNAL:
+
 					if (mode != FEX_ABORT)
 						mode = FEX_SIGNAL;
+
 					handler = simd_handler[i];
 					break;
 				case FEX_NOHANDLER:
+
 					if (mode != FEX_ABORT && mode !=
 					    FEX_SIGNAL)
 						mode = FEX_NOHANDLER;
+
 					break;
 				}
 			}
+
 			if (e == (enum fex_exception)-1) {
 				__fenv_setcwsw(&oldcwsw);
 				__fenv_setmxcsr(&oldmxcsr);
 				goto not_ieee;
 			}
-			accrued |= uap->uc_mcontext.fpregs.fp_reg_set.
-			    fpchip_state.status;
+
+			accrued |=
+			    uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+			    status;
 			ap = __fex_accrued();
 			accrued |= *ap;
 			accrued &= 0x3d;
@@ -488,6 +524,7 @@
 			}
 
 			*ap = 0;
+
 			for (i = 0; i < 4; i++) {
 				if ((int)simd_e[i] < 0)
 					continue;
@@ -501,6 +538,7 @@
 			}
 
 			__fex_st_simd_result(uap, &inst, simd_e, simd_info);
+
 			for (i = 0; i < 4; i++) {
 				if ((int)simd_e[i] < 0)
 					continue;
@@ -511,19 +549,20 @@
 			if ((int)inst.op & INTREG) {
 				/* set MMX mode */
 #if defined(__amd64)
-				uap->uc_mcontext.fpregs.fp_reg_set.
-				    fpchip_state.sw &= ~0x3800;
-				uap->uc_mcontext.fpregs.fp_reg_set.
-				    fpchip_state.fctw = 0;
+				uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+				    sw &= ~0x3800;
+				uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+				    fctw = 0;
 #else
-				uap->uc_mcontext.fpregs.fp_reg_set.
-				    fpchip_state.state[1] &= ~0x3800;
-				uap->uc_mcontext.fpregs.fp_reg_set.
-				    fpchip_state.state[2] = 0;
+				uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+				    state[1] &= ~0x3800;
+				uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+				    state[2] = 0;
 #endif
 			}
 		} else {
 			e = __fex_get_sse_op(uap, &inst, &info);
+
 			if ((int)e < 0) {
 				__fenv_setcwsw(&oldcwsw);
 				__fenv_setmxcsr(&oldmxcsr);
@@ -533,6 +572,7 @@
 			mode = FEX_NOHANDLER;
 			handler = oact.sa_handler;
 			thr_handlers = __fex_get_thr_handlers();
+
 			if (thr_handlers && thr_handlers[(int)e].__mode !=
 			    FEX_NOHANDLER) {
 				mode = thr_handlers[(int)e].__mode;
@@ -540,10 +580,12 @@
 			}
 
 			addr = (unsigned long)uap->uc_mcontext.gregs[REG_PC];
-			accrued = uap->uc_mcontext.fpregs.fp_reg_set.
-			    fpchip_state.mxcsr & ~te_bit[(int)e];
-			accrued |= uap->uc_mcontext.fpregs.fp_reg_set.
-			    fpchip_state.status;
+			accrued =
+			    uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+			    mxcsr & ~te_bit[(int)e];
+			accrued |=
+			    uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
+			    status;
 			ap = __fex_accrued();
 			accrued |= *ap;
 			accrued &= 0x3d;
@@ -563,12 +605,14 @@
 				return;
 			} else if (mode == FEX_CUSTOM) {
 				*ap = 0;
+
 				if (addr >= (unsigned long)feraiseexcept &&
 				    addr < (unsigned long)fetestexcept) {
 					info.op = fex_other;
 					info.op1.type = info.op2.type =
 					    info.res.type = fex_nodata;
 				}
+
 				handler(1 << (int)e, &info);
 				__fenv_setcwsw(&cwsw);
 				__fenv_setmxcsr(&mxcsr);
@@ -598,6 +642,7 @@
 
 	/* determine which exception occurred */
 	__fex_get_x86_exc(sip, uap);
+
 	switch (sip->si_code) {
 	case FPE_FLTDIV:
 		e = fex_division;
@@ -612,8 +657,10 @@
 		e = fex_inexact;
 		break;
 	case FPE_FLTINV:
+
 		if ((int)(e = __fex_get_invalid_type(sip, uap)) < 0)
 			goto not_ieee;
+
 		break;
 	default:
 		/* not an IEEE exception */
@@ -624,6 +671,7 @@
 	mode = FEX_NOHANDLER;
 	handler = oact.sa_handler; /* for log; just looking, no need to lock */
 	thr_handlers = __fex_get_thr_handlers();
+
 	if (thr_handlers && thr_handlers[(int)e].__mode != FEX_NOHANDLER) {
 		mode = thr_handlers[(int)e].__mode;
 		handler = thr_handlers[(int)e].__handler;
@@ -631,28 +679,30 @@
 
 	/* make an entry in the log of retro. diag. if need be */
 #if defined(__amd64)
-	addr = (unsigned long)uap->uc_mcontext.fpregs.fp_reg_set.
-	    fpchip_state.rip;
+	addr = (unsigned
+	    long)uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.rip;
 #else
-	addr = (unsigned long)uap->uc_mcontext.fpregs.fp_reg_set.
-	    fpchip_state.state[3];
+	addr = (unsigned
+	    long)uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[3];
 #endif
-	accrued = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.status & 
+	accrued = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.status &
 	    ~te_bit[(int)e];
+
 	if (test_sse_hw)
-		accrued |= uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.
-		    mxcsr;
+		accrued |=
+		    uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.mxcsr;
+
 	ap = __fex_accrued();
 	accrued |= *ap;
 	accrued &= 0x3d;
 	__fex_mklog(uap, (char *)addr, accrued, e, mode, (void *)handler);
 
 	/* handle the exception based on the mode */
-	if (mode == FEX_NOHANDLER)
+	if (mode == FEX_NOHANDLER) {
 		goto not_ieee;
-	else if (mode == FEX_ABORT)
+	} else if (mode == FEX_ABORT) {
 		abort();
-	else if (mode == FEX_SIGNAL) {
+	} else if (mode == FEX_SIGNAL) {
 		handler(sig, &osip, uap);
 		return;
 	}
@@ -661,11 +711,13 @@
 	__fenv_getcwsw(&cwsw);
 	cwsw = (cwsw & ~0x3f) | 0x003f0000;
 	__fenv_setcwsw(&cwsw);
+
 	if (test_sse_hw) {
 		__fenv_getmxcsr(&mxcsr);
 		mxcsr = (mxcsr & ~0x3f) | 0x1f80;
 		__fenv_setmxcsr(&mxcsr);
 	}
+
 	*ap = 0;
 
 	/* decode the operation */
@@ -674,8 +726,8 @@
 	/* if a custom mode handler is installed, invoke it */
 	if (mode == FEX_CUSTOM) {
 		/* if we got here from feraiseexcept, pass dummy info */
-		if (addr >= (unsigned long)feraiseexcept &&
-		    addr < (unsigned long)fetestexcept) {
+		if (addr >= (unsigned long)feraiseexcept && addr < (unsigned
+		    long)fetestexcept) {
 			info.op = fex_other;
 			info.op1.type = info.op2.type = info.res.type =
 			    fex_nodata;
@@ -685,6 +737,7 @@
 
 		/* restore modes in case the user's handler changed them */
 		__fenv_setcwsw(&cwsw);
+
 		if (test_sse_hw)
 			__fenv_setmxcsr(&mxcsr);
 	}
@@ -704,18 +757,20 @@
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.cw &= ~i;
 #else
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[1] &= ~0x3d;
-	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[1] |=
-	    (accrued & ~i);
+	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[1] |= (accrued &
+	    ~i);
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[0] |= 0x3d;
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[0] &= ~i;
 #endif
+
 	if (test_sse_hw) {
 		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.mxcsr &= ~0x3d;
 		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.mxcsr |=
 		    0x1e80 | (accrued & ~i);
-		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.mxcsr &=
-		    ~(i << 7);
+		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.mxcsr &= ~(i <<
+		    7);
 	}
+
 	return;
 
 not_ieee:
@@ -723,6 +778,7 @@
 	mutex_lock(&hdlr_lock);
 	act = oact;
 	mutex_unlock(&hdlr_lock);
+
 	switch ((unsigned long)act.sa_handler) {
 	case (unsigned long)SIG_DFL:
 		/* simulate trap with no handler installed */
@@ -737,75 +793,86 @@
 		act.sa_handler(sig, &osip, uap);
 	}
 }
-
 #else
 #error Unknown architecture
 #endif
 
 /*
-*  Return a pointer to the thread-specific handler data, and
-*  initialize it if necessary
-*/
+ *  Return a pointer to the thread-specific handler data, and
+ *  initialize it if necessary
+ */
 struct fex_handler_data *
 __fex_get_thr_handlers()
 {
-	struct fex_handler_data	*ptr;
-	unsigned long			fsr;
-	int						i, te;
+	struct fex_handler_data *ptr;
+	unsigned long fsr;
+	int i, te;
 
 	if (thr_main()) {
 		if (!handlers_initialized) {
-			/* initialize to FEX_NOHANDLER if trap is enabled,
-			   FEX_NONSTOP if trap is disabled */
+			/*
+			 * initialize to FEX_NOHANDLER if trap is enabled,
+			 * FEX_NONSTOP if trap is disabled
+			 */
 			__fenv_getfsr(&fsr);
 			te = (int)__fenv_get_te(fsr);
+
 			for (i = 0; i < FEX_NUM_EXC; i++)
-				main_handlers[i].__mode =
-					((te & te_bit[i])? FEX_NOHANDLER : FEX_NONSTOP);
+				main_handlers[i].__mode = ((te & te_bit[i]) ?
+				    FEX_NOHANDLER : FEX_NONSTOP);
+
 			handlers_initialized = 1;
 		}
-		return main_handlers;
-	}
-	else {
+
+		return (main_handlers);
+	} else {
 		ptr = NULL;
 		mutex_lock(&handlers_key_lock);
+
 		if (thr_getspecific(handlers_key, (void **)&ptr) != 0 &&
-			thr_keycreate(&handlers_key, free) != 0) {
+		    thr_keycreate(&handlers_key, free) != 0) {
 			mutex_unlock(&handlers_key_lock);
-			return NULL;
+			return (NULL);
 		}
+
 		mutex_unlock(&handlers_key_lock);
+
 		if (!ptr) {
-			if ((ptr = (struct fex_handler_data *)
-				malloc(sizeof(fex_handler_t))) == NULL) {
-				return NULL;
-			}
+			if ((ptr = malloc(sizeof (fex_handler_t))) == NULL)
+				return (NULL);
+
 			if (thr_setspecific(handlers_key, (void *)ptr) != 0) {
-				(void)free(ptr);
-				return NULL;
+				(void) free(ptr);
+				return (NULL);
 			}
-			/* initialize to FEX_NOHANDLER if trap is enabled,
-			   FEX_NONSTOP if trap is disabled */
+
+			/*
+			 * initialize to FEX_NOHANDLER if trap is enabled,
+			 * FEX_NONSTOP if trap is disabled
+			 */
 			__fenv_getfsr(&fsr);
 			te = (int)__fenv_get_te(fsr);
+
 			for (i = 0; i < FEX_NUM_EXC; i++)
-				ptr[i].__mode = ((te & te_bit[i])? FEX_NOHANDLER : FEX_NONSTOP);
+				ptr[i].__mode = ((te & te_bit[i]) ?
+				    FEX_NOHANDLER : FEX_NONSTOP);
 		}
-		return ptr;
+
+		return (ptr);
 	}
 }
 
 /*
-*  Update the trap enable bits according to the selected modes
-*/
+ *  Update the trap enable bits according to the selected modes
+ */
 void
 __fex_update_te()
 {
-	struct fex_handler_data	*thr_handlers;
-	struct sigaction		act, tmpact;
-	sigset_t				blocked;
-	unsigned long			fsr;
-	int						te;
+	struct fex_handler_data *thr_handlers;
+	struct sigaction act, tmpact;
+	sigset_t blocked;
+	unsigned long fsr;
+	int te;
 
 	/* determine which traps are needed */
 	thr_handlers = __fex_get_thr_handlers();
@@ -818,18 +885,19 @@
 		sigemptyset(&act.sa_mask);
 		act.sa_flags = SA_SIGINFO;
 		sigaction(SIGFPE, &act, &tmpact);
-		if (tmpact.sa_handler != __fex_hdlr)
-		{
+
+		if (tmpact.sa_handler != __fex_hdlr) {
 			mutex_lock(&hdlr_lock);
 			oact = tmpact;
 			mutex_unlock(&hdlr_lock);
 		}
+
 		hdlr_installed = 1;
 	}
 
 	/* set the new trap enable bits (only if SIGFPE is not blocked) */
-	if (sigprocmask(0, NULL, &blocked) == 0 &&
-		!sigismember(&blocked, SIGFPE)) {
+	if (sigprocmask(0, NULL, &blocked) == 0 && !sigismember(&blocked,
+	    SIGFPE)) {
 		__fenv_set_te(fsr, te);
 		__fenv_setfsr(&fsr);
 	}
--- old/usr/src/lib/libm/common/m9x/__fex_i386.c	2019-06-06 20:40:04.835696295 +0000
+++ new/usr/src/lib/libm/common/m9x/__fex_i386.c	2019-06-06 20:40:04.844765799 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -44,63 +45,73 @@
 #include "fenv_inlines.h"
 
 #if defined(__amd64)
-#define test_sse_hw	1
+#define	test_sse_hw		1
 #else
 /*
  * The following variable lives in libc on Solaris 10, where it
  * gets set to a nonzero value at startup time on systems with SSE.
  */
 extern int _sse_hw;
-#define test_sse_hw	_sse_hw
+
+#define	test_sse_hw		_sse_hw
 #endif
 
 static int accrued = 0;
 static thread_key_t accrued_key;
 static mutex_t accrued_key_lock = DEFAULTMUTEX;
-
 int *
 __fex_accrued()
 {
-	int		*p;
+	int *p;
 
-	if (thr_main())
-		return &accrued;
-	else {
+	if (thr_main()) {
+		return (&accrued);
+	} else {
 		p = NULL;
 		mutex_lock(&accrued_key_lock);
+
 		if (thr_getspecific(accrued_key, (void **)&p) != 0 &&
-			thr_keycreate(&accrued_key, free) != 0) {
+		    thr_keycreate(&accrued_key, free) != 0) {
 			mutex_unlock(&accrued_key_lock);
-			return NULL;
+			return (NULL);
 		}
+
 		mutex_unlock(&accrued_key_lock);
+
 		if (!p) {
-			if ((p = (int*) malloc(sizeof(int))) == NULL)
-				return NULL;
+			if ((p = (int *)malloc(sizeof (int))) == NULL)
+				return (NULL);
+
 			if (thr_setspecific(accrued_key, (void *)p) != 0) {
-				(void)free(p);
-				return NULL;
+				(void) free(p);
+				return (NULL);
 			}
+
 			*p = 0;
 		}
-		return p;
+
+		return (p);
 	}
 }
 
 void
 __fenv_getfsr(unsigned long *fsr)
 {
-	unsigned int	cwsw, mxcsr;
+	unsigned int cwsw, mxcsr;
 
 	__fenv_getcwsw(&cwsw);
 	/* clear reserved bits for no particularly good reason */
 	cwsw &= ~0xe0c00000u;
+
 	if (test_sse_hw) {
-		/* pick up exception flags (excluding denormal operand
-		   flag) from mxcsr */
+		/*
+		 * pick up exception flags (excluding denormal operand flag)
+		 * from mxcsr
+		 */
 		__fenv_getmxcsr(&mxcsr);
 		cwsw |= (mxcsr & 0x3d);
 	}
+
 	cwsw |= *__fex_accrued();
 	*fsr = cwsw ^ 0x003f0000u;
 }
@@ -108,47 +119,53 @@
 void
 __fenv_setfsr(const unsigned long *fsr)
 {
-	unsigned int	cwsw, mxcsr;
-	int				te;
+	unsigned int cwsw, mxcsr;
+	int te;
 
 	/* save accrued exception flags corresponding to enabled exceptions */
 	cwsw = (unsigned int)*fsr;
 	te = __fenv_get_te(cwsw);
 	*__fex_accrued() = cwsw & te;
 	cwsw = (cwsw & ~te) ^ 0x003f0000;
+
 	if (test_sse_hw) {
-		/* propagate rounding direction, masks, and exception flags
-		   (excluding denormal operand mask and flag) to mxcsr */
+		/*
+		 * propagate rounding direction, masks, and exception flags
+		 * (excluding denormal operand mask and flag) to mxcsr
+		 */
 		__fenv_getmxcsr(&mxcsr);
-		mxcsr = (mxcsr & ~0x7ebd) | ((cwsw >> 13) & 0x6000) |
-			((cwsw >> 9) & 0x1e80) | (cwsw & 0x3d);
+		mxcsr = (mxcsr & ~0x7ebd) | ((cwsw >> 13) & 0x6000) | ((cwsw >>
+		    9) & 0x1e80) | (cwsw & 0x3d);
 		__fenv_setmxcsr(&mxcsr);
 	}
+
 	__fenv_setcwsw(&cwsw);
 }
 
 /* Offsets into the fp environment save area (assumes 32-bit protected mode) */
-#define CW	0	/* control word */
-#define SW	1	/* status word */
-#define TW	2	/* tag word */
-#define IP	3	/* instruction pointer */
-#define OP	4	/* opcode */
-#define EA	5	/* operand address */
+#define	CW			0	/* control word */
+#define	SW			1	/* status word */
+#define	TW			2	/* tag word */
+#define	IP			3	/* instruction pointer */
+#define	OP			4	/* opcode */
+#define	EA			5	/* operand address */
 
 /* macro for accessing fp registers in the save area */
 #if defined(__amd64)
-#define fpreg(u,x)	*(long double *)(10*(x)+(char*)&(u)->uc_mcontext.fpregs.fp_reg_set.fpchip_state.st)
+#define	fpreg(u, x)		*(long double *)(10 * (x) + \
+	(char *)&(u)->uc_mcontext.fpregs.fp_reg_set.fpchip_state.st)
 #else
-#define fpreg(u,x)	*(long double *)(10*(x)+(char*)&(u)->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[7])
+#define	fpreg(u, x)		*(long double *)(10 * (x) + \
+	(char *)&(u)->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[7])
 #endif
 
 /*
-*  Fix sip->si_code; the Solaris x86 kernel can get it wrong
-*/
+ *  Fix sip->si_code; the Solaris x86 kernel can get it wrong
+ */
 void
 __fex_get_x86_exc(siginfo_t *sip, ucontext_t *uap)
 {
-	unsigned	sw, cw;
+	unsigned sw, cw;
 
 	sw = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.status;
 #if defined(__amd64)
@@ -156,9 +173,10 @@
 #else
 	cw = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[CW];
 #endif
+
 	if ((sw & FE_INVALID) && !(cw & (1 << fp_trap_invalid)))
 		/* store 0 for stack fault, FPE_FLTINV for IEEE invalid op */
-		sip->si_code = ((sw & 0x40)? 0 : FPE_FLTINV);
+		sip->si_code = ((sw & 0x40) ? 0 : FPE_FLTINV);
 	else if ((sw & FE_DIVBYZERO) && !(cw & (1 << fp_trap_division)))
 		sip->si_code = FPE_FLTDIV;
 	else if ((sw & FE_OVERFLOW) && !(cw & (1 << fp_trap_overflow)))
@@ -174,72 +192,78 @@
 static enum fp_class_type
 my_fp_classf(float *x)
 {
-	int		i = *(int*)x & ~0x80000000;
+	int i = *(int *)x & ~0x80000000;
 
 	if (i < 0x7f800000) {
 		if (i < 0x00800000)
-			return ((i == 0)? fp_zero : fp_subnormal);
-		return fp_normal;
+			return ((i == 0) ? fp_zero : fp_subnormal);
+
+		return (fp_normal);
+	} else if (i == 0x7f800000) {
+		return (fp_infinity);
+	} else if (i & 0x400000) {
+		return (fp_quiet);
+	} else {
+		return (fp_signaling);
 	}
-	else if (i == 0x7f800000)
-		return fp_infinity;
-	else if (i & 0x400000)
-		return fp_quiet;
-	else
-		return fp_signaling;
 }
 
 static enum fp_class_type
 my_fp_class(double *x)
 {
-	int		i = *(1+(int*)x) & ~0x80000000;
+	int i = *(1 + (int *)x) & ~0x80000000;
 
 	if (i < 0x7ff00000) {
 		if (i < 0x00100000)
-			return (((i | *(int*)x) == 0)? fp_zero : fp_subnormal);
-		return fp_normal;
+			return (((i | *(int *)x) == 0) ? fp_zero :
+			    fp_subnormal);
+
+		return (fp_normal);
+	} else if (i == 0x7ff00000 && *(int *)x == 0) {
+		return (fp_infinity);
+	} else if (i & 0x80000) {
+		return (fp_quiet);
+	} else {
+		return (fp_signaling);
 	}
-	else if (i == 0x7ff00000 && *(int*)x == 0)
-		return fp_infinity;
-	else if (i & 0x80000)
-		return fp_quiet;
-	else
-		return fp_signaling;
 }
 
 static enum fp_class_type
 my_fp_classl(long double *x)
 {
-	int		i = *(2+(int*)x) & 0x7fff;
+	int i = *(2 + (int *)x) & 0x7fff;
 
 	if (i < 0x7fff) {
 		if (i < 1) {
-			if (*(1+(int*)x) < 0) return fp_normal; /* pseudo-denormal */
-			return (((*(1+(int*)x) | *(int*)x) == 0)?
-				fp_zero : fp_subnormal);
+			if (*(1 + (int *)x) < 0)
+				return (fp_normal);	/* pseudo-denormal */
+
+			return (((*(1 + (int *)x) | *(int *)x) == 0) ? fp_zero :
+			    fp_subnormal);
 		}
-		return ((*(1+(int*)x) < 0)? fp_normal :
-			(enum fp_class_type) -1); /* unsupported format */
+
+		return ((*(1 + (int *)x) < 0) ? fp_normal :
+		    (enum fp_class_type)-1);	/* unsupported format */
+	} else if (*(1 + (int *)x) == 0x80000000 && *(int *)x == 0) {
+		return (fp_infinity);
+	} else if (*(1 + (unsigned *)x) >= 0xc0000000) {
+		return (fp_quiet);
+	} else if (*(1 + (int *)x) < 0) {
+		return (fp_signaling);
+	} else {
+		return ((enum fp_class_type)-1);	/* unsupported format */
 	}
-	else if (*(1+(int*)x) == 0x80000000 && *(int*)x == 0)
-		return fp_infinity;
-	else if (*(1+(unsigned*)x) >= 0xc0000000)
-		return fp_quiet;
-	else if (*(1+(int*)x) < 0)
-		return fp_signaling;
-	else
-		return (enum fp_class_type) -1; /* unsupported format */
 }
 
 /*
-*  Determine which type of invalid operation exception occurred
-*/
+ *  Determine which type of invalid operation exception occurred
+ */
 enum fex_exception
 __fex_get_invalid_type(siginfo_t *sip, ucontext_t *uap)
 {
-	unsigned			op;
-	unsigned long			ea;
-	enum fp_class_type	t1, t2;
+	unsigned op;
+	unsigned long ea;
+	enum fp_class_type t1, t2;
 
 	/* get the opcode and data address */
 #if defined(__amd64)
@@ -250,8 +274,10 @@
 	ea = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[EA];
 #endif
 
-	/* if the instruction is fld, the source must be snan (it can't be
-	   an unsupported format, since fldt doesn't raise any exceptions) */
+	/*
+	 * if the instruction is fld, the source must be snan (it can't be
+	 * an unsupported format, since fldt doesn't raise any exceptions)
+	 */
 	switch (op & 0x7f8) {
 	case 0x100:
 	case 0x140:
@@ -259,18 +285,20 @@
 	case 0x500:
 	case 0x540:
 	case 0x580:
-		return fex_inv_snan;
+		return (fex_inv_snan);
 	}
 
 	/* otherwise st is one of the operands; see if it's snan */
 	t1 = my_fp_classl(&fpreg(uap, 0));
+
 	if (t1 == fp_signaling)
-		return fex_inv_snan;
-	else if (t1 == (enum fp_class_type) -1)
-		return (enum fex_exception) -1;
+		return (fex_inv_snan);
+	else if (t1 == (enum fp_class_type)-1)
+		return ((enum fex_exception)-1);
 
 	/* determine the class of the second operand if there is one */
 	t2 = fp_normal;
+
 	switch (op & 0x7e0) {
 	case 0x600:
 	case 0x620:
@@ -278,11 +306,14 @@
 	case 0x660:
 	case 0x680:
 	case 0x6a0:
+
 		/* short memory operand */
 		if (!ea)
-			return (enum fex_exception) -1;
+			return ((enum fex_exception)-1);
+
 		if (*(short *)ea == 0)
 			t2 = fp_zero;
+
 		break;
 
 	case 0x200:
@@ -291,11 +322,14 @@
 	case 0x260:
 	case 0x280:
 	case 0x2a0:
+
 		/* int memory operand */
 		if (!ea)
-			return (enum fex_exception) -1;
+			return ((enum fex_exception)-1);
+
 		if (*(int *)ea == 0)
 			t2 = fp_zero;
+
 		break;
 
 	case 0x000:
@@ -304,9 +338,11 @@
 	case 0x060:
 	case 0x080:
 	case 0x0a0:
+
 		/* single precision memory operand */
 		if (!ea)
-			return (enum fex_exception) -1;
+			return ((enum fex_exception)-1);
+
 		t2 = my_fp_classf((float *)ea);
 		break;
 
@@ -316,9 +352,11 @@
 	case 0x460:
 	case 0x480:
 	case 0x4a0:
+
 		/* double precision memory operand */
 		if (!ea)
-			return (enum fex_exception) -1;
+			return ((enum fex_exception)-1);
+
 		t2 = my_fp_class((double *)ea);
 		break;
 
@@ -331,6 +369,7 @@
 	case 0x6c0:
 	case 0x6e0:
 	case 0x7e0:
+
 		/* register operand determined by opcode */
 		switch (op & 0x7f8) {
 		case 0x3e0:
@@ -345,30 +384,33 @@
 		default:
 			t2 = my_fp_classl(&fpreg(uap, op & 7));
 		}
+
 		break;
 
 	case 0x1e0:
 	case 0x2e0:
+
 		/* special forms */
 		switch (op) {
-		case 0x1f1: /* fyl2x */
-		case 0x1f3: /* fpatan */
-		case 0x1f5: /* fprem1 */
-		case 0x1f8: /* fprem */
-		case 0x1f9: /* fyl2xp1 */
-		case 0x1fd: /* fscale */
-		case 0x2e9: /* fucompp */
+		case 0x1f1:		/* fyl2x */
+		case 0x1f3:		/* fpatan */
+		case 0x1f5:		/* fprem1 */
+		case 0x1f8:		/* fprem */
+		case 0x1f9:		/* fyl2xp1 */
+		case 0x1fd:		/* fscale */
+		case 0x2e9:		/* fucompp */
 			t2 = my_fp_classl(&fpreg(uap, 1));
 			break;
 		}
+
 		break;
 	}
 
 	/* see if the second op is snan */
 	if (t2 == fp_signaling)
-		return fex_inv_snan;
-	else if (t2 == (enum fp_class_type) -1)
-		return (enum fex_exception) -1;
+		return (fex_inv_snan);
+	else if (t2 == (enum fp_class_type)-1)
+		return ((enum fex_exception)-1);
 
 	/* determine the type of operation */
 	switch (op & 0x7f8) {
@@ -399,9 +441,11 @@
 	case 0x6c0:
 	case 0x6e0:
 	case 0x6e8:
+
 		/* fadd, fsub, fsubr */
 		if (t1 == fp_infinity && t2 == fp_infinity)
-			return fex_inv_isi;
+			return (fex_inv_isi);
+
 		break;
 
 	case 0x008:
@@ -419,10 +463,12 @@
 	case 0x648:
 	case 0x688:
 	case 0x6c8:
+
 		/* fmul */
 		if ((t1 == fp_zero && t2 == fp_infinity) || (t2 == fp_zero &&
-		  t1 == fp_infinity))
-			return fex_inv_zmi;
+		    t1 == fp_infinity))
+			return (fex_inv_zmi);
+
 		break;
 
 	case 0x030:
@@ -455,17 +501,19 @@
 	case 0x6b8:
 	case 0x6f0:
 	case 0x6f8:
+
 		/* fdiv */
 		if (t1 == fp_zero && t2 == fp_zero)
-			return fex_inv_zdz;
+			return (fex_inv_zdz);
 		else if (t1 == fp_infinity && t2 == fp_infinity)
-			return fex_inv_idi;
+			return (fex_inv_idi);
+
 		break;
 
 	case 0x1f0:
 	case 0x1f8:
 		/* fsqrt, other special ops */
-		return fex_inv_sqrt;
+		return (fex_inv_sqrt);
 
 	case 0x010:
 	case 0x018:
@@ -502,15 +550,19 @@
 	case 0x6d0:
 	case 0x6d8:
 	case 0x7f0:
+
 		/* fcom */
 		if (t1 == fp_quiet || t2 == fp_quiet)
-			return fex_inv_cmp;
+			return (fex_inv_cmp);
+
 		break;
 
 	case 0x1e0:
+
 		/* ftst */
 		if (op == 0x1e4 && t1 == fp_quiet)
-			return fex_inv_cmp;
+			return (fex_inv_cmp);
+
 		break;
 
 	case 0x310:
@@ -532,18 +584,22 @@
 	case 0x7b0:
 	case 0x7b8:
 		/* fist, fbst */
-		return fex_inv_int;
+		return (fex_inv_int);
 	}
 
-	return (enum fex_exception) -1;
+	return ((enum fex_exception)-1);
 }
 
 /* scale factors for exponent unwrapping */
+/* 2^12288 */
+static const long double
+    two12288 = 1.139165225263043370845938579315932009e+3699l;
+/* 2^-12288 */
 static const long double
-	two12288 = 1.139165225263043370845938579315932009e+3699l,	/* 2^12288 */
-	twom12288 = 8.778357852076208839765066529179033145e-3700l,	/* 2^-12288 */
-	twom12288mulp = 8.778357852076208839289190796475222545e-3700l;
-		/* (")*(1-2^-64) */
+    twom12288 = 8.778357852076208839765066529179033145e-3700l;
+/* (")*(1-2^-64) */
+static const long double
+    twom12288mulp = 8.778357852076208839289190796475222545e-3700l;
 
 /* inline templates */
 extern long double f2xm1(long double);
@@ -562,17 +618,17 @@
 extern long double fcos(long double);
 
 /*
-*  Get the operands, generate the default untrapped result with
-*  exceptions, and set a code indicating the type of operation
-*/
+ *  Get the operands, generate the default untrapped result with
+ *  exceptions, and set a code indicating the type of operation
+ */
 void
 __fex_get_op(siginfo_t *sip, ucontext_t *uap, fex_info_t *info)
 {
-	fex_numeric_t			t;
-	long double			op2v, x;
-	unsigned int			cwsw, ex, sw, op;
-	unsigned long			ea;
-	volatile int			c __unused;
+	fex_numeric_t t;
+	long double op2v, x;
+	unsigned int cwsw, ex, sw, op;
+	unsigned long ea;
+	volatile int c __unused;
 
 	/* get the exception type, status word, opcode, and data address */
 	ex = sip->si_code;
@@ -585,43 +641,52 @@
 	ea = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[EA];
 #endif
 
-	/* initialize res to the default untrapped result and ex to the
-	   corresponding flags (assume trapping is disabled and flags
-	   are clear) */
+	/*
+	 * initialize res to the default untrapped result and ex to the
+	 * corresponding flags (assume trapping is disabled and flags are
+	 * clear)
+	 */
 
 	/* single operand instructions */
 	info->op = fex_cnvt;
 	info->op2.type = fex_nodata;
+
 	switch (op & 0x7f8) {
 	/* load instructions */
 	case 0x100:
 	case 0x140:
 	case 0x180:
+
 		if (!ea) {
 			info->op = fex_other;
-			info->op1.type = info->op2.type = info->res.type = fex_nodata;
+			info->op1.type = info->op2.type = info->res.type =
+			    fex_nodata;
 			info->flags = 0;
 			return;
 		}
+
 		info->op1.type = fex_float;
 		info->op1.val.f = *(float *)ea;
 		info->res.type = fex_ldouble;
-		info->res.val.q = (long double) info->op1.val.f;
+		info->res.val.q = (long double)info->op1.val.f;
 		goto done;
 
 	case 0x500:
 	case 0x540:
 	case 0x580:
+
 		if (!ea) {
 			info->op = fex_other;
-			info->op1.type = info->op2.type = info->res.type = fex_nodata;
+			info->op1.type = info->op2.type = info->res.type =
+			    fex_nodata;
 			info->flags = 0;
 			return;
 		}
+
 		info->op1.type = fex_double;
 		info->op1.val.d = *(double *)ea;
 		info->res.type = fex_ldouble;
-		info->res.val.q = (long double) info->op1.val.d;
+		info->res.val.q = (long double)info->op1.val.d;
 		goto done;
 
 	/* store instructions */
@@ -632,22 +697,26 @@
 	case 0x190:
 	case 0x198:
 		info->res.type = fex_float;
+
 		if (ex == FPE_FLTRES && (op & 8) != 0) {
 			/* inexact, stack popped */
 			if (!ea) {
 				info->op = fex_other;
-				info->op1.type = info->op2.type = info->res.type = fex_nodata;
+				info->op1.type = info->op2.type =
+				    info->res.type = fex_nodata;
 				info->flags = 0;
 				return;
 			}
+
 			info->op1.type = fex_nodata;
 			info->res.val.f = *(float *)ea;
 			info->flags = FE_INEXACT;
 			return;
 		}
+
 		info->op1.type = fex_ldouble;
 		info->op1.val.q = fpreg(uap, 0);
-		info->res.val.f = (float) info->op1.val.q;
+		info->res.val.f = (float)info->op1.val.q;
 		goto done;
 
 	case 0x310:
@@ -657,22 +726,26 @@
 	case 0x390:
 	case 0x398:
 		info->res.type = fex_int;
+
 		if (ex == FPE_FLTRES && (op & 8) != 0) {
 			/* inexact, stack popped */
 			if (!ea) {
 				info->op = fex_other;
-				info->op1.type = info->op2.type = info->res.type = fex_nodata;
+				info->op1.type = info->op2.type =
+				    info->res.type = fex_nodata;
 				info->flags = 0;
 				return;
 			}
+
 			info->op1.type = fex_nodata;
 			info->res.val.i = *(int *)ea;
 			info->flags = FE_INEXACT;
 			return;
 		}
+
 		info->op1.type = fex_ldouble;
 		info->op1.val.q = fpreg(uap, 0);
-		info->res.val.i = (int) info->op1.val.q;
+		info->res.val.i = (int)info->op1.val.q;
 		goto done;
 
 	case 0x510:
@@ -682,22 +755,26 @@
 	case 0x590:
 	case 0x598:
 		info->res.type = fex_double;
+
 		if (ex == FPE_FLTRES && (op & 8) != 0) {
 			/* inexact, stack popped */
 			if (!ea) {
 				info->op = fex_other;
-				info->op1.type = info->op2.type = info->res.type = fex_nodata;
+				info->op1.type = info->op2.type =
+				    info->res.type = fex_nodata;
 				info->flags = 0;
 				return;
 			}
+
 			info->op1.type = fex_nodata;
 			info->res.val.d = *(double *)ea;
 			info->flags = FE_INEXACT;
 			return;
 		}
+
 		info->op1.type = fex_ldouble;
 		info->op1.val.q = fpreg(uap, 0);
-		info->res.val.d = (double) info->op1.val.q;
+		info->res.val.d = (double)info->op1.val.q;
 		goto done;
 
 	case 0x710:
@@ -707,22 +784,26 @@
 	case 0x790:
 	case 0x798:
 		info->res.type = fex_int;
+
 		if (ex == FPE_FLTRES && (op & 8) != 0) {
 			/* inexact, stack popped */
 			if (!ea) {
 				info->op = fex_other;
-				info->op1.type = info->op2.type = info->res.type = fex_nodata;
+				info->op1.type = info->op2.type =
+				    info->res.type = fex_nodata;
 				info->flags = 0;
 				return;
 			}
+
 			info->op1.type = fex_nodata;
 			info->res.val.i = *(short *)ea;
 			info->flags = FE_INEXACT;
 			return;
 		}
+
 		info->op1.type = fex_ldouble;
 		info->op1.val.q = fpreg(uap, 0);
-		info->res.val.i = (short) info->op1.val.q;
+		info->res.val.i = (short)info->op1.val.q;
 		goto done;
 
 	case 0x730:
@@ -738,36 +819,43 @@
 	case 0x778:
 	case 0x7b8:
 		info->res.type = fex_llong;
+
 		if (ex == FPE_FLTRES) {
 			/* inexact, stack popped */
 			if (!ea) {
 				info->op = fex_other;
-				info->op1.type = info->op2.type = info->res.type = fex_nodata;
+				info->op1.type = info->op2.type =
+				    info->res.type = fex_nodata;
 				info->flags = 0;
 				return;
 			}
+
 			info->op1.type = fex_nodata;
 			info->res.val.l = *(long long *)ea;
 			info->flags = FE_INEXACT;
 			return;
 		}
+
 		info->op1.type = fex_ldouble;
 		info->op1.val.q = fpreg(uap, 0);
-		info->res.val.l = (long long) info->op1.val.q;
+		info->res.val.l = (long long)info->op1.val.q;
 		goto done;
 	}
 
-	/* all other ops (except compares) have destinations on the stack
-	   so overflow, underflow, and inexact will stomp their operands */
+	/*
+	 * all other ops (except compares) have destinations on the stack so
+	 * overflow, underflow, and inexact will stomp their operands
+	 */
 	if (ex == FPE_FLTOVF || ex == FPE_FLTUND || ex == FPE_FLTRES) {
 		/* find the trapped result */
 		info->op1.type = info->op2.type = fex_nodata;
 		info->res.type = fex_ldouble;
+
 		switch (op & 0x7f8) {
 		case 0x1f0:
 			/* fptan pushes 1.0 afterward, so result is in st(1) */
-			info->res.val.q = ((op == 0x1f2)? fpreg(uap, 1) :
-				fpreg(uap, 0));
+			info->res.val.q = ((op == 0x1f2) ? fpreg(uap, 1) :
+			    fpreg(uap, 0));
 			break;
 
 		case 0x4c0:
@@ -797,53 +885,59 @@
 		if (ex == FPE_FLTOVF) {
 			/* generate an overflow with the sign of the result */
 			x = two12288;
-			*(4+(short*)&x) |= (*(4+(short*)&info->res.val.q) & 0x8000);
+			*(4 + (short *)&x) |= (*(4 +
+			    (short *)&info->res.val.q) & 0x8000);
 			info->res.val.q = x * two12288;
 			info->flags = FE_OVERFLOW | FE_INEXACT;
 			__fenv_getcwsw(&cwsw);
 			cwsw &= ~FE_ALL_EXCEPT;
 			__fenv_setcwsw(&cwsw);
-		}
-		else if (ex == FPE_FLTUND) {
-			/* undo the scaling; we can't distinguish a chopped result
-			   from an exact one without futzing around to trap all in-
-			   exact exceptions so as to keep the flag clear, so we just
-			   punt */
-			if (sw & 0x200) /* result was rounded up */
-				info->res.val.q = (info->res.val.q * twom12288) * twom12288mulp;
+		} else if (ex == FPE_FLTUND) {
+			/*
+			 * undo the scaling; we can't distinguish a chopped
+			 * result from an exact one without futzing around to
+			 * trap all in- exact exceptions so as to keep the
+			 * flag clear, so we just punt
+			 */
+			if (sw & 0x200)	/* result was rounded up */
+				info->res.val.q = (info->res.val.q *
+				    twom12288) * twom12288mulp;
 			else
-				info->res.val.q = (info->res.val.q * twom12288) * twom12288;
+				info->res.val.q = (info->res.val.q *
+				    twom12288) * twom12288;
+
 			__fenv_getcwsw(&cwsw);
 			info->flags = (cwsw & FE_INEXACT) | FE_UNDERFLOW;
 			cwsw &= ~FE_ALL_EXCEPT;
 			__fenv_setcwsw(&cwsw);
-		}
-		else
+		} else {
 			info->flags = FE_INEXACT;
+		}
 
 		/* determine the operation code */
 		switch (op) {
-		case 0x1f0: /* f2xm1 */
-		case 0x1f1: /* fyl2x */
-		case 0x1f2: /* fptan */
-		case 0x1f3: /* fpatan */
-		case 0x1f5: /* fprem1 */
-		case 0x1f8: /* fprem */
-		case 0x1f9: /* fyl2xp1 */
-		case 0x1fb: /* fsincos */
-		case 0x1fc: /* frndint */
-		case 0x1fd: /* fscale */
-		case 0x1fe: /* fsin */
-		case 0x1ff: /* fcos */
+		case 0x1f0:		/* f2xm1 */
+		case 0x1f1:		/* fyl2x */
+		case 0x1f2:		/* fptan */
+		case 0x1f3:		/* fpatan */
+		case 0x1f5:		/* fprem1 */
+		case 0x1f8:		/* fprem */
+		case 0x1f9:		/* fyl2xp1 */
+		case 0x1fb:		/* fsincos */
+		case 0x1fc:		/* frndint */
+		case 0x1fd:		/* fscale */
+		case 0x1fe:		/* fsin */
+		case 0x1ff:		/* fcos */
 			info->op = fex_other;
 			return;
 
-		case 0x1fa: /* fsqrt */
+		case 0x1fa:		/* fsqrt */
 			info->op = fex_sqrt;
 			return;
 		}
 
 		info->op = fex_other;
+
 		switch (op & 0x7c0) {
 		case 0x000:
 		case 0x040:
@@ -860,6 +954,7 @@
 		case 0x640:
 		case 0x680:
 		case 0x6c0:
+
 			switch (op & 0x38) {
 			case 0x00:
 				info->op = fex_add;
@@ -880,11 +975,14 @@
 				break;
 			}
 		}
+
 		return;
 	}
 
-	/* for other exceptions, the operands are preserved, so we can
-	   just emulate the operation with traps disabled */
+	/*
+	 * for other exceptions, the operands are preserved, so we can just
+	 * emulate the operation with traps disabled
+	 */
 
 	/* one operand is always in st */
 	info->op1.type = fex_ldouble;
@@ -892,8 +990,9 @@
 
 	/* oddball instructions */
 	info->op = fex_other;
+
 	switch (op) {
-	case 0x1e4: /* ftst */
+	case 0x1e4:			/* ftst */
 		info->op = fex_cmp;
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = 0.0l;
@@ -901,90 +1000,90 @@
 		c = (info->op1.val.q < info->op2.val.q);
 		goto done;
 
-	case 0x1f0: /* f2xm1 */
+	case 0x1f0:			/* f2xm1 */
 		info->res.type = fex_ldouble;
 		info->res.val.q = f2xm1(info->op1.val.q);
 		goto done;
 
-	case 0x1f1: /* fyl2x */
+	case 0x1f1:			/* fyl2x */
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, 1);
 		info->res.type = fex_ldouble;
 		info->res.val.q = fyl2x(info->op1.val.q, info->op2.val.q);
 		goto done;
 
-	case 0x1f2: /* fptan */
+	case 0x1f2:			/* fptan */
 		info->res.type = fex_ldouble;
 		info->res.val.q = fptan(info->op1.val.q);
 		goto done;
 
-	case 0x1f3: /* fpatan */
+	case 0x1f3:			/* fpatan */
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, 1);
 		info->res.type = fex_ldouble;
 		info->res.val.q = fpatan(info->op1.val.q, info->op2.val.q);
 		goto done;
 
-	case 0x1f4: /* fxtract */
+	case 0x1f4:			/* fxtract */
 		info->res.type = fex_ldouble;
 		info->res.val.q = fxtract(info->op1.val.q);
 		goto done;
 
-	case 0x1f5: /* fprem1 */
+	case 0x1f5:			/* fprem1 */
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, 1);
 		info->res.type = fex_ldouble;
 		info->res.val.q = fprem1(info->op1.val.q, info->op2.val.q);
 		goto done;
 
-	case 0x1f8: /* fprem */
+	case 0x1f8:			/* fprem */
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, 1);
 		info->res.type = fex_ldouble;
 		info->res.val.q = fprem(info->op1.val.q, info->op2.val.q);
 		goto done;
 
-	case 0x1f9: /* fyl2xp1 */
+	case 0x1f9:			/* fyl2xp1 */
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, 1);
 		info->res.type = fex_ldouble;
 		info->res.val.q = fyl2xp1(info->op1.val.q, info->op2.val.q);
 		goto done;
 
-	case 0x1fa: /* fsqrt */
+	case 0x1fa:			/* fsqrt */
 		info->op = fex_sqrt;
 		info->res.type = fex_ldouble;
 		info->res.val.q = fsqrt(info->op1.val.q);
 		goto done;
 
-	case 0x1fb: /* fsincos */
+	case 0x1fb:			/* fsincos */
 		info->res.type = fex_ldouble;
 		info->res.val.q = fsincos(info->op1.val.q);
 		goto done;
 
-	case 0x1fc: /* frndint */
+	case 0x1fc:			/* frndint */
 		info->res.type = fex_ldouble;
 		info->res.val.q = frndint(info->op1.val.q);
 		goto done;
 
-	case 0x1fd: /* fscale */
+	case 0x1fd:			/* fscale */
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, 1);
 		info->res.type = fex_ldouble;
 		info->res.val.q = fscale(info->op1.val.q, info->op2.val.q);
 		goto done;
 
-	case 0x1fe: /* fsin */
+	case 0x1fe:			/* fsin */
 		info->res.type = fex_ldouble;
 		info->res.val.q = fsin(info->op1.val.q);
 		goto done;
 
-	case 0x1ff: /* fcos */
+	case 0x1ff:			/* fcos */
 		info->res.type = fex_ldouble;
 		info->res.val.q = fcos(info->op1.val.q);
 		goto done;
 
-	case 0x2e9: /* fucompp */
+	case 0x2e9:			/* fucompp */
 		info->op = fex_cmp;
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, 1);
@@ -998,7 +1097,7 @@
 	case 0x3e8:
 	case 0x5e0:
 	case 0x5e8:
-	case 0x7e8: /* unordered compares */
+	case 0x7e8:			/* unordered compares */
 		info->op = fex_cmp;
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, op & 7);
@@ -1007,7 +1106,7 @@
 		goto done;
 
 	case 0x3f0:
-	case 0x7f0: /* ordered compares */
+	case 0x7f0:			/* ordered compares */
 		info->op = fex_cmp;
 		info->op2.type = fex_ldouble;
 		info->op2.val.q = fpreg(uap, op & 7);
@@ -1016,23 +1115,28 @@
 		goto done;
 	}
 
-	/* all other instructions come in groups of the form
-	   fadd, fmul, fcom, fcomp, fsub, fsubr, fdiv, fdivr */
+	/*
+	 * all other instructions come in groups of the form
+	 * fadd, fmul, fcom, fcomp, fsub, fsubr, fdiv, fdivr
+	 */
 
 	/* get the second operand */
 	switch (op & 0x7c0) {
 	case 0x000:
 	case 0x040:
 	case 0x080:
+
 		if (!ea) {
 			info->op = fex_other;
-			info->op1.type = info->op2.type = info->res.type = fex_nodata;
+			info->op1.type = info->op2.type = info->res.type =
+			    fex_nodata;
 			info->flags = 0;
 			return;
 		}
+
 		info->op2.type = fex_float;
 		info->op2.val.f = *(float *)ea;
-		op2v = (long double) info->op2.val.f;
+		op2v = (long double)info->op2.val.f;
 		break;
 
 	case 0x0c0:
@@ -1043,29 +1147,35 @@
 	case 0x200:
 	case 0x240:
 	case 0x280:
+
 		if (!ea) {
 			info->op = fex_other;
-			info->op1.type = info->op2.type = info->res.type = fex_nodata;
+			info->op1.type = info->op2.type = info->res.type =
+			    fex_nodata;
 			info->flags = 0;
 			return;
 		}
+
 		info->op2.type = fex_int;
 		info->op2.val.i = *(int *)ea;
-		op2v = (long double) info->op2.val.i;
+		op2v = (long double)info->op2.val.i;
 		break;
 
 	case 0x400:
 	case 0x440:
 	case 0x480:
+
 		if (!ea) {
 			info->op = fex_other;
-			info->op1.type = info->op2.type = info->res.type = fex_nodata;
+			info->op1.type = info->op2.type = info->res.type =
+			    fex_nodata;
 			info->flags = 0;
 			return;
 		}
+
 		info->op2.type = fex_double;
 		info->op2.val.d = *(double *)ea;
-		op2v = (long double) info->op2.val.d;
+		op2v = (long double)info->op2.val.d;
 		break;
 
 	case 0x4c0:
@@ -1081,15 +1191,18 @@
 	case 0x600:
 	case 0x640:
 	case 0x680:
+
 		if (!ea) {
 			info->op = fex_other;
-			info->op1.type = info->op2.type = info->res.type = fex_nodata;
+			info->op1.type = info->op2.type = info->res.type =
+			    fex_nodata;
 			info->flags = 0;
 			return;
 		}
+
 		info->op2.type = fex_int;
 		info->op2.val.i = *(short *)ea;
-		op2v = (long double) info->op2.val.i;
+		op2v = (long double)info->op2.val.i;
 		break;
 
 	default:
@@ -1101,6 +1214,7 @@
 
 	/* distinguish different operations in the group */
 	info->res.type = fex_ldouble;
+
 	switch (op & 0x38) {
 	case 0x00:
 		info->op = fex_add;
@@ -1160,7 +1274,8 @@
 }
 
 /* pop the saved stack */
-static void pop(ucontext_t *uap)
+static void
+pop(ucontext_t *uap)
 {
 	unsigned top;
 
@@ -1172,26 +1287,26 @@
 	fpreg(uap, 5) = fpreg(uap, 6);
 	fpreg(uap, 6) = fpreg(uap, 7);
 #if defined(__amd64)
-	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw >> 10)
-		& 0xe;
+	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw >> 10) & 0xe;
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.fctw |= (3 << top);
 	top = (top + 2) & 0xe;
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw =
-		(uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw & ~0x3800)
-		| (top << 10);
+	    (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw & ~0x3800) |
+	    (top << 10);
 #else
-	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] >> 10)
-		& 0xe;
+	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] >>
+	    10) & 0xe;
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[TW] |= (3 << top);
 	top = (top + 2) & 0xe;
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] =
-		(uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] & ~0x3800)
-		| (top << 10);
+	    (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] &
+	    ~0x3800) | (top << 10);
 #endif
 }
 
 /* push x onto the saved stack */
-static void push(long double x, ucontext_t *uap)
+static void
+push(long double x, ucontext_t *uap)
 {
 	unsigned top;
 
@@ -1204,54 +1319,54 @@
 	fpreg(uap, 1) = fpreg(uap, 0);
 	fpreg(uap, 0) = x;
 #if defined(__amd64)
-	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw >> 10)
-		& 0xe;
+	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw >> 10) & 0xe;
 	top = (top - 2) & 0xe;
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.fctw &= ~(3 << top);
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw =
-		(uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw & ~0x3800)
-		| (top << 10);
+	    (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw & ~0x3800) |
+	    (top << 10);
 #else
-	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] >> 10)
-		& 0xe;
+	top = (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] >>
+	    10) & 0xe;
 	top = (top - 2) & 0xe;
-	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[TW] &= ~(3 << top);
+	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[TW] &= ~(3 <<
+	    top);
 	uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] =
-		(uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] & ~0x3800)
-		| (top << 10);
+	    (uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] &
+	    ~0x3800) | (top << 10);
 #endif
 }
 
 /* scale factors for exponent wrapping */
-static const float
-	fun = 7.922816251e+28f,	/* 2^96 */
-	fov = 1.262177448e-29f;	/* 2^-96 */
-static const double
-	dun = 1.552518092300708935e+231,	/* 2^768 */
-	dov = 6.441148769597133308e-232;	/* 2^-768 */
+static const float fun = 7.922816251e+28f,		/* 2^96 */
+	fov = 1.262177448e-29f;				/* 2^-96 */
+static const double dun = 1.552518092300708935e+231,	/* 2^768 */
+	dov = 6.441148769597133308e-232;		/* 2^-768 */
 
 /*
-*  Store the specified result; if no result is given but the exception
-*  is underflow or overflow, use the default trapped result
-*/
+ *  Store the specified result; if no result is given but the exception
+ *  is underflow or overflow, use the default trapped result
+ */
 void
 __fex_st_result(siginfo_t *sip, ucontext_t *uap, fex_info_t *info)
 {
-	fex_numeric_t	r;
-	unsigned long		ex, op, ea, stack;
+	fex_numeric_t r;
+	unsigned long ex, op, ea, stack;
 
 	/* get the exception type, opcode, and data address */
 	ex = sip->si_code;
 #if defined(__amd64)
 	op = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.fop >> 16;
-	ea = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.rdp; /*???*/
+	ea = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.rdp; /* ??? */
 #else
 	op = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[OP] >> 16;
 	ea = uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[EA];
 #endif
 
-	/* if the instruction is a compare, set the condition codes
-	   to unordered and update the stack */
+	/*
+	 * if the instruction is a compare, set the condition codes
+	 * to unordered and update the stack
+	 */
 	switch (op & 0x7f8) {
 	case 0x010:
 	case 0x050:
@@ -1272,7 +1387,8 @@
 #if defined(__amd64)
 		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw |= 0x4500;
 #else
-		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] |= 0x4500;
+		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] |=
+		    0x4500;
 #endif
 		return;
 
@@ -1296,7 +1412,8 @@
 #if defined(__amd64)
 		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw |= 0x4500;
 #else
-		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] |= 0x4500;
+		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] |=
+		    0x4500;
 #endif
 		pop(uap);
 		return;
@@ -1307,21 +1424,26 @@
 #if defined(__amd64)
 		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw |= 0x4500;
 #else
-		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] |= 0x4500;
+		uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] |=
+		    0x4500;
 #endif
 		pop(uap);
 		pop(uap);
 		return;
 
 	case 0x1e0:
-		if (op == 0x1e4) { /* ftst */
+
+		if (op == 0x1e4) {	/* ftst */
 #if defined(__amd64)
-			uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw |= 0x4500;
+			uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.sw |=
+			    0x4500;
 #else
-			uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.state[SW] |= 0x4500;
+			uap->uc_mcontext.fpregs.fp_reg_set.
+			    fpchip_state.state[SW] |= 0x4500;
 #endif
 			return;
 		}
+
 		break;
 
 	case 0x3e8:
@@ -1346,9 +1468,12 @@
 		return;
 	}
 
-	/* if there is no result available and the exception is overflow
-	   or underflow, use the wrapped result */
+	/*
+	 * if there is no result available and the exception is overflow
+	 * or underflow, use the wrapped result
+	 */
 	r = info->res;
+
 	if (r.type == fex_nodata) {
 		if (ex == FPE_FLTOVF || ex == FPE_FLTUND) {
 			/* for store instructions, do the scaling and store */
@@ -1359,14 +1484,20 @@
 			case 0x158:
 			case 0x190:
 			case 0x198:
+
 				if (!ea)
 					return;
+
 				if (ex == FPE_FLTOVF)
-					*(float *)ea = (fpreg(uap, 0) * fov) * fov;
+					*(float *)ea = (fpreg(uap, 0) * fov) *
+					    fov;
 				else
-					*(float *)ea = (fpreg(uap, 0) * fun) * fun;
+					*(float *)ea = (fpreg(uap, 0) * fun) *
+					    fun;
+
 				if ((op & 8) != 0)
 					pop(uap);
+
 				break;
 
 			case 0x510:
@@ -1375,26 +1506,36 @@
 			case 0x558:
 			case 0x590:
 			case 0x598:
+
 				if (!ea)
 					return;
+
 				if (ex == FPE_FLTOVF)
-					*(double *)ea = (fpreg(uap, 0) * dov) * dov;
+					*(double *)ea = (fpreg(uap, 0) * dov) *
+					    dov;
 				else
-					*(double *)ea = (fpreg(uap, 0) * dun) * dun;
+					*(double *)ea = (fpreg(uap, 0) * dun) *
+					    dun;
+
 				if ((op & 8) != 0)
 					pop(uap);
+
 				break;
 			}
 		}
+
 #ifdef DEBUG
-		else if (ex != FPE_FLTRES)
+		else if (ex != FPE_FLTRES) {
 			printf("No result supplied, stack may be hosed\n");
+		}
 #endif
 		return;
 	}
 
-	/* otherwise convert the supplied result to the correct type,
-	   put it in the destination, and update the stack as need be */
+	/*
+	 * otherwise convert the supplied result to the correct type, put it
+	 * in the destination, and update the stack as need be
+	 */
 
 	/* store instructions */
 	switch (op & 0x7f8) {
@@ -1404,15 +1545,17 @@
 	case 0x158:
 	case 0x190:
 	case 0x198:
+
 		if (!ea)
 			return;
+
 		switch (r.type) {
 		case fex_int:
-			*(float *)ea = (float) r.val.i;
+			*(float *)ea = (float)r.val.i;
 			break;
 
 		case fex_llong:
-			*(float *)ea = (float) r.val.l;
+			*(float *)ea = (float)r.val.l;
 			break;
 
 		case fex_float:
@@ -1420,18 +1563,20 @@
 			break;
 
 		case fex_double:
-			*(float *)ea = (float) r.val.d;
+			*(float *)ea = (float)r.val.d;
 			break;
 
 		case fex_ldouble:
-			*(float *)ea = (float) r.val.q;
+			*(float *)ea = (float)r.val.q;
 			break;
 
 		default:
 			break;
 		}
+
 		if (ex != FPE_FLTRES && (op & 8) != 0)
 			pop(uap);
+
 		return;
 
 	case 0x310:
@@ -1440,34 +1585,38 @@
 	case 0x358:
 	case 0x390:
 	case 0x398:
+
 		if (!ea)
 			return;
+
 		switch (r.type) {
 		case fex_int:
 			*(int *)ea = r.val.i;
 			break;
 
 		case fex_llong:
-			*(int *)ea = (int) r.val.l;
+			*(int *)ea = (int)r.val.l;
 			break;
 
 		case fex_float:
-			*(int *)ea = (int) r.val.f;
+			*(int *)ea = (int)r.val.f;
 			break;
 
 		case fex_double:
-			*(int *)ea = (int) r.val.d;
+			*(int *)ea = (int)r.val.d;
 			break;
 
 		case fex_ldouble:
-			*(int *)ea = (int) r.val.q;
+			*(int *)ea = (int)r.val.q;
 			break;
 
 		default:
 			break;
 		}
+
 		if (ex != FPE_FLTRES && (op & 8) != 0)
 			pop(uap);
+
 		return;
 
 	case 0x510:
@@ -1476,19 +1625,21 @@
 	case 0x558:
 	case 0x590:
 	case 0x598:
+
 		if (!ea)
 			return;
+
 		switch (r.type) {
 		case fex_int:
-			*(double *)ea = (double) r.val.i;
+			*(double *)ea = (double)r.val.i;
 			break;
 
 		case fex_llong:
-			*(double *)ea = (double) r.val.l;
+			*(double *)ea = (double)r.val.l;
 			break;
 
 		case fex_float:
-			*(double *)ea = (double) r.val.f;
+			*(double *)ea = (double)r.val.f;
 			break;
 
 		case fex_double:
@@ -1496,14 +1647,16 @@
 			break;
 
 		case fex_ldouble:
-			*(double *)ea = (double) r.val.q;
+			*(double *)ea = (double)r.val.q;
 			break;
 
 		default:
 			break;
 		}
+
 		if (ex != FPE_FLTRES && (op & 8) != 0)
 			pop(uap);
+
 		return;
 
 	case 0x710:
@@ -1512,52 +1665,60 @@
 	case 0x758:
 	case 0x790:
 	case 0x798:
+
 		if (!ea)
 			return;
+
 		switch (r.type) {
 		case fex_int:
-			*(short *)ea = (short) r.val.i;
+			*(short *)ea = (short)r.val.i;
 			break;
 
 		case fex_llong:
-			*(short *)ea = (short) r.val.l;
+			*(short *)ea = (short)r.val.l;
 			break;
 
 		case fex_float:
-			*(short *)ea = (short) r.val.f;
+			*(short *)ea = (short)r.val.f;
 			break;
 
 		case fex_double:
-			*(short *)ea = (short) r.val.d;
+			*(short *)ea = (short)r.val.d;
 			break;
 
 		case fex_ldouble:
-			*(short *)ea = (short) r.val.q;
+			*(short *)ea = (short)r.val.q;
 			break;
 
 		default:
 			break;
 		}
+
 		if (ex != FPE_FLTRES && (op & 8) != 0)
 			pop(uap);
+
 		return;
 
 	case 0x730:
 	case 0x770:
 	case 0x7b0:
+
 		/* fbstp; don't bother */
 		if (ea && ex != FPE_FLTRES)
 			pop(uap);
+
 		return;
 
 	case 0x738:
 	case 0x778:
 	case 0x7b8:
+
 		if (!ea)
 			return;
+
 		switch (r.type) {
 		case fex_int:
-			*(long long *)ea = (long long) r.val.i;
+			*(long long *)ea = (long long)r.val.i;
 			break;
 
 		case fex_llong:
@@ -1565,41 +1726,43 @@
 			break;
 
 		case fex_float:
-			*(long long *)ea = (long long) r.val.f;
+			*(long long *)ea = (long long)r.val.f;
 			break;
 
 		case fex_double:
-			*(long long *)ea = (long long) r.val.d;
+			*(long long *)ea = (long long)r.val.d;
 			break;
 
 		case fex_ldouble:
-			*(long long *)ea = (long long) r.val.q;
+			*(long long *)ea = (long long)r.val.q;
 			break;
 
 		default:
 			break;
 		}
+
 		if (ex != FPE_FLTRES)
 			pop(uap);
+
 		return;
 	}
 
 	/* for all other instructions, the result goes into a register */
 	switch (r.type) {
 	case fex_int:
-		r.val.q = (long double) r.val.i;
+		r.val.q = (long double)r.val.i;
 		break;
 
 	case fex_llong:
-		r.val.q = (long double) r.val.l;
+		r.val.q = (long double)r.val.l;
 		break;
 
 	case fex_float:
-		r.val.q = (long double) r.val.f;
+		r.val.q = (long double)r.val.f;
 		break;
 
 	case fex_double:
-		r.val.q = (long double) r.val.d;
+		r.val.q = (long double)r.val.d;
 		break;
 
 	default:
@@ -1614,45 +1777,57 @@
 	case 0x500:
 	case 0x540:
 	case 0x580:
+
 		if (ea)
 			push(r.val.q, uap);
+
 		return;
 	}
 
-	/* for all other instructions, if the exception is overflow,
-	   underflow, or inexact, the stack has already been updated */
+	/*
+	 * for all other instructions, if the exception is overflow,
+	 * underflow, or inexact, the stack has already been updated
+	 */
 	stack = (ex == FPE_FLTOVF || ex == FPE_FLTUND || ex == FPE_FLTRES);
+
 	switch (op & 0x7f8) {
-	case 0x1f0: /* oddballs */
+	case 0x1f0:			/* oddballs */
+
 		switch (op) {
-		case 0x1f1: /* fyl2x */
-		case 0x1f3: /* fpatan */
-		case 0x1f9: /* fyl2xp1 */
+		case 0x1f1:		/* fyl2x */
+		case 0x1f3:		/* fpatan */
+		case 0x1f9:		/* fyl2xp1 */
+
 			/* pop the stack, leaving the result in st */
 			if (!stack)
 				pop(uap);
+
 			fpreg(uap, 0) = r.val.q;
 			return;
 
-		case 0x1f2: /* fpatan */
+		case 0x1f2:		/* fpatan */
+
 			/* fptan pushes 1.0 afterward */
-			if (stack)
+			if (stack) {
 				fpreg(uap, 1) = r.val.q;
-			else {
+			} else {
 				fpreg(uap, 0) = r.val.q;
 				push(1.0L, uap);
 			}
+
 			return;
 
-		case 0x1f4: /* fxtract */
-		case 0x1fb: /* fsincos */
+		case 0x1f4:		/* fxtract */
+		case 0x1fb:		/* fsincos */
+
 			/* leave the supplied result in st */
-			if (stack)
+			if (stack) {
 				fpreg(uap, 0) = r.val.q;
-			else {
-				fpreg(uap, 0) = 0.0; /* punt */
+			} else {
+				fpreg(uap, 0) = 0.0;	/* punt */
 				push(r.val.q, uap);
 			}
+
 			return;
 		}
 
@@ -1675,13 +1850,15 @@
 	case 0x6e8:
 	case 0x6f0:
 	case 0x6f8:
+
 		/* stack is popped afterward */
-		if (stack)
+		if (stack) {
 			fpreg(uap, (op - 1) & 7) = r.val.q;
-		else {
+		} else {
 			fpreg(uap, op & 7) = r.val.q;
 			pop(uap);
 		}
+
 		return;
 
 	default:
--- old/usr/src/lib/libm/common/m9x/__fex_sparc.c	2019-06-06 20:40:05.494870347 +0000
+++ new/usr/src/lib/libm/common/m9x/__fex_sparc.c	2019-06-06 20:40:05.512612327 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -45,23 +46,21 @@
 #include "libm_inlines.h"
 
 #ifdef __sparcv9
+#define	FPreg(X)	&uap->uc_mcontext.fpregs.fpu_fr.fpu_regs[X]
 
-#define FPreg(X)	&uap->uc_mcontext.fpregs.fpu_fr.fpu_regs[X]
-
-#define FPREG(X)	&uap->uc_mcontext.fpregs.fpu_fr.fpu_dregs[(X>>1)| \
-					((X&1)<<4)]
-
+#define	FPREG(X)	&uap->uc_mcontext.fpregs.fpu_fr.fpu_dregs[(X >> 1) | \
+	((X & 1) << 4)]
 #else
-
 #include <sys/procfs.h>
 
-#define FPxreg(X)	&((prxregset_t*)uap->uc_mcontext.xrs.xrs_ptr)->pr_un.pr_v8p.pr_xfr.pr_regs[X]
+#define	FPxreg(X)		& \
+	((prxregset_t *)uap->uc_mcontext.xrs.xrs_ptr)->pr_un.pr_v8p.pr_xfr. \
+	    pr_regs[X]
 
-#define FPreg(X)	&uap->uc_mcontext.fpregs.fpu_fr.fpu_regs[X]
+#define	FPreg(X)		& uap->uc_mcontext.fpregs.fpu_fr.fpu_regs[X]
 
-#define FPREG(X)	((X & 1)? FPxreg(X - 1) : FPreg(X))
-
-#endif	/* __sparcv9 */
+#define	FPREG(X)		((X & 1) ? FPxreg(X - 1) : FPreg(X))
+#endif /* __sparcv9 */
 
 #include "fex_handler.h"
 
@@ -69,32 +68,35 @@
 static enum fp_class_type
 my_fp_classl(long double *a)
 {
-	int		msw = *(int*)a & ~0x80000000;
+	int msw = *(int *)a & ~0x80000000;
 
 	if (msw >= 0x7fff0000) {
-		if (((msw & 0xffff) | *(1+(int*)a) | *(2+(int*)a) | *(3+(int*)a)) == 0)
-			return fp_infinity;
+		if (((msw & 0xffff) | *(1 + (int *)a) | *(2 + (int *)a) | *(3 +
+		    (int *)a)) == 0)
+			return (fp_infinity);
 		else if (msw & 0x8000)
-			return fp_quiet;
+			return (fp_quiet);
 		else
-			return fp_signaling;
+			return (fp_signaling);
 	} else if (msw < 0x10000) {
-		if ((msw | *(1+(int*)a) | *(2+(int*)a) | *(3+(int*)a)) == 0)
-			return fp_zero;
+		if ((msw | *(1 + (int *)a) | *(2 + (int *)a) | *(3 +
+		    (int *)a)) == 0)
+			return (fp_zero);
 		else
-			return fp_subnormal;
-	} else
-		return fp_normal;
+			return (fp_subnormal);
+	} else {
+		return (fp_normal);
+	}
 }
 
 /*
-*  Determine which type of invalid operation exception occurred
-*/
+ *  Determine which type of invalid operation exception occurred
+ */
 enum fex_exception
 __fex_get_invalid_type(siginfo_t *sip, ucontext_t *uap)
 {
-	unsigned			instr, opf, rs1, rs2;
-	enum fp_class_type	t1, t2;
+	unsigned instr, opf, rs1, rs2;
+	enum fp_class_type t1, t2;
 
 	/* parse the instruction which caused the exception */
 	instr = uap->uc_mcontext.fpregs.fpu_q->FQu.fpq.fpq_instr;
@@ -104,73 +106,79 @@
 
 	/* determine the classes of the operands */
 	switch (opf & 3) {
-	case 1: /* single */
-		t1 = fp_classf(*(float*)FPreg(rs1));
-		t2 = fp_classf(*(float*)FPreg(rs2));
+	case 1:				/* single */
+		t1 = fp_classf(*(float *)FPreg(rs1));
+		t2 = fp_classf(*(float *)FPreg(rs2));
 		break;
 
-	case 2: /* double */
-		t1 = fp_class(*(double*)FPREG(rs1));
-		t2 = fp_class(*(double*)FPREG(rs2));
+	case 2:				/* double */
+		t1 = fp_class(*(double *)FPREG(rs1));
+		t2 = fp_class(*(double *)FPREG(rs2));
 		break;
 
-	case 3: /* quad */
-		t1 = my_fp_classl((long double*)FPREG(rs1));
-		t2 = my_fp_classl((long double*)FPREG(rs2));
+	case 3:				/* quad */
+		t1 = my_fp_classl((long double *)FPREG(rs1));
+		t2 = my_fp_classl((long double *)FPREG(rs2));
 		break;
 
-	default: /* integer operands never cause an invalid operation */
-		return (enum fex_exception) -1;
+	default:	/* integer operands never cause an invalid operation */
+		return ((enum fex_exception)-1);
 	}
 
 	/* if rs2 is snan, return immediately */
 	if (t2 == fp_signaling)
-		return fex_inv_snan;
+		return (fex_inv_snan);
 
 	/* determine the type of operation */
 	switch ((instr >> 19) & 0x183f) {
 	case 0x1034: /* add, subtract, multiply, divide, square root, convert */
+
 		switch (opf & 0x1fc) {
 		case 0x40:
-		case 0x44: /* add or subtract */
+		case 0x44:		/* add or subtract */
+
 			if (t1 == fp_signaling)
-				return fex_inv_snan;
+				return (fex_inv_snan);
 			else
-				return fex_inv_isi;
+				return (fex_inv_isi);
 
 		case 0x48:
 		case 0x68:
-		case 0x6c: /* multiply */
+		case 0x6c:		/* multiply */
+
 			if (t1 == fp_signaling)
-				return fex_inv_snan;
+				return (fex_inv_snan);
 			else
-				return fex_inv_zmi;
+				return (fex_inv_zmi);
+
+		case 0x4c:		/* divide */
 
-		case 0x4c: /* divide */
 			if (t1 == fp_signaling)
-				return fex_inv_snan;
+				return (fex_inv_snan);
 			else if (t1 == fp_zero)
-				return fex_inv_zdz;
+				return (fex_inv_zdz);
 			else
-				return fex_inv_idi;
+				return (fex_inv_idi);
 
-		case 0x28: /* square root */
-			return fex_inv_sqrt;
+		case 0x28:		/* square root */
+			return (fex_inv_sqrt);
 
 		case 0x80:
-		case 0xd0: /* convert to integer */
-			return fex_inv_int;
+		case 0xd0:		/* convert to integer */
+			return (fex_inv_int);
 		}
+
 		break;
 
-	case 0x1035: /* compare */
+	case 0x1035:			/* compare */
+
 		if (t1 == fp_signaling)
-			return fex_inv_snan;
+			return (fex_inv_snan);
 		else
-			return fex_inv_cmp;
+			return (fex_inv_cmp);
 	}
 
-	return (enum fex_exception) -1;
+	return ((enum fex_exception)-1);
 }
 
 #ifdef __sparcv9
@@ -180,15 +188,15 @@
 #endif
 
 /*
-*  Get the operands, generate the default untrapped result with
-*  exceptions, and set a code indicating the type of operation
-*/
+ *  Get the operands, generate the default untrapped result with
+ *  exceptions, and set a code indicating the type of operation
+ */
 void
 __fex_get_op(siginfo_t *sip, ucontext_t *uap, fex_info_t *info)
 {
-	unsigned long	fsr;
-	unsigned		instr, opf, rs1, rs2;
-	volatile int	c;
+	unsigned long fsr;
+	unsigned instr, opf, rs1, rs2;
+	volatile int c;
 
 	/* parse the instruction which caused the exception */
 	instr = uap->uc_mcontext.fpregs.fpu_q->FQu.fpq.fpq_instr;
@@ -198,160 +206,168 @@
 
 	/* get the operands */
 	switch (opf & 3) {
-	case 0: /* integer */
+	case 0:				/* integer */
 		info->op1.type = fex_nodata;
+
 		if (opf & 0x40) {
 			info->op2.type = fex_int;
-			info->op2.val.i = *(int*)FPreg(rs2);
-		}
-		else {
+			info->op2.val.i = *(int *)FPreg(rs2);
+		} else {
 			info->op2.type = fex_llong;
-			info->op2.val.l = *(long long*)FPREG(rs2);
+			info->op2.val.l = *(long long *)FPREG(rs2);
 		}
+
 		break;
 
-	case 1: /* single */
+	case 1:				/* single */
 		info->op1.type = info->op2.type = fex_float;
-		info->op1.val.f = *(float*)FPreg(rs1);
-		info->op2.val.f = *(float*)FPreg(rs2);
+		info->op1.val.f = *(float *)FPreg(rs1);
+		info->op2.val.f = *(float *)FPreg(rs2);
 		break;
 
-	case 2: /* double */
+	case 2:				/* double */
 		info->op1.type = info->op2.type = fex_double;
-		info->op1.val.d = *(double*)FPREG(rs1);
-		info->op2.val.d = *(double*)FPREG(rs2);
+		info->op1.val.d = *(double *)FPREG(rs1);
+		info->op2.val.d = *(double *)FPREG(rs2);
 		break;
 
-	case 3: /* quad */
+	case 3:				/* quad */
 		info->op1.type = info->op2.type = fex_ldouble;
-		info->op1.val.q = *(long double*)FPREG(rs1);
-		info->op2.val.q = *(long double*)FPREG(rs2);
+		info->op1.val.q = *(long double *)FPREG(rs1);
+		info->op2.val.q = *(long double *)FPREG(rs2);
 		break;
 	}
 
-	/* initialize res to the default untrapped result and ex to the
-	   corresponding flags (assume trapping is disabled and flags
-	   are clear) */
+	/*
+	 * initialize res to the default untrapped result and ex to the
+	 * corresponding flags (assume trapping is disabled and flags are
+	 * clear)
+	 */
 	info->op = fex_other;
 	info->res.type = fex_nodata;
+
 	switch ((instr >> 19) & 0x183f) {
-	case 0x1035: /* compare */
+	case 0x1035:			/* compare */
 		info->op = fex_cmp;
+
 		switch (opf) {
-		case 0x51: /* compare single */
+		case 0x51:		/* compare single */
 			c = (info->op1.val.f == info->op2.val.f);
 			break;
 
-		case 0x52: /* compare double */
+		case 0x52:		/* compare double */
 			c = (info->op1.val.d == info->op2.val.d);
 			break;
 
-		case 0x53: /* compare quad */
+		case 0x53:		/* compare quad */
 			c = (info->op1.val.q == info->op2.val.q);
 			break;
 
-		case 0x55: /* compare single with exception */
+		case 0x55:		/* compare single with exception */
 			c = (info->op1.val.f < info->op2.val.f);
 			break;
 
-		case 0x56: /* compare double with exception */
+		case 0x56:		/* compare double with exception */
 			c = (info->op1.val.d < info->op2.val.d);
 			break;
 
-		case 0x57: /* compare quad with exception */
+		case 0x57:		/* compare quad with exception */
 			c = (info->op1.val.q < info->op2.val.q);
 			break;
 		}
+
 		break;
 
 	case 0x1034: /* add, subtract, multiply, divide, square root, convert */
+
 		switch (opf) {
-		case 0x41: /* add single */
+		case 0x41:		/* add single */
 			info->op = fex_add;
 			info->res.type = fex_float;
 			info->res.val.f = info->op1.val.f + info->op2.val.f;
 			break;
 
-		case 0x42: /* add double */
+		case 0x42:		/* add double */
 			info->op = fex_add;
 			info->res.type = fex_double;
 			info->res.val.d = info->op1.val.d + info->op2.val.d;
 			break;
 
-		case 0x43: /* add quad */
+		case 0x43:		/* add quad */
 			info->op = fex_add;
 			info->res.type = fex_ldouble;
 			info->res.val.q = info->op1.val.q + info->op2.val.q;
 			break;
 
-		case 0x45: /* subtract single */
+		case 0x45:		/* subtract single */
 			info->op = fex_sub;
 			info->res.type = fex_float;
 			info->res.val.f = info->op1.val.f - info->op2.val.f;
 			break;
 
-		case 0x46: /* subtract double */
+		case 0x46:		/* subtract double */
 			info->op = fex_sub;
 			info->res.type = fex_double;
 			info->res.val.d = info->op1.val.d - info->op2.val.d;
 			break;
 
-		case 0x47: /* subtract quad */
+		case 0x47:		/* subtract quad */
 			info->op = fex_sub;
 			info->res.type = fex_ldouble;
 			info->res.val.q = info->op1.val.q - info->op2.val.q;
 			break;
 
-		case 0x49: /* multiply single */
+		case 0x49:		/* multiply single */
 			info->op = fex_mul;
 			info->res.type = fex_float;
 			info->res.val.f = info->op1.val.f * info->op2.val.f;
 			break;
 
-		case 0x4a: /* multiply double */
+		case 0x4a:		/* multiply double */
 			info->op = fex_mul;
 			info->res.type = fex_double;
 			info->res.val.d = info->op1.val.d * info->op2.val.d;
 			break;
 
-		case 0x4b: /* multiply quad */
+		case 0x4b:		/* multiply quad */
 			info->op = fex_mul;
 			info->res.type = fex_ldouble;
 			info->res.val.q = info->op1.val.q * info->op2.val.q;
 			break;
 
-		case 0x69: /* fsmuld */
+		case 0x69:		/* fsmuld */
 			info->op = fex_mul;
 			info->res.type = fex_double;
-			info->res.val.d = (double)info->op1.val.f * (double)info->op2.val.f;
+			info->res.val.d = (double)info->op1.val.f *
+			    (double)info->op2.val.f;
 			break;
 
-		case 0x6e: /* fdmulq */
+		case 0x6e:		/* fdmulq */
 			info->op = fex_mul;
 			info->res.type = fex_ldouble;
-			info->res.val.q = (long double)info->op1.val.d *
-				(long double)info->op2.val.d;
+			info->res.val.q = (long double)info->op1.val.d * (long
+			    double)info->op2.val.d;
 			break;
 
-		case 0x4d: /* divide single */
+		case 0x4d:		/* divide single */
 			info->op = fex_div;
 			info->res.type = fex_float;
 			info->res.val.f = info->op1.val.f / info->op2.val.f;
 			break;
 
-		case 0x4e: /* divide double */
+		case 0x4e:		/* divide double */
 			info->op = fex_div;
 			info->res.type = fex_double;
 			info->res.val.d = info->op1.val.d / info->op2.val.d;
 			break;
 
-		case 0x4f: /* divide quad */
+		case 0x4f:		/* divide quad */
 			info->op = fex_div;
 			info->res.type = fex_ldouble;
 			info->res.val.q = info->op1.val.q / info->op2.val.q;
 			break;
 
-		case 0x29: /* square root single */
+		case 0x29:		/* square root single */
 			info->op = fex_sqrt;
 			info->op1 = info->op2;
 			info->op2.type = fex_nodata;
@@ -359,7 +375,7 @@
 			info->res.val.f = sqrtf(info->op1.val.f);
 			break;
 
-		case 0x2a: /* square root double */
+		case 0x2a:		/* square root double */
 			info->op = fex_sqrt;
 			info->op1 = info->op2;
 			info->op2.type = fex_nodata;
@@ -367,7 +383,7 @@
 			info->res.val.d = sqrt(info->op1.val.d);
 			break;
 
-		case 0x2b: /* square root quad */
+		case 0x2b:		/* square root quad */
 			info->op = fex_sqrt;
 			info->op1 = info->op2;
 			info->op2.type = fex_nodata;
@@ -379,89 +395,92 @@
 #endif
 			break;
 
-		default: /* conversions */
+		default:		/* conversions */
 			info->op = fex_cnvt;
 			info->op1 = info->op2;
 			info->op2.type = fex_nodata;
+
 			switch (opf) {
-			case 0xd1: /* convert single to int */
+			case 0xd1:	/* convert single to int */
 				info->res.type = fex_int;
-				info->res.val.i = (int) info->op1.val.f;
+				info->res.val.i = (int)info->op1.val.f;
 				break;
 
-			case 0xd2: /* convert double to int */
+			case 0xd2:	/* convert double to int */
 				info->res.type = fex_int;
-				info->res.val.i = (int) info->op1.val.d;
+				info->res.val.i = (int)info->op1.val.d;
 				break;
 
-			case 0xd3: /* convert quad to int */
+			case 0xd3:	/* convert quad to int */
 				info->res.type = fex_int;
-				info->res.val.i = (int) info->op1.val.q;
+				info->res.val.i = (int)info->op1.val.q;
 				break;
 
-			case 0x81: /* convert single to long long */
+			case 0x81:	/* convert single to long long */
 				info->res.type = fex_llong;
-				info->res.val.l = (long long) info->op1.val.f;
+				info->res.val.l = (long long)info->op1.val.f;
 				break;
 
-			case 0x82: /* convert double to long long */
+			case 0x82:	/* convert double to long long */
 				info->res.type = fex_llong;
-				info->res.val.l = (long long) info->op1.val.d;
+				info->res.val.l = (long long)info->op1.val.d;
 				break;
 
-			case 0x83: /* convert quad to long long */
+			case 0x83:	/* convert quad to long long */
 				info->res.type = fex_llong;
-				info->res.val.l = (long long) info->op1.val.q;
+				info->res.val.l = (long long)info->op1.val.q;
 				break;
 
-			case 0xc4: /* convert int to single */
+			case 0xc4:	/* convert int to single */
 				info->res.type = fex_float;
-				info->res.val.f = (float) info->op1.val.i;
+				info->res.val.f = (float)info->op1.val.i;
 				break;
 
-			case 0x84: /* convert long long to single */
+			case 0x84:	/* convert long long to single */
 				info->res.type = fex_float;
-				info->res.val.f = (float) info->op1.val.l;
+				info->res.val.f = (float)info->op1.val.l;
 				break;
 
-			case 0x88: /* convert long long to double */
+			case 0x88:	/* convert long long to double */
 				info->res.type = fex_double;
-				info->res.val.d = (double) info->op1.val.l;
+				info->res.val.d = (double)info->op1.val.l;
 				break;
 
-			case 0xc6: /* convert double to single */
+			case 0xc6:	/* convert double to single */
 				info->res.type = fex_float;
-				info->res.val.f = (float) info->op1.val.d;
+				info->res.val.f = (float)info->op1.val.d;
 				break;
 
-			case 0xc7: /* convert quad to single */
+			case 0xc7:	/* convert quad to single */
 				info->res.type = fex_float;
-				info->res.val.f = (float) info->op1.val.q;
+				info->res.val.f = (float)info->op1.val.q;
 				break;
 
-			case 0xc9: /* convert single to double */
+			case 0xc9:	/* convert single to double */
 				info->res.type = fex_double;
-				info->res.val.d = (double) info->op1.val.f;
+				info->res.val.d = (double)info->op1.val.f;
 				break;
 
-			case 0xcb: /* convert quad to double */
+			case 0xcb:	/* convert quad to double */
 				info->res.type = fex_double;
-				info->res.val.d = (double) info->op1.val.q;
+				info->res.val.d = (double)info->op1.val.q;
 				break;
 
-			case 0xcd: /* convert single to quad */
+			case 0xcd:	/* convert single to quad */
 				info->res.type = fex_ldouble;
-				info->res.val.q = (long double) info->op1.val.f;
+				info->res.val.q = (long double)info->op1.val.f;
 				break;
 
-			case 0xce: /* convert double to quad */
+			case 0xce:	/* convert double to quad */
 				info->res.type = fex_ldouble;
-				info->res.val.q = (long double) info->op1.val.d;
+				info->res.val.q = (long double)info->op1.val.d;
 				break;
 			}
 		}
+
 		break;
 	}
+
 	__fenv_getfsr(&fsr);
 	info->flags = (int)__fenv_get_ex(fsr);
 	__fenv_set_ex(fsr, 0);
@@ -469,16 +488,16 @@
 }
 
 /*
-*  Store the specified result; if no result is given but the exception
-*  is underflow or overflow, supply the default trapped result
-*/
+ *  Store the specified result; if no result is given but the exception
+ *  is underflow or overflow, supply the default trapped result
+ */
 void
 __fex_st_result(siginfo_t *sip, ucontext_t *uap, fex_info_t *info)
 {
-	unsigned		instr, opf, rs1, rs2, rd;
-	long double		qscl;
-	double			dscl;
-	float			fscl;
+	unsigned instr, opf, rs1, rs2, rd;
+	long double qscl;
+	double dscl;
+	float fscl;
 
 	/* parse the instruction which caused the exception */
 	instr = uap->uc_mcontext.fpregs.fpu_q->FQu.fpq.fpq_instr;
@@ -489,150 +508,169 @@
 
 	/* if the instruction is a compare, just set fcc to unordered */
 	if (((instr >> 19) & 0x183f) == 0x1035) {
-		if (rd == 0)
+		if (rd == 0) {
 			uap->uc_mcontext.fpregs.fpu_fsr |= 0xc00;
-		else {
+		} else {
 #ifdef __sparcv9
-			uap->uc_mcontext.fpregs.fpu_fsr |= (3l << ((rd << 1) + 30));
+			uap->uc_mcontext.fpregs.fpu_fsr |= (3l << ((rd << 1) +
+			    30));
 #else
-			((prxregset_t*)uap->uc_mcontext.xrs.xrs_ptr)->pr_un.pr_v8p.pr_xfsr |= (3 << ((rd - 1) << 1));
+			((prxregset_t *)uap->uc_mcontext.xrs.xrs_ptr)->pr_un.
+			    pr_v8p.pr_xfsr |= (3 << ((rd - 1) << 1));
 #endif
 		}
+
 		return;
 	}
 
-	/* if there is no result available, try to generate the untrapped
-	   default */
+	/*
+	 * if there is no result available, try to generate the untrapped
+	 * default
+	 */
 	if (info->res.type == fex_nodata) {
 		/* set scale factors for exponent wrapping */
 		switch (sip->si_code) {
 		case FPE_FLTOVF:
-			fscl = 1.262177448e-29f;	/* 2^-96 */
-			dscl = 6.441148769597133308e-232;	/* 2^-768 */
-			qscl = 8.778357852076208839765066529179033145e-3700l;/* 2^-12288 */
+			/* 2^-96 */
+			fscl = 1.262177448e-29f;
+			/* 2^-768 */
+			dscl = 6.441148769597133308e-232;
+			/* 2^-12288 */
+			qscl = 8.778357852076208839765066529179033145e-3700l;
 			break;
 
 		case FPE_FLTUND:
-			fscl = 7.922816251e+28f;	/* 2^96 */
-			dscl = 1.552518092300708935e+231;	/* 2^768 */
-			qscl = 1.139165225263043370845938579315932009e+3699l;/* 2^12288 */
+			/* 2^96 */
+			fscl = 7.922816251e+28f;
+			/* 2^768 */
+			dscl = 1.552518092300708935e+231;
+			/* 2^12288 */
+			qscl = 1.139165225263043370845938579315932009e+3699l;
 			break;
 
 		default:
-			/* user may have blown away the default result by mistake,
-			   so try to regenerate it */
+
+			/*
+			 * user may have blown away the default result by
+			 * mistake, so try to regenerate it
+			 */
 			(void) __fex_get_op(sip, uap, info);
+
 			if (info->res.type != fex_nodata)
 				goto stuff;
+
 			/* couldn't do it */
 			return;
 		}
 
 		/* get the operands */
 		switch (opf & 3) {
-		case 1: /* single */
-			info->op1.val.f = *(float*)FPreg(rs1);
-			info->op2.val.f = *(float*)FPreg(rs2);
+		case 1:			/* single */
+			info->op1.val.f = *(float *)FPreg(rs1);
+			info->op2.val.f = *(float *)FPreg(rs2);
 			break;
 
-		case 2: /* double */
-			info->op1.val.d = *(double*)FPREG(rs1);
-			info->op2.val.d = *(double*)FPREG(rs2);
+		case 2:			/* double */
+			info->op1.val.d = *(double *)FPREG(rs1);
+			info->op2.val.d = *(double *)FPREG(rs2);
 			break;
 
-		case 3: /* quad */
-			info->op1.val.q = *(long double*)FPREG(rs1);
-			info->op2.val.q = *(long double*)FPREG(rs2);
+		case 3:			/* quad */
+			info->op1.val.q = *(long double *)FPREG(rs1);
+			info->op2.val.q = *(long double *)FPREG(rs2);
 			break;
 		}
 
 		/* generate the wrapped result */
 		switch (opf) {
-		case 0x41: /* add single */
+		case 0x41:		/* add single */
 			info->res.type = fex_float;
 			info->res.val.f = fscl * (fscl * info->op1.val.f +
-				fscl * info->op2.val.f);
+			    fscl * info->op2.val.f);
 			break;
 
-		case 0x42: /* add double */
+		case 0x42:		/* add double */
 			info->res.type = fex_double;
 			info->res.val.d = dscl * (dscl * info->op1.val.d +
-				dscl * info->op2.val.d);
+			    dscl * info->op2.val.d);
 			break;
 
-		case 0x43: /* add quad */
+		case 0x43:		/* add quad */
 			info->res.type = fex_ldouble;
 			info->res.val.q = qscl * (qscl * info->op1.val.q +
-				qscl * info->op2.val.q);
+			    qscl * info->op2.val.q);
 			break;
 
-		case 0x45: /* subtract single */
+		case 0x45:		/* subtract single */
 			info->res.type = fex_float;
 			info->res.val.f = fscl * (fscl * info->op1.val.f -
-				fscl * info->op2.val.f);
+			    fscl * info->op2.val.f);
 			break;
 
-		case 0x46: /* subtract double */
+		case 0x46:		/* subtract double */
 			info->res.type = fex_double;
 			info->res.val.d = dscl * (dscl * info->op1.val.d -
-				dscl * info->op2.val.d);
+			    dscl * info->op2.val.d);
 			break;
 
-		case 0x47: /* subtract quad */
+		case 0x47:		/* subtract quad */
 			info->res.type = fex_ldouble;
 			info->res.val.q = qscl * (qscl * info->op1.val.q -
-				qscl * info->op2.val.q);
+			    qscl * info->op2.val.q);
 			break;
 
-		case 0x49: /* multiply single */
+		case 0x49:		/* multiply single */
 			info->res.type = fex_float;
-			info->res.val.f = (fscl * info->op1.val.f) *
-				(fscl * info->op2.val.f);
+			info->res.val.f = (fscl * info->op1.val.f) * (fscl *
+			    info->op2.val.f);
 			break;
 
-		case 0x4a: /* multiply double */
+		case 0x4a:		/* multiply double */
 			info->res.type = fex_double;
-			info->res.val.d = (dscl * info->op1.val.d) *
-				(dscl * info->op2.val.d);
+			info->res.val.d = (dscl * info->op1.val.d) * (dscl *
+			    info->op2.val.d);
 			break;
 
-		case 0x4b: /* multiply quad */
+		case 0x4b:		/* multiply quad */
 			info->res.type = fex_ldouble;
-			info->res.val.q = (qscl * info->op1.val.q) *
-				(qscl * info->op2.val.q);
+			info->res.val.q = (qscl * info->op1.val.q) * (qscl *
+			    info->op2.val.q);
 			break;
 
-		case 0x4d: /* divide single */
+		case 0x4d:		/* divide single */
 			info->res.type = fex_float;
 			info->res.val.f = (fscl * info->op1.val.f) /
-				(info->op2.val.f / fscl);
+			    (info->op2.val.f / fscl);
 			break;
 
-		case 0x4e: /* divide double */
+		case 0x4e:		/* divide double */
 			info->res.type = fex_double;
 			info->res.val.d = (dscl * info->op1.val.d) /
-				(info->op2.val.d / dscl);
+			    (info->op2.val.d / dscl);
 			break;
 
-		case 0x4f: /* divide quad */
+		case 0x4f:		/* divide quad */
 			info->res.type = fex_ldouble;
 			info->res.val.q = (qscl * info->op1.val.q) /
-				(info->op2.val.q / qscl);
+			    (info->op2.val.q / qscl);
 			break;
 
-		case 0xc6: /* convert double to single */
+		case 0xc6:		/* convert double to single */
 			info->res.type = fex_float;
-			info->res.val.f = (float) (fscl * (fscl * info->op1.val.d));
+			info->res.val.f = (float)(fscl * (fscl *
+			    info->op1.val.d));
 			break;
 
-		case 0xc7: /* convert quad to single */
+		case 0xc7:		/* convert quad to single */
 			info->res.type = fex_float;
-			info->res.val.f = (float) (fscl * (fscl * info->op1.val.q));
+			info->res.val.f = (float)(fscl * (fscl *
+			    info->op1.val.q));
 			break;
 
-		case 0xcb: /* convert quad to double */
+		case 0xcb:		/* convert quad to double */
 			info->res.type = fex_double;
-			info->res.val.d = (double) (dscl * (dscl * info->op1.val.q));
+			info->res.val.d = (double)(dscl * (dscl *
+			    info->op1.val.q));
 			break;
 		}
 
@@ -643,257 +681,278 @@
 
 stuff:
 	/* stick the result in the destination */
-	if (opf & 0x80) { /* conversion */
-		if (opf & 0x10) { /* result is an int */
+	if (opf & 0x80) {		/* conversion */
+		if (opf & 0x10) {	/* result is an int */
 			switch (info->res.type) {
 			case fex_llong:
-				info->res.val.i = (int) info->res.val.l;
+				info->res.val.i = (int)info->res.val.l;
 				break;
 
 			case fex_float:
-				info->res.val.i = (int) info->res.val.f;
+				info->res.val.i = (int)info->res.val.f;
 				break;
 
 			case fex_double:
-				info->res.val.i = (int) info->res.val.d;
+				info->res.val.i = (int)info->res.val.d;
 				break;
 
 			case fex_ldouble:
-				info->res.val.i = (int) info->res.val.q;
+				info->res.val.i = (int)info->res.val.q;
 				break;
 
 			default:
 				break;
 			}
-			*(int*)FPreg(rd) = info->res.val.i;
+
+			*(int *)FPreg(rd) = info->res.val.i;
 			return;
 		}
 
 		switch (opf & 0xc) {
-		case 0: /* result is long long */
+		case 0:			/* result is long long */
+
 			switch (info->res.type) {
 			case fex_int:
-				info->res.val.l = (long long) info->res.val.i;
+				info->res.val.l = (long long)info->res.val.i;
 				break;
 
 			case fex_float:
-				info->res.val.l = (long long) info->res.val.f;
+				info->res.val.l = (long long)info->res.val.f;
 				break;
 
 			case fex_double:
-				info->res.val.l = (long long) info->res.val.d;
+				info->res.val.l = (long long)info->res.val.d;
 				break;
 
 			case fex_ldouble:
-				info->res.val.l = (long long) info->res.val.q;
+				info->res.val.l = (long long)info->res.val.q;
 				break;
 
 			default:
 				break;
 			}
-			*(long long*)FPREG(rd) = info->res.val.l;
+
+			*(long long *)FPREG(rd) = info->res.val.l;
 			break;
 
-		case 0x4: /* result is float */
+		case 0x4:		/* result is float */
+
 			switch (info->res.type) {
 			case fex_int:
-				info->res.val.f = (float) info->res.val.i;
+				info->res.val.f = (float)info->res.val.i;
 				break;
 
 			case fex_llong:
-				info->res.val.f = (float) info->res.val.l;
+				info->res.val.f = (float)info->res.val.l;
 				break;
 
 			case fex_double:
-				info->res.val.f = (float) info->res.val.d;
+				info->res.val.f = (float)info->res.val.d;
 				break;
 
 			case fex_ldouble:
-				info->res.val.f = (float) info->res.val.q;
+				info->res.val.f = (float)info->res.val.q;
 				break;
 
 			default:
 				break;
 			}
-			*(float*)FPreg(rd) = info->res.val.f;
+
+			*(float *)FPreg(rd) = info->res.val.f;
 			break;
 
-		case 0x8: /* result is double */
+		case 0x8:		/* result is double */
+
 			switch (info->res.type) {
 			case fex_int:
-				info->res.val.d = (double) info->res.val.i;
+				info->res.val.d = (double)info->res.val.i;
 				break;
 
 			case fex_llong:
-				info->res.val.d = (double) info->res.val.l;
+				info->res.val.d = (double)info->res.val.l;
 				break;
 
 			case fex_float:
-				info->res.val.d = (double) info->res.val.f;
+				info->res.val.d = (double)info->res.val.f;
 				break;
 
 			case fex_ldouble:
-				info->res.val.d = (double) info->res.val.q;
+				info->res.val.d = (double)info->res.val.q;
 				break;
 
 			default:
 				break;
 			}
-			*(double*)FPREG(rd) = info->res.val.d;
+
+			*(double *)FPREG(rd) = info->res.val.d;
 			break;
 
-		case 0xc: /* result is long double */
+		case 0xc:		/* result is long double */
+
 			switch (info->res.type) {
 			case fex_int:
-				info->res.val.q = (long double) info->res.val.i;
+				info->res.val.q = (long double)info->res.val.i;
 				break;
 
 			case fex_llong:
-				info->res.val.q = (long double) info->res.val.l;
+				info->res.val.q = (long double)info->res.val.l;
 				break;
 
 			case fex_float:
-				info->res.val.q = (long double) info->res.val.f;
+				info->res.val.q = (long double)info->res.val.f;
 				break;
 
 			case fex_double:
-				info->res.val.q = (long double) info->res.val.d;
+				info->res.val.q = (long double)info->res.val.d;
 				break;
 
 			default:
 				break;
 			}
-			*(long double*)FPREG(rd) = info->res.val.q;
+
+			*(long double *)FPREG(rd) = info->res.val.q;
 			break;
 		}
+
 		return;
 	}
 
-	if ((opf & 0xf0) == 0x60) { /* fsmuld, fdmulq */
+	if ((opf & 0xf0) == 0x60) {	/* fsmuld, fdmulq */
 		switch (opf & 0xc0) {
-		case 0x8: /* result is double */
+		case 0x8:		/* result is double */
+
 			switch (info->res.type) {
 			case fex_int:
-				info->res.val.d = (double) info->res.val.i;
+				info->res.val.d = (double)info->res.val.i;
 				break;
 
 			case fex_llong:
-				info->res.val.d = (double) info->res.val.l;
+				info->res.val.d = (double)info->res.val.l;
 				break;
 
 			case fex_float:
-				info->res.val.d = (double) info->res.val.f;
+				info->res.val.d = (double)info->res.val.f;
 				break;
 
 			case fex_ldouble:
-				info->res.val.d = (double) info->res.val.q;
+				info->res.val.d = (double)info->res.val.q;
 				break;
 
 			default:
 				break;
 			}
-			*(double*)FPREG(rd) = info->res.val.d;
+
+			*(double *)FPREG(rd) = info->res.val.d;
 			break;
 
-		case 0xc: /* result is long double */
+		case 0xc:		/* result is long double */
+
 			switch (info->res.type) {
 			case fex_int:
-				info->res.val.q = (long double) info->res.val.i;
+				info->res.val.q = (long double)info->res.val.i;
 				break;
 
 			case fex_llong:
-				info->res.val.q = (long double) info->res.val.l;
+				info->res.val.q = (long double)info->res.val.l;
 				break;
 
 			case fex_float:
-				info->res.val.q = (long double) info->res.val.f;
+				info->res.val.q = (long double)info->res.val.f;
 				break;
 
 			case fex_double:
-				info->res.val.q = (long double) info->res.val.d;
+				info->res.val.q = (long double)info->res.val.d;
 				break;
 
 			default:
 				break;
 			}
-			*(long double*)FPREG(rd) = info->res.val.q;
+
+			*(long double *)FPREG(rd) = info->res.val.q;
 			break;
 		}
+
 		return;
 	}
 
-	switch (opf & 3) { /* other arithmetic op */
-	case 1: /* result is float */
+	switch (opf & 3) {		/* other arithmetic op */
+	case 1:				/* result is float */
+
 		switch (info->res.type) {
 		case fex_int:
-			info->res.val.f = (float) info->res.val.i;
+			info->res.val.f = (float)info->res.val.i;
 			break;
 
 		case fex_llong:
-			info->res.val.f = (float) info->res.val.l;
+			info->res.val.f = (float)info->res.val.l;
 			break;
 
 		case fex_double:
-			info->res.val.f = (float) info->res.val.d;
+			info->res.val.f = (float)info->res.val.d;
 			break;
 
 		case fex_ldouble:
-			info->res.val.f = (float) info->res.val.q;
+			info->res.val.f = (float)info->res.val.q;
 			break;
 
 		default:
 			break;
 		}
-		*(float*)FPreg(rd) = info->res.val.f;
+
+		*(float *)FPreg(rd) = info->res.val.f;
 		break;
 
-	case 2: /* result is double */
+	case 2:				/* result is double */
+
 		switch (info->res.type) {
 		case fex_int:
-			info->res.val.d = (double) info->res.val.i;
+			info->res.val.d = (double)info->res.val.i;
 			break;
 
 		case fex_llong:
-			info->res.val.d = (double) info->res.val.l;
+			info->res.val.d = (double)info->res.val.l;
 			break;
 
 		case fex_float:
-			info->res.val.d = (double) info->res.val.f;
+			info->res.val.d = (double)info->res.val.f;
 			break;
 
 		case fex_ldouble:
-			info->res.val.d = (double) info->res.val.q;
+			info->res.val.d = (double)info->res.val.q;
 			break;
 
 		default:
 			break;
 		}
-		*(double*)FPREG(rd) = info->res.val.d;
+
+		*(double *)FPREG(rd) = info->res.val.d;
 		break;
 
-	case 3: /* result is long double */
+	case 3:				/* result is long double */
+
 		switch (info->res.type) {
 		case fex_int:
-			info->res.val.q = (long double) info->res.val.i;
+			info->res.val.q = (long double)info->res.val.i;
 			break;
 
 		case fex_llong:
-			info->res.val.q = (long double) info->res.val.l;
+			info->res.val.q = (long double)info->res.val.l;
 			break;
 
 		case fex_float:
-			info->res.val.q = (long double) info->res.val.f;
+			info->res.val.q = (long double)info->res.val.f;
 			break;
 
 		case fex_double:
-			info->res.val.q = (long double) info->res.val.d;
+			info->res.val.q = (long double)info->res.val.d;
 			break;
 
 		default:
 			break;
 		}
-		*(long double*)FPREG(rd) = info->res.val.q;
+
+		*(long double *)FPREG(rd) = info->res.val.q;
 		break;
 	}
 }
-#endif	/* defined(__sparc) */
+#endif /* defined(__sparc) */
--- old/usr/src/lib/libm/common/m9x/__fex_sse.c	2019-06-06 20:40:06.098970671 +0000
+++ new/usr/src/lib/libm/common/m9x/__fex_sse.c	2019-06-06 20:40:06.118025545 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,18 +39,18 @@
 #include "fenv_inlines.h"
 
 #if !defined(REG_PC)
-#define REG_PC	EIP
+#define	REG_PC		EIP
 #endif
 
 #if !defined(REG_PS)
-#define REG_PS	EFL
+#define	REG_PS		EFL
 #endif
 
 #ifdef __amd64
-#define regno(X)	((X < 4)? REG_RAX - X : \
-			((X > 4)? REG_RAX + 1 - X : REG_RSP))
+#define	regno(X)	((X < 4) ? REG_RAX - X : ((X > 4) ? REG_RAX + 1 - X : \
+	REG_RSP))
 #else
-#define regno(X)	(EAX - X)
+#define	regno(X)	(EAX - X)
 #endif
 
 /*
@@ -63,9 +64,9 @@
 int
 __fex_parse_sse(ucontext_t *uap, sseinst_t *inst)
 {
-	unsigned char	*ip;
-	char		*addr;
-	int		i, dbl, simd, rex, modrm, sib, r;
+	unsigned char *ip;
+	char *addr;
+	int i, dbl, simd, rex, modrm, sib, r;
 
 	i = 0;
 	ip = (unsigned char *)uap->uc_mcontext.gregs[REG_PC];
@@ -73,6 +74,7 @@
 	/* look for pseudo-prefixes */
 	dbl = 0;
 	simd = SIMD;
+
 	if (ip[i] == 0xF3) {
 		simd = 0;
 		i++;
@@ -87,6 +89,7 @@
 
 	/* look for AMD64 REX prefix */
 	rex = 0;
+
 	if (ip[i] >= 0x40 && ip[i] <= 0x4F) {
 		rex = ip[i];
 		i++;
@@ -94,37 +97,48 @@
 
 	/* parse opcode */
 	if (ip[i++] != 0x0F)
-		return 0;
+		return (0);
+
 	switch (ip[i++]) {
 	case 0x2A:
 		inst->op = (int)cvtsi2ss + simd + dbl;
+
 		if (!simd)
 			inst->op = (int)inst->op + (rex & 8);
+
 		break;
 
 	case 0x2C:
 		inst->op = (int)cvttss2si + simd + dbl;
+
 		if (!simd)
 			inst->op = (int)inst->op + (rex & 8);
+
 		break;
 
 	case 0x2D:
 		inst->op = (int)cvtss2si + simd + dbl;
+
 		if (!simd)
 			inst->op = (int)inst->op + (rex & 8);
+
 		break;
 
 	case 0x2E:
+
 		/* oddball: scalar instruction in a SIMD opcode group */
 		if (!simd)
-			return 0;
+			return (0);
+
 		inst->op = (int)ucomiss + dbl;
 		break;
 
 	case 0x2F:
+
 		/* oddball: scalar instruction in a SIMD opcode group */
 		if (!simd)
-			return 0;
+			return (0);
+
 		inst->op = (int)comiss + dbl;
 		break;
 
@@ -145,14 +159,16 @@
 		break;
 
 	case 0x5B:
+
 		if (dbl) {
 			if (simd)
 				inst->op = cvtps2dq;
 			else
-				return 0;
+				return (0);
 		} else {
-			inst->op = (simd)? cvtdq2ps : cvttps2dq;
+			inst->op = (simd) ? cvtdq2ps : cvttps2dq;
 		}
+
 		break;
 
 	case 0x5C:
@@ -176,78 +192,86 @@
 		break;
 
 	case 0xE6:
+
 		if (simd) {
 			if (dbl)
 				inst->op = cvttpd2dq;
 			else
-				return 0;
+				return (0);
 		} else {
-			inst->op = (dbl)? cvtpd2dq : cvtdq2pd;
+			inst->op = (dbl) ? cvtpd2dq : cvtdq2pd;
 		}
+
 		break;
 
 	default:
-		return 0;
+		return (0);
 	}
 
 	/* locate operands */
 	modrm = ip[i++];
 
-	if (inst->op == cvtss2si || inst->op == cvttss2si ||
-	    inst->op == cvtsd2si || inst->op == cvttsd2si ||
-	    inst->op == cvtss2siq || inst->op == cvttss2siq ||
-	    inst->op == cvtsd2siq || inst->op == cvttsd2siq) {
+	if (inst->op == cvtss2si || inst->op == cvttss2si || inst->op ==
+	    cvtsd2si || inst->op == cvttsd2si || inst->op == cvtss2siq ||
+	    inst->op == cvttss2siq || inst->op == cvtsd2siq || inst->op ==
+	    cvttsd2siq) {
 		/* op1 is a gp register */
 		r = ((rex & 4) << 1) | ((modrm >> 3) & 7);
 		inst->op1 = (sseoperand_t *)&uap->uc_mcontext.gregs[regno(r)];
-	} else if (inst->op == cvtps2pi || inst->op == cvttps2pi ||
-	    inst->op == cvtpd2pi || inst->op == cvttpd2pi) {
+	} else if (inst->op == cvtps2pi || inst->op == cvttps2pi || inst->op ==
+	    cvtpd2pi || inst->op == cvttpd2pi) {
 		/* op1 is a mmx register */
 #ifdef __amd64
-		inst->op1 = (sseoperand_t *)&uap->uc_mcontext.fpregs.fp_reg_set.
-		    fpchip_state.st[(modrm >> 3) & 7];
+		inst->op1 = (sseoperand_t *)
+		    &uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state
+		    .st[(modrm >> 3) & 7];
 #else
 		inst->op1 = (sseoperand_t *)(10 * ((modrm >> 3) & 7) +
-		    (char *)&uap->uc_mcontext.fpregs.fp_reg_set.
-		    fpchip_state.state[7]);
+		    (char *)&uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state
+		    .state[7]);
 #endif
 	} else {
 		/* op1 is a xmm register */
 		r = ((rex & 4) << 1) | ((modrm >> 3) & 7);
-		inst->op1 = (sseoperand_t *)&uap->uc_mcontext.fpregs.
-		    fp_reg_set.fpchip_state.xmm[r];
+		inst->op1 =
+		    (sseoperand_t *)&uap->uc_mcontext.fpregs.fp_reg_set
+		    .fpchip_state.xmm[r];
 	}
 
 	if ((modrm >> 6) == 3) {
-		if (inst->op == cvtsi2ss || inst->op == cvtsi2sd ||
-		    inst->op == cvtsi2ssq || inst->op == cvtsi2sdq) {
+		if (inst->op == cvtsi2ss || inst->op == cvtsi2sd || inst->op ==
+		    cvtsi2ssq || inst->op == cvtsi2sdq) {
 			/* op2 is a gp register */
 			r = ((rex & 1) << 3) | (modrm & 7);
-			inst->op2 = (sseoperand_t *)&uap->uc_mcontext.
-			    gregs[regno(r)];
+			inst->op2 =
+			    (sseoperand_t *)&uap->uc_mcontext.gregs[regno(r)];
 		} else if (inst->op == cvtpi2ps || inst->op == cvtpi2pd) {
 			/* op2 is a mmx register */
 #ifdef __amd64
-			inst->op2 = (sseoperand_t *)&uap->uc_mcontext.fpregs.
-			    fp_reg_set.fpchip_state.st[modrm & 7];
+			inst->op2 =
+			    (sseoperand_t *)&uap->uc_mcontext.fpregs.fp_reg_set
+			    .fpchip_state.st[modrm & 7];
 #else
 			inst->op2 = (sseoperand_t *)(10 * (modrm & 7) +
-			    (char *)&uap->uc_mcontext.fpregs.fp_reg_set.
-			    fpchip_state.state[7]);
+			    (char *)&uap->uc_mcontext.fpregs.fp_reg_set
+			    .fpchip_state.state[7]);
 #endif
 		} else {
 			/* op2 is a xmm register */
 			r = ((rex & 1) << 3) | (modrm & 7);
-			inst->op2 = (sseoperand_t *)&uap->uc_mcontext.fpregs.
-			    fp_reg_set.fpchip_state.xmm[r];
+			inst->op2 =
+			    (sseoperand_t *)&uap->uc_mcontext.fpregs.fp_reg_set
+			    .fpchip_state.xmm[r];
 		}
 	} else if ((modrm & 0xc7) == 0x05) {
 #ifdef __amd64
 		/* address of next instruction + offset */
 		r = i + 4;
-		if (inst->op == cmpss || inst->op == cmpps ||
-		    inst->op == cmpsd || inst->op == cmppd)
+
+		if (inst->op == cmpss || inst->op == cmpps || inst->op ==
+		    cmpsd || inst->op == cmppd)
 			r++;
+
 		inst->op2 = (sseoperand_t *)(ip + r + *(int *)(ip + i));
 #else
 		/* absolute address */
@@ -259,6 +283,7 @@
 		if ((modrm & 7) == 4) {
 			/* parse sib byte */
 			sib = ip[i++];
+
 			if ((sib & 7) == 5 && (modrm >> 6) == 0) {
 				/* start with absolute address */
 				addr = (char *)(uintptr_t)(*(int *)(ip + i));
@@ -268,11 +293,13 @@
 				r = ((rex & 1) << 3) | (sib & 7);
 				addr = (char *)uap->uc_mcontext.gregs[regno(r)];
 			}
+
 			r = ((rex & 2) << 2) | ((sib >> 3) & 7);
+
 			if (r != 4) {
 				/* add scaled index */
-				addr += uap->uc_mcontext.gregs[regno(r)]
-				    << (sib >> 6);
+				addr += uap->uc_mcontext.gregs[regno(r)] <<
+				    (sib >> 6);
 			}
 		} else {
 			r = ((rex & 1) << 3) | (modrm & 7);
@@ -286,6 +313,7 @@
 			addr += *(int *)(ip + i);
 			i += 4;
 		}
+
 		inst->op2 = (sseoperand_t *)addr;
 	}
 
@@ -295,43 +323,46 @@
 		inst->imm = ip[i++];
 	}
 
-	return i;
+	return (i);
 }
 
 static enum fp_class_type
 my_fp_classf(float *x)
 {
-	int	i = *(int *)x & ~0x80000000;
+	int i = *(int *)x & ~0x80000000;
 
 	if (i < 0x7f800000) {
 		if (i < 0x00800000)
-			return ((i == 0)? fp_zero : fp_subnormal);
-		return fp_normal;
+			return ((i == 0) ? fp_zero : fp_subnormal);
+
+		return (fp_normal);
+	} else if (i == 0x7f800000) {
+		return (fp_infinity);
+	} else if (i & 0x400000) {
+		return (fp_quiet);
+	} else {
+		return (fp_signaling);
 	}
-	else if (i == 0x7f800000)
-		return fp_infinity;
-	else if (i & 0x400000)
-		return fp_quiet;
-	else
-		return fp_signaling;
 }
 
 static enum fp_class_type
 my_fp_class(double *x)
 {
-	int	i = *(1+(int *)x) & ~0x80000000;
+	int i = *(1 + (int *)x) & ~0x80000000;
 
 	if (i < 0x7ff00000) {
 		if (i < 0x00100000)
-			return (((i | *(int *)x) == 0)? fp_zero : fp_subnormal);
-		return fp_normal;
+			return (((i | *(int *)x) == 0) ? fp_zero :
+			    fp_subnormal);
+
+		return (fp_normal);
+	} else if (i == 0x7ff00000 && *(int *)x == 0) {
+		return (fp_infinity);
+	} else if (i & 0x80000) {
+		return (fp_quiet);
+	} else {
+		return (fp_signaling);
 	}
-	else if (i == 0x7ff00000 && *(int *)x == 0)
-		return fp_infinity;
-	else if (i & 0x80000)
-		return fp_quiet;
-	else
-		return fp_signaling;
 }
 
 /*
@@ -341,24 +372,25 @@
 static enum fex_exception
 __fex_get_sse_invalid_type(sseinst_t *inst)
 {
-	enum fp_class_type	t1, t2;
+	enum fp_class_type t1, t2;
 
 	/* check op2 for signaling nan */
-	t2 = ((int)inst->op & DOUBLE)? my_fp_class(&inst->op2->d[0]) :
+	t2 = ((int)inst->op & DOUBLE) ? my_fp_class(&inst->op2->d[0]) :
 	    my_fp_classf(&inst->op2->f[0]);
+
 	if (t2 == fp_signaling)
-		return fex_inv_snan;
+		return (fex_inv_snan);
 
 	/* eliminate all single-operand instructions */
 	switch (inst->op) {
 	case cvtsd2ss:
 	case cvtss2sd:
 		/* hmm, this shouldn't have happened */
-		return (enum fex_exception) -1;
+		return ((enum fex_exception)-1);
 
 	case sqrtss:
 	case sqrtsd:
-		return fex_inv_sqrt;
+		return (fex_inv_sqrt);
 
 	case cvtss2si:
 	case cvtsd2si:
@@ -368,16 +400,17 @@
 	case cvtsd2siq:
 	case cvttss2siq:
 	case cvttsd2siq:
-		return fex_inv_int;
+		return (fex_inv_int);
 	default:
 		break;
 	}
 
 	/* check op1 for signaling nan */
-	t1 = ((int)inst->op & DOUBLE)? my_fp_class(&inst->op1->d[0]) :
+	t1 = ((int)inst->op & DOUBLE) ? my_fp_class(&inst->op1->d[0]) :
 	    my_fp_classf(&inst->op1->f[0]);
+
 	if (t1 == fp_signaling)
-		return fex_inv_snan;
+		return (fex_inv_snan);
 
 	/* check two-operand instructions for other cases */
 	switch (inst->op) {
@@ -389,34 +422,41 @@
 	case maxsd:
 	case comiss:
 	case comisd:
-		return fex_inv_cmp;
+		return (fex_inv_cmp);
 
 	case addss:
 	case addsd:
 	case subss:
 	case subsd:
+
 		if (t1 == fp_infinity && t2 == fp_infinity)
-			return fex_inv_isi;
+			return (fex_inv_isi);
+
 		break;
 
 	case mulss:
 	case mulsd:
-		if ((t1 == fp_zero && t2 == fp_infinity) ||
-		    (t2 == fp_zero && t1 == fp_infinity))
-			return fex_inv_zmi;
+
+		if ((t1 == fp_zero && t2 == fp_infinity) || (t2 == fp_zero &&
+		    t1 == fp_infinity))
+			return (fex_inv_zmi);
+
 		break;
 
 	case divss:
 	case divsd:
+
 		if (t1 == fp_zero && t2 == fp_zero)
-			return fex_inv_zdz;
+			return (fex_inv_zdz);
+
 		if (t1 == fp_infinity && t2 == fp_infinity)
-			return fex_inv_idi;
+			return (fex_inv_idi);
+
 	default:
 		break;
 	}
 
-	return (enum fex_exception)-1;
+	return ((enum fex_exception)-1);
 }
 
 /* inline templates */
@@ -437,11 +477,13 @@
 extern void sse_cvtsi2ss(int *, float *);
 extern void sse_cvttss2si(float *, int *);
 extern void sse_cvtss2si(float *, int *);
+
 #ifdef __amd64
 extern void sse_cvtsi2ssq(long long *, float *);
 extern void sse_cvttss2siq(float *, long long *);
 extern void sse_cvtss2siq(float *, long long *);
 #endif
+
 extern void sse_cmpeqsd(double *, double *, long long *);
 extern void sse_cmpltsd(double *, double *, long long *);
 extern void sse_cmplesd(double *, double *, long long *);
@@ -459,6 +501,7 @@
 extern void sse_cvtsi2sd(int *, double *);
 extern void sse_cvttsd2si(double *, int *);
 extern void sse_cvtsd2si(double *, int *);
+
 #ifdef __amd64
 extern void sse_cvtsi2sdq(long long *, double *);
 extern void sse_cvttsd2siq(double *, long long *);
@@ -478,7 +521,7 @@
 enum fex_exception
 __fex_get_sse_op(ucontext_t *uap, sseinst_t *inst, fex_info_t *info)
 {
-	unsigned int	e, te, mxcsr, oldmxcsr, subnorm;
+	unsigned int e, te, mxcsr, oldmxcsr, subnorm;
 
 	/*
 	 * Perform the operation with traps disabled and check the
@@ -487,6 +530,7 @@
 	 */
 	__fenv_getmxcsr(&oldmxcsr);
 	subnorm = 0;
+
 	if ((int)inst->op & DOUBLE) {
 		if (inst->op == cvtsi2sd) {
 			info->op1.type = fex_int;
@@ -497,8 +541,8 @@
 			info->op1.val.l = inst->op2->l[0];
 			info->op2.type = fex_nodata;
 		} else if (inst->op == sqrtsd || inst->op == cvtsd2ss ||
-		    inst->op == cvttsd2si || inst->op == cvtsd2si ||
-		    inst->op == cvttsd2siq || inst->op == cvtsd2siq) {
+		    inst->op == cvttsd2si || inst->op == cvtsd2si || inst->op ==
+		    cvttsd2siq || inst->op == cvtsd2siq) {
 			info->op1.type = fex_double;
 			info->op1.val.d = inst->op2->d[0];
 			info->op2.type = fex_nodata;
@@ -508,11 +552,14 @@
 			info->op2.type = fex_double;
 			info->op2.val.d = inst->op2->d[0];
 		}
+
 		info->res.type = fex_double;
+
 		switch (inst->op) {
 		case cmpsd:
 			info->op = fex_cmp;
 			info->res.type = fex_llong;
+
 			switch (inst->imm & 3) {
 			case 0:
 				sse_cmpeqsd(&info->op1.val.d, &info->op2.val.d,
@@ -533,8 +580,10 @@
 				sse_cmpunordsd(&info->op1.val.d,
 				    &info->op2.val.d, &info->res.val.l);
 			}
+
 			if (inst->imm & 4)
 				info->res.val.l ^= 0xffffffffffffffffull;
+
 			break;
 
 		case minsd:
@@ -553,32 +602,40 @@
 			info->op = fex_add;
 			sse_addsd(&info->op1.val.d, &info->op2.val.d,
 			    &info->res.val.d);
+
 			if (my_fp_class(&info->res.val.d) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case subsd:
 			info->op = fex_sub;
 			sse_subsd(&info->op1.val.d, &info->op2.val.d,
 			    &info->res.val.d);
+
 			if (my_fp_class(&info->res.val.d) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case mulsd:
 			info->op = fex_mul;
 			sse_mulsd(&info->op1.val.d, &info->op2.val.d,
 			    &info->res.val.d);
+
 			if (my_fp_class(&info->res.val.d) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case divsd:
 			info->op = fex_div;
 			sse_divsd(&info->op1.val.d, &info->op2.val.d,
 			    &info->res.val.d);
+
 			if (my_fp_class(&info->res.val.d) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case sqrtsd:
@@ -590,8 +647,10 @@
 			info->op = fex_cnvt;
 			info->res.type = fex_float;
 			sse_cvtsd2ss(&info->op1.val.d, &info->res.val.f);
+
 			if (my_fp_classf(&info->res.val.f) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case cvtsi2sd:
@@ -654,8 +713,8 @@
 			info->op1.val.l = inst->op2->l[0];
 			info->op2.type = fex_nodata;
 		} else if (inst->op == sqrtss || inst->op == cvtss2sd ||
-		    inst->op == cvttss2si || inst->op == cvtss2si ||
-		    inst->op == cvttss2siq || inst->op == cvtss2siq) {
+		    inst->op == cvttss2si || inst->op == cvtss2si || inst->op ==
+		    cvttss2siq || inst->op == cvtss2siq) {
 			info->op1.type = fex_float;
 			info->op1.val.f = inst->op2->f[0];
 			info->op2.type = fex_nodata;
@@ -665,11 +724,14 @@
 			info->op2.type = fex_float;
 			info->op2.val.f = inst->op2->f[0];
 		}
+
 		info->res.type = fex_float;
+
 		switch (inst->op) {
 		case cmpss:
 			info->op = fex_cmp;
 			info->res.type = fex_int;
+
 			switch (inst->imm & 3) {
 			case 0:
 				sse_cmpeqss(&info->op1.val.f, &info->op2.val.f,
@@ -690,8 +752,10 @@
 				sse_cmpunordss(&info->op1.val.f,
 				    &info->op2.val.f, &info->res.val.i);
 			}
+
 			if (inst->imm & 4)
 				info->res.val.i ^= 0xffffffffu;
+
 			break;
 
 		case minss:
@@ -710,32 +774,40 @@
 			info->op = fex_add;
 			sse_addss(&info->op1.val.f, &info->op2.val.f,
 			    &info->res.val.f);
+
 			if (my_fp_classf(&info->res.val.f) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case subss:
 			info->op = fex_sub;
 			sse_subss(&info->op1.val.f, &info->op2.val.f,
 			    &info->res.val.f);
+
 			if (my_fp_classf(&info->res.val.f) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case mulss:
 			info->op = fex_mul;
 			sse_mulss(&info->op1.val.f, &info->op2.val.f,
 			    &info->res.val.f);
+
 			if (my_fp_classf(&info->res.val.f) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case divss:
 			info->op = fex_div;
 			sse_divss(&info->op1.val.f, &info->op2.val.f,
 			    &info->res.val.f);
+
 			if (my_fp_classf(&info->res.val.f) == fp_subnormal)
 				subnorm = 1;
+
 			break;
 
 		case sqrtss:
@@ -800,25 +872,32 @@
 			break;
 		}
 	}
+
 	__fenv_getmxcsr(&mxcsr);
 	info->flags = mxcsr & 0x3d;
 	__fenv_setmxcsr(&oldmxcsr);
 
 	/* determine which exception would have been trapped */
-	te = ~(uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.mxcsr
-	    >> 7) & 0x3d;
+	te = ~(uap->uc_mcontext.fpregs.fp_reg_set.fpchip_state.mxcsr >> 7) &
+	    0x3d;
 	e = mxcsr & te;
+
 	if (e & FE_INVALID)
-		return __fex_get_sse_invalid_type(inst);
+		return (__fex_get_sse_invalid_type(inst));
+
 	if (e & FE_DIVBYZERO)
-		return fex_division;
+		return (fex_division);
+
 	if (e & FE_OVERFLOW)
-		return fex_overflow;
+		return (fex_overflow);
+
 	if ((e & FE_UNDERFLOW) || (subnorm && (te & FE_UNDERFLOW)))
-		return fex_underflow;
+		return (fex_underflow);
+
 	if (e & FE_INEXACT)
-		return fex_inexact;
-	return (enum fex_exception)-1;
+		return (fex_inexact);
+
+	return ((enum fex_exception)-1);
 }
 
 /*
@@ -837,8 +916,8 @@
 __fex_get_simd_op(ucontext_t *uap, sseinst_t *inst, enum fex_exception *e,
     fex_info_t *info)
 {
-	sseinst_t	dummy;
-	int		i;
+	sseinst_t dummy;
+	int i;
 
 	e[0] = e[1] = e[2] = e[3] = -1;
 
@@ -847,249 +926,303 @@
 	case cmpps:
 		dummy.op = cmpss;
 		dummy.imm = inst->imm;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case minps:
 		dummy.op = minss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case maxps:
 		dummy.op = maxss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case addps:
 		dummy.op = addss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case subps:
 		dummy.op = subss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case mulps:
 		dummy.op = mulss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case divps:
 		dummy.op = divss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case sqrtps:
 		dummy.op = sqrtss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtdq2ps:
 		dummy.op = cvtsi2ss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->i[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvttps2dq:
 		dummy.op = cvttss2si;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtps2dq:
 		dummy.op = cvtss2si;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtpi2ps:
 		dummy.op = cvtsi2ss;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->i[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvttps2pi:
 		dummy.op = cvttss2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtps2pi:
 		dummy.op = cvtss2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cmppd:
 		dummy.op = cmpsd;
 		dummy.imm = inst->imm;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case minpd:
 		dummy.op = minsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case maxpd:
 		dummy.op = maxsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case addpd:
 		dummy.op = addsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case subpd:
 		dummy.op = subsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case mulpd:
 		dummy.op = mulsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case divpd:
 		dummy.op = divsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case sqrtpd:
 		dummy.op = sqrtsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtpi2pd:
 	case cvtdq2pd:
 		dummy.op = cvtsi2sd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->i[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvttpd2pi:
 	case cvttpd2dq:
 		dummy.op = cvttsd2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtpd2pi:
 	case cvtpd2dq:
 		dummy.op = cvtsd2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtps2pd:
 		dummy.op = cvtss2sd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 		break;
 
 	case cvtpd2ps:
 		dummy.op = cvtsd2ss;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			e[i] = __fex_get_sse_op(uap, &dummy, &info[i]);
 		}
+
 	default:
 		break;
 	}
@@ -1107,38 +1240,44 @@
 __fex_st_sse_result(ucontext_t *uap, sseinst_t *inst, enum fex_exception e,
     fex_info_t *info)
 {
-	int		i = 0;
-	long long	l = 0L;;
-	float		f = 0.0, fscl;
-	double		d = 0.0L, dscl;
-
-	/* for compares that write eflags, just set the flags
-	   to indicate "unordered" */
-	if (inst->op == ucomiss || inst->op == comiss ||
-	    inst->op == ucomisd || inst->op == comisd) {
+	int i = 0;
+	long long l = 0L;
+	float f = 0.0, fscl;
+	double d = 0.0L, dscl;
+
+	/*
+	 * for compares that write eflags, just set the flags
+	 * to indicate "unordered"
+	 */
+	if (inst->op == ucomiss || inst->op == comiss || inst->op == ucomisd ||
+	    inst->op == comisd) {
 		uap->uc_mcontext.gregs[REG_PS] |= 0x45;
 		return;
 	}
 
-	/* if info doesn't specify a result value, try to generate
-	   the default trapped result */
+	/*
+	 * if info doesn't specify a result value, try to generate
+	 * the default trapped result
+	 */
 	if (info->res.type == fex_nodata) {
 		/* set scale factors for exponent wrapping */
 		switch (e) {
 		case fex_overflow:
-			fscl = 1.262177448e-29f; /* 2^-96 */
-			dscl = 6.441148769597133308e-232; /* 2^-768 */
+			fscl = 1.262177448e-29f;		/* 2^-96 */
+			dscl = 6.441148769597133308e-232;	/* 2^-768 */
 			break;
 
 		case fex_underflow:
-			fscl = 7.922816251e+28f; /* 2^96 */
-			dscl = 1.552518092300708935e+231; /* 2^768 */
+			fscl = 7.922816251e+28f;		/* 2^96 */
+			dscl = 1.552518092300708935e+231;	/* 2^768 */
 			break;
 
 		default:
 			(void) __fex_get_sse_op(uap, inst, info);
+
 			if (info->res.type == fex_nodata)
 				return;
+
 			goto stuff;
 		}
 
@@ -1156,6 +1295,7 @@
 			info->op2.type = fex_double;
 			info->op2.val.d = inst->op2->d[0];
 			info->res.type = fex_double;
+
 			switch (inst->op) {
 			case addsd:
 				info->res.val.d = dscl * (dscl *
@@ -1186,6 +1326,7 @@
 			info->op2.type = fex_float;
 			info->op2.val.f = inst->op2->f[0];
 			info->res.type = fex_float;
+
 			switch (inst->op) {
 			case addss:
 				info->res.val.f = fscl * (fscl *
@@ -1215,8 +1356,8 @@
 
 	/* put the result in the destination */
 stuff:
-	if (inst->op == cmpss || inst->op == cvttss2si || inst->op == cvtss2si
-	    || inst->op == cvttsd2si || inst->op == cvtsd2si) {
+	if (inst->op == cmpss || inst->op == cvttss2si || inst->op ==
+	    cvtss2si || inst->op == cvttsd2si || inst->op == cvtsd2si) {
 		switch (info->res.type) {
 		case fex_int:
 			i = info->res.val.i;
@@ -1241,10 +1382,10 @@
 		default:
 			break;
 		}
+
 		inst->op1->i[0] = i;
-	} else if (inst->op == cmpsd || inst->op == cvttss2siq ||
-	    inst->op == cvtss2siq || inst->op == cvttsd2siq ||
-	    inst->op == cvtsd2siq) {
+	} else if (inst->op == cmpsd || inst->op == cvttss2siq || inst->op ==
+	    cvtss2siq || inst->op == cvttsd2siq || inst->op == cvtsd2siq) {
 		switch (info->res.type) {
 		case fex_int:
 			l = info->res.val.i;
@@ -1269,6 +1410,7 @@
 		default:
 			break;
 		}
+
 		inst->op1->l[0] = l;
 	} else if ((((int)inst->op & DOUBLE) && inst->op != cvtsd2ss) ||
 	    inst->op == cvtss2sd) {
@@ -1296,6 +1438,7 @@
 		default:
 			break;
 		}
+
 		inst->op1->d[0] = d;
 	} else {
 		switch (info->res.type) {
@@ -1322,6 +1465,7 @@
 		default:
 			break;
 		}
+
 		inst->op1->f[0] = f;
 	}
 }
@@ -1340,263 +1484,319 @@
 __fex_st_simd_result(ucontext_t *uap, sseinst_t *inst, enum fex_exception *e,
     fex_info_t *info)
 {
-	sseinst_t	dummy;
-	int		i;
+	sseinst_t dummy;
+	int i;
 
 	/* store each part */
 	switch (inst->op) {
 	case cmpps:
 		dummy.op = cmpss;
 		dummy.imm = inst->imm;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case minps:
 		dummy.op = minss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case maxps:
 		dummy.op = maxss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case addps:
 		dummy.op = addss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case subps:
 		dummy.op = subss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case mulps:
 		dummy.op = mulss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case divps:
 		dummy.op = divss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case sqrtps:
 		dummy.op = sqrtss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvtdq2ps:
 		dummy.op = cvtsi2ss;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->i[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvttps2dq:
 		dummy.op = cvttss2si;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvtps2dq:
 		dummy.op = cvtss2si;
+
 		for (i = 0; i < 4; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvtpi2ps:
 		dummy.op = cvtsi2ss;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->i[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvttps2pi:
 		dummy.op = cvttss2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvtps2pi:
 		dummy.op = cvtss2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cmppd:
 		dummy.op = cmpsd;
 		dummy.imm = inst->imm;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case minpd:
 		dummy.op = minsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case maxpd:
 		dummy.op = maxsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case addpd:
 		dummy.op = addsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case subpd:
 		dummy.op = subsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case mulpd:
 		dummy.op = mulsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case divpd:
 		dummy.op = divsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case sqrtpd:
 		dummy.op = sqrtsd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvtpi2pd:
 	case cvtdq2pd:
 		dummy.op = cvtsi2sd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->i[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvttpd2pi:
 	case cvttpd2dq:
 		dummy.op = cvttsd2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		/* for cvttpd2dq, zero the high 64 bits of the destination */
 		if (inst->op == cvttpd2dq)
 			inst->op1->l[1] = 0ll;
+
 		break;
 
 	case cvtpd2pi:
 	case cvtpd2dq:
 		dummy.op = cvtsd2si;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->i[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		/* for cvtpd2dq, zero the high 64 bits of the destination */
 		if (inst->op == cvtpd2dq)
 			inst->op1->l[1] = 0ll;
+
 		break;
 
 	case cvtps2pd:
 		dummy.op = cvtss2sd;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->d[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->f[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		break;
 
 	case cvtpd2ps:
 		dummy.op = cvtsd2ss;
+
 		for (i = 0; i < 2; i++) {
 			dummy.op1 = (sseoperand_t *)&inst->op1->f[i];
 			dummy.op2 = (sseoperand_t *)&inst->op2->d[i];
 			__fex_st_sse_result(uap, &dummy, e[i], &info[i]);
 		}
+
 		/* zero the high 64 bits of the destination */
 		inst->op1->l[1] = 0ll;
 
@@ -1604,4 +1804,3 @@
 		break;
 	}
 }
-
--- old/usr/src/lib/libm/common/m9x/__fex_sym.c	2019-06-06 20:40:06.820868715 +0000
+++ new/usr/src/lib/libm/common/m9x/__fex_sym.c	2019-06-06 20:40:06.838871412 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,258 +38,261 @@
 #include <sys/stat.h>
 
 #if defined(__sparcv9) || defined(__amd64)
-
-#define Elf_Ehdr	Elf64_Ehdr
-#define Elf_Phdr	Elf64_Phdr
-#define Elf_Shdr	Elf64_Shdr
-#define Elf_Sym		Elf64_Sym
-#define ELF_ST_BIND	ELF64_ST_BIND
-#define ELF_ST_TYPE	ELF64_ST_TYPE
-
+#define	Elf_Ehdr		Elf64_Ehdr
+#define	Elf_Phdr		Elf64_Phdr
+#define	Elf_Shdr		Elf64_Shdr
+#define	Elf_Sym			Elf64_Sym
+#define	ELF_ST_BIND		ELF64_ST_BIND
+#define	ELF_ST_TYPE		ELF64_ST_TYPE
 #else
-
-#define Elf_Ehdr	Elf32_Ehdr
-#define Elf_Phdr	Elf32_Phdr
-#define Elf_Shdr	Elf32_Shdr
-#define Elf_Sym		Elf32_Sym
-#define ELF_ST_BIND	ELF32_ST_BIND
-#define ELF_ST_TYPE	ELF32_ST_TYPE
-
-#endif	/* __sparcv9 */
+#define	Elf_Ehdr		Elf32_Ehdr
+#define	Elf_Phdr		Elf32_Phdr
+#define	Elf_Shdr		Elf32_Shdr
+#define	Elf_Sym			Elf32_Sym
+#define	ELF_ST_BIND		ELF32_ST_BIND
+#define	ELF_ST_TYPE		ELF32_ST_TYPE
+#endif /* __sparcv9 */
 
 /* semi-permanent data established by __fex_sym_init */
-static	prmap_t		*pm = NULL;		/* prmap_t array */
-static	int			npm = 0;		/* number of entries in pm */
+static prmap_t *pm = NULL;		/* prmap_t array */
+static int npm = 0;			/* number of entries in pm */
 
 /* transient data modified by __fex_sym */
-static	prmap_t		*lpm = NULL;	/* prmap_t found in last call */
-static	Elf_Phdr	*ph = NULL;		/* program header array */
-static	int			phsize = 0;		/* size of ph */
-static	int			nph;			/* number of entries in ph */
-static	char		*stbuf = NULL;	/* symbol and string table buffer */
-static	int			stbufsize = 0;	/* size of stbuf */
-static	int			stoffset;		/* offset of string table in stbuf */
-static	int			nsyms;			/* number of symbols in stbuf */
+static prmap_t *lpm = NULL;		/* prmap_t found in last call */
+static Elf_Phdr *ph = NULL;		/* program header array */
+static int phsize = 0;			/* size of ph */
+static int nph;				/* number of entries in ph */
+static char *stbuf = NULL;		/* symbol and string table buffer */
+static int stbufsize = 0;		/* size of stbuf */
+static int stoffset;			/* offset of string table in stbuf */
+static int nsyms;			/* number of symbols in stbuf */
 
 /* get a current prmap_t list (must call this before each stack trace) */
 void
 __fex_sym_init()
 {
-	struct stat	statbuf;
-	long		n;
-	int			i;
+	struct stat statbuf;
+	long n;
+	int i;
 
 	/* clear out the previous prmap_t list */
 	if (pm != NULL)
 		free(pm);
+
 	pm = lpm = NULL;
 	npm = 0;
 
 	/* get the current prmap_t list */
 	if (stat("/proc/self/map", &statbuf) < 0 || statbuf.st_size <= 0 ||
-		(pm = (prmap_t*)malloc(statbuf.st_size)) == NULL)
+	    (pm = (prmap_t *)malloc(statbuf.st_size)) == NULL)
 		return;
-	if ((i = open("/proc/self/map", O_RDONLY)) < 0)
-	{
+
+	if ((i = open("/proc/self/map", O_RDONLY)) < 0) {
 		free(pm);
 		pm = NULL;
 		return;
 	}
+
 	n = read(i, pm, statbuf.st_size);
 	close(i);
-	if (n != statbuf.st_size)
-	{
+
+	if (n != statbuf.st_size) {
 		free(pm);
 		pm = NULL;
+	} else {
+		npm = (int)(n / sizeof (prmap_t));
 	}
-	else
-		npm = (int) (n / sizeof(prmap_t));
 }
 
 /* read ELF program headers and symbols; return -1 on error, 0 otherwise */
 static int
 __fex_read_syms(int fd)
 {
-	Elf_Ehdr	h;
-	Elf_Shdr	*sh;
-	int			i, size;
+	Elf_Ehdr h;
+	Elf_Shdr *sh;
+	int i, size;
 
 	/* read the ELF header */
-	if (read(fd, &h, sizeof(h)) != sizeof(h))
-		return -1;
-	if (h.e_ident[EI_MAG0] != ELFMAG0 ||
-		h.e_ident[EI_MAG1] != ELFMAG1 ||
-		h.e_ident[EI_MAG2] != ELFMAG2 ||
-		h.e_ident[EI_MAG3] != ELFMAG3 ||
-		h.e_phentsize != sizeof(Elf_Phdr) ||
-		h.e_shentsize != sizeof(Elf_Shdr))
-		return -1;
+	if (read(fd, &h, sizeof (h)) != sizeof (h))
+		return (-1);
+
+	if (h.e_ident[EI_MAG0] != ELFMAG0 || h.e_ident[EI_MAG1] != ELFMAG1 ||
+	    h.e_ident[EI_MAG2] != ELFMAG2 || h.e_ident[EI_MAG3] != ELFMAG3 ||
+	    h.e_phentsize != sizeof (Elf_Phdr) || h.e_shentsize !=
+	    sizeof (Elf_Shdr))
+		return (-1);
 
 	/* get space for the program headers */
 	size = h.e_phnum * h.e_phentsize;
-	if (size > phsize)
-	{
+
+	if (size > phsize) {
 		if (ph)
 			free(ph);
+
 		phsize = nph = 0;
-		if ((ph = (Elf_Phdr*)malloc(size)) == NULL)
-			return -1;
+
+		if ((ph = (Elf_Phdr *)malloc(size)) == NULL)
+			return (-1);
+
 		phsize = size;
 	}
 
 	/* read the program headers */
-	if (lseek(fd, h.e_phoff, SEEK_SET) != h.e_phoff ||
-		read(fd, ph, size) != (ssize_t)size)
-	{
+	if (lseek(fd, h.e_phoff, SEEK_SET) != h.e_phoff || read(fd, ph, size) !=
+	    (ssize_t)size) {
 		nph = 0;
-		return -1;
+		return (-1);
 	}
+
 	nph = h.e_phnum;
 
 	/* read the section headers */
 	size = h.e_shnum * h.e_shentsize;
-	if ((sh = (Elf_Shdr*)malloc(size)) == NULL)
-		return -1;
-	if (lseek(fd, h.e_shoff, SEEK_SET) != h.e_shoff ||
-		read(fd, sh, size) != (ssize_t)size)
-	{
+
+	if ((sh = (Elf_Shdr *)malloc(size)) == NULL)
+		return (-1);
+
+	if (lseek(fd, h.e_shoff, SEEK_SET) != h.e_shoff || read(fd, sh, size) !=
+	    (ssize_t)size) {
 		free(sh);
-		return -1;
+		return (-1);
 	}
 
 	/* find the symtab section header */
-	for (i = 0; i < h.e_shnum; i++)
-	{
+	for (i = 0; i < h.e_shnum; i++) {
 		if (sh[i].sh_type == SHT_SYMTAB)
-			break; /* assume there is only one */
+			break;		/* assume there is only one */
 	}
-	if (i == h.e_shnum || sh[i].sh_size == 0 ||
-		sh[i].sh_entsize != sizeof(Elf_Sym) ||
-		sh[i].sh_link < 1 || sh[i].sh_link >= h.e_shnum ||
-		sh[sh[i].sh_link].sh_type != SHT_STRTAB ||
-		sh[sh[i].sh_link].sh_size == 0)
-	{
+
+	if (i == h.e_shnum || sh[i].sh_size == 0 || sh[i].sh_entsize !=
+	    sizeof (Elf_Sym) || sh[i].sh_link < 1 || sh[i].sh_link >=
+	    h.e_shnum || sh[sh[i].sh_link].sh_type != SHT_STRTAB ||
+	    sh[sh[i].sh_link].sh_size == 0) {
 		free(sh);
-		return -1;
+		return (-1);
 	}
 
 	/* get space for the symbol and string tables */
-	size = (int) (sh[i].sh_size + sh[sh[i].sh_link].sh_size);
-	if (size > stbufsize)
-	{
+	size = (int)(sh[i].sh_size + sh[sh[i].sh_link].sh_size);
+
+	if (size > stbufsize) {
 		if (stbuf)
 			free(stbuf);
+
 		stbufsize = nsyms = 0;
-		if ((stbuf = (char*)malloc(size)) == NULL)
-		{
+
+		if ((stbuf = (char *)malloc(size)) == NULL) {
 			free(sh);
-			return -1;
+			return (-1);
 		}
+
 		stbufsize = size;
 	}
 
 	/* read the symbol and string tables */
 	if (lseek(fd, sh[i].sh_offset, SEEK_SET) != sh[i].sh_offset ||
-		read(fd, stbuf, sh[i].sh_size) != sh[i].sh_size ||
-		lseek(fd, sh[sh[i].sh_link].sh_offset, SEEK_SET) !=
-			sh[sh[i].sh_link].sh_offset ||
-		read(fd, stbuf + sh[i].sh_size, sh[sh[i].sh_link].sh_size) !=
-			sh[sh[i].sh_link].sh_size)
-	{
+	    read(fd, stbuf, sh[i].sh_size) != sh[i].sh_size ||
+	    lseek(fd, sh[sh[i].sh_link].sh_offset, SEEK_SET) !=
+	    sh[sh[i].sh_link].sh_offset ||
+	    read(fd, stbuf + sh[i].sh_size, sh[sh[i].sh_link].sh_size) !=
+	    sh[sh[i].sh_link].sh_size) {
 		free(sh);
 		return (-1);
 	}
-	nsyms = (int) (sh[i].sh_size / sh[i].sh_entsize);
-	stoffset = (int) sh[i].sh_size;
+
+	nsyms = (int)(sh[i].sh_size / sh[i].sh_entsize);
+	stoffset = (int)sh[i].sh_size;
 
 	free(sh);
 	return (0);
 }
 
-/* find the symbol corresponding to the given text address;
-   return NULL on error, symbol address otherwise */
+/*
+ * find the symbol corresponding to the given text address;
+ * return NULL on error, symbol address otherwise
+ */
 char *
 __fex_sym(char *a, char **name)
 {
-	Elf_Sym			*s;
-	unsigned long	fo, va, value;
-	int				fd, i, j, nm;
-	char			fname[PRMAPSZ+20];
+	Elf_Sym *s;
+	unsigned long fo, va, value;
+	int fd, i, j, nm;
+	char fname[PRMAPSZ + 20];
 
 	/* see if the last prmap_t found contains the indicated address */
-	if (lpm)
-	{
-		if (a >= (char*)lpm->pr_vaddr && a < (char*)lpm->pr_vaddr +
-			lpm->pr_size)
+	if (lpm) {
+		if (a >= (char *)lpm->pr_vaddr && a < (char *)lpm->pr_vaddr +
+		    lpm->pr_size)
 			goto cont;
 	}
 
 	/* look for a prmap_t that contains the indicated address */
-	for (i = 0; i < npm; i++)
-	{
-		if (a >= (char*)pm[i].pr_vaddr && a < (char*)pm[i].pr_vaddr +
-			pm[i].pr_size)
+	for (i = 0; i < npm; i++) {
+		if (a >= (char *)pm[i].pr_vaddr && a < (char *)pm[i].pr_vaddr +
+		    pm[i].pr_size)
 			break;
 	}
+
 	if (i == npm)
-		return NULL;
+		return (NULL);
 
 	/* get an open file descriptor for the mapped object */
 	if (pm[i].pr_mapname[0] == '\0')
-		return NULL;
+		return (NULL);
+
 	strcpy(fname, "/proc/self/object/");
 	strncat(fname, pm[i].pr_mapname, PRMAPSZ);
 	fd = open(fname, O_RDONLY);
+
 	if (fd < 0)
-		return NULL;
+		return (NULL);
 
 	/* read the program headers and symbols */
 	lpm = NULL;
 	j = __fex_read_syms(fd);
 	close(fd);
+
 	if (j < 0)
-		return NULL;
+		return (NULL);
+
 	lpm = &pm[i];
 
 cont:
 	/* compute the file offset corresponding to the mapped address */
-	fo = (a - (char*)lpm->pr_vaddr) + lpm->pr_offset;
+	fo = (a - (char *)lpm->pr_vaddr) + lpm->pr_offset;
 
 	/* find the program header containing the file offset */
-	for (i = 0; i < nph; i++)
-	{
-		if (ph[i].p_type == PT_LOAD && fo >= ph[i].p_offset &&
-			fo < ph[i].p_offset + ph[i].p_filesz)
+	for (i = 0; i < nph; i++) {
+		if (ph[i].p_type == PT_LOAD && fo >= ph[i].p_offset && fo <
+		    ph[i].p_offset + ph[i].p_filesz)
 			break;
 	}
+
 	if (i == nph)
-		return NULL;
+		return (NULL);
 
 	/* compute the virtual address corresponding to the file offset */
 	va = (fo - ph[i].p_offset) + ph[i].p_vaddr;
 
-	/* find the symbol in this segment with the highest value
-	   less than or equal to the virtual address */
-	s = (Elf_Sym*)stbuf;
+	/*
+	 * find the symbol in this segment with the highest value
+	 * less than or equal to the virtual address
+	 */
+	s = (Elf_Sym *)stbuf;
 	value = nm = 0;
-	for (j = 0; j < nsyms; j++)
-	{
+
+	for (j = 0; j < nsyms; j++) {
 		if (s[j].st_name == 0 || s[j].st_shndx == SHN_UNDEF ||
-			(ELF_ST_BIND(s[j].st_info) != STB_LOCAL &&
-			ELF_ST_BIND(s[j].st_info) != STB_GLOBAL &&
-			ELF_ST_BIND(s[j].st_info) != STB_WEAK) ||
-			(ELF_ST_TYPE(s[j].st_info) != STT_NOTYPE &&
-			ELF_ST_TYPE(s[j].st_info) != STT_OBJECT &&
-			ELF_ST_TYPE(s[j].st_info) != STT_FUNC))
-		{
+		    (ELF_ST_BIND(s[j].st_info) != STB_LOCAL && ELF_ST_BIND(
+		    s[j].st_info) != STB_GLOBAL && ELF_ST_BIND(s[j].st_info) !=
+		    STB_WEAK) || (ELF_ST_TYPE(s[j].st_info) != STT_NOTYPE &&
+		    ELF_ST_TYPE(s[j].st_info) != STT_OBJECT && ELF_ST_TYPE(
+		    s[j].st_info) != STT_FUNC))
 			continue;
-		}
 
-		if (s[j].st_value < ph[i].p_vaddr || s[j].st_value >= ph[i].p_vaddr
-			+ ph[i].p_memsz)
-		{
+		if (s[j].st_value < ph[i].p_vaddr || s[j].st_value >=
+		    ph[i].p_vaddr + ph[i].p_memsz)
 			continue;
-		}
 
 		if (s[j].st_value < value || s[j].st_value > va)
 			continue;
@@ -296,11 +300,12 @@
 		value = s[j].st_value;
 		nm = s[j].st_name;
 	}
+
 	if (nm == 0)
-		return NULL;
+		return (NULL);
 
 	/* pass back the name and return the mapped address of the symbol */
 	*name = stbuf + stoffset + nm;
 	fo = (value - ph[i].p_vaddr) + ph[i].p_offset;
-	return (char*)lpm->pr_vaddr + (fo - lpm->pr_offset);
+	return ((char *)lpm->pr_vaddr + (fo - lpm->pr_offset));
 }
--- old/usr/src/lib/libm/common/m9x/fdim.c	2019-06-06 20:40:07.334246752 +0000
+++ new/usr/src/lib/libm/common/m9x/fdim.c	2019-06-06 20:40:07.352761407 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,13 +39,15 @@
  * NaN.  Otherwise, it raises no exceptions.
  */
 
-#include "libm.h"	/* for islessequal macro */
+#include "libm.h"			/* for islessequal macro */
 
 double
-__fdim(double x, double y) {
+__fdim(double x, double y)
+{
 	if (islessequal(x, y)) {
 		x = 0.0;
 		y = -x;
 	}
+
 	return (x - y);
 }
--- old/usr/src/lib/libm/common/m9x/fdimf.c	2019-06-06 20:40:07.806428486 +0000
+++ new/usr/src/lib/libm/common/m9x/fdimf.c	2019-06-06 20:40:07.823971691 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,10 +30,11 @@
 
 #pragma weak fdimf = __fdimf
 
-#include "libm.h"	/* for islessequal macro */
+#include "libm.h"			/* for islessequal macro */
 
 float
-__fdimf(float x, float y) {
+__fdimf(float x, float y)
+{
 	/*
 	 * On SPARC v8plus/v9, this could be implemented as follows
 	 * (assuming %f0 = x, %f1 = y, return value left in %f0):
@@ -49,5 +51,6 @@
 		x = 0.0f;
 		y = -x;
 	}
+
 	return (x - y);
 }
--- old/usr/src/lib/libm/common/m9x/fdiml.c	2019-06-06 20:40:08.318744516 +0000
+++ new/usr/src/lib/libm/common/m9x/fdiml.c	2019-06-06 20:40:08.337571187 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,13 +30,15 @@
 
 #pragma weak fdiml = __fdiml
 
-#include "libm.h"	/* for islessequal macro */
+#include "libm.h"			/* for islessequal macro */
 
 long double
-__fdiml(long double x, long double y) {
+__fdiml(long double x, long double y)
+{
 	if (islessequal(x, y)) {
 		x = 0.0l;
 		y = -x;
 	}
+
 	return (x - y);
 }
--- old/usr/src/lib/libm/common/m9x/feexcept.c	2019-06-06 20:40:08.810158012 +0000
+++ new/usr/src/lib/libm/common/m9x/feexcept.c	2019-06-06 20:40:08.827501090 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -46,92 +47,105 @@
 #include "fex_handler.h"
 #include "fenv_inlines.h"
 
-
-int feclearexcept(int e)
+int
+feclearexcept(int e)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
 	__fenv_set_ex(fsr, __fenv_get_ex(fsr) & ~e);
 	__fenv_setfsr(&fsr);
+
 	if (fex_get_log())
 		__fex_update_te();
-	return 0;
+
+	return (0);
 }
 
 /*
-*  note - __fex_hdlr depends on fetestexcept following feraiseexcept
-*/
-int feraiseexcept(int e)
+ *  note - __fex_hdlr depends on fetestexcept following feraiseexcept
+ */
+int
+feraiseexcept(int e)
 {
-	volatile double	t;
-	unsigned long	fsr;
+	volatile double t;
+	unsigned long fsr;
 
 	if (e & FE_INVALID) {
 		t = 0.0;
 		t /= 0.0;
 	}
+
 	if (e & FE_DIVBYZERO) {
 		t = 1.0e300;
 		t /= 0.0;
 	}
+
 	if (e & FE_OVERFLOW) {
 		/* if overflow is not trapped, avoid raising inexact */
 		__fenv_getfsr(&fsr);
+
 		if (!(__fenv_get_te(fsr) & (1 << fp_trap_overflow))) {
 			__fenv_set_ex(fsr, __fenv_get_ex(fsr) | FE_OVERFLOW);
 			__fenv_setfsr(&fsr);
-		}
-		else {
+		} else {
 			t = 1.0e300;
 			t *= 1.0e300;
 		}
 	}
+
 	if (e & FE_UNDERFLOW) {
 		/* if underflow is not trapped, avoid raising inexact */
 		__fenv_getfsr(&fsr);
+
 		if (!(__fenv_get_te(fsr) & (1 << fp_trap_underflow))) {
 			__fenv_set_ex(fsr, __fenv_get_ex(fsr) | FE_UNDERFLOW);
 			__fenv_setfsr(&fsr);
-		}
-		else {
+		} else {
 			t = 1.0e-307;
 			t -= 1.001e-307;
 		}
 	}
+
 	if (e & FE_INEXACT) {
 		t = 1.0e300;
 		t += 1.0e-307;
 	}
-	return 0;
+
+	return (0);
 }
 
-int fetestexcept(int e)
+int
+fetestexcept(int e)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
-	return (int)__fenv_get_ex(fsr) & e;
+	return ((int)__fenv_get_ex(fsr) & e);
 }
 
-int fegetexceptflag(fexcept_t *p, int e)
+int
+fegetexceptflag(fexcept_t *p, int e)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
 	*p = (int)__fenv_get_ex(fsr) & e;
-	return 0;
+	return (0);
 }
 
-int fesetexceptflag(const fexcept_t *p, int e)
+int
+fesetexceptflag(const fexcept_t *p, int e)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
 	__fenv_set_ex(fsr, (((int)__fenv_get_ex(fsr) & ~e) | (*p & e)) &
-		FE_ALL_EXCEPT);
+	    FE_ALL_EXCEPT);
 	__fenv_setfsr(&fsr);
+
 	if (fex_get_log())
 		__fex_update_te();
-	return 0;
+
+	return (0);
 }
--- old/usr/src/lib/libm/common/m9x/fenv.c	2019-06-06 20:40:09.321615642 +0000
+++ new/usr/src/lib/libm/common/m9x/fenv.c	2019-06-06 20:40:09.339676114 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -46,18 +47,18 @@
 
 const fenv_t __fenv_dfl_env = {
 	{
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
-		{ FEX_NONSTOP, (void(*)())0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
+		{ FEX_NONSTOP, (void (*)()) 0 },
 	},
 #ifdef __x86
 	0x13000000
@@ -66,51 +67,58 @@
 #endif
 };
 
-int feholdexcept(fenv_t *p)
+int
+feholdexcept(fenv_t *p)
 {
 	(void) fegetenv(p);
 	(void) feclearexcept(FE_ALL_EXCEPT);
-	return !fex_set_handling(FEX_ALL, FEX_NONSTOP, NULL);
+	return (!fex_set_handling(FEX_ALL, FEX_NONSTOP, NULL));
 }
 
-int feholdexcept96(fenv_t *p)
+int
+feholdexcept96(fenv_t *p)
 {
 	(void) fegetenv(p);
 	(void) feclearexcept(FE_ALL_EXCEPT);
-	return fex_set_handling(FEX_ALL, FEX_NONSTOP, NULL);
+	return (fex_set_handling(FEX_ALL, FEX_NONSTOP, NULL));
 }
 
-int feupdateenv(const fenv_t *p)
+int
+feupdateenv(const fenv_t *p)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
 	(void) fesetenv(p);
 	(void) feraiseexcept((int)__fenv_get_ex(fsr));
-	return 0;
+	return (0);
 }
 
-int fegetenv(fenv_t *p)
+int
+fegetenv(fenv_t *p)
 {
 	fex_getexcepthandler(&p->__handlers, FEX_ALL);
 	__fenv_getfsr(&p->__fsr);
-	return 0;
+	return (0);
 }
 
-int fesetenv(const fenv_t *p)
+int
+fesetenv(const fenv_t *p)
 {
 	__fenv_setfsr(&p->__fsr);
 	fex_setexcepthandler(&p->__handlers, FEX_ALL);
-	return 0;
+	return (0);
 }
 
-void fex_merge_flags(const fenv_t *p)
+void
+fex_merge_flags(const fenv_t *p)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
 	__fenv_set_ex(fsr, __fenv_get_ex(fsr) | __fenv_get_ex(p->__fsr));
 	__fenv_setfsr(&fsr);
+
 	if (fex_get_log())
 		__fex_update_te();
 }
--- old/usr/src/lib/libm/common/m9x/fenv_inlines.h	2019-06-06 20:40:09.845191833 +0000
+++ new/usr/src/lib/libm/common/m9x/fenv_inlines.h	2019-06-06 20:40:09.866239129 +0000
@@ -17,7 +17,6 @@
 #define	_FENV_INLINES_H
 
 #ifdef __GNUC__
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -25,7 +24,6 @@
 #include <sys/types.h>
 
 #if defined(__x86)
-
 /*
  * Floating point Control Word and Status Word
  * Definition should actually be shared with x86
@@ -68,7 +66,7 @@
 	    : "r" (cwsw.words.cw), "r" (cwsw.words.sw)
 	    /* For practical purposes, we clobber the whole FPU */
 	    : "cc", "st", "st(1)", "st(2)", "st(3)", "st(4)", "st(5)",
-	      "st(6)", "st(7)");
+	    "st(6)", "st(7)");
 }
 
 extern __GNU_INLINE void
@@ -425,7 +423,6 @@
 	    : "=m" (*ll1), "=r" (tmp)
 	    : "m" (*f1));
 }
-
 #endif
 
 extern __GNU_INLINE void
@@ -637,7 +634,6 @@
 	    : "m" (*d1));
 }
 #endif
-
 #elif defined(__sparc)
 extern __GNU_INLINE void
 __fenv_getfsr(unsigned long *l)
@@ -681,7 +677,5 @@
 #ifdef __cplusplus
 }
 #endif
-
 #endif  /* __GNUC__ */
-
 #endif /* _FENV_INLINES_H */
--- old/usr/src/lib/libm/common/m9x/feprec.c	2019-06-06 20:40:10.384633392 +0000
+++ new/usr/src/lib/libm/common/m9x/feprec.c	2019-06-06 20:40:10.403591313 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,22 +36,25 @@
 #include <thread.h>
 #include "fex_handler.h"
 
-int fegetprec(void)
+int
+fegetprec(void)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
-	return __fenv_get_rp(fsr);
+	return (__fenv_get_rp(fsr));
 }
 
-int fesetprec(int r)
+int
+fesetprec(int r)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	if (r != FE_FLTPREC && r != FE_DBLPREC && r != FE_LDBLPREC)
-		return 0;
+		return (0);
+
 	__fenv_getfsr(&fsr);
 	__fenv_set_rp(fsr, r);
 	__fenv_setfsr(&fsr);
-	return 1;
+	return (1);
 }
--- old/usr/src/lib/libm/common/m9x/feround.c	2019-06-06 20:40:10.886730921 +0000
+++ new/usr/src/lib/libm/common/m9x/feround.c	2019-06-06 20:40:10.905037752 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,40 +43,45 @@
 #include <float.h>
 #endif
 
-int fegetround(void)
+int
+fegetround(void)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	__fenv_getfsr(&fsr);
-	return (int)__fenv_get_rd(fsr);
+	return ((int)__fenv_get_rd(fsr));
 }
 
-int fesetround(int r)
+int
+fesetround(int r)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	if (r & ~3)
-		return -1;
+		return (-1);
+
 	__fenv_getfsr(&fsr);
 	__fenv_set_rd(fsr, r);
 	__fenv_setfsr(&fsr);
 #if defined(__i386) && !defined(__amd64)
 	FLT_ROUNDS = (0x2D >> (r << 1)) & 3;	/* 0->1, 1->3, 2->2, 3->0 */
 #endif
-	return 0;
+	return (0);
 }
 
-int fesetround96(int r)
+int
+fesetround96(int r)
 {
-	unsigned long	fsr;
+	unsigned long fsr;
 
 	if (r & ~3)
-		return 0;
+		return (0);
+
 	__fenv_getfsr(&fsr);
 	__fenv_set_rd(fsr, r);
 	__fenv_setfsr(&fsr);
 #if defined(__i386) && !defined(__amd64)
 	FLT_ROUNDS = (0x2D >> (r << 1)) & 3;	/* 0->1, 1->3, 2->2, 3->0 */
 #endif
-	return 1;
+	return (1);
 }
--- old/usr/src/lib/libm/common/m9x/fex_handler.c	2019-06-06 20:40:11.389761167 +0000
+++ new/usr/src/lib/libm/common/m9x/fex_handler.c	2019-06-06 20:40:11.407437663 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,55 +38,67 @@
 #include <thread.h>
 #include "fex_handler.h"
 
-int fex_get_handling(int e)
+int
+fex_get_handling(int e)
 {
-	struct fex_handler_data	*thr_handlers;
-	int						i;
+	struct fex_handler_data *thr_handlers;
+	int i;
 
 	thr_handlers = __fex_get_thr_handlers();
+
 	for (i = 0; i < FEX_NUM_EXC; i++)
 		if (e & (1 << i))
-			return thr_handlers[i].__mode;
-	return FEX_NOHANDLER;
+			return (thr_handlers[i].__mode);
+
+	return (FEX_NOHANDLER);
 }
 
-int fex_set_handling(int e, int mode, void (*handler)())
+int
+fex_set_handling(int e, int mode, void (*handler)())
 {
-	struct fex_handler_data	*thr_handlers;
-	int						i;
+	struct fex_handler_data *thr_handlers;
+	int i;
 
 	if (e & ~((1 << FEX_NUM_EXC) - 1))
-		return 0;
+		return (0);
+
 	thr_handlers = __fex_get_thr_handlers();
+
 	for (i = 0; i < FEX_NUM_EXC; i++) {
 		if (e & (1 << i)) {
 			thr_handlers[i].__mode = mode;
 			thr_handlers[i].__handler = handler;
 		}
 	}
+
 	__fex_update_te();
-	return 1;
+	return (1);
 }
 
-void fex_getexcepthandler(fex_handler_t *buf, int e)
+void
+fex_getexcepthandler(fex_handler_t *buf, int e)
 {
-	struct fex_handler_data	*thr_handlers;
-	int						i;
+	struct fex_handler_data *thr_handlers;
+	int i;
 
 	thr_handlers = __fex_get_thr_handlers();
+
 	for (i = 0; i < FEX_NUM_EXC; i++)
 		if (e & (1 << i))
 			(*buf)[i] = thr_handlers[i];
 }
 
-void fex_setexcepthandler(const fex_handler_t *buf, int e)
+void
+fex_setexcepthandler(const fex_handler_t *buf, int e)
 {
-	struct fex_handler_data	*thr_handlers;
-	int						i;
+	struct fex_handler_data *thr_handlers;
+	int i;
 
 	thr_handlers = __fex_get_thr_handlers();
+
 	for (i = 0; i < FEX_NUM_EXC; i++)
 		if (e & (1 << i))
 			thr_handlers[i] = (*buf)[i];
+
 	__fex_update_te();
 }
--- old/usr/src/lib/libm/common/m9x/fex_handler.h	2019-06-06 20:40:11.898785304 +0000
+++ new/usr/src/lib/libm/common/m9x/fex_handler.h	2019-06-06 20:40:11.915460445 +0000
@@ -69,37 +69,34 @@
 extern void __fenv_setfsr(const unsigned long *);
 
 #if defined(__sparc)
+#define	__fenv_get_rd(X)	((X >> 30) & 0x3)
+#define	__fenv_set_rd(X, Y)	X = (X & ~0xc0000000ul) | ((Y) << 30)
 
-#define __fenv_get_rd(X)	((X>>30)&0x3)
-#define __fenv_set_rd(X,Y)	X=(X&~0xc0000000ul)|((Y)<<30)
-
-#define __fenv_get_te(X)	((X>>23)&0x1f)
-#define __fenv_set_te(X,Y)	X=(X&~0x0f800000ul)|((Y)<<23)
-
-#define __fenv_get_ex(X)	((X>>5)&0x1f)
-#define __fenv_set_ex(X,Y)	X=(X&~0x000003e0ul)|((Y)<<5)
+#define	__fenv_get_te(X)	((X >> 23) & 0x1f)
+#define	__fenv_set_te(X, Y)	X = (X & ~0x0f800000ul) | ((Y) << 23)
 
+#define	__fenv_get_ex(X)	((X >> 5) & 0x1f)
+#define	__fenv_set_ex(X, Y)	X = (X & ~0x000003e0ul) |((Y) << 5)
 #elif defined(__x86)
-
 extern void __fenv_getcwsw(unsigned int *);
 extern void __fenv_setcwsw(const unsigned int *);
 
 extern void __fenv_getmxcsr(unsigned int *);
 extern void __fenv_setmxcsr(const unsigned int *);
 
-#define __fenv_get_rd(X)	((X>>26)&3)
-#define __fenv_set_rd(X,Y)	X=(X&~0x0c000000)|((Y)<<26)
+#define	__fenv_get_rd(X)	((X >> 26) & 3)
+#define	__fenv_set_rd(X, Y)	X = (X & ~0x0c000000) | ((Y) << 26)
 
-#define __fenv_get_rp(X)	((X>>24)&3)
-#define __fenv_set_rp(X,Y)	X=(X&~0x03000000)|((Y)<<24)
+#define	__fenv_get_rp(X)	((X >> 24) & 3)
+#define	__fenv_set_rp(X, Y)	X = (X & ~0x03000000) | ((Y) << 24)
 
-#define __fenv_get_te(X)	((X>>16)&0x3d)
-#define __fenv_set_te(X,Y)	X=(X&~0x003d0000)|((Y)<<16)
+#define	__fenv_get_te(X)	((X >> 16) & 0x3d)
+#define	__fenv_set_te(X, Y)	X = (X & ~0x003d0000) |((Y) << 16)
 
-#define __fenv_get_ex(X)	(X&0x3d)
-#define __fenv_set_ex(X,Y)	X=(X&~0x0000003d)|(Y)
+#define	__fenv_get_ex(X)	(X & 0x3d)
+#define	__fenv_set_ex(X, Y)	X = (X & ~0x0000003d) | (Y)
 
-/* 
+/*
  * These macros define some useful distinctions between various
  * SSE instructions.  In some cases, distinctions are made for
  * the purpose of simplifying the decoding of instructions, while
@@ -107,9 +104,9 @@
  * emulation.  Note that these values serve as bit flags within
  * the enum values in sseinst_t.
  */
-#define DOUBLE		0x100
-#define SIMD		0x080
-#define INTREG		0x040
+#define	DOUBLE		0x100
+#define	SIMD		0x080
+#define	INTREG		0x040
 
 typedef union {
 	double		d[2];
@@ -209,9 +206,7 @@
 	enum fex_exception, fex_info_t *);
 extern void __fex_st_simd_result(ucontext_t *, sseinst_t *,
 	enum fex_exception *, fex_info_t *);
-
 #else
 #error Unknown architecture
 #endif
-
 #endif	/* _M9X_FEX_HANDLER_H */
--- old/usr/src/lib/libm/common/m9x/fex_log.c	2019-06-06 20:40:12.381320913 +0000
+++ new/usr/src/lib/libm/common/m9x/fex_log.c	2019-06-06 20:40:12.397819675 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -56,148 +57,165 @@
 static FILE *log_fp = NULL;
 static mutex_t log_lock = DEFAULTMUTEX;
 static int log_depth = 100;
-
-FILE *fex_get_log(void)
+FILE *
+fex_get_log(void)
 {
-	FILE	*fp;
+	FILE *fp;
 
 	mutex_lock(&log_lock);
 	fp = log_fp;
 	mutex_unlock(&log_lock);
-	return fp;
+	return (fp);
 }
 
-int fex_set_log(FILE *fp)
+int
+fex_set_log(FILE *fp)
 {
 	mutex_lock(&log_lock);
 	log_fp = fp;
 	mutex_unlock(&log_lock);
 	__fex_update_te();
-	return 1;
+	return (1);
 }
 
-int fex_get_log_depth(void)
+int
+fex_get_log_depth(void)
 {
-	int	d;
+	int d;
 
 	mutex_lock(&log_lock);
 	d = log_depth;
 	mutex_unlock(&log_lock);
-	return d;
+	return (d);
 }
 
-int fex_set_log_depth(int d)
+int
+fex_set_log_depth(int d)
 {
 	if (d < 0)
-		return 0;
+		return (0);
+
 	mutex_lock(&log_lock);
 	log_depth = d;
 	mutex_unlock(&log_lock);
-	return 1;
+	return (1);
 }
 
 static struct exc_list {
-	struct exc_list		*next;
-	char			*addr;
-	unsigned long		code;
-	int			nstack;
-	char			*stack[1]; /* actual length is max(1,nstack) */
+	struct exc_list *next;
+	char *addr;
+	unsigned long code;
+	int nstack;
+	char *stack[1];			/* actual length is max(1,nstack) */
 } *list = NULL;
 
 #ifdef __sparcv9
-#define FRAMEP(X)	(struct frame *)((char*)(X)+(((long)(X)&1)?2047:0))
+#define	FRAMEP(X)		(struct frame *)((char *)(X) + (((long)(X) & \
+	1) ? 2047 : 0))
 #else
-#define FRAMEP(X)	(struct frame *)(X)
+#define	FRAMEP(X)		(struct frame *)(X)
 #endif
 
 #ifdef _LP64
-#define PDIG		"16"
+#define	PDIG			"16"
 #else
-#define PDIG		"8"
+#define	PDIG			"8"
 #endif
 
-/* look for a matching exc_list; return 1 if one is found,
-   otherwise add this one to the list and return 0 */
-static int check_exc_list(char *addr, unsigned long code, char *stk,
-    struct frame *fp)
+/*
+ * look for a matching exc_list; return 1 if one is found,
+ * otherwise add this one to the list and return 0
+ */
+static int
+check_exc_list(char *addr, unsigned long code, char *stk, struct frame *fp)
 {
-	struct exc_list	*l, *ll = NULL;
-	struct frame	*f;
-	int		i, n;
+	struct exc_list *l, *ll = NULL;
+	struct frame *f;
+	int i, n;
 
 	if (list) {
 		for (l = list; l; ll = l, l = l->next) {
 			if (l->addr != addr || l->code != code)
 				continue;
+
 			if (log_depth < 1 || l->nstack < 1)
-				return 1;
+				return (1);
+
 			if (l->stack[0] != stk)
 				continue;
+
 			n = 1;
+
 			for (i = 1, f = fp; i < log_depth && i < l->nstack &&
 			    f && f->fr_savpc; i++, f = FRAMEP(f->fr_savfp))
 				if (l->stack[i] != (char *)f->fr_savpc) {
 					n = 0;
 					break;
 				}
+
 			if (n)
-				return 1;
+				return (1);
 		}
 	}
 
 	/* create a new exc_list structure and tack it on the list */
 	for (n = 1, f = fp; n < log_depth && f && f->fr_savpc;
-	    n++, f = FRAMEP(f->fr_savfp)) ;
-	if ((l = (struct exc_list *)malloc(sizeof(struct exc_list) +
-	    (n - 1) * sizeof(char *))) != NULL) {
+	    n++, f = FRAMEP(f->fr_savfp))
+		;
+
+	if ((l = (struct exc_list *)malloc(sizeof (struct exc_list) + (n - 1) *
+	    sizeof (char *))) != NULL) {
 		l->next = NULL;
 		l->addr = addr;
 		l->code = code;
-		l->nstack = ((log_depth < 1)? 0 : n);
+		l->nstack = ((log_depth < 1) ? 0 : n);
 		l->stack[0] = stk;
+
 		for (i = 1; i < n; i++) {
 			l->stack[i] = (char *)fp->fr_savpc;
 			fp = FRAMEP(fp->fr_savfp);
 		}
+
 		if (list)
 			ll->next = l;
 		else
 			list = l;
 	}
-	return 0;
+
+	return (0);
 }
 
 /*
-* Warning: cleverness ahead
-*
-* In the following code, the use of sprintf+write rather than fprintf
-* to send output to the log file is intentional.  The reason is that
-* fprintf is not async-signal-safe.  "But," you protest, "SIGFPE is
-* not an asynchronous signal!  It's always handled by the same thread
-* that executed the fpop that provoked it."  That's true, but a prob-
-* lem arises because (i) base conversion in fprintf can cause a fp
-* exception and (ii) my signal handler acquires a mutex lock before
-* sending output to the log file (so that outputs for entries from
-* different threads aren't interspersed).  Therefore, if the code
-* were to use fprintf, a deadlock could occur as follows:
-*
-*	Thread A			Thread B
-*
-*	Incurs a fp exception,		Calls fprintf,
-*	acquires log_lock		acquires file rmutex lock
-*
-*	Calls fprintf,			Incurs a fp exception,
-*	waits for file rmutex lock	waits for log_lock
-*
-* (I could just verify that fprintf doesn't hold the rmutex lock while
-* it's doing the base conversion, but since efficiency is of little
-* concern here, I opted for the safe and dumb route.)
-*/
-
-static void print_stack(int fd, char *addr, struct frame *fp)
+ * Warning: cleverness ahead
+ *
+ * In the following code, the use of sprintf+write rather than fprintf
+ * to send output to the log file is intentional.  The reason is that
+ * fprintf is not async-signal-safe.  "But," you protest, "SIGFPE is
+ * not an asynchronous signal!  It's always handled by the same thread
+ * that executed the fpop that provoked it."  That's true, but a prob-
+ * lem arises because (i) base conversion in fprintf can cause a fp
+ * exception and (ii) my signal handler acquires a mutex lock before
+ * sending output to the log file (so that outputs for entries from
+ * different threads aren't interspersed).  Therefore, if the code
+ * were to use fprintf, a deadlock could occur as follows:
+ *
+ *	Thread A			Thread B
+ *
+ *	Incurs a fp exception,		Calls fprintf,
+ *	acquires log_lock		acquires file rmutex lock
+ *
+ *	Calls fprintf,			Incurs a fp exception,
+ *	waits for file rmutex lock	waits for log_lock
+ *
+ * (I could just verify that fprintf doesn't hold the rmutex lock while
+ * it's doing the base conversion, but since efficiency is of little
+ * concern here, I opted for the safe and dumb route.)
+ */
+static void
+print_stack(int fd, char *addr, struct frame *fp)
 {
-	int	i;
-	char	*name, buf[30];
+	int i;
+	char *name, buf[30];
 
 	for (i = 0; i < log_depth && addr != NULL; i++) {
 		if (__fex_sym(addr, &name) != NULL) {
@@ -205,47 +223,56 @@
 			    (long)addr));
 			write(fd, name, strlen(name));
 			write(fd, "\n", 1);
-			if (!strcmp(name, "main"))
+
+			if (strcmp(name, "main") == 0)
 				break;
 		} else {
 			write(fd, buf, sprintf(buf, "  0x%0" PDIG "lx\n",
 			    (long)addr));
 		}
+
 		if (fp == NULL)
 			break;
+
 		addr = (char *)fp->fr_savpc;
 		fp = FRAMEP(fp->fr_savfp);
 	}
 }
 
-void fex_log_entry(const char *msg)
+void
+fex_log_entry(const char *msg)
 {
-	ucontext_t	uc;
-	struct frame	*fp;
-	char		*stk;
-	int		fd;
+	ucontext_t uc;
+	struct frame *fp;
+	char *stk;
+	int fd;
 
 	/* if logging is disabled, just return */
 	mutex_lock(&log_lock);
+
 	if (log_fp == NULL) {
 		mutex_unlock(&log_lock);
 		return;
 	}
 
-	/* get the frame pointer from the current context and
-	   pop our own frame */
+	/*
+	 * get the frame pointer from the current context and
+	 * pop our own frame
+	 */
 	getcontext(&uc);
 #if defined(__sparc) || defined(__amd64)
 	fp = FRAMEP(uc.uc_mcontext.gregs[REG_SP]);
-#elif defined(__i386)	/* !defined(__amd64) */
+#elif defined(__i386)			/* !defined(__amd64) */
 	fp = FRAMEP(uc.uc_mcontext.gregs[EBP]);
 #else
 #error Unknown architecture
 #endif
+
 	if (fp == NULL) {
 		mutex_unlock(&log_lock);
 		return;
 	}
+
 	stk = (char *)fp->fr_savpc;
 	fp = FRAMEP(fp->fr_savfp);
 
@@ -266,30 +293,24 @@
 }
 
 static const char *exception[FEX_NUM_EXC] = {
-	"inexact result",
-	"division by zero",
-	"underflow",
-	"overflow",
-	"invalid operation (0/0)",
-	"invalid operation (inf/inf)",
-	"invalid operation (inf-inf)",
-	"invalid operation (0*inf)",
-	"invalid operation (sqrt)",
-	"invalid operation (snan)",
-	"invalid operation (int)",
-	"invalid operation (cmp)"
+	"inexact result", "division by zero", "underflow", "overflow",
+	"invalid operation (0/0)", "invalid operation (inf/inf)",
+	"invalid operation (inf-inf)", "invalid operation (0*inf)",
+	"invalid operation (sqrt)", "invalid operation (snan)",
+	"invalid operation (int)", "invalid operation (cmp)"
 };
 
 void
-__fex_mklog(ucontext_t *uap, char *addr, int f, enum fex_exception e,
-    int m, void *p)
+__fex_mklog(ucontext_t *uap, char *addr, int f, enum fex_exception e, int m,
+    void *p)
 {
-	struct	frame	*fp;
-	char		*stk, *name, buf[30];
-	int		fd;
+	struct  frame *fp;
+	char *stk, *name, buf[30];
+	int fd;
 
 	/* if logging is disabled, just return */
 	mutex_lock(&log_lock);
+
 	if (log_fp == NULL) {
 		mutex_unlock(&log_lock);
 		return;
@@ -297,57 +318,71 @@
 
 	/* get stack info */
 #if defined(__sparc)
-	stk = (char*)uap->uc_mcontext.gregs[REG_PC];
+	stk = (char *)uap->uc_mcontext.gregs[REG_PC];
 	fp = FRAMEP(uap->uc_mcontext.gregs[REG_SP]);
 #elif defined(__amd64)
-	stk = (char*)uap->uc_mcontext.gregs[REG_PC];
+	stk = (char *)uap->uc_mcontext.gregs[REG_PC];
 	fp = FRAMEP(uap->uc_mcontext.gregs[REG_RBP]);
-#elif defined(__i386)	/* !defined(__amd64) */
-	stk = (char*)uap->uc_mcontext.gregs[PC];
+#elif defined(__i386)			/* !defined(__amd64) */
+	stk = (char *)uap->uc_mcontext.gregs[PC];
 	fp = FRAMEP(uap->uc_mcontext.gregs[EBP]);
 #else
 #error Unknown architecture
 #endif
 
-	/* if the handling mode is the default and this exception's
-	   flag is already raised, don't make an entry */
+	/*
+	 * if the handling mode is the default and this exception's
+	 * flag is already raised, don't make an entry
+	 */
 	if (m == FEX_NONSTOP) {
 		switch (e) {
 		case fex_inexact:
+
 			if (f & FE_INEXACT) {
 				mutex_unlock(&log_lock);
 				return;
 			}
+
 			break;
 		case fex_underflow:
+
 			if (f & FE_UNDERFLOW) {
 				mutex_unlock(&log_lock);
 				return;
 			}
+
 			break;
 		case fex_overflow:
+
 			if (f & FE_OVERFLOW) {
 				mutex_unlock(&log_lock);
 				return;
 			}
+
 			break;
 		case fex_division:
+
 			if (f & FE_DIVBYZERO) {
 				mutex_unlock(&log_lock);
 				return;
 			}
+
 			break;
 		default:
+
 			if (f & FE_INVALID) {
 				mutex_unlock(&log_lock);
 				return;
 			}
+
 			break;
 		}
 	}
 
-	/* if we've already logged this exception at this address,
-	   don't make an entry */
+	/*
+	 * if we've already logged this exception at this address,
+	 * don't make an entry
+	 */
 	if (check_exc_list(addr, (unsigned long)e, stk, fp)) {
 		mutex_unlock(&log_lock);
 		return;
@@ -359,10 +394,12 @@
 	write(fd, exception[e], strlen(exception[e]));
 	write(fd, buf, sprintf(buf, " at 0x%0" PDIG "lx", (long)addr));
 	__fex_sym_init();
+
 	if (__fex_sym(addr, &name) != NULL) {
 		write(fd, " ", 1);
 		write(fd, name, strlen(name));
 	}
+
 	switch (m) {
 	case FEX_NONSTOP:
 		write(fd, ", nonstop mode\n", 15);
@@ -373,17 +410,19 @@
 		break;
 
 	case FEX_NOHANDLER:
+
 		if (p == (void *)SIG_DFL) {
 			write(fd, ", handler: SIG_DFL\n", 19);
 			break;
-		}
-		else if (p == (void *)SIG_IGN) {
+		} else if (p == (void *)SIG_IGN) {
 			write(fd, ", handler: SIG_IGN\n", 19);
 			break;
 		}
-		/* fall through*/
+
+	/* FALLTHROUGH */
 	default:
 		write(fd, ", handler: ", 11);
+
 		if (__fex_sym((char *)p, &name) != NULL) {
 			write(fd, name, strlen(name));
 			write(fd, "\n", 1);
@@ -391,8 +430,10 @@
 			write(fd, buf, sprintf(buf, "0x%0" PDIG "lx\n",
 			    (long)p));
 		}
+
 		break;
 	}
+
 	print_stack(fd, stk, fp);
 	mutex_unlock(&log_lock);
 }
--- old/usr/src/lib/libm/common/m9x/fma.c	2019-06-06 20:40:12.871150277 +0000
+++ new/usr/src/lib/libm/common/m9x/fma.c	2019-06-06 20:40:12.888178530 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,7 +35,6 @@
 #include "fenv_inlines.h"
 
 #if defined(__sparc)
-
 static const union {
 	unsigned i[2];
 	double d;
@@ -51,16 +51,16 @@
 	{ 0x00100001u, 0 }
 };
 
-#define	half	C[0].d
-#define	two	C[1].d
-#define	two52	C[2].d
-#define	two27	C[3].d
-#define	twom26	C[4].d
-#define	twom32	C[5].d
-#define	twom64	C[6].d
-#define	huge	C[7].d
-#define	tiny	C[8].d
-#define	tiny2	C[9].d
+#define	half		C[0].d
+#define	two		C[1].d
+#define	two52		C[2].d
+#define	two27		C[3].d
+#define	twom26		C[4].d
+#define	twom32		C[5].d
+#define	twom64		C[6].d
+#define	huge		C[7].d
+#define	tiny		C[8].d
+#define	tiny2		C[9].d
 
 static const unsigned int fsr_rm = 0xc0000000u;
 
@@ -68,15 +68,17 @@
  * fma for SPARC: 64-bit double precision, big-endian
  */
 double
-__fma(double x, double y, double z) {
+__fma(double x, double y, double z)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx, yy, zz;
+
 	double xhi, yhi, xlo, ylo, t;
 	unsigned int xy0, xy1, xy2, xy3, z0, z1, z2, z3, fsr, rm, sticky;
 	int hx, hy, hz, ex, ey, ez, exy, sxy, sz, e, ibit;
-	volatile double	dummy;
+	volatile double dummy;
 
 	/* extract the high order words of the arguments */
 	xx.d = x;
@@ -87,14 +89,14 @@
 	hz = zz.i[0] & ~0x80000000;
 
 	/* dispense with inf, nan, and zero cases */
-	if (hx >= 0x7ff00000 || hy >= 0x7ff00000 || (hx | xx.i[1]) == 0 ||
-		(hy | yy.i[1]) == 0)	/* x or y is inf, nan, or zero */
+	if (hx >= 0x7ff00000 || hy >= 0x7ff00000 || (hx | xx.i[1]) == 0 || (hy |
+	    yy.i[1]) == 0)		/* x or y is inf, nan, or zero */
 		return (x * y + z);
 
 	if (hz >= 0x7ff00000)	/* z is inf or nan */
 		return (x + z);	/* avoid spurious under/overflow in x * y */
 
-	if ((hz | zz.i[1]) == 0)	/* z is zero */
+	if ((hz | zz.i[1]) == 0) /* z is zero */
 		/*
 		 * x * y isn't zero but could underflow to zero,
 		 * so don't add z, lest we perturb the sign
@@ -113,16 +115,21 @@
 	sxy = (xx.i[0] ^ yy.i[0]) & 0x80000000;
 	sz = zz.i[0] & 0x80000000;
 	ex = hx >> 20;
+
 	if (!ex) {
 		xx.d = x * two52;
 		ex = ((xx.i[0] & ~0x80000000) >> 20) - 52;
 	}
+
 	ey = hy >> 20;
+
 	if (!ey) {
 		yy.d = y * two52;
 		ey = ((yy.i[0] & ~0x80000000) >> 20) - 52;
 	}
+
 	ez = hz >> 20;
+
 	if (!ez) {
 		zz.d = z * two52;
 		ez = ((zz.i[0] & ~0x80000000) >> 20) - 52;
@@ -140,6 +147,7 @@
 	ylo = y - yhi;
 	x *= y;
 	y = ((xhi * yhi - x) + xhi * ylo + xlo * yhi) + xlo * ylo;
+
 	if (x >= two) {
 		x *= half;
 		y *= half;
@@ -162,47 +170,66 @@
 	 * now x*y is represented by sxy, exy, and xy[0-3], and z is
 	 * represented likewise; swap if need be so |xy| <= |z|
 	 */
-	if (exy > ez || (exy == ez && (xy0 > z0 || (xy0 == z0 &&
-		(xy1 > z1 || (xy1 == z1 && (xy2 | xy3) != 0)))))) {
-		e = sxy; sxy = sz; sz = e;
-		e = exy; exy = ez; ez = e;
-		e = xy0; xy0 = z0; z0 = e;
-		e = xy1; xy1 = z1; z1 = e;
-		z2 = xy2; xy2 = 0;
-		z3 = xy3; xy3 = 0;
+	if (exy > ez || (exy == ez && (xy0 > z0 || (xy0 == z0 && (xy1 > z1 ||
+	    (xy1 == z1 && (xy2 | xy3) != 0)))))) {
+		e = sxy;
+		sxy = sz;
+		sz = e;
+		e = exy;
+		exy = ez;
+		ez = e;
+		e = xy0;
+		xy0 = z0;
+		z0 = e;
+		e = xy1;
+		xy1 = z1;
+		z1 = e;
+		z2 = xy2;
+		xy2 = 0;
+		z3 = xy3;
+		xy3 = 0;
 	}
 
 	/* shift the significand of xy keeping a sticky bit */
 	e = ez - exy;
+
 	if (e > 116) {
 		xy0 = xy1 = xy2 = 0;
 		xy3 = 1;
 	} else if (e >= 96) {
 		sticky = xy3 | xy2 | xy1 | ((xy0 << 1) << (127 - e));
 		xy3 = xy0 >> (e - 96);
+
 		if (sticky)
 			xy3 |= 1;
+
 		xy0 = xy1 = xy2 = 0;
 	} else if (e >= 64) {
 		sticky = xy3 | xy2 | ((xy1 << 1) << (95 - e));
 		xy3 = (xy1 >> (e - 64)) | ((xy0 << 1) << (95 - e));
+
 		if (sticky)
 			xy3 |= 1;
+
 		xy2 = xy0 >> (e - 64);
 		xy0 = xy1 = 0;
 	} else if (e >= 32) {
 		sticky = xy3 | ((xy2 << 1) << (63 - e));
 		xy3 = (xy2 >> (e - 32)) | ((xy1 << 1) << (63 - e));
+
 		if (sticky)
 			xy3 |= 1;
+
 		xy2 = (xy1 >> (e - 32)) | ((xy0 << 1) << (63 - e));
 		xy1 = xy0 >> (e - 32);
 		xy0 = 0;
 	} else if (e) {
 		sticky = (xy3 << 1) << (31 - e);
 		xy3 = (xy3 >> e) | ((xy2 << 1) << (31 - e));
+
 		if (sticky)
 			xy3 |= 1;
+
 		xy2 = (xy2 >> e) | ((xy1 << 1) << (31 - e));
 		xy1 = (xy1 >> e) | ((xy0 << 1) << (31 - e));
 		xy0 >>= e;
@@ -214,6 +241,7 @@
 		xy1 = ~xy1;
 		xy2 = ~xy2;
 		xy3 = -xy3;
+
 		if (xy3 == 0)
 			if (++xy2 == 0)
 				if (++xy1 == 0)
@@ -224,18 +252,25 @@
 	z3 += xy3;
 	e = (z3 < xy3);
 	z2 += xy2;
+
 	if (e) {
 		z2++;
 		e = (z2 <= xy2);
-	} else
+	} else {
 		e = (z2 < xy2);
+	}
+
 	z1 += xy1;
+
 	if (e) {
 		z1++;
 		e = (z1 <= xy1);
-	} else
+	} else {
 		e = (z1 < xy1);
+	}
+
 	z0 += xy0;
+
 	if (e)
 		z0++;
 
@@ -243,31 +278,39 @@
 	if (ez < 1) {
 		/* result is tiny; shift right until exponent is within range */
 		e = 1 - ez;
+
 		if (e > 56) {
-			z2 = 1;	/* result can't be exactly zero */
+			z2 = 1;		/* result can't be exactly zero */
 			z0 = z1 = 0;
 		} else if (e >= 32) {
 			sticky = z3 | z2 | ((z1 << 1) << (63 - e));
 			z2 = (z1 >> (e - 32)) | ((z0 << 1) << (63 - e));
+
 			if (sticky)
 				z2 |= 1;
+
 			z1 = z0 >> (e - 32);
 			z0 = 0;
 		} else {
 			sticky = z3 | (z2 << 1) << (31 - e);
 			z2 = (z2 >> e) | ((z1 << 1) << (31 - e));
+
 			if (sticky)
 				z2 |= 1;
+
 			z1 = (z1 >> e) | ((z0 << 1) << (31 - e));
 			z0 >>= e;
 		}
+
 		ez = 1;
 	} else if (z0 >= 0x200000) {
 		/* carry out; shift right by one */
 		sticky = (z2 & 1) | z3;
 		z2 = (z2 >> 1) | (z1 << 31);
+
 		if (sticky)
 			z2 |= 1;
+
 		z1 = (z1 >> 1) | (z0 << 31);
 		z0 >>= 1;
 		ez++;
@@ -284,6 +327,7 @@
 				z3 = 0;
 				ez -= 32;
 			}
+
 			while (z0 < 0x100000 && ez > 1) {
 				z0 = (z0 << 1) | (z1 >> 31);
 				z1 = (z1 << 1) | (z2 >> 31);
@@ -292,6 +336,7 @@
 				ez--;
 			}
 		}
+
 		if (z3)
 			z2 |= 1;
 	}
@@ -302,11 +347,13 @@
 
 	/* strip off the integer bit, if there is one */
 	ibit = z0 & 0x100000;
-	if (ibit)
+
+	if (ibit) {
 		z0 -= 0x100000;
-	else {
+	} else {
 		ez = 0;
-		if (!(z0 | z1 | z2)) { /* exact zero */
+
+		if (!(z0 | z1 | z2)) {	/* exact zero */
 			zz.i[0] = rm == FSR_RM ? 0x80000000 : 0;
 			zz.i[1] = 0;
 			__fenv_setfsr32(&fsr);
@@ -326,8 +373,8 @@
 		fsr |= FSR_NXC;
 
 		/* decide whether to round the fraction up */
-		if (rm == FSR_RP || (rm == FSR_RN && (z2 > 0x80000000u ||
-			(z2 == 0x80000000u && (z1 & 1))))) {
+		if (rm == FSR_RP || (rm == FSR_RN && (z2 > 0x80000000u || (z2 ==
+		    0x80000000u && (z1 & 1))))) {
 			/* round up and renormalize if necessary */
 			if (++z1 == 0) {
 				if (++z0 == 0x100000) {
@@ -347,6 +394,7 @@
 			zz.i[0] = sz | 0x7fefffff;
 			zz.i[1] = 0xffffffff;
 		}
+
 		fsr |= FSR_OFC | FSR_NXC;
 	} else {
 		zz.i[0] = sz | (ez << 20) | z0;
@@ -367,11 +415,13 @@
 	/* restore the fsr and emulate exceptions as needed */
 	if ((fsr & FSR_CEXC) & (fsr >> 23)) {
 		__fenv_setfsr32(&fsr);
+
 		if (fsr & FSR_OFC) {
 			dummy = huge;
 			dummy *= huge;
 		} else if (fsr & FSR_UFC) {
 			dummy = tiny;
+
 			if (fsr & FSR_NXC)
 				dummy *= tiny;
 			else
@@ -384,34 +434,35 @@
 		fsr |= (fsr & 0x1f) << 5;
 		__fenv_setfsr32(&fsr);
 	}
+
 	return (zz.d);
 }
-
 #elif defined(__x86)
-
 #if defined(__amd64)
-#define	NI	4
+#define	NI		4
 #else
-#define	NI	3
+#define	NI		3
 #endif
 
 /*
  *  fma for x86: 64-bit double precision, little-endian
  */
 double
-__fma(double x, double y, double z) {
+__fma(double x, double y, double z)
+{
 	union {
 		unsigned i[NI];
 		long double e;
 	} xx, yy, zz;
+
 	long double xe, ye, xhi, xlo, yhi, ylo;
 	int ex, ey, ez;
 	unsigned cwsw, oldcwsw, rm;
 
 	/* convert the operands to double extended */
-	xx.e = (long double) x;
-	yy.e = (long double) y;
-	zz.e = (long double) z;
+	xx.e = (long double)x;
+	yy.e = (long double)y;
+	zz.e = (long double)z;
 
 	/* extract the exponents of the arguments */
 	ex = xx.i[2] & 0x7fff;
@@ -421,11 +472,12 @@
 	/* dispense with inf, nan, and zero cases */
 	if (ex == 0x7fff || ey == 0x7fff || ex == 0 || ey == 0)
 		/* x or y is inf, nan, or zero */
-		return ((double) (xx.e * yy.e + zz.e));
+		return ((double)(xx.e * yy.e + zz.e));
 
-	if (ez >= 0x7fff) /* z is inf or nan */
-		return ((double) (xx.e + zz.e));
-					/* avoid spurious inexact in x * y */
+	if (ez >= 0x7fff)		/* z is inf or nan */
+		return ((double)(xx.e + zz.e));
+
+	/* avoid spurious inexact in x * y */
 
 	/*
 	 * save the control and status words, mask all exceptions, and
@@ -438,8 +490,8 @@
 	/* multiply x*y to 106 bits */
 	xe = xx.e;
 	xx.i[0] = 0;
-	xhi = xx.e; /* hi 32 bits */
-	xlo = xe - xhi; /* lo 21 bits */
+	xhi = xx.e;			/* hi 32 bits */
+	xlo = xe - xhi;			/* lo 21 bits */
 	ye = yy.e;
 	yy.i[0] = 0;
 	yhi = yy.e;
@@ -451,7 +503,7 @@
 	xhi = ye + zz.e;
 	yhi = xhi - ye;
 	xlo = (zz.e - yhi) + (ye - (xhi - yhi));
-						/* now (xhi,xlo) = ye + z */
+	/* now (xhi,xlo) = ye + z */
 
 	yhi = xe + xhi;
 	ye = yhi - xe;
@@ -464,13 +516,14 @@
 	yy.e = yhi + xhi;
 	ylo = (yhi - yy.e) + xhi;		/* now (yy.e,ylo) = xhi + yhi */
 
-	if (yy.i[1] != 0) {	/* yy.e is nonzero */
+	if (yy.i[1] != 0) {			/* yy.e is nonzero */
 		/* perturb yy.e if its least significant 10 bits are zero */
 		if (!(yy.i[0] & 0x3ff)) {
 			xx.e = ylo + xlo;
+
 			if (xx.i[1] != 0) {
-				xx.i[2] = (xx.i[2] & 0x8000) |
-					((yy.i[2] & 0x7fff) - 63);
+				xx.i[2] = (xx.i[2] & 0x8000) | ((yy.i[2] &
+				    0x7fff) - 63);
 				xx.i[1] = 0x80000000;
 				xx.i[0] = 0;
 				yy.e += xx.e;
@@ -479,7 +532,7 @@
 	} else {
 		/* set sign of zero result according to rounding direction */
 		rm = oldcwsw & 0x0c000000;
-		yy.i[2] = ((rm == FCW_RM)? 0x8000 : 0);
+		yy.i[2] = ((rm == FCW_RM) ? 0x8000 : 0);
 	}
 
 	/*
@@ -487,9 +540,8 @@
 	 * to double
 	 */
 	__fenv_setcwsw(&oldcwsw);
-	return ((double) yy.e);
+	return ((double)yy.e);
 }
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/fma.h	2019-06-06 20:40:13.390596975 +0000
+++ new/usr/src/lib/libm/common/m9x/fma.h	2019-06-06 20:40:13.408437481 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,7 +36,6 @@
 #endif
 
 #ifdef __sparc
-
 /*
  * Common definitions for fma routines (SPARC)
  */
@@ -48,7 +48,7 @@
 #define	FSR_UFC		0x4
 #define	FSR_OFC		0x8
 #define	FSR_NVC		0x10
-#define	FSR_CEXC	0x1f	/* mask for all cexc bits */
+#define	FSR_CEXC	0x1f		/* mask for all cexc bits */
 
 /* accrued exception bits */
 #define	FSR_NXA		0x20
@@ -73,12 +73,9 @@
 /* inline templates */
 extern void __fenv_getfsr32(unsigned int *);
 extern void __fenv_setfsr32(const unsigned int *);
-
 #endif /* __sparc */
 
-
 #if defined(__x86)
-
 /*
  * Common definitions for fma routines (x86)
  */
@@ -100,7 +97,7 @@
 #define	FCW_OFM		0x00080000
 #define	FCW_UFM		0x00100000
 #define	FCW_NXM		0x00200000
-#define FCW_ALLM	0x003f0000
+#define	FCW_ALLM	0x003f0000
 
 /* rounding directions */
 #define	FCW_RN		0x00000000
@@ -109,18 +106,16 @@
 #define	FCW_RZ		0x0c000000
 
 /* rounding precisions */
-#define FCW_P24		0x00000000
-#define FCW_P53		0x02000000
-#define FCW_P64		0x03000000
+#define	FCW_P24		0x00000000
+#define	FCW_P53		0x02000000
+#define	FCW_P64		0x03000000
 
 /* inline templates */
 extern void __fenv_getcwsw(unsigned int *);
 extern void __fenv_setcwsw(const unsigned int *);
-
 #endif /* __x86 */
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif	/* _FMA_H */
+#endif /* _FMA_H */
--- old/usr/src/lib/libm/common/m9x/fmaf.c	2019-06-06 20:40:13.879398448 +0000
+++ new/usr/src/lib/libm/common/m9x/fmaf.c	2019-06-06 20:40:13.896221963 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,16 +35,17 @@
 #include "fenv_inlines.h"
 
 #if defined(__sparc)
-
 /*
  * fmaf for SPARC: 32-bit single precision, big-endian
  */
 float
-__fmaf(float x, float y, float z) {
+__fmaf(float x, float y, float z)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xy, zz;
+
 	unsigned u, s;
 	int exy, ez;
 
@@ -52,8 +54,8 @@
 	 * and then only if either x*y is of the form Inf*0 or one of x,
 	 * y, or z is a signaling NaN
 	 */
-	xy.d = (double) x * y;
-	zz.d = (double) z;
+	xy.d = (double)x * y;
+	zz.d = (double)z;
 
 	/*
 	 * if the sum xy + z will be exact, just compute it and cast the
@@ -61,10 +63,10 @@
 	 */
 	exy = (xy.i[0] >> 20) & 0x7ff;
 	ez = (zz.i[0] >> 20) & 0x7ff;
+
 	if ((ez - exy <= 4 && exy - ez <= 28) || exy == 0x7ff || exy == 0 ||
-		ez == 0x7ff || ez == 0) {
-		return ((float) (xy.d + zz.d));
-	}
+	    ez == 0x7ff || ez == 0)
+		return ((float)(xy.d + zz.d));
 
 	/*
 	 * collapse the tail of the smaller summand into a "sticky bit"
@@ -74,14 +76,18 @@
 		if (ez - exy < 31) {
 			u = xy.i[1];
 			s = 2 << (ez - exy);
+
 			if (u & (s - 1))
 				u |= s;
+
 			xy.i[1] = u & ~(s - 1);
 		} else if (ez - exy < 51) {
 			u = xy.i[0];
 			s = 1 << (ez - exy - 31);
+
 			if ((u & (s - 1)) | xy.i[1])
 				u |= s;
+
 			xy.i[0] = u & ~(s - 1);
 			xy.i[1] = 0;
 		} else {
@@ -93,14 +99,18 @@
 		if (exy - ez < 31) {
 			u = zz.i[1];
 			s = 2 << (exy - ez);
+
 			if (u & (s - 1))
 				u |= s;
+
 			zz.i[1] = u & ~(s - 1);
 		} else if (exy - ez < 51) {
 			u = zz.i[0];
 			s = 1 << (exy - ez - 31);
+
 			if ((u & (s - 1)) | zz.i[1])
 				u |= s;
+
 			zz.i[0] = u & ~(s - 1);
 			zz.i[1] = 0;
 		} else {
@@ -110,26 +120,26 @@
 		}
 	}
 
-	return ((float) (xy.d + zz.d));
+	return ((float)(xy.d + zz.d));
 }
-
 #elif defined(__x86)
-
 #if defined(__amd64)
-#define	NI	4
+#define	NI		4
 #else
-#define	NI	3
+#define	NI		3
 #endif
 
 /*
  * fmaf for x86: 32-bit single precision, little-endian
  */
 float
-__fmaf(float x, float y, float z) {
+__fmaf(float x, float y, float z)
+{
 	union {
 		unsigned i[NI];
 		long double e;
 	} xy, zz;
+
 	unsigned u, s, cwsw, oldcwsw;
 	int exy, ez;
 
@@ -143,8 +153,8 @@
 	 * and then only if either x*y is of the form Inf*0 or one of x,
 	 * y, or z is a signaling NaN
 	 */
-	xy.e = (long double) x * y;
-	zz.e = (long double) z;
+	xy.e = (long double)x * y;
+	zz.e = (long double)z;
 
 	/*
 	 * if the sum xy + z will be exact, just compute it and cast the
@@ -152,10 +162,10 @@
 	 */
 	exy = xy.i[2] & 0x7fff;
 	ez = zz.i[2] & 0x7fff;
+
 	if ((ez - exy <= 15 && exy - ez <= 39) || exy == 0x7fff || exy == 0 ||
-		ez == 0x7fff || ez == 0) {
+	    ez == 0x7fff || ez == 0)
 		goto cont;
-	}
 
 	/*
 	 * collapse the tail of the smaller summand into a "sticky bit"
@@ -165,14 +175,18 @@
 		if (ez - exy < 31) {
 			u = xy.i[0];
 			s = 2 << (ez - exy);
+
 			if (u & (s - 1))
 				u |= s;
+
 			xy.i[0] = u & ~(s - 1);
 		} else if (ez - exy < 62) {
 			u = xy.i[1];
 			s = 1 << (ez - exy - 31);
+
 			if ((u & (s - 1)) | xy.i[0])
 				u |= s;
+
 			xy.i[1] = u & ~(s - 1);
 			xy.i[0] = 0;
 		} else {
@@ -185,8 +199,10 @@
 		if (exy - ez < 62) {
 			u = zz.i[1];
 			s = 1 << (exy - ez - 31);
+
 			if ((u & (s - 1)) | zz.i[0])
 				u |= s;
+
 			zz.i[1] = u & ~(s - 1);
 			zz.i[0] = 0;
 		} else {
@@ -205,7 +221,7 @@
 	cwsw = (cwsw & 0xfcffffff) | (oldcwsw & 0x03000000);
 	__fenv_setcwsw(&cwsw);
 
-	return ((float) xy.e);
+	return ((float)xy.e);
 }
 
 #if 0
@@ -214,7 +230,8 @@
  * long double (80-bit double extended) precision
  */
 long double
-__fmaf(float x, float y, float z) {
+__fmaf(float x, float y, float z)
+{
 	/*
 	 * Note: This implementation assumes the rounding precision mode
 	 * is set to the default, rounding to 64 bit precision.  If this
@@ -232,10 +249,9 @@
 	 * the exception masks or flags, since the product x * y may raise
 	 * an invalid operation exception.
 	 */
-	return ((long double) x * y + z);
+	return ((long double)x * y + z);
 }
 #endif
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/fmal.c	2019-06-06 20:40:14.358530283 +0000
+++ new/usr/src/lib/libm/common/m9x/fmal.c	2019-06-06 20:40:14.383380777 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,7 +35,6 @@
 #include "fenv_inlines.h"
 
 #if defined(__sparc)
-
 static const union {
 	unsigned i[2];
 	double d;
@@ -57,22 +57,22 @@
 	{ 0x7ff00001u, 0 }
 };
 
-#define	half	C[0].d
-#define	two	C[1].d
-#define	twom16	C[2].d
-#define	twom24	C[3].d
-#define	two20	C[4].d
-#define	twom28	C[5].d
-#define	twom76	C[6].d
-#define	twom124	C[7].d
-#define	two36	C[8].d
-#define	twom32	C[9].d
-#define	huge	C[10].d
-#define	tiny	C[11].d
-#define	tiny2	C[12].d
-#define	zero	C[13].d
-#define	inf	C[14].d
-#define	snan	C[15].d
+#define	half		C[0].d
+#define	two		C[1].d
+#define	twom16		C[2].d
+#define	twom24		C[3].d
+#define	two20		C[4].d
+#define	twom28		C[5].d
+#define	twom76		C[6].d
+#define	twom124		C[7].d
+#define	two36		C[8].d
+#define	twom32		C[9].d
+#define	huge		C[10].d
+#define	tiny		C[11].d
+#define	tiny2		C[12].d
+#define	zero		C[13].d
+#define	inf		C[14].d
+#define	snan		C[15].d
 
 static const unsigned int fsr_rm = 0xc0000000u;
 
@@ -80,7 +80,8 @@
  * fmal for SPARC: 128-bit quad precision, big-endian
  */
 long double
-__fmal(long double x, long double y, long double z) {
+__fmal(long double x, long double y, long double z)
+{
 	union {
 		unsigned int i[4];
 		long double q;
@@ -89,6 +90,7 @@
 		unsigned int i[2];
 		double d;
 	} u;
+
 	double dx[5], dy[5], dxy[9], c, s;
 	unsigned int xy0, xy1, xy2, xy3, xy4, xy5, xy6, xy7;
 	unsigned int z0, z1, z2, z3, z4, z5, z6, z7;
@@ -96,7 +98,7 @@
 	unsigned int fsr;
 	int hx, hy, hz, ex, ey, ez, exy, sxy, sz, e, ibit;
 	int cx, cy, cz;
-	volatile double	dummy;
+	volatile double dummy;
 
 	/* extract the high order words of the arguments */
 	xx.q = x;
@@ -119,14 +121,17 @@
 				xx.i[0] |= 0x8000;
 				return (xx.q);
 			}
-			cx = 3;	/* quiet nan */
-		} else
-			cx = 2;	/* inf */
+
+			cx = 3;		/* quiet nan */
+		} else {
+			cx = 2;		/* inf */
+		}
 	} else if (hx == 0) {
 		cx = (xx.i[1] | xx.i[2] | xx.i[3]) ? 1 : 0;
-				/* subnormal or zero */
-	} else
-		cx = 1;		/* finite nonzero */
+		/* subnormal or zero */
+	} else {
+		cx = 1;			/* finite nonzero */
+	}
 
 	if (hy >= 0x7fff0000) {
 		if ((hy & 0xffff) | yy.i[1] | yy.i[2] | yy.i[3]) {
@@ -136,13 +141,16 @@
 				yy.i[0] |= 0x8000;
 				return (yy.q);
 			}
+
 			cy = 3;
-		} else
+		} else {
 			cy = 2;
+		}
 	} else if (hy == 0) {
 		cy = (yy.i[1] | yy.i[2] | yy.i[3]) ? 1 : 0;
-	} else
+	} else {
 		cy = 1;
+	}
 
 	if (hz >= 0x7fff0000) {
 		if ((hz & 0xffff) | zz.i[1] | zz.i[2] | zz.i[3]) {
@@ -152,13 +160,16 @@
 				zz.i[0] |= 0x8000;
 				return (zz.q);
 			}
+
 			cz = 3;
-		} else
+		} else {
 			cz = 2;
+		}
 	} else if (hz == 0) {
 		cz = (zz.i[1] | zz.i[2] | zz.i[3]) ? 1 : 0;
-	} else
+	} else {
 		cz = 1;
+	}
 
 	/* get the fsr and clear current exceptions */
 	__fenv_getfsr32(&fsr);
@@ -171,6 +182,7 @@
 			__fenv_setfsr32(&fsr);
 			return (x);
 		}
+
 		if (cy == 3) {
 			__fenv_setfsr32(&fsr);
 			return (y);
@@ -201,21 +213,22 @@
 			 * the result is the same as z depending on signs
 			 */
 			if (cz == 2) {
-				if ((int) ((xx.i[0] ^ yy.i[0]) ^ zz.i[0]) < 0) {
+				if ((int)((xx.i[0] ^ yy.i[0]) ^ zz.i[0]) < 0) {
 					dummy = inf;
 					dummy -= inf;
 					zz.i[0] = 0x7fffffff;
 					zz.i[1] = zz.i[2] = zz.i[3] =
-						0xffffffff;
+					    0xffffffff;
 					return (zz.q);
 				}
+
 				__fenv_setfsr32(&fsr);
 				return (z);
 			}
 
 			/* otherwise the result is inf with appropriate sign */
 			zz.i[0] = ((xx.i[0] ^ yy.i[0]) & 0x80000000) |
-				0x7fff0000;
+			    0x7fff0000;
 			zz.i[1] = zz.i[2] = zz.i[3] = 0;
 			__fenv_setfsr32(&fsr);
 			return (zz.q);
@@ -233,13 +246,14 @@
 		 */
 		if (cx == 0 || cy == 0) {
 			/* either we have 0-0 or the result is the same as z */
-			if (cz == 0 && (int) ((xx.i[0] ^ yy.i[0]) ^ zz.i[0]) <
-				0) {
+			if (cz == 0 && (int)((xx.i[0] ^ yy.i[0]) ^ zz.i[0]) <
+			    0) {
 				zz.i[0] = (fsr >> 30) == FSR_RM ? 0x80000000 :
-					0;
+				    0;
 				__fenv_setfsr32(&fsr);
 				return (zz.q);
 			}
+
 			__fenv_setfsr32(&fsr);
 			return (z);
 		}
@@ -261,6 +275,7 @@
 	sxy = (xx.i[0] ^ yy.i[0]) & 0x80000000;
 	ex = hx >> 16;
 	hx &= 0xffff;
+
 	if (!ex) {
 		if (hx | (xx.i[1] & 0xfffe0000)) {
 			ex = 1;
@@ -280,6 +295,7 @@
 			xx.i[1] = xx.i[2] = xx.i[3] = 0;
 			ex = -95;
 		}
+
 		while ((hx & 0x10000) == 0) {
 			hx = (hx << 1) | (xx.i[1] >> 31);
 			xx.i[1] = (xx.i[1] << 1) | (xx.i[2] >> 31);
@@ -287,10 +303,13 @@
 			xx.i[3] <<= 1;
 			ex--;
 		}
-	} else
+	} else {
 		hx |= 0x10000;
+	}
+
 	ey = hy >> 16;
 	hy &= 0xffff;
+
 	if (!ey) {
 		if (hy | (yy.i[1] & 0xfffe0000)) {
 			ey = 1;
@@ -310,6 +329,7 @@
 			yy.i[1] = yy.i[2] = yy.i[3] = 0;
 			ey = -95;
 		}
+
 		while ((hy & 0x10000) == 0) {
 			hy = (hy << 1) | (yy.i[1] >> 31);
 			yy.i[1] = (yy.i[1] << 1) | (yy.i[2] >> 31);
@@ -317,45 +337,45 @@
 			yy.i[3] <<= 1;
 			ey--;
 		}
-	} else
+	} else {
 		hy |= 0x10000;
+	}
+
 	exy = ex + ey - 0x3fff;
 
 	/* convert the significands of x and y to doubles */
 	c = twom16;
-	dx[0] = (double) ((int) hx) * c;
-	dy[0] = (double) ((int) hy) * c;
+	dx[0] = (double)((int)hx) * c;
+	dy[0] = (double)((int)hy) * c;
 
 	c *= twom24;
-	dx[1] = (double) ((int) (xx.i[1] >> 8)) * c;
-	dy[1] = (double) ((int) (yy.i[1] >> 8)) * c;
+	dx[1] = (double)((int)(xx.i[1] >> 8)) * c;
+	dy[1] = (double)((int)(yy.i[1] >> 8)) * c;
 
 	c *= twom24;
-	dx[2] = (double) ((int) (((xx.i[1] << 16) | (xx.i[2] >> 16)) &
+	dx[2] = (double)((int)(((xx.i[1] << 16) | (xx.i[2] >> 16)) &
 	    0xffffff)) * c;
-	dy[2] = (double) ((int) (((yy.i[1] << 16) | (yy.i[2] >> 16)) &
+	dy[2] = (double)((int)(((yy.i[1] << 16) | (yy.i[2] >> 16)) &
 	    0xffffff)) * c;
 
 	c *= twom24;
-	dx[3] = (double) ((int) (((xx.i[2] << 8) | (xx.i[3] >> 24)) &
-	    0xffffff)) * c;
-	dy[3] = (double) ((int) (((yy.i[2] << 8) | (yy.i[3] >> 24)) &
-	    0xffffff)) * c;
+	dx[3] = (double)((int)(((xx.i[2] << 8) | (xx.i[3] >> 24)) & 0xffffff)) *
+	    c;
+	dy[3] = (double)((int)(((yy.i[2] << 8) | (yy.i[3] >> 24)) & 0xffffff)) *
+	    c;
 
 	c *= twom24;
-	dx[4] = (double) ((int) (xx.i[3] & 0xffffff)) * c;
-	dy[4] = (double) ((int) (yy.i[3] & 0xffffff)) * c;
+	dx[4] = (double)((int)(xx.i[3] & 0xffffff)) * c;
+	dy[4] = (double)((int)(yy.i[3] & 0xffffff)) * c;
 
 	/* form the "digits" of the product */
 	dxy[0] = dx[0] * dy[0];
 	dxy[1] = dx[0] * dy[1] + dx[1] * dy[0];
 	dxy[2] = dx[0] * dy[2] + dx[1] * dy[1] + dx[2] * dy[0];
-	dxy[3] = dx[0] * dy[3] + dx[1] * dy[2] + dx[2] * dy[1] +
-	    dx[3] * dy[0];
-	dxy[4] = dx[0] * dy[4] + dx[1] * dy[3] + dx[2] * dy[2] +
-	    dx[3] * dy[1] + dx[4] * dy[0];
-	dxy[5] = dx[1] * dy[4] + dx[2] * dy[3] + dx[3] * dy[2] +
-	    dx[4] * dy[1];
+	dxy[3] = dx[0] * dy[3] + dx[1] * dy[2] + dx[2] * dy[1] + dx[3] * dy[0];
+	dxy[4] = dx[0] * dy[4] + dx[1] * dy[3] + dx[2] * dy[2] + dx[3] * dy[1] +
+	    dx[4] * dy[0];
+	dxy[5] = dx[1] * dy[4] + dx[2] * dy[3] + dx[3] * dy[2] + dx[4] * dy[1];
 	dxy[6] = dx[2] * dy[4] + dx[3] * dy[3] + dx[4] * dy[2];
 	dxy[7] = dx[3] * dy[4] + dx[4] * dy[3];
 	dxy[8] = dx[4] * dy[4];
@@ -379,6 +399,7 @@
 	dxy[5] = dxy[4] + dxy[7];
 	dxy[3] = dxy[2] + dxy[5];
 	dxy[1] = dxy[0] + dxy[3];
+
 	if (dxy[1] >= two) {
 		dxy[0] *= half;
 		dxy[1] *= half;
@@ -448,6 +469,7 @@
 	sz = zz.i[0] & 0x80000000;
 	ez = hz >> 16;
 	z0 = hz & 0xffff;
+
 	if (!ez) {
 		if (z0 | (zz.i[1] & 0xfffe0000)) {
 			z1 = zz.i[1];
@@ -470,6 +492,7 @@
 			z1 = z2 = z3 = 0;
 			ez = -95;
 		}
+
 		while ((z0 & 0x10000) == 0) {
 			z0 = (z0 << 1) | (z1 >> 31);
 			z1 = (z1 << 1) | (z2 >> 31);
@@ -483,6 +506,7 @@
 		z2 = zz.i[2];
 		z3 = zz.i[3];
 	}
+
 	z4 = z5 = z6 = z7 = 0;
 
 	/*
@@ -490,54 +514,79 @@
 	 * represented likewise; swap if need be so |xy| <= |z|
 	 */
 	if (exy > ez || (exy == ez && (xy0 > z0 || (xy0 == z0 && (xy1 > z1 ||
-		(xy1 == z1 && (xy2 > z2 || (xy2 == z2 && (xy3 > z3 ||
-		(xy3 == z3 && (xy4 | xy5 | xy6 | xy7) != 0)))))))))) {
-		e = sxy; sxy = sz; sz = e;
-		e = exy; exy = ez; ez = e;
-		e = xy0; xy0 = z0; z0 = e;
-		e = xy1; xy1 = z1; z1 = e;
-		e = xy2; xy2 = z2; z2 = e;
-		e = xy3; xy3 = z3; z3 = e;
-		z4 = xy4; xy4 = 0;
-		z5 = xy5; xy5 = 0;
-		z6 = xy6; xy6 = 0;
-		z7 = xy7; xy7 = 0;
+	    (xy1 == z1 && (xy2 > z2 || (xy2 == z2 && (xy3 > z3 || (xy3 == z3 &&
+	    (xy4 | xy5 | xy6 | xy7) != 0)))))))))) {
+		e = sxy;
+		sxy = sz;
+		sz = e;
+		e = exy;
+		exy = ez;
+		ez = e;
+		e = xy0;
+		xy0 = z0;
+		z0 = e;
+		e = xy1;
+		xy1 = z1;
+		z1 = e;
+		e = xy2;
+		xy2 = z2;
+		z2 = e;
+		e = xy3;
+		xy3 = z3;
+		z3 = e;
+		z4 = xy4;
+		xy4 = 0;
+		z5 = xy5;
+		xy5 = 0;
+		z6 = xy6;
+		xy6 = 0;
+		z7 = xy7;
+		xy7 = 0;
 	}
 
 	/* shift the significand of xy keeping a sticky bit */
 	e = ez - exy;
+
 	if (e > 236) {
 		xy0 = xy1 = xy2 = xy3 = xy4 = xy5 = xy6 = 0;
 		xy7 = 1;
 	} else if (e >= 224) {
-		sticky = xy7 | xy6 | xy5 | xy4 | xy3 | xy2 | xy1 |
-			((xy0 << 1) << (255 - e));
+		sticky = xy7 | xy6 | xy5 | xy4 | xy3 | xy2 | xy1 | ((xy0 <<
+		    1) << (255 - e));
 		xy7 = xy0 >> (e - 224);
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy0 = xy1 = xy2 = xy3 = xy4 = xy5 = xy6 = 0;
 	} else if (e >= 192) {
-		sticky = xy7 | xy6 | xy5 | xy4 | xy3 | xy2 |
-			((xy1 << 1) << (223 - e));
+		sticky = xy7 | xy6 | xy5 | xy4 | xy3 | xy2 | ((xy1 << 1) <<
+		    (223 - e));
 		xy7 = (xy1 >> (e - 192)) | ((xy0 << 1) << (223 - e));
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy6 = xy0 >> (e - 192);
 		xy0 = xy1 = xy2 = xy3 = xy4 = xy5 = 0;
 	} else if (e >= 160) {
-		sticky = xy7 | xy6 | xy5 | xy4 | xy3 |
-			((xy2 << 1) << (191 - e));
+		sticky = xy7 | xy6 | xy5 | xy4 | xy3 | ((xy2 << 1) << (191 -
+		    e));
 		xy7 = (xy2 >> (e - 160)) | ((xy1 << 1) << (191 - e));
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy6 = (xy1 >> (e - 160)) | ((xy0 << 1) << (191 - e));
 		xy5 = xy0 >> (e - 160);
 		xy0 = xy1 = xy2 = xy3 = xy4 = 0;
 	} else if (e >= 128) {
 		sticky = xy7 | xy6 | xy5 | xy4 | ((xy3 << 1) << (159 - e));
 		xy7 = (xy3 >> (e - 128)) | ((xy2 << 1) << (159 - e));
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy6 = (xy2 >> (e - 128)) | ((xy1 << 1) << (159 - e));
 		xy5 = (xy1 >> (e - 128)) | ((xy0 << 1) << (159 - e));
 		xy4 = xy0 >> (e - 128);
@@ -545,8 +594,10 @@
 	} else if (e >= 96) {
 		sticky = xy7 | xy6 | xy5 | ((xy4 << 1) << (127 - e));
 		xy7 = (xy4 >> (e - 96)) | ((xy3 << 1) << (127 - e));
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy6 = (xy3 >> (e - 96)) | ((xy2 << 1) << (127 - e));
 		xy5 = (xy2 >> (e - 96)) | ((xy1 << 1) << (127 - e));
 		xy4 = (xy1 >> (e - 96)) | ((xy0 << 1) << (127 - e));
@@ -555,8 +606,10 @@
 	} else if (e >= 64) {
 		sticky = xy7 | xy6 | ((xy5 << 1) << (95 - e));
 		xy7 = (xy5 >> (e - 64)) | ((xy4 << 1) << (95 - e));
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy6 = (xy4 >> (e - 64)) | ((xy3 << 1) << (95 - e));
 		xy5 = (xy3 >> (e - 64)) | ((xy2 << 1) << (95 - e));
 		xy4 = (xy2 >> (e - 64)) | ((xy1 << 1) << (95 - e));
@@ -566,8 +619,10 @@
 	} else if (e >= 32) {
 		sticky = xy7 | ((xy6 << 1) << (63 - e));
 		xy7 = (xy6 >> (e - 32)) | ((xy5 << 1) << (63 - e));
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy6 = (xy5 >> (e - 32)) | ((xy4 << 1) << (63 - e));
 		xy5 = (xy4 >> (e - 32)) | ((xy3 << 1) << (63 - e));
 		xy4 = (xy3 >> (e - 32)) | ((xy2 << 1) << (63 - e));
@@ -578,8 +633,10 @@
 	} else if (e) {
 		sticky = (xy7 << 1) << (31 - e);
 		xy7 = (xy7 >> e) | ((xy6 << 1) << (31 - e));
+
 		if (sticky)
 			xy7 |= 1;
+
 		xy6 = (xy6 >> e) | ((xy5 << 1) << (31 - e));
 		xy5 = (xy5 >> e) | ((xy4 << 1) << (31 - e));
 		xy4 = (xy4 >> e) | ((xy3 << 1) << (31 - e));
@@ -599,6 +656,7 @@
 		xy5 = ~xy5;
 		xy6 = ~xy6;
 		xy7 = -xy7;
+
 		if (xy7 == 0)
 			if (++xy6 == 0)
 				if (++xy5 == 0)
@@ -613,42 +671,61 @@
 	z7 += xy7;
 	e = (z7 < xy7);
 	z6 += xy6;
+
 	if (e) {
 		z6++;
 		e = (z6 <= xy6);
-	} else
+	} else {
 		e = (z6 < xy6);
+	}
+
 	z5 += xy5;
+
 	if (e) {
 		z5++;
 		e = (z5 <= xy5);
-	} else
+	} else {
 		e = (z5 < xy5);
+	}
+
 	z4 += xy4;
+
 	if (e) {
 		z4++;
 		e = (z4 <= xy4);
-	} else
+	} else {
 		e = (z4 < xy4);
+	}
+
 	z3 += xy3;
+
 	if (e) {
 		z3++;
 		e = (z3 <= xy3);
-	} else
+	} else {
 		e = (z3 < xy3);
+	}
+
 	z2 += xy2;
+
 	if (e) {
 		z2++;
 		e = (z2 <= xy2);
-	} else
+	} else {
 		e = (z2 < xy2);
+	}
+
 	z1 += xy1;
+
 	if (e) {
 		z1++;
 		e = (z1 <= xy1);
-	} else
+	} else {
 		e = (z1 < xy1);
+	}
+
 	z0 += xy0;
+
 	if (e)
 		z0++;
 
@@ -656,31 +733,38 @@
 	if (ez < 1) {
 		/* result is tiny; shift right until exponent is within range */
 		e = 1 - ez;
+
 		if (e > 116) {
-			z4 = 1; /* result can't be exactly zero */
+			z4 = 1;		/* result can't be exactly zero */
 			z0 = z1 = z2 = z3 = 0;
 		} else if (e >= 96) {
-			sticky = z7 | z6 | z5 | z4 | z3 | z2 |
-				((z1 << 1) << (127 - e));
+			sticky = z7 | z6 | z5 | z4 | z3 | z2 | ((z1 << 1) <<
+			    (127 - e));
 			z4 = (z1 >> (e - 96)) | ((z0 << 1) << (127 - e));
+
 			if (sticky)
 				z4 |= 1;
+
 			z3 = z0 >> (e - 96);
 			z0 = z1 = z2 = 0;
 		} else if (e >= 64) {
-			sticky = z7 | z6 | z5 | z4 | z3 |
-				((z2 << 1) << (95 - e));
+			sticky = z7 | z6 | z5 | z4 | z3 | ((z2 << 1) << (95 -
+			    e));
 			z4 = (z2 >> (e - 64)) | ((z1 << 1) << (95 - e));
+
 			if (sticky)
 				z4 |= 1;
+
 			z3 = (z1 >> (e - 64)) | ((z0 << 1) << (95 - e));
 			z2 = z0 >> (e - 64);
 			z0 = z1 = 0;
 		} else if (e >= 32) {
 			sticky = z7 | z6 | z5 | z4 | ((z3 << 1) << (63 - e));
 			z4 = (z3 >> (e - 32)) | ((z2 << 1) << (63 - e));
+
 			if (sticky)
 				z4 |= 1;
+
 			z3 = (z2 >> (e - 32)) | ((z1 << 1) << (63 - e));
 			z2 = (z1 >> (e - 32)) | ((z0 << 1) << (63 - e));
 			z1 = z0 >> (e - 32);
@@ -688,28 +772,33 @@
 		} else {
 			sticky = z7 | z6 | z5 | (z4 << 1) << (31 - e);
 			z4 = (z4 >> e) | ((z3 << 1) << (31 - e));
+
 			if (sticky)
 				z4 |= 1;
+
 			z3 = (z3 >> e) | ((z2 << 1) << (31 - e));
 			z2 = (z2 >> e) | ((z1 << 1) << (31 - e));
 			z1 = (z1 >> e) | ((z0 << 1) << (31 - e));
 			z0 >>= e;
 		}
+
 		ez = 1;
 	} else if (z0 >= 0x20000) {
 		/* carry out; shift right by one */
 		sticky = (z4 & 1) | z5 | z6 | z7;
 		z4 = (z4 >> 1) | (z3 << 31);
+
 		if (sticky)
 			z4 |= 1;
+
 		z3 = (z3 >> 1) | (z2 << 31);
 		z2 = (z2 >> 1) | (z1 << 31);
 		z1 = (z1 >> 1) | (z0 << 31);
 		z0 >>= 1;
 		ez++;
 	} else {
-		if (z0 < 0x10000 && (z0 | z1 | z2 | z3 | z4 | z5 | z6 | z7)
-			!= 0) {
+		if (z0 < 0x10000 && (z0 | z1 | z2 | z3 | z4 | z5 | z6 | z7) !=
+		    0) {
 			/*
 			 * borrow/cancellation; shift left as much as
 			 * exponent allows
@@ -725,6 +814,7 @@
 				z7 = 0;
 				ez -= 32;
 			}
+
 			while (z0 < 0x10000 && ez > 1) {
 				z0 = (z0 << 1) | (z1 >> 31);
 				z1 = (z1 << 1) | (z2 >> 31);
@@ -737,6 +827,7 @@
 				ez--;
 			}
 		}
+
 		if (z5 | z6 | z7)
 			z4 |= 1;
 	}
@@ -746,11 +837,13 @@
 
 	/* strip off the integer bit, if there is one */
 	ibit = z0 & 0x10000;
-	if (ibit)
+
+	if (ibit) {
 		z0 -= 0x10000;
-	else {
+	} else {
 		ez = 0;
-		if (!(z0 | z1 | z2 | z3 | z4)) { /* exact zero */
+
+		if (!(z0 | z1 | z2 | z3 | z4)) {	/* exact zero */
 			zz.i[0] = rm == FSR_RM ? 0x80000000 : 0;
 			zz.i[1] = zz.i[2] = zz.i[3] = 0;
 			__fenv_setfsr32(&fsr);
@@ -770,8 +863,8 @@
 		fsr |= FSR_NXC;
 
 		/* decide whether to round the fraction up */
-		if (rm == FSR_RP || (rm == FSR_RN && (z4 > 0x80000000u ||
-			(z4 == 0x80000000u && (z3 & 1))))) {
+		if (rm == FSR_RP || (rm == FSR_RN && (z4 > 0x80000000u || (z4 ==
+		    0x80000000u && (z3 & 1))))) {
 			/* round up and renormalize if necessary */
 			if (++z3 == 0)
 				if (++z2 == 0)
@@ -792,6 +885,7 @@
 			zz.i[0] = sz | 0x7ffeffff;
 			zz.i[1] = zz.i[2] = zz.i[3] = 0xffffffff;
 		}
+
 		fsr |= FSR_OFC | FSR_NXC;
 	} else {
 		zz.i[0] = sz | (ez << 16) | z0;
@@ -814,11 +908,13 @@
 	/* restore the fsr and emulate exceptions as needed */
 	if ((fsr & FSR_CEXC) & (fsr >> 23)) {
 		__fenv_setfsr32(&fsr);
+
 		if (fsr & FSR_OFC) {
 			dummy = huge;
 			dummy *= huge;
 		} else if (fsr & FSR_UFC) {
 			dummy = tiny;
+
 			if (fsr & FSR_NXC)
 				dummy *= tiny;
 			else
@@ -831,11 +927,10 @@
 		fsr |= (fsr & 0x1f) << 5;
 		__fenv_setfsr32(&fsr);
 	}
+
 	return (zz.q);
 }
-
 #elif defined(__x86)
-
 static const union {
 	unsigned i[2];
 	double d;
@@ -851,36 +946,38 @@
 	{ 0, 0x00100001u }
 };
 
-#define	half	C[0].d
-#define	two	C[1].d
-#define	twom32	C[2].d
-#define	twom64	C[3].d
-#define	two32	C[4].d
-#define	two63	C[5].d
-#define	huge	C[6].d
-#define	tiny	C[7].d
-#define	tiny2	C[8].d
+#define	half		C[0].d
+#define	two		C[1].d
+#define	twom32		C[2].d
+#define	twom64		C[3].d
+#define	two32		C[4].d
+#define	two63		C[5].d
+#define	huge		C[6].d
+#define	tiny		C[7].d
+#define	tiny2		C[8].d
 
 #if defined(__amd64)
-#define	NI	4
+#define	NI		4
 #else
-#define	NI	3
+#define	NI		3
 #endif
 
 /*
  * fmal for x86: 80-bit extended double precision, little-endian
  */
 long double
-__fmal(long double x, long double y, long double z) {
+__fmal(long double x, long double y, long double z)
+{
 	union {
 		unsigned i[NI];
 		long double e;
 	} xx, yy, zz;
+
 	long double xhi, yhi, xlo, ylo, t;
 	unsigned xy0, xy1, xy2, xy3, xy4, z0, z1, z2, z3, z4;
 	unsigned oldcwsw, cwsw, rm, sticky, carry;
 	int ex, ey, ez, exy, sxy, sz, e, tinyafter;
-	volatile double	dummy;
+	volatile double dummy;
 
 	/* extract the exponents of the arguments */
 	xx.e = x;
@@ -892,10 +989,10 @@
 
 	/* dispense with inf, nan, and zero cases */
 	if (ex == 0x7fff || ey == 0x7fff || (ex | xx.i[1] | xx.i[0]) == 0 ||
-		(ey | yy.i[1] | yy.i[0]) == 0)	/* x or y is inf, nan, or 0 */
+	    (ey | yy.i[1] | yy.i[0]) == 0)	/* x or y is inf, nan, or 0 */
 		return (x * y + z);
 
-	if (ez == 0x7fff)			/* z is inf or nan */
+	if (ez == 0x7fff)	/* z is inf or nan */
 		return (x + z);	/* avoid spurious under/overflow in x * y */
 
 	if ((ez | zz.i[1] | zz.i[0]) == 0)	/* z is zero */
@@ -912,14 +1009,17 @@
 	 */
 	sxy = (xx.i[2] ^ yy.i[2]) & 0x8000;
 	sz = zz.i[2] & 0x8000;
+
 	if (!ex) {
 		xx.e = x * two63;
 		ex = (xx.i[2] & 0x7fff) - 63;
 	}
+
 	if (!ey) {
 		yy.e = y * two63;
 		ey = (yy.i[2] & 0x7fff) - 63;
 	}
+
 	if (!ez) {
 		zz.e = z * two63;
 		ez = (zz.i[2] & 0x7fff) - 63;
@@ -945,6 +1045,7 @@
 	ylo = y - yhi;
 	x *= y;
 	y = ((xhi * yhi - x) + xhi * ylo + xlo * yhi) + xlo * ylo;
+
 	if (x >= two) {
 		x *= half;
 		y *= half;
@@ -968,47 +1069,66 @@
 	 * now x*y is represented by sxy, exy, and xy[0-4], and z is
 	 * represented likewise; swap if need be so |xy| <= |z|
 	 */
-	if (exy > ez || (exy == ez && (xy0 > z0 || (xy0 == z0 &&
-		(xy1 > z1 || (xy1 == z1 && (xy2 | xy3) != 0)))))) {
-		e = sxy; sxy = sz; sz = e;
-		e = exy; exy = ez; ez = e;
-		e = xy0; xy0 = z0; z0 = e;
-		e = xy1; xy1 = z1; z1 = e;
-		z2 = xy2; xy2 = 0;
-		z3 = xy3; xy3 = 0;
+	if (exy > ez || (exy == ez && (xy0 > z0 || (xy0 == z0 && (xy1 > z1 ||
+	    (xy1 == z1 && (xy2 | xy3) != 0)))))) {
+		e = sxy;
+		sxy = sz;
+		sz = e;
+		e = exy;
+		exy = ez;
+		ez = e;
+		e = xy0;
+		xy0 = z0;
+		z0 = e;
+		e = xy1;
+		xy1 = z1;
+		z1 = e;
+		z2 = xy2;
+		xy2 = 0;
+		z3 = xy3;
+		xy3 = 0;
 	}
 
 	/* shift the significand of xy keeping a sticky bit */
 	e = ez - exy;
+
 	if (e > 130) {
 		xy0 = xy1 = xy2 = xy3 = 0;
 		xy4 = 1;
 	} else if (e >= 128) {
 		sticky = xy3 | xy2 | xy1 | ((xy0 << 1) << (159 - e));
 		xy4 = xy0 >> (e - 128);
+
 		if (sticky)
 			xy4 |= 1;
+
 		xy0 = xy1 = xy2 = xy3 = 0;
 	} else if (e >= 96) {
 		sticky = xy3 | xy2 | ((xy1 << 1) << (127 - e));
 		xy4 = (xy1 >> (e - 96)) | ((xy0 << 1) << (127 - e));
+
 		if (sticky)
 			xy4 |= 1;
+
 		xy3 = xy0 >> (e - 96);
 		xy0 = xy1 = xy2 = 0;
 	} else if (e >= 64) {
 		sticky = xy3 | ((xy2 << 1) << (95 - e));
 		xy4 = (xy2 >> (e - 64)) | ((xy1 << 1) << (95 - e));
+
 		if (sticky)
 			xy4 |= 1;
+
 		xy3 = (xy1 >> (e - 64)) | ((xy0 << 1) << (95 - e));
 		xy2 = xy0 >> (e - 64);
 		xy0 = xy1 = 0;
 	} else if (e >= 32) {
 		sticky = (xy3 << 1) << (63 - e);
 		xy4 = (xy3 >> (e - 32)) | ((xy2 << 1) << (63 - e));
+
 		if (sticky)
 			xy4 |= 1;
+
 		xy3 = (xy2 >> (e - 32)) | ((xy1 << 1) << (63 - e));
 		xy2 = (xy1 >> (e - 32)) | ((xy0 << 1) << (63 - e));
 		xy1 = xy0 >> (e - 32);
@@ -1028,6 +1148,7 @@
 		xy2 = ~xy2;
 		xy3 = ~xy3;
 		xy4 = -xy4;
+
 		if (xy4 == 0)
 			if (++xy3 == 0)
 				if (++xy2 == 0)
@@ -1039,29 +1160,40 @@
 	z4 += xy4;
 	carry = (z4 < xy4);
 	z3 += xy3;
+
 	if (carry) {
 		z3++;
 		carry = (z3 <= xy3);
-	} else
+	} else {
 		carry = (z3 < xy3);
+	}
+
 	z2 += xy2;
+
 	if (carry) {
 		z2++;
 		carry = (z2 <= xy2);
-	} else
+	} else {
 		carry = (z2 < xy2);
+	}
+
 	z1 += xy1;
+
 	if (carry) {
 		z1++;
 		carry = (z1 <= xy1);
-	} else
+	} else {
 		carry = (z1 < xy1);
+	}
+
 	z0 += xy0;
+
 	if (carry) {
 		z0++;
 		carry = (z0 <= xy0);
-	} else
+	} else {
 		carry = (z0 < xy0);
+	}
 
 	/* for a magnitude subtract, ignore the last carry out */
 	if (sxy ^ sz)
@@ -1071,38 +1203,48 @@
 	if (ez < 1) {
 		/* result is tiny; shift right until exponent is within range */
 		e = 1 - ez;
+
 		if (e > 67) {
-			z2 = 1;	/* result can't be exactly zero */
+			z2 = 1;		/* result can't be exactly zero */
 			z0 = z1 = 0;
 		} else if (e >= 64) {
 			sticky = z4 | z3 | z2 | z1 | ((z0 << 1) << (95 - e));
 			z2 = (z0 >> (e - 64)) | ((carry << 1) << (95 - e));
+
 			if (sticky)
 				z2 |= 1;
+
 			z1 = carry >> (e - 64);
 			z0 = 0;
 		} else if (e >= 32) {
 			sticky = z4 | z3 | z2 | ((z1 << 1) << (63 - e));
 			z2 = (z1 >> (e - 32)) | ((z0 << 1) << (63 - e));
+
 			if (sticky)
 				z2 |= 1;
+
 			z1 = (z0 >> (e - 32)) | ((carry << 1) << (63 - e));
 			z0 = carry >> (e - 32);
 		} else {
 			sticky = z4 | z3 | (z2 << 1) << (31 - e);
 			z2 = (z2 >> e) | ((z1 << 1) << (31 - e));
+
 			if (sticky)
 				z2 |= 1;
+
 			z1 = (z1 >> e) | ((z0 << 1) << (31 - e));
 			z0 = (z0 >> e) | ((carry << 1) << (31 - e));
 		}
+
 		ez = 1;
 	} else if (carry) {
 		/* carry out; shift right by one */
 		sticky = (z2 & 1) | z3 | z4;
 		z2 = (z2 >> 1) | (z1 << 31);
+
 		if (sticky)
 			z2 |= 1;
+
 		z1 = (z1 >> 1) | (z0 << 31);
 		z0 = (z0 >> 1) | 0x80000000;
 		ez++;
@@ -1120,6 +1262,7 @@
 				z4 = 0;
 				ez -= 32;
 			}
+
 			while (z0 < 0x80000000u && ez > 1) {
 				z0 = (z0 << 1) | (z1 >> 31);
 				z1 = (z1 << 1) | (z2 >> 31);
@@ -1129,6 +1272,7 @@
 				ez--;
 			}
 		}
+
 		if (z3 | z4)
 			z2 |= 1;
 	}
@@ -1138,10 +1282,12 @@
 
 	/* adjust exponent if result is subnormal */
 	tinyafter = 0;
+
 	if (!(z0 & 0x80000000)) {
 		ez = 0;
 		tinyafter = 1;
-		if (!(z0 | z1 | z2)) { /* exact zero */
+
+		if (!(z0 | z1 | z2)) {	/* exact zero */
 			zz.i[2] = rm == FCW_RM ? 0x8000 : 0;
 			zz.i[1] = zz.i[0] = 0;
 			__fenv_setcwsw(&oldcwsw);
@@ -1158,8 +1304,8 @@
 
 	/* round */
 	if (z2) {
-		if (rm == FCW_RP || (rm == FCW_RN && (z2 > 0x80000000u ||
-			(z2 == 0x80000000u && (z1 & 1))))) {
+		if (rm == FCW_RP || (rm == FCW_RN && (z2 > 0x80000000u || (z2 ==
+		    0x80000000u && (z1 & 1))))) {
 			/* round up and renormalize if necessary */
 			if (++z1 == 0) {
 				if (++z0 == 0) {
@@ -1168,9 +1314,10 @@
 				} else if (z0 == 0x80000000) {
 					/* rounded up to smallest normal */
 					ez = 1;
+
 					if ((rm == FCW_RP && z2 >
-						0x80000000u) || (rm == FCW_RN &&
-						z2 >= 0xc0000000u))
+					    0x80000000u) || (rm == FCW_RN &&
+					    z2 >= 0xc0000000u))
 						/*
 						 * would have rounded up to
 						 * smallest normal even with
@@ -1184,6 +1331,7 @@
 
 	/* restore the control and status words, check for over/underflow */
 	__fenv_setcwsw(&oldcwsw);
+
 	if (ez >= 0x7fff) {
 		if (rm == FCW_RN || rm == FCW_RP) {
 			zz.i[2] = sz | 0x7fff;
@@ -1194,6 +1342,7 @@
 			zz.i[1] = 0xffffffff;
 			zz.i[0] = 0xffffffff;
 		}
+
 		dummy = huge;
 		dummy *= huge;
 	} else {
@@ -1207,6 +1356,7 @@
 		 */
 		if (tinyafter) {
 			dummy = tiny;
+
 			if (z2)
 				dummy *= tiny;
 			else
@@ -1219,7 +1369,6 @@
 
 	return (zz.e);
 }
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/fmax.c	2019-06-06 20:40:14.968228272 +0000
+++ new/usr/src/lib/libm/common/m9x/fmax.c	2019-06-06 20:40:14.983697306 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,15 +38,17 @@
  * See fmaxf.c for a discussion of implementation trade-offs.
  */
 
-#include "libm.h"	/* for isgreaterequal macro */
+#include "libm.h"			/* for isgreaterequal macro */
 #include <fenv.h>
 
 double
-__fmax(double x, double y) {
+__fmax(double x, double y)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx, yy;
+
 	unsigned s;
 
 	/* if y is nan, replace it by x */
--- old/usr/src/lib/libm/common/m9x/fmaxf.c	2019-06-06 20:40:15.439257431 +0000
+++ new/usr/src/lib/libm/common/m9x/fmaxf.c	2019-06-06 20:40:15.451663926 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -70,10 +71,11 @@
  *    operation exception.  Otherwise, it raises no exceptions.
  */
 
-#include "libm.h"	/* for isgreaterequal macro */
+#include "libm.h"			/* for isgreaterequal macro */
 
 float
-__fmaxf(float x, float y) {
+__fmaxf(float x, float y)
+{
 	/*
 	 * On SPARC v8plus/v9, this could be implemented as follows
 	 * (assuming %f0 = x, %f1 = y, return value left in %f0):
@@ -115,6 +117,7 @@
 		unsigned i;
 		float f;
 	} xx, yy;
+
 	unsigned s;
 
 	/* if y is nan, replace it by x */
--- old/usr/src/lib/libm/common/m9x/fmaxl.c	2019-06-06 20:40:15.901209864 +0000
+++ new/usr/src/lib/libm/common/m9x/fmaxl.c	2019-06-06 20:40:15.918044409 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,10 +30,11 @@
 
 #pragma weak fmaxl = __fmaxl
 
-#include "libm.h"	/* for isgreaterequal macro */
+#include "libm.h"			/* for isgreaterequal macro */
 
 long double
-__fmaxl(long double x, long double y) {
+__fmaxl(long double x, long double y)
+{
 	union {
 #if defined(__sparc)
 		unsigned i[4];
@@ -41,8 +43,10 @@
 #else
 #error Unknown architecture
 #endif
+
 		long double ld;
 	} xx, yy;
+
 	unsigned s;
 
 	/* if y is nan, replace it by x */
--- old/usr/src/lib/libm/common/m9x/fmin.c	2019-06-06 20:40:16.395526877 +0000
+++ new/usr/src/lib/libm/common/m9x/fmin.c	2019-06-06 20:40:16.411897952 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,20 +38,22 @@
  * See fmaxf.c for a discussion of implementation trade-offs.
  */
 
-#include "libm.h"	/* for islessequal macro */
+#include "libm.h"			/* for islessequal macro */
 
 #include "fenv_inlines.h"
 #include <stdio.h>
 #include <sys/isa_defs.h>
 
 double
-__fmin(double x, double y) {
+__fmin(double x, double y)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx, yy;
+
 	unsigned s;
-	
+
 	/* if y is nan, replace it by x */
 	if (y != y)
 		y = x;
--- old/usr/src/lib/libm/common/m9x/fminf.c	2019-06-06 20:40:16.898620235 +0000
+++ new/usr/src/lib/libm/common/m9x/fminf.c	2019-06-06 20:40:16.917544579 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,10 +30,11 @@
 
 #pragma weak fminf = __fminf
 
-#include "libm.h"	/* for islessequal macro */
+#include "libm.h"			/* for islessequal macro */
 
 float
-__fminf(float x, float y) {
+__fminf(float x, float y)
+{
 	/*
 	 * On SPARC v8plus/v9, this could be implemented as follows
 	 * (assuming %f0 = x, %f1 = y, return value left in %f0):
@@ -74,6 +76,7 @@
 		unsigned i;
 		float f;
 	} xx, yy;
+
 	unsigned s;
 
 	/* if y is nan, replace it by x */
--- old/usr/src/lib/libm/common/m9x/fminl.c	2019-06-06 20:40:17.391793574 +0000
+++ new/usr/src/lib/libm/common/m9x/fminl.c	2019-06-06 20:40:17.408974811 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,10 +30,11 @@
 
 #pragma weak fminl = __fminl
 
-#include "libm.h"	/* for islessequal macro */
+#include "libm.h"			/* for islessequal macro */
 
 long double
-__fminl(long double x, long double y) {
+__fminl(long double x, long double y)
+{
 	union {
 #if defined(__sparc)
 		unsigned i[4];
@@ -41,8 +43,10 @@
 #else
 #error Unknown architecture
 #endif
+
 		long double ld;
 	} xx, yy;
+
 	unsigned s;
 
 	/* if y is nan, replace it by x */
--- old/usr/src/lib/libm/common/m9x/frexp.c	2019-06-06 20:40:17.887880919 +0000
+++ new/usr/src/lib/libm/common/m9x/frexp.c	2019-06-06 20:40:17.904982752 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -46,11 +47,13 @@
 #include "libm.h"
 
 double
-__frexp(double x, int *exp) {
+__frexp(double x, int *exp)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx, yy;
+
 	double t;
 	unsigned hx;
 	int e;
@@ -58,13 +61,14 @@
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 
-	if (hx >= 0x7ff00000) { /* x is infinite or NaN */
+	if (hx >= 0x7ff00000) {		/* x is infinite or NaN */
 		*exp = 0;
 		return (x);
 	}
 
 	e = 0;
-	if (hx < 0x00100000) { /* x is subnormal or zero */
+
+	if (hx < 0x00100000) {		/* x is subnormal or zero */
 		if ((hx | xx.i[LOWORD]) == 0) {
 			*exp = 0;
 			return (x);
@@ -88,8 +92,8 @@
 		t = yy.d;
 		yy.i[HIWORD] = 0x43300000;
 		yy.i[LOWORD] = 0;
-		t -= yy.d; /* t = |x| scaled */
-		xx.d = ((int)xx.i[HIWORD] < 0)? -t : t;
+		t -= yy.d;		/* t = |x| scaled */
+		xx.d = ((int)xx.i[HIWORD] < 0) ? -t : t;
 		hx = xx.i[HIWORD] & ~0x80000000;
 		e = -1074;
 	}
--- old/usr/src/lib/libm/common/m9x/frexpf.c	2019-06-06 20:40:18.370804597 +0000
+++ new/usr/src/lib/libm/common/m9x/frexpf.c	2019-06-06 20:40:18.387135515 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,31 +33,34 @@
 #include "libm.h"
 
 float
-__frexpf(float x, int *exp) {
+__frexpf(float x, int *exp)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx;
+
 	unsigned hx;
 	int e;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
 
-	if (hx >= 0x7f800000) { /* x is infinite or NaN */
+	if (hx >= 0x7f800000) {		/* x is infinite or NaN */
 		*exp = 0;
 		return (x);
 	}
 
 	e = 0;
-	if (hx < 0x00800000) { /* x is subnormal or zero */
+
+	if (hx < 0x00800000) {		/* x is subnormal or zero */
 		if (hx == 0) {
 			*exp = 0;
 			return (x);
 		}
 
 		/* normalize x by regarding it as an integer */
-		xx.f = (int) xx.i < 0 ? -(int) hx : (int) hx;
+		xx.f = (int)xx.i < 0 ? -(int)hx : (int)hx;
 		hx = xx.i & ~0x80000000;
 		e = -149;
 	}
--- old/usr/src/lib/libm/common/m9x/frexpl.c	2019-06-06 20:40:18.827310770 +0000
+++ new/usr/src/lib/libm/common/m9x/frexpl.c	2019-06-06 20:40:18.843859956 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,26 +33,28 @@
 #include "libm.h"
 
 #if defined(__sparc)
-
 long double
-__frexpl(long double x, int *exp) {
+__frexpl(long double x, int *exp)
+{
 	union {
 		unsigned i[4];
 		long double q;
 	} xx;
+
 	unsigned hx;
 	int e, s;
 
 	xx.q = x;
 	hx = xx.i[0] & ~0x80000000;
 
-	if (hx >= 0x7fff0000) {	/* x is infinite or NaN */
+	if (hx >= 0x7fff0000) {		/* x is infinite or NaN */
 		*exp = 0;
 		return (x);
 	}
 
 	e = 0;
-	if (hx < 0x00010000) {	/* x is subnormal or zero */
+
+	if (hx < 0x00010000) {		/* x is subnormal or zero */
 		if ((hx | xx.i[1] | xx.i[2] | xx.i[3]) == 0) {
 			*exp = 0;
 			return (x);
@@ -59,6 +62,7 @@
 
 		/* normalize x */
 		s = xx.i[0] & 0x80000000;
+
 		while ((hx | (xx.i[1] & 0xffff0000)) == 0) {
 			hx = xx.i[1];
 			xx.i[1] = xx.i[2];
@@ -66,6 +70,7 @@
 			xx.i[3] = 0;
 			e -= 32;
 		}
+
 		while (hx < 0x10000) {
 			hx = (hx << 1) | (xx.i[1] >> 31);
 			xx.i[1] = (xx.i[1] << 1) | (xx.i[2] >> 31);
@@ -73,6 +78,7 @@
 			xx.i[3] <<= 1;
 			e--;
 		}
+
 		xx.i[0] = s | hx;
 	}
 
@@ -81,28 +87,29 @@
 	*exp = e + (hx >> 16) - 0x3ffe;
 	return (xx.q);
 }
-
 #elif defined(__x86)
-
 long double
-__frexpl(long double x, int *exp) {
+__frexpl(long double x, int *exp)
+{
 	union {
 		unsigned i[3];
 		long double e;
 	} xx;
+
 	unsigned hx;
 	int e;
 
 	xx.e = x;
 	hx = xx.i[2] & 0x7fff;
 
-	if (hx >= 0x7fff) {	/* x is infinite or NaN */
+	if (hx >= 0x7fff) {		/* x is infinite or NaN */
 		*exp = 0;
 		return (x);
 	}
 
 	e = 0;
-	if (hx < 0x0001) {	/* x is subnormal or zero */
+
+	if (hx < 0x0001) {		/* x is subnormal or zero */
 		if ((xx.i[0] | xx.i[1]) == 0) {
 			*exp = 0;
 			return (x);
@@ -119,7 +126,6 @@
 	*exp = e + hx - 0x3ffe;
 	return (xx.e);
 }
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/ldexp.c	2019-06-06 20:40:19.309472471 +0000
+++ new/usr/src/lib/libm/common/m9x/ldexp.c	2019-06-06 20:40:19.329215763 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,23 +34,27 @@
 #include <errno.h>
 
 double
-ldexp(double x, int n) {
-	int *px = (int *) &x, ix = px[HIWORD] & ~0x80000000;
+ldexp(double x, int n)
+{
+	int *px = (int *)&x, ix = px[HIWORD] & ~0x80000000;
 
 	if (ix >= 0x7ff00000 || (px[LOWORD] | ix) == 0)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (ix >= 0x7ff80000 ? x : x + x);
-		/* assumes sparc-like QNaN */
+
+	/* assumes sparc-like QNaN */
 #else
 		return (x + x);
 #endif
 	x = scalbn(x, n);
 	ix = px[HIWORD] & ~0x80000000;
+
 	/*
 	 * SVID3 requires both overflow and underflow cases to set errno
 	 * XPG3/XPG4/XPG4.2/SUSv2 requires overflow to set errno
 	 */
 	if (ix >= 0x7ff00000 || (px[LOWORD] | ix) == 0)
 		errno = ERANGE;
+
 	return (x);
 }
--- old/usr/src/lib/libm/common/m9x/ldexpf.c	2019-06-06 20:40:19.864057395 +0000
+++ new/usr/src/lib/libm/common/m9x/ldexpf.c	2019-06-06 20:40:19.881957817 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,6 +33,7 @@
 #include "libm.h"
 
 float
-ldexpf(float x, int n) {
+ldexpf(float x, int n)
+{
 	return (scalbnf(x, n));
 }
--- old/usr/src/lib/libm/common/m9x/ldexpl.c	2019-06-06 20:40:20.367371156 +0000
+++ new/usr/src/lib/libm/common/m9x/ldexpl.c	2019-06-06 20:40:20.385938101 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,6 +33,7 @@
 #include "libm.h"
 
 long double
-ldexpl(long double x, int n) {
+ldexpl(long double x, int n)
+{
 	return (scalbnl(x, n));
 }
--- old/usr/src/lib/libm/common/m9x/llrint.c	2019-06-06 20:40:20.860256737 +0000
+++ new/usr/src/lib/libm/common/m9x/llrint.c	2019-06-06 20:40:20.878149672 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -46,7 +47,8 @@
 #include "libm.h"
 
 long long
-llrint(double x) {
+llrint(double x)
+{
 	/*
 	 * Note: The following code works on x86 (in the default rounding
 	 * precision mode), but one should just use the fistpll instruction
@@ -56,16 +58,17 @@
 		unsigned i[2];
 		double d;
 	} xx, yy;
+
 	unsigned hx;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 
-	if (hx < 0x43300000) { /* |x| < 2^52 */
+	if (hx < 0x43300000) {		/* |x| < 2^52 */
 		/* add and subtract a power of two to round x to an integer */
 #if defined(__sparc) || defined(__amd64)
 		yy.i[HIWORD] = (xx.i[HIWORD] & 0x80000000) | 0x43300000;
-#elif defined(__i386)	/* !defined(__amd64) */
+#elif defined(__i386)			/* !defined(__amd64) */
 		yy.i[HIWORD] = (xx.i[HIWORD] & 0x80000000) | 0x43e00000;
 #else
 #error Unknown architecture
@@ -75,5 +78,5 @@
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long long) x);
+	return ((long long)x);
 }
--- old/usr/src/lib/libm/common/m9x/llrintf.c	2019-06-06 20:40:21.341769552 +0000
+++ new/usr/src/lib/libm/common/m9x/llrintf.c	2019-06-06 20:40:21.358379570 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,7 +37,8 @@
 #include "libm.h"
 
 long long
-llrintf(float x) {
+llrintf(float x)
+{
 	/*
 	 * Note: The following code works on x86 (in the default rounding
 	 * precision mode), but one should just use the fistpll instruction
@@ -46,12 +48,13 @@
 		unsigned i;
 		float f;
 	} xx, yy;
+
 	unsigned hx;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
 
-	if (hx < 0x4b000000) { /* |x| < 2^23 */
+	if (hx < 0x4b000000) {		/* |x| < 2^23 */
 		/* add and subtract a power of two to round x to an integer */
 #if defined(__sparc) || defined(__amd64)
 		yy.i = (xx.i & 0x80000000) | 0x4b000000;
@@ -67,9 +70,9 @@
 		 * on LP32 architectures, we can just convert x to a 32-bit
 		 * integer and sign-extend it
 		 */
-		return ((long) x);
+		return ((long)x);
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long long) x);
+	return ((long long)x);
 }
--- old/usr/src/lib/libm/common/m9x/llrintl.c	2019-06-06 20:40:21.806200875 +0000
+++ new/usr/src/lib/libm/common/m9x/llrintl.c	2019-06-06 20:40:21.823766090 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,12 +37,12 @@
 #include "libm.h"
 
 #if defined(__sparc)
-
 #include "fma.h"
 #include "fenv_inlines.h"
 
 long long
-llrintl(long double x) {
+llrintl(long double x)
+{
 	union {
 		unsigned i[4];
 		long double q;
@@ -54,6 +55,7 @@
 		unsigned i;
 		float f;
 	} tt;
+
 	unsigned int hx, sx, frac, fsr;
 	int rm, j;
 	volatile float dummy;
@@ -63,12 +65,13 @@
 	hx = xx.i[0] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx > 0x403e0000) { /* |x| > 2^63 + ... or x is nan */
+	if (hx > 0x403e0000) {		/* |x| > 2^63 + ... or x is nan */
 		/* convert an out-of-range float */
 		tt.i = sx | 0x7f000000;
-		return ((long long) tt.f);
-	} else if ((hx | xx.i[1] | xx.i[2] | xx.i[3]) == 0) /* x is zero */
+		return ((long long)tt.f);
+	} else if ((hx | xx.i[1] | xx.i[2] | xx.i[3]) == 0) {	/* x is zero */
 		return (0LL);
+	}
 
 	/* get the rounding mode */
 	__fenv_getfsr32(&fsr);
@@ -80,49 +83,55 @@
 
 	/* handle |x| < 1 */
 	if (hx < 0x3fff0000) {
-		dummy = 1.0e30f; /* x is nonzero, so raise inexact */
+		dummy = 1.0e30f;	/* x is nonzero, so raise inexact */
 		dummy += 1.0e-30f;
-		if (rm == FSR_RP || (rm == FSR_RN && (hx >= 0x3ffe0000 &&
-			((hx & 0xffff) | xx.i[1] | xx.i[2] | xx.i[3]))))
+
+		if (rm == FSR_RP || (rm == FSR_RN && (hx >= 0x3ffe0000 && ((hx &
+		    0xffff) | xx.i[1] | xx.i[2] | xx.i[3]))))
 			return (sx ? -1LL : 1LL);
+
 		return (0LL);
 	}
 
 	/* extract the integer and fractional parts of x */
 	j = 0x406f - (hx >> 16);
 	xx.i[0] = 0x10000 | (xx.i[0] & 0xffff);
+
 	if (j >= 96) {
 		zz.i[0] = 0;
 		zz.i[1] = xx.i[0] >> (j - 96);
 		frac = ((xx.i[0] << 1) << (127 - j)) | (xx.i[1] >> (j - 96));
+
 		if (((xx.i[1] << 1) << (127 - j)) | xx.i[2] | xx.i[3])
 			frac |= 1;
 	} else if (j >= 64) {
 		zz.i[0] = xx.i[0] >> (j - 64);
 		zz.i[1] = ((xx.i[0] << 1) << (95 - j)) | (xx.i[1] >> (j - 64));
 		frac = ((xx.i[1] << 1) << (95 - j)) | (xx.i[2] >> (j - 64));
+
 		if (((xx.i[2] << 1) << (95 - j)) | xx.i[3])
 			frac |= 1;
 	} else {
 		zz.i[0] = ((xx.i[0] << 1) << (63 - j)) | (xx.i[1] >> (j - 32));
 		zz.i[1] = ((xx.i[1] << 1) << (63 - j)) | (xx.i[2] >> (j - 32));
 		frac = ((xx.i[2] << 1) << (63 - j)) | (xx.i[3] >> (j - 32));
+
 		if ((xx.i[3] << 1) << (63 - j))
 			frac |= 1;
 	}
 
 	/* round */
 	if (frac && (rm == FSR_RP || (rm == FSR_RN && (frac > 0x80000000u ||
-		(frac == 0x80000000 && (zz.i[1] & 1)))))) {
+	    (frac == 0x80000000 && (zz.i[1] & 1)))))) {
 		if (++zz.i[1] == 0)
 			zz.i[0]++;
 	}
 
 	/* check for result out of range (note that z is |x| at this point) */
 	if (zz.i[0] > 0x80000000u || (zz.i[0] == 0x80000000 && (zz.i[1] ||
-		!sx))) {
+	    !sx))) {
 		tt.i = sx | 0x7f000000;
-		return ((long long) tt.f);
+		return ((long long)tt.f);
 	}
 
 	/* raise inexact if need be */
@@ -135,14 +144,17 @@
 	if (sx) {
 		zz.i[0] = ~zz.i[0];
 		zz.i[1] = -zz.i[1];
+
 		if (zz.i[1] == 0)
 			zz.i[0]++;
 	}
+
 	return (zz.l);
 }
 #elif defined(__x86)
 long long
-llrintl(long double x) {
+llrintl(long double x)
+{
 	/*
 	 * Note: The following code works on x86 (in the default rounding
 	 * precision mode), but one ought to just use the fistpll instruction
@@ -152,12 +164,13 @@
 		unsigned i[3];
 		long double e;
 	} xx, yy;
+
 	int ex;
 
 	xx.e = x;
 	ex = xx.i[2] & 0x7fff;
 
-	if (ex < 0x403e) { /* |x| < 2^63 */
+	if (ex < 0x403e) {		/* |x| < 2^63 */
 		/* add and subtract a power of two to round x to an integer */
 		yy.i[2] = (xx.i[2] & 0x8000) | 0x403e;
 		yy.i[1] = 0x80000000;
@@ -166,7 +179,7 @@
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long long) x);
+	return ((long long)x);
 }
 #else
 #error Unknown architecture
--- old/usr/src/lib/libm/common/m9x/llround.c	2019-06-06 20:40:22.309339144 +0000
+++ new/usr/src/lib/libm/common/m9x/llround.c	2019-06-06 20:40:22.326504756 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -45,22 +46,25 @@
 #include "libm.h"
 
 long long
-llround(double x) {
+llround(double x)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 	sx = xx.i[HIWORD] & 0x80000000;
 
-	if (hx < 0x43300000) { /* |x| < 2^52 */
+	if (hx < 0x43300000) {		/* |x| < 2^52 */
 		/* handle |x| < 1 */
 		if (hx < 0x3ff00000) {
 			if (hx >= 0x3fe00000)
 				return (sx ? -1LL : 1LL);
+
 			return (0LL);
 		}
 
@@ -72,12 +76,14 @@
 		} else {
 			i = 1 << (0x432 - (hx >> 20));
 			xx.i[LOWORD] += i;
+
 			if (xx.i[LOWORD] < i)
 				xx.i[HIWORD]++;
+
 			xx.i[LOWORD] &= ~(i | (i - 1));
 		}
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long long) xx.d);
+	return ((long long)xx.d);
 }
--- old/usr/src/lib/libm/common/m9x/llroundf.c	2019-06-06 20:40:22.788301102 +0000
+++ new/usr/src/lib/libm/common/m9x/llroundf.c	2019-06-06 20:40:22.805536480 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -36,22 +37,25 @@
 #include "libm.h"
 
 long long
-llroundf(float x) {
+llroundf(float x)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
 	sx = xx.i & 0x80000000;
 
-	if (hx < 0x4b000000) { /* |x| < 2^23 */
+	if (hx < 0x4b000000) {		/* |x| < 2^23 */
 		/* handle |x| < 1 */
 		if (hx < 0x3f800000) {
 			if (hx >= 0x3f000000)
 				return (sx ? -1LL : 1LL);
+
 			return (0LL);
 		}
 
@@ -63,9 +67,9 @@
 		 * on LP32 architectures, we can just convert x to a 32-bit
 		 * integer and sign-extend it
 		 */
-		return ((long) xx.f);
+		return ((long)xx.f);
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long long) x);
+	return ((long long)x);
 }
--- old/usr/src/lib/libm/common/m9x/llroundl.c	2019-06-06 20:40:23.254164969 +0000
+++ new/usr/src/lib/libm/common/m9x/llroundl.c	2019-06-06 20:40:23.272224489 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,7 +38,8 @@
 
 #if defined(__sparc)
 long long
-llroundl(long double x) {
+llroundl(long double x)
+{
 	union {
 		unsigned i[4];
 		long double q;
@@ -50,6 +52,7 @@
 		unsigned i;
 		float f;
 	} tt;
+
 	unsigned hx, sx, frac;
 	int j;
 
@@ -58,38 +61,43 @@
 	hx = xx.i[0] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx > 0x403e0000) { /* |x| > 2^63 + ... or x is nan */
+	if (hx > 0x403e0000) {		/* |x| > 2^63 + ... or x is nan */
 		/* convert an out-of-range float */
 		tt.i = sx | 0x7f000000;
-		return ((long long) tt.f);
+		return ((long long)tt.f);
 	}
 
 	/* handle |x| < 1 */
 	if (hx < 0x3fff0000) {
 		if (hx >= 0x3ffe0000)
 			return (sx ? -1LL : 1LL);
+
 		return (0LL);
 	}
 
 	/* extract the integer and fractional parts of x */
 	j = 0x406f - (hx >> 16);
 	xx.i[0] = 0x10000 | (xx.i[0] & 0xffff);
+
 	if (j >= 96) {
 		zz.i[0] = 0;
 		zz.i[1] = xx.i[0] >> (j - 96);
 		frac = ((xx.i[0] << 1) << (127 - j)) | (xx.i[1] >> (j - 96));
+
 		if (((xx.i[1] << 1) << (127 - j)) | xx.i[2] | xx.i[3])
 			frac |= 1;
 	} else if (j >= 64) {
 		zz.i[0] = xx.i[0] >> (j - 64);
 		zz.i[1] = ((xx.i[0] << 1) << (95 - j)) | (xx.i[1] >> (j - 64));
 		frac = ((xx.i[1] << 1) << (95 - j)) | (xx.i[2] >> (j - 64));
+
 		if (((xx.i[2] << 1) << (95 - j)) | xx.i[3])
 			frac |= 1;
 	} else {
 		zz.i[0] = ((xx.i[0] << 1) << (63 - j)) | (xx.i[1] >> (j - 32));
 		zz.i[1] = ((xx.i[1] << 1) << (63 - j)) | (xx.i[2] >> (j - 32));
 		frac = ((xx.i[2] << 1) << (63 - j)) | (xx.i[3] >> (j - 32));
+
 		if ((xx.i[3] << 1) << (63 - j))
 			frac |= 1;
 	}
@@ -102,15 +110,16 @@
 
 	/* check for result out of range (note that z is |x| at this point) */
 	if (zz.i[0] > 0x80000000u || (zz.i[0] == 0x80000000 && (zz.i[1] ||
-		!sx))) {
+	    !sx))) {
 		tt.i = sx | 0x7f000000;
-		return ((long long) tt.f);
+		return ((long long)tt.f);
 	}
 
 	/* negate result if need be */
 	if (sx) {
 		zz.i[0] = ~zz.i[0];
 		zz.i[1] = -zz.i[1];
+
 		if (zz.i[1] == 0)
 			zz.i[0]++;
 	}
@@ -119,22 +128,25 @@
 }
 #elif defined(__x86)
 long long
-llroundl(long double x) {
+llroundl(long double x)
+{
 	union {
 		unsigned i[3];
 		long double e;
 	} xx;
+
 	int ex, sx, i;
 
 	xx.e = x;
 	ex = xx.i[2] & 0x7fff;
 	sx = xx.i[2] & 0x8000;
 
-	if (ex < 0x403e) { /* |x| < 2^63 */
+	if (ex < 0x403e) {		/* |x| < 2^63 */
 		/* handle |x| < 1 */
 		if (ex < 0x3fff) {
 			if (ex >= 0x3ffe)
 				return (sx ? -1LL : 1LL);
+
 			return (0LL);
 		}
 
@@ -146,10 +158,13 @@
 		} else {
 			i = 1 << (0x403d - ex);
 			xx.i[0] += i;
+
 			if (xx.i[0] < i)
 				xx.i[1]++;
+
 			xx.i[0] &= ~(i | (i - 1));
 		}
+
 		if (xx.i[1] == 0) {
 			xx.i[2] = sx | ++ex;
 			xx.i[1] = 0x80000000U;
@@ -157,7 +172,7 @@
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long long) xx.e);
+	return ((long long)xx.e);
 }
 #else
 #error Unknown architecture
--- old/usr/src/lib/libm/common/m9x/lrint.c	2019-06-06 20:40:23.764760726 +0000
+++ new/usr/src/lib/libm/common/m9x/lrint.c	2019-06-06 20:40:23.783998103 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -39,12 +40,13 @@
  * If x is not an integer, the inexact exception is raised.
  */
 
-#include <sys/isa_defs.h>	/* _ILP32 */
+#include <sys/isa_defs.h>		/* _ILP32 */
 #include "libm.h"
 
 #if defined(_ILP32)
 long
-lrint(double x) {
+lrint(double x)
+{
 	/*
 	 * Note: The following code works on x86 (in the default rounding
 	 * precision mode), but one should just use the fistpl instruction
@@ -54,11 +56,13 @@
 		unsigned i[2];
 		double d;
 	} xx, yy;
+
 	unsigned hx;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
-	if (hx < 0x43300000) { /* |x| < 2^52 */
+
+	if (hx < 0x43300000) {		/* |x| < 2^52 */
 		/* add and subtract a power of two to round x to an integer */
 #if defined(__sparc)
 		yy.i[HIWORD] = (xx.i[HIWORD] & 0x80000000) | 0x43300000;
@@ -72,8 +76,8 @@
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long) x);
+	return ((long)x);
 }
 #else
 #error Unsupported architecture
-#endif	/* defined(_ILP32) */
+#endif /* defined(_ILP32) */
--- old/usr/src/lib/libm/common/m9x/lrintf.c	2019-06-06 20:40:24.300416119 +0000
+++ new/usr/src/lib/libm/common/m9x/lrintf.c	2019-06-06 20:40:24.322117685 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,12 +30,13 @@
 
 #pragma weak __lrintf = lrintf
 
-#include <sys/isa_defs.h>	/* _ILP32 */
+#include <sys/isa_defs.h>		/* _ILP32 */
 #include "libm.h"
 
 #if defined(_ILP32)
 long
-lrintf(float x) {
+lrintf(float x)
+{
 	/*
 	 * Note: The following code works on x86 (in the default rounding
 	 * precision mode), but one should just use the fistpl instruction
@@ -44,11 +46,13 @@
 		unsigned i;
 		float f;
 	} xx, yy;
+
 	unsigned hx;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
-	if (hx < 0x4b000000) {	/* |x| < 2^23 */
+
+	if (hx < 0x4b000000) {		/* |x| < 2^23 */
 		/* add and subtract a power of two to round x to an integer */
 #if defined(__sparc)
 		yy.i = (xx.i & 0x80000000) | 0x4b000000;
@@ -59,12 +63,12 @@
 #error Unknown architecture
 #endif
 		x = (x + yy.f) - yy.f;
-		return ((long) x);
+		return ((long)x);
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long) x);
+	return ((long)x);
 }
 #else
 #error Unsupported architecture
-#endif	/* defined(_ILP32) */
+#endif /* defined(_ILP32) */
--- old/usr/src/lib/libm/common/m9x/lrintl.c	2019-06-06 20:40:24.829605199 +0000
+++ new/usr/src/lib/libm/common/m9x/lrintl.c	2019-06-06 20:40:24.849193473 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,17 +30,17 @@
 
 #pragma weak __lrintl = lrintl
 
-#include <sys/isa_defs.h>	/* _ILP32 */
+#include <sys/isa_defs.h>		/* _ILP32 */
 #include "libm.h"
 
 #if defined(_ILP32)
 #if defined(__sparc)
-
 #include "fma.h"
 #include "fenv_inlines.h"
 
 long
-lrintl(long double x) {
+lrintl(long double x)
+{
 	union {
 		unsigned int i[4];
 		long double q;
@@ -48,6 +49,7 @@
 		unsigned int i;
 		float f;
 	} tt;
+
 	unsigned int hx, sx, frac, l, fsr;
 	int rm, j;
 	volatile float dummy;
@@ -57,12 +59,13 @@
 	hx = xx.i[0] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx > 0x401e0000) { /* |x| > 2^31 + ... or x is nan */
+	if (hx > 0x401e0000) {		/* |x| > 2^31 + ... or x is nan */
 		/* convert an out-of-range float */
 		tt.i = sx | 0x7f000000;
-		return ((long) tt.f);
-	} else if ((hx | xx.i[1] | xx.i[2] | xx.i[3]) == 0) /* x is zero */
+		return ((long)tt.f);
+	} else if ((hx | xx.i[1] | xx.i[2] | xx.i[3]) == 0) {	/* x is zero */
 		return (0L);
+	}
 
 	/* get the rounding mode */
 	__fenv_getfsr32(&fsr);
@@ -74,38 +77,43 @@
 
 	/* handle |x| < 1 */
 	if (hx < 0x3fff0000) {
-		dummy = 1.0e30F; /* x is nonzero, so raise inexact */
+		dummy = 1.0e30F;	/* x is nonzero, so raise inexact */
 		dummy += 1.0e-30F;
-		if (rm == FSR_RP || (rm == FSR_RN && (hx >= 0x3ffe0000 &&
-			((hx & 0xffff) | xx.i[1] | xx.i[2] | xx.i[3]))))
+
+		if (rm == FSR_RP || (rm == FSR_RN && (hx >= 0x3ffe0000 && ((hx &
+		    0xffff) | xx.i[1] | xx.i[2] | xx.i[3]))))
 			return (sx ? -1L : 1L);
+
 		return (0L);
 	}
 
 	/* extract the integer and fractional parts of x */
-	j = 0x406f - (hx >> 16);		/* 91 <= j <= 112 */
+	j = 0x406f - (hx >> 16);	/* 91 <= j <= 112 */
 	xx.i[0] = 0x10000 | (xx.i[0] & 0xffff);
-	if (j >= 96) {				/* 96 <= j <= 112 */
+
+	if (j >= 96) {			/* 96 <= j <= 112 */
 		l = xx.i[0] >> (j - 96);
 		frac = ((xx.i[0] << 1) << (127 - j)) | (xx.i[1] >> (j - 96));
+
 		if (((xx.i[1] << 1) << (127 - j)) | xx.i[2] | xx.i[3])
 			frac |= 1;
-	} else {				/* 91 <= j <= 95 */
+	} else {			/* 91 <= j <= 95 */
 		l = (xx.i[0] << (96 - j)) | (xx.i[1] >> (j - 64));
 		frac = (xx.i[1] << (96 - j)) | (xx.i[2] >> (j - 64));
+
 		if ((xx.i[2] << (96 - j)) | xx.i[3])
 			frac |= 1;
 	}
 
 	/* round */
 	if (frac && (rm == FSR_RP || (rm == FSR_RN && (frac > 0x80000000U ||
-		(frac == 0x80000000 && (l & 1))))))
+	    (frac == 0x80000000 && (l & 1))))))
 		l++;
 
 	/* check for result out of range (note that z is |x| at this point) */
 	if (l > 0x80000000U || (l == 0x80000000U && !sx)) {
 		tt.i = sx | 0x7f000000;
-		return ((long) tt.f);
+		return ((long)tt.f);
 	}
 
 	/* raise inexact if need be */
@@ -117,11 +125,13 @@
 	/* negate result if need be */
 	if (sx)
 		l = -l;
-	return ((long) l);
+
+	return ((long)l);
 }
 #elif defined(__x86)
 long
-lrintl(long double x) {
+lrintl(long double x)
+{
 	/*
 	 * Note: The following code works on x86 (in the default rounding
 	 * precision mode), but one ought to just use the fistpl instruction
@@ -131,11 +141,13 @@
 		unsigned i[3];
 		long double e;
 	} xx, yy;
+
 	int ex;
 
 	xx.e = x;
 	ex = xx.i[2] & 0x7fff;
-	if (ex < 0x403e) {	/* |x| < 2^63 */
+
+	if (ex < 0x403e) {		/* |x| < 2^63 */
 		/* add and subtract a power of two to round x to an integer */
 		yy.i[2] = (xx.i[2] & 0x8000) | 0x403e;
 		yy.i[1] = 0x80000000;
@@ -144,11 +156,11 @@
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long) x);
+	return ((long)x);
 }
 #else
 #error Unknown architecture
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
 #else
 #error Unsupported architecture
-#endif	/* defined(_ILP32) */
+#endif /* defined(_ILP32) */
--- old/usr/src/lib/libm/common/m9x/lround.c	2019-06-06 20:40:25.343070158 +0000
+++ new/usr/src/lib/libm/common/m9x/lround.c	2019-06-06 20:40:25.361787285 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,25 +38,29 @@
  * would exceed 32 bits, the invalid operation exception is raised.
  */
 
-#include <sys/isa_defs.h>	/* _ILP32 */
+#include <sys/isa_defs.h>		/* _ILP32 */
 #include "libm.h"
 
 #if defined(_ILP32)
 long
-lround(double x) {
+lround(double x)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 	sx = xx.i[HIWORD] & 0x80000000;
-	if (hx < 0x43300000) {	/* |x| < 2^52 */
+
+	if (hx < 0x43300000) {		/* |x| < 2^52 */
 		if (hx < 0x3ff00000) {	/* |x| < 1 */
 			if (hx >= 0x3fe00000)
 				return (sx ? -1L : 1L);
+
 			return (0L);
 		}
 
@@ -67,15 +72,17 @@
 		} else {
 			i = 1 << (0x432 - (hx >> 20));
 			xx.i[LOWORD] += i;
+
 			if (xx.i[LOWORD] < i)
 				xx.i[HIWORD]++;
+
 			xx.i[LOWORD] &= ~(i | (i - 1));
 		}
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long) xx.d);
+	return ((long)xx.d);
 }
 #else
 #error Unsupported architecture
-#endif	/* defined(_ILP32) */
+#endif /* defined(_ILP32) */
--- old/usr/src/lib/libm/common/m9x/lroundf.c	2019-06-06 20:40:25.821670044 +0000
+++ new/usr/src/lib/libm/common/m9x/lroundf.c	2019-06-06 20:40:25.839565924 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,37 +30,41 @@
 
 #pragma weak __lroundf = lroundf
 
-#include <sys/isa_defs.h>	/* _ILP32 */
+#include <sys/isa_defs.h>		/* _ILP32 */
 #include "libm.h"
 
 #if defined(_ILP32)
 long
-lroundf(float x) {
+lroundf(float x)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
 	sx = xx.i & 0x80000000;
+
 	if (hx < 0x4b000000) {		/* |x| < 2^23 */
-		if (hx < 0x3f800000) {		/* |x| < 1 */
+		if (hx < 0x3f800000) {	/* |x| < 1 */
 			if (hx >= 0x3f000000)
 				return (sx ? -1L : 1L);
+
 			return (0L);
 		}
 
 		/* round x at the integer bit */
 		i = 1 << (0x95 - (hx >> 23));
 		xx.i = (xx.i + i) & ~((i << 1) - 1);
-		return ((long) xx.f);
+		return ((long)xx.f);
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long) x);
+	return ((long)x);
 }
 #else
 #error Unsupported architecture
-#endif	/* defined(_ILP32) */
+#endif /* defined(_ILP32) */
--- old/usr/src/lib/libm/common/m9x/lroundl.c	2019-06-06 20:40:26.329036437 +0000
+++ new/usr/src/lib/libm/common/m9x/lroundl.c	2019-06-06 20:40:26.347209087 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,13 +30,14 @@
 
 #pragma weak __lroundl = lroundl
 
-#include <sys/isa_defs.h>	/* _ILP32 */
+#include <sys/isa_defs.h>		/* _ILP32 */
 #include "libm.h"
 
 #if defined(_ILP32)
 #if defined(__sparc)
 long
-lroundl(long double x) {
+lroundl(long double x)
+{
 	union {
 		unsigned i[4];
 		long double q;
@@ -44,6 +46,7 @@
 		unsigned i;
 		float f;
 	} tt;
+
 	unsigned hx, sx, frac, l;
 	int j;
 
@@ -52,30 +55,34 @@
 	hx = xx.i[0] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx > 0x401e0000) { /* |x| > 2^31 + ... or x is nan */
+	if (hx > 0x401e0000) {		/* |x| > 2^31 + ... or x is nan */
 		/* convert an out-of-range float */
 		tt.i = sx | 0x7f000000;
-		return ((long) tt.f);
+		return ((long)tt.f);
 	}
 
 	/* handle |x| < 1 */
 	if (hx < 0x3fff0000) {
 		if (hx >= 0x3ffe0000)
 			return (sx ? -1L : 1L);
+
 		return (0L);
 	}
 
 	/* extract the integer and fractional parts of x */
-	j = 0x406f - (hx >> 16);		/* 91 <= j <= 112 */
+	j = 0x406f - (hx >> 16);	/* 91 <= j <= 112 */
 	xx.i[0] = 0x10000 | (xx.i[0] & 0xffff);
-	if (j >= 96) {				/* 96 <= j <= 112 */
+
+	if (j >= 96) {			/* 96 <= j <= 112 */
 		l = xx.i[0] >> (j - 96);
 		frac = ((xx.i[0] << 1) << (127 - j)) | (xx.i[1] >> (j - 96));
+
 		if (((xx.i[1] << 1) << (127 - j)) | xx.i[2] | xx.i[3])
 			frac |= 1;
-	} else {				/* 91 <= j <= 95 */
+	} else {			/* 91 <= j <= 95 */
 		l = (xx.i[0] << (96 - j)) | (xx.i[1] >> (j - 64));
 		frac = (xx.i[1] << (96 - j)) | (xx.i[2] >> (j - 64));
+
 		if ((xx.i[2] << (96 - j)) | xx.i[3])
 			frac |= 1;
 	}
@@ -87,30 +94,35 @@
 	/* check for result out of range (note that z is |x| at this point) */
 	if (l > 0x80000000U || (l == 0x80000000U && !sx)) {
 		tt.i = sx | 0x7f000000;
-		return ((long) tt.f);
+		return ((long)tt.f);
 	}
 
 	/* negate result if need be */
 	if (sx)
 		l = -l;
-	return ((long) l);
+
+	return ((long)l);
 }
 #elif defined(__x86)
 long
-lroundl(long double x) {
+lroundl(long double x)
+{
 	union {
 		unsigned i[3];
 		long double e;
 	} xx;
+
 	int ex, sx, i;
 
 	xx.e = x;
 	ex = xx.i[2] & 0x7fff;
 	sx = xx.i[2] & 0x8000;
-	if (ex < 0x403e) {	/* |x| < 2^63 */
+
+	if (ex < 0x403e) {		/* |x| < 2^63 */
 		if (ex < 0x3fff) {	/* |x| < 1 */
 			if (ex >= 0x3ffe)
 				return (sx ? -1L : 1L);
+
 			return (0L);
 		}
 
@@ -122,10 +134,13 @@
 		} else {
 			i = 1 << (0x403d - ex);
 			xx.i[0] += i;
+
 			if (xx.i[0] < i)
 				xx.i[1]++;
+
 			xx.i[0] &= ~(i | (i - 1));
 		}
+
 		if (xx.i[1] == 0) {
 			xx.i[2] = sx | ++ex;
 			xx.i[1] = 0x80000000U;
@@ -133,11 +148,11 @@
 	}
 
 	/* now x is nan, inf, or integral */
-	return ((long) xx.e);
+	return ((long)xx.e);
 }
 #else
 #error Unknown architecture
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
 #else
 #error Unsupported architecture
-#endif	/* defined(_ILP32) */
+#endif /* defined(_ILP32) */
--- old/usr/src/lib/libm/common/m9x/modf.c	2019-06-06 20:40:26.846427465 +0000
+++ new/usr/src/lib/libm/common/m9x/modf.c	2019-06-06 20:40:26.865303472 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -45,27 +46,31 @@
 #include "libm.h"
 
 double
-__modf(double x, double *iptr) {
+__modf(double x, double *iptr)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx, yy;
+
 	unsigned hx, s;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 
-	if (hx >= 0x43300000) {	/* x is NaN, infinite, or integral */
+	if (hx >= 0x43300000) {		/* x is NaN, infinite, or integral */
 		*iptr = x;
-		if (hx < 0x7ff00000 || (hx == 0x7ff00000 &&
-			xx.i[LOWORD] == 0)) {
+
+		if (hx < 0x7ff00000 || (hx == 0x7ff00000 && xx.i[LOWORD] ==
+		    0)) {
 			xx.i[HIWORD] &= 0x80000000;
 			xx.i[LOWORD] = 0;
 		}
+
 		return (xx.d);
 	}
 
-	if (hx < 0x3ff00000) {	/* |x| < 1 */
+	if (hx < 0x3ff00000) {		/* |x| < 1 */
 		xx.i[HIWORD] &= 0x80000000;
 		xx.i[LOWORD] = 0;
 		*iptr = xx.d;
@@ -74,18 +79,20 @@
 
 	/* split x at the binary point */
 	s = xx.i[HIWORD] & 0x80000000;
+
 	if (hx < 0x41400000) {
 		yy.i[HIWORD] = xx.i[HIWORD] & ~((1 << (0x413 - (hx >> 20))) -
-			1);
+		    1);
 		yy.i[LOWORD] = 0;
 	} else {
 		yy.i[HIWORD] = xx.i[HIWORD];
 		yy.i[LOWORD] = xx.i[LOWORD] & ~((1 << (0x433 - (hx >> 20))) -
-			1);
+		    1);
 	}
+
 	*iptr = yy.d;
 	xx.d -= yy.d;
 	xx.i[HIWORD] = (xx.i[HIWORD] & ~0x80000000) | s;
-							/* keep sign of x */
+	/* keep sign of x */
 	return (xx.d);
 }
--- old/usr/src/lib/libm/common/m9x/modff.c	2019-06-06 20:40:27.343744969 +0000
+++ new/usr/src/lib/libm/common/m9x/modff.c	2019-06-06 20:40:27.362611203 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,24 +34,28 @@
 #include "libm.h"
 
 float
-__modff(float x, float *iptr) {
+__modff(float x, float *iptr)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx, yy;
+
 	unsigned hx, s;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
 
-	if (hx >= 0x4b000000) {	/* x is NaN, infinite, or integral */
+	if (hx >= 0x4b000000) {		/* x is NaN, infinite, or integral */
 		*iptr = x;
+
 		if (hx <= 0x7f800000)
 			xx.i &= 0x80000000;
+
 		return (xx.f);
 	}
 
-	if (hx < 0x3f800000) {	/* |x| < 1 */
+	if (hx < 0x3f800000) {		/* |x| < 1 */
 		xx.i &= 0x80000000;
 		*iptr = xx.f;
 		return (x);
@@ -62,6 +67,6 @@
 	*iptr = yy.f;
 	xx.f -= yy.f;
 	xx.i = (xx.i & ~0x80000000) | s;
-				/* restore sign in case difference is 0 */
+	/* restore sign in case difference is 0 */
 	return (xx.f);
 }
--- old/usr/src/lib/libm/common/m9x/modfl.c	2019-06-06 20:40:27.842269173 +0000
+++ new/usr/src/lib/libm/common/m9x/modfl.c	2019-06-06 20:40:27.859791260 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,29 +33,32 @@
 #include "libm.h"
 
 #if defined(__sparc)
-
 long double
-__modfl(long double x, long double *iptr) {
+__modfl(long double x, long double *iptr)
+{
 	union {
 		unsigned i[4];
 		long double q;
 	} xx, yy;
+
 	unsigned hx, s;
 
 	xx.q = x;
 	hx = xx.i[0] & ~0x80000000;
 
-	if (hx >= 0x406f0000) {	/* x is NaN, infinite, or integral */
+	if (hx >= 0x406f0000) {		/* x is NaN, infinite, or integral */
 		*iptr = x;
-		if (hx < 0x7fff0000 || (hx == 0x7fff0000 &&
-			(xx.i[1] | xx.i[2] | xx.i[3]) == 0)) {
+
+		if (hx < 0x7fff0000 || (hx == 0x7fff0000 && (xx.i[1] | xx.i[2] |
+		    xx.i[3]) == 0)) {
 			xx.i[0] &= 0x80000000;
 			xx.i[1] = xx.i[2] = xx.i[3] = 0;
 		}
+
 		return (xx.q);
 	}
 
-	if (hx < 0x3fff0000) {	/* |x| < 1 */
+	if (hx < 0x3fff0000) {		/* |x| < 1 */
 		xx.i[0] &= 0x80000000;
 		xx.i[1] = xx.i[2] = xx.i[3] = 0;
 		*iptr = xx.q;
@@ -63,6 +67,7 @@
 
 	/* split x at the binary point */
 	s = xx.i[0] & 0x80000000;
+
 	if (hx < 0x40100000) {
 		yy.i[0] = xx.i[0] & ~((1 << (0x400f - (hx >> 16))) - 1);
 		yy.i[1] = yy.i[2] = yy.i[3] = 0;
@@ -81,6 +86,7 @@
 		yy.i[2] = xx.i[2];
 		yy.i[3] = xx.i[3] & ~((1 << (0x406f - (hx >> 16))) - 1);
 	}
+
 	*iptr = yy.q;
 
 	/*
@@ -92,15 +98,15 @@
 	xx.i[0] = (xx.i[0] & ~0x80000000) | s;	/* keep sign of x */
 	return (xx.q);
 }
-
 #elif defined(__x86)
-
 long double
-__modfl(long double x, long double *iptr) {
+__modfl(long double x, long double *iptr)
+{
 	union {
 		unsigned i[3];
 		long double e;
 	} xx, yy;
+
 	unsigned hx, s;
 
 	/*
@@ -110,17 +116,19 @@
 	xx.e = x;
 	hx = xx.i[2] & 0x7fff;
 
-	if (hx >= 0x403e) {	/* x is NaN, infinite, or integral */
+	if (hx >= 0x403e) {		/* x is NaN, infinite, or integral */
 		*iptr = x;
-		if (hx < 0x7fff || (hx == 0x7fff &&
-			((xx.i[1] << 1) | xx.i[0]) == 0)) {
+
+		if (hx < 0x7fff || (hx == 0x7fff && ((xx.i[1] << 1) |
+		    xx.i[0]) == 0)) {
 			xx.i[2] &= 0x8000;
 			xx.i[1] = xx.i[0] = 0;
 		}
+
 		return (xx.e);
 	}
 
-	if (hx < 0x3fff) {	/* |x| < 1 */
+	if (hx < 0x3fff) {		/* |x| < 1 */
 		xx.i[2] &= 0x8000;
 		xx.i[1] = xx.i[0] = 0;
 		*iptr = xx.e;
@@ -130,6 +138,7 @@
 	/* split x at the binary point */
 	s = xx.i[2] & 0x8000;
 	yy.i[2] = xx.i[2];
+
 	if (hx < 0x401f) {
 		yy.i[1] = xx.i[1] & ~((1 << (0x401e - hx)) - 1);
 		yy.i[0] = 0;
@@ -137,12 +146,12 @@
 		yy.i[1] = xx.i[1];
 		yy.i[0] = xx.i[0] & ~((1 << (0x403e - hx)) - 1);
 	}
+
 	*iptr = yy.e;
 	xx.e -= yy.e;
 	xx.i[2] = (xx.i[2] & ~0x8000) | s;	/* keep sign of x */
 	return (xx.e);
 }
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/nan.c	2019-06-06 20:40:28.350561893 +0000
+++ new/usr/src/lib/libm/common/m9x/nan.c	2019-06-06 20:40:28.369550149 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -37,25 +38,22 @@
 #include <sys/isa_defs.h>
 
 #if defined(__sparc)
-
 static const union {
 	unsigned i[2];
 	double d;
 } __nan_union = { 0x7fffffff, 0xffffffff };
-
 #elif defined(__i386) || defined(__amd64)
-
 static const union {
 	unsigned i[2];
 	double d;
 } __nan_union = { 0xffffffff, 0x7fffffff };
-
 #else
 #error Unknown architecture
 #endif
 
 /* ARGSUSED0 */
 double
-__nan(const char *c) {
+__nan(const char *c)
+{
 	return (__nan_union.d);
 }
--- old/usr/src/lib/libm/common/m9x/nanf.c	2019-06-06 20:40:28.846225989 +0000
+++ new/usr/src/lib/libm/common/m9x/nanf.c	2019-06-06 20:40:28.865066019 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -38,6 +39,7 @@
 
 /* ARGSUSED0 */
 float
-__nanf(const char *c) {
+__nanf(const char *c)
+{
 	return (__nanf_union.f);
 }
--- old/usr/src/lib/libm/common/m9x/nanl.c	2019-06-06 20:40:29.384614591 +0000
+++ new/usr/src/lib/libm/common/m9x/nanl.c	2019-06-06 20:40:29.409512930 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,25 +33,22 @@
 #include "libm.h"
 
 #if defined(__sparc)
-
 static const union {
 	unsigned i[4];
 	long double ld;
 } __nanl_union = { 0x7fffffff, 0xffffffff, 0xffffffff, 0xffffffff };
-
 #elif defined(__x86)
-
 static const union {
 	unsigned i[3];
 	long double ld;
 } __nanl_union = { 0xffffffff, 0xffffffff, 0x7fff };
-
 #else
 #error Unknown architecture
 #endif
 
 /* ARGSUSED0 */
 long double
-__nanl(const char *c) {
+__nanl(const char *c)
+{
 	return (__nanl_union.ld);
 }
--- old/usr/src/lib/libm/common/m9x/nearbyint.c	2019-06-06 20:40:29.911304423 +0000
+++ new/usr/src/lib/libm/common/m9x/nearbyint.c	2019-06-06 20:40:29.929118507 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -42,11 +43,13 @@
 #include <fenv.h>
 
 double
-__nearbyint(double x) {
+__nearbyint(double x)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx;
+
 	unsigned hx, sx, i, frac;
 	int rm, j;
 
@@ -55,17 +58,19 @@
 	hx = xx.i[HIWORD] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx >= 0x43300000) {	/* x is nan, inf, or already integral */
+	if (hx >= 0x43300000) {		/* x is nan, inf, or already integral */
 		if (hx >= 0x7ff00000)	/* x is inf or nan */
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 			return (hx >= 0x7ff80000 ? x : x + x);
-			/* assumes sparc-like QNaN */
+
+		/* assumes sparc-like QNaN */
 #else
 			return (x + x);
 #endif
 		return (x);
-	} else if ((hx | xx.i[LOWORD]) == 0)	/* x is zero */
+	} else if ((hx | xx.i[LOWORD]) == 0) {	/* x is zero */
 		return (x);
+	}
 
 	/* get the rounding mode */
 	rm = fegetround();
@@ -76,44 +81,55 @@
 
 	/* handle |x| < 1 */
 	if (hx < 0x3ff00000) {
-		if (rm == FE_UPWARD || (rm == FE_TONEAREST &&
-			(hx >= 0x3fe00000 && ((hx & 0xfffff) | xx.i[LOWORD]))))
+		if (rm == FE_UPWARD || (rm == FE_TONEAREST && (hx >=
+		    0x3fe00000 && ((hx & 0xfffff) | xx.i[LOWORD]))))
 			xx.i[HIWORD] = sx | 0x3ff00000;
 		else
 			xx.i[HIWORD] = sx;
+
 		xx.i[LOWORD] = 0;
 		return (xx.d);
 	}
 
 	/* round x at the integer bit */
 	j = 0x433 - (hx >> 20);
+
 	if (j >= 32) {
 		i = 1 << (j - 32);
-		frac = ((xx.i[HIWORD] << 1) << (63 - j)) |
-			(xx.i[LOWORD] >> (j - 32));
+		frac = ((xx.i[HIWORD] << 1) << (63 - j)) | (xx.i[LOWORD] >> (j -
+		    32));
+
 		if (xx.i[LOWORD] & (i - 1))
 			frac |= 1;
+
 		if (!frac)
 			return (x);
+
 		xx.i[LOWORD] = 0;
 		xx.i[HIWORD] &= ~(i - 1);
-		if ((rm == FE_UPWARD) || ((rm == FE_TONEAREST) &&
-			((frac > 0x80000000u) || ((frac == 0x80000000) &&
-			(xx.i[HIWORD] & i)))))
+
+		if ((rm == FE_UPWARD) || ((rm == FE_TONEAREST) && ((frac >
+		    0x80000000u) || ((frac == 0x80000000) && (xx.i[HIWORD] &
+		    i)))))
 			xx.i[HIWORD] += i;
 	} else {
 		i = 1 << j;
 		frac = (xx.i[LOWORD] << 1) << (31 - j);
+
 		if (!frac)
 			return (x);
+
 		xx.i[LOWORD] &= ~(i - 1);
-		if ((rm == FE_UPWARD) || ((rm == FE_TONEAREST) &&
-			(frac > 0x80000000u || ((frac == 0x80000000) &&
-			(xx.i[LOWORD] & i))))) {
+
+		if ((rm == FE_UPWARD) || ((rm == FE_TONEAREST) && (frac >
+		    0x80000000u || ((frac == 0x80000000) && (xx.i[LOWORD] &
+		    i))))) {
 			xx.i[LOWORD] += i;
+
 			if (xx.i[LOWORD] == 0)
 				xx.i[HIWORD]++;
 		}
 	}
+
 	return (xx.d);
 }
--- old/usr/src/lib/libm/common/m9x/nearbyintf.c	2019-06-06 20:40:30.449642391 +0000
+++ new/usr/src/lib/libm/common/m9x/nearbyintf.c	2019-06-06 20:40:30.467845105 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,11 +34,13 @@
 #include <fenv.h>
 
 float
-__nearbyintf(float x) {
+__nearbyintf(float x)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx;
+
 	unsigned hx, sx, i, frac;
 	int rm;
 
@@ -46,12 +49,14 @@
 	hx = xx.i & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx >= 0x4b000000) {	/* x is nan, inf, or already integral */
+	if (hx >= 0x4b000000) {		/* x is nan, inf, or already integral */
 		if (hx > 0x7f800000)	/* x is nan */
 			return (x * x);		/* + -> * for Cheetah */
+
 		return (x);
-	} else if (hx == 0)		/* x is zero */
+	} else if (hx == 0) {			/* x is zero */
 		return (x);
+	}
 
 	/* get the rounding mode */
 	rm = fegetround();
@@ -66,26 +71,29 @@
 			xx.i = sx | 0x3f800000;
 		else
 			xx.i = sx;
+
 		return (xx.f);
 	}
 
 	/* round x at the integer bit */
 	i = 1 << (0x96 - (hx >> 23));
 	frac = hx & (i - 1);
+
 	if (!frac)
 		return (x);
 
 	hx &= ~(i - 1);
+
 	if (rm == FE_UPWARD || (rm == FE_TONEAREST && (frac > (i >> 1) ||
-		((frac == (i >> 1)) && (hx & i)))))
+	    ((frac == (i >> 1)) && (hx & i)))))
 		xx.i = sx | (hx + i);
 	else
 		xx.i = sx | hx;
+
 	return (xx.f);
 }
 
 #if 0
-
 /*
  * Alternate implementations for SPARC, x86, using fp ops.  These may
  * be faster depending on how expensive saving and restoring the fp
@@ -96,13 +104,14 @@
 #include "fma.h"
 
 #if defined(__sparc)
-
 float
-__nearbyintf(float x) {
+__nearbyintf(float x)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx, yy;
+
 	float z;
 	unsigned hx, sx, fsr, oldfsr;
 	int rm;
@@ -112,9 +121,9 @@
 	hx = xx.i & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx >= 0x4b000000)	/* x is nan, inf, or already integral */
+	if (hx >= 0x4b000000)		/* x is nan, inf, or already integral */
 		return (x + 0.0f);
-	else if (hx == 0)	/* x is zero */
+	else if (hx == 0)		/* x is zero */
 		return (x);
 
 	/* save the fsr */
@@ -124,12 +133,15 @@
 	if (hx < 0x3f800000) {
 		/* flip the sense of directed roundings if x is negative */
 		rm = oldfsr >> 30;
+
 		if (sx)
 			rm ^= rm >> 1;
+
 		if (rm == FSR_RP || (rm == FSR_RN && hx > 0x3f000000))
 			xx.i = sx | 0x3f800000;
 		else
 			xx.i = sx;
+
 		return (xx.f);
 	}
 
@@ -146,14 +158,13 @@
 
 	return (z);
 }
-
 #elif defined(__x86)
-
 /* inline template */
 extern long double frndint(long double);
 
 float
-__nearbyintf(float x) {
+__nearbyintf(float x)
+{
 	long double z;
 	unsigned oldcwsw, cwsw;
 
@@ -162,7 +173,7 @@
 	cwsw = oldcwsw | 0x00200000;
 	__fenv_setcwsw(&cwsw);
 
-	z = frndint((long double) x);
+	z = frndint((long double)x);
 
 	/*
 	 * restore the control and status words, preserving all but the
@@ -175,9 +186,7 @@
 	/* note: the value of z is representable in single precision */
 	return (z);
 }
-
 #else
 #error Unknown architecture
 #endif
-
 #endif
--- old/usr/src/lib/libm/common/m9x/nearbyintl.c	2019-06-06 20:40:30.974865685 +0000
+++ new/usr/src/lib/libm/common/m9x/nearbyintl.c	2019-06-06 20:40:30.993042105 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -34,39 +35,41 @@
 #include "fenv_inlines.h"
 
 #if defined(__sparc)
-
 static union {
 	unsigned i;
 	float f;
 } snan = { 0x7f800001 };
-
 long double
-__nearbyintl(long double x) {
+__nearbyintl(long double x)
+{
 	union {
 		unsigned i[4];
 		long double q;
 	} xx;
+
 	unsigned hx, sx, i, frac;
 	unsigned int fsr;
 	int rm, j;
-	volatile float	dummy;
+	volatile float dummy;
 
 	xx.q = x;
 	sx = xx.i[0] & 0x80000000;
 	hx = xx.i[0] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx >= 0x406f0000) {	/* x is nan, inf, or already integral */
+	if (hx >= 0x406f0000) {		/* x is nan, inf, or already integral */
 		/* check for signaling nan */
-		if ((hx > 0x7fff0000 || (hx == 0x7fff0000 &&
-			(xx.i[1] | xx.i[2] | xx.i[3]))) && !(hx & 0x8000)) {
+		if ((hx > 0x7fff0000 || (hx == 0x7fff0000 && (xx.i[1] |
+		    xx.i[2] | xx.i[3]))) && !(hx & 0x8000)) {
 			dummy = snan.f;
 			dummy += snan.f;
 			xx.i[0] = sx | hx | 0x8000;
 		}
+
 		return (xx.q);
-	} else if ((hx | xx.i[1] | xx.i[2] | xx.i[3]) == 0)	/* x is zero */
+	} else if ((hx | xx.i[1] | xx.i[2] | xx.i[3]) == 0) {	/* x is zero */
 		return (x);
+	}
 
 	/* get the rounding mode */
 	__fenv_getfsr32(&fsr);
@@ -78,56 +81,72 @@
 
 	/* handle |x| < 1 */
 	if (hx < 0x3fff0000) {
-		if (rm == FSR_RP || (rm == FSR_RN && (hx >= 0x3ffe0000 &&
-			((hx & 0xffff) | xx.i[1] | xx.i[2] | xx.i[3]))))
+		if (rm == FSR_RP || (rm == FSR_RN && (hx >= 0x3ffe0000 && ((hx &
+		    0xffff) | xx.i[1] | xx.i[2] | xx.i[3]))))
 			xx.i[0] = sx | 0x3fff0000;
 		else
 			xx.i[0] = sx;
+
 		xx.i[1] = xx.i[2] = xx.i[3] = 0;
 		return (xx.q);
 	}
 
 	/* round x at the integer bit */
 	j = 0x406f - (hx >> 16);
+
 	if (j >= 96) {
 		i = 1 << (j - 96);
 		frac = ((xx.i[0] << 1) << (127 - j)) | (xx.i[1] >> (j - 96));
+
 		if ((xx.i[1] & (i - 1)) | xx.i[2] | xx.i[3])
 			frac |= 1;
+
 		if (!frac)
 			return (x);
+
 		xx.i[1] = xx.i[2] = xx.i[3] = 0;
 		xx.i[0] &= ~(i - 1);
+
 		if (rm == FSR_RP || (rm == FSR_RN && (frac > 0x80000000u ||
-			(frac == 0x80000000 && (xx.i[0] & i)))))
+		    (frac == 0x80000000 && (xx.i[0] & i)))))
 			xx.i[0] += i;
 	} else if (j >= 64) {
 		i = 1 << (j - 64);
 		frac = ((xx.i[1] << 1) << (95 - j)) | (xx.i[2] >> (j - 64));
+
 		if ((xx.i[2] & (i - 1)) | xx.i[3])
 			frac |= 1;
+
 		if (!frac)
 			return (x);
+
 		xx.i[2] = xx.i[3] = 0;
 		xx.i[1] &= ~(i - 1);
+
 		if (rm == FSR_RP || (rm == FSR_RN && (frac > 0x80000000u ||
-			(frac == 0x80000000 && (xx.i[1] & i))))) {
+		    (frac == 0x80000000 && (xx.i[1] & i))))) {
 			xx.i[1] += i;
+
 			if (xx.i[1] == 0)
 				xx.i[0]++;
 		}
 	} else if (j >= 32) {
 		i = 1 << (j - 32);
 		frac = ((xx.i[2] << 1) << (63 - j)) | (xx.i[3] >> (j - 32));
+
 		if (xx.i[3] & (i - 1))
 			frac |= 1;
+
 		if (!frac)
 			return (x);
+
 		xx.i[3] = 0;
 		xx.i[2] &= ~(i - 1);
+
 		if (rm == FSR_RP || (rm == FSR_RN && (frac > 0x80000000u ||
-			(frac == 0x80000000 && (xx.i[2] & i))))) {
+		    (frac == 0x80000000 && (xx.i[2] & i))))) {
 			xx.i[2] += i;
+
 			if (xx.i[2] == 0)
 				if (++xx.i[1] == 0)
 					xx.i[0]++;
@@ -135,12 +154,16 @@
 	} else {
 		i = 1 << j;
 		frac = (xx.i[3] << 1) << (31 - j);
+
 		if (!frac)
 			return (x);
+
 		xx.i[3] &= ~(i - 1);
+
 		if (rm == FSR_RP || (rm == FSR_RN && (frac > 0x80000000u ||
-			(frac == 0x80000000 && (xx.i[3] & i))))) {
+		    (frac == 0x80000000 && (xx.i[3] & i))))) {
 			xx.i[3] += i;
+
 			if (xx.i[3] == 0)
 				if (++xx.i[2] == 0)
 					if (++xx.i[1] == 0)
@@ -150,14 +173,12 @@
 
 	return (xx.q);
 }
-
 #elif defined(__x86)
-
 /* inline template */
 extern long double frndint(long double);
-
 long double
-__nearbyintl(long double x) {
+__nearbyintl(long double x)
+{
 	long double z;
 	unsigned oldcwsw, cwsw;
 
@@ -178,7 +199,6 @@
 
 	return (z);
 }
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/nexttoward.c	2019-06-06 20:40:31.498524721 +0000
+++ new/usr/src/lib/libm/common/m9x/nexttoward.c	2019-06-06 20:40:31.517667259 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -43,35 +44,30 @@
 #include "libm.h"
 
 #if defined(__sparc)
-
 static union {
 	unsigned i[2];
 	double d;
 } C[] = {
-	0x00100000, 0,
-	0x7fe00000, 0,
-	0x7fffffff, 0xffffffff
+	0x00100000, 0, 0x7fe00000, 0, 0x7fffffff, 0xffffffff
 };
 
-#define	tiny	C[0].d
-#define	huge	C[1].d
-#define	qnan	C[2].d
+#define	tiny		C[0].d
+#define	huge		C[1].d
+#define	qnan		C[2].d
 
 enum fcc_type {
-	fcc_equal = 0,
-	fcc_less = 1,
-	fcc_greater = 2,
-	fcc_unordered = 3
+	fcc_equal = 0, fcc_less = 1, fcc_greater = 2, fcc_unordered = 3
 };
 
 #ifdef __sparcv9
-#define	_Q_cmp	_Qp_cmp
+#define	_Q_cmp		_Qp_cmp
 #endif
 
 extern enum fcc_type _Q_cmp(const long double *, const long double *);
 
 double
-__nexttoward(double x, long double y) {
+__nexttoward(double x, long double y)
+{
 	union {
 		unsigned i[2];
 		double d;
@@ -80,9 +76,10 @@
 		unsigned i[4];
 		long double q;
 	} yy;
+
 	long double lx;
 	unsigned hx;
-	volatile double	dummy;
+	volatile double dummy;
 	enum fcc_type rel;
 
 	/*
@@ -97,6 +94,7 @@
 
 	/* check for each of four possible orderings */
 	rel = _Q_cmp(&lx, &y);
+
 	if (rel == fcc_unordered)
 		return (qnan);
 
@@ -106,11 +104,12 @@
 			xx.i[0] = yy.i[0];
 			return (xx.d);
 		}
+
 		return (x);
 	}
 
 	if (rel == fcc_less) {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0;
 			xx.i[1] = 0x00000001;
 		} else if ((int)xx.i[0] >= 0) {	/* x is positive */
@@ -121,7 +120,7 @@
 				xx.i[0]--;
 		}
 	} else {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0x80000000;
 			xx.i[1] = 0x00000001;
 		} else if ((int)xx.i[0] >= 0) {	/* x is positive */
@@ -135,6 +134,7 @@
 
 	/* raise exceptions as needed */
 	hx = xx.i[0] & ~0x80000000;
+
 	if (hx == 0x7ff00000) {
 		dummy = huge;
 		dummy *= huge;
@@ -145,42 +145,40 @@
 
 	return (xx.d);
 }
-
 #elif defined(__x86)
-
 static union {
 	unsigned i[2];
 	double d;
 } C[] = {
-	0, 0x00100000,
-	0, 0x7fe00000,
-};
+	0, 0x00100000, 0, 0x7fe00000, };
 
-#define	tiny	C[0].d
-#define	huge	C[1].d
+#define	tiny		C[0].d
+#define	huge		C[1].d
 
 double
-__nexttoward(double x, long double y) {
+__nexttoward(double x, long double y)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx;
+
 	unsigned hx;
 	long double lx;
-	volatile double	dummy;
+	volatile double dummy;
 
 	lx = xx.d = x;
 	hx = (xx.i[1] & ~0x80000000) | xx.i[0];
 
 	/* check for each of four possible orderings */
 	if (isunordered(lx, y))
-		return ((double) (lx + y));
+		return ((double)(lx + y));
 
 	if (lx == y)
-		return ((double) y);
+		return ((double)y);
 
 	if (lx < y) {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0x00000001;
 			xx.i[1] = 0;
 		} else if ((int)xx.i[1] >= 0) {	/* x is positive */
@@ -191,7 +189,7 @@
 				xx.i[1]--;
 		}
 	} else {
-		if (hx == 0) {	/* x is zero */
+		if (hx == 0) {			/* x is zero */
 			xx.i[0] = 0x00000001;
 			xx.i[1] = 0x80000000;
 		} else if ((int)xx.i[1] >= 0) {	/* x is positive */
@@ -205,6 +203,7 @@
 
 	/* raise exceptions as needed */
 	hx = xx.i[1] & ~0x80000000;
+
 	if (hx == 0x7ff00000) {
 		dummy = huge;
 		dummy *= huge;
@@ -215,7 +214,6 @@
 
 	return (xx.d);
 }
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/nexttowardf.c	2019-06-06 20:40:32.025179343 +0000
+++ new/usr/src/lib/libm/common/m9x/nexttowardf.c	2019-06-06 20:40:32.045029232 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -35,22 +36,16 @@
 	unsigned i;
 	float f;
 } C[] = {
-	0x00800000,
-	0x7f000000,
-	0x7fffffff
+	0x00800000, 0x7f000000, 0x7fffffff
 };
 
-#define	tiny	C[0].f
-#define	huge	C[1].f
-#define	qnan	C[2].f
+#define	tiny		C[0].f
+#define	huge		C[1].f
+#define	qnan		C[2].f
 
 #if defined(__sparc)
-
 enum fcc_type {
-	fcc_equal = 0,
-	fcc_less = 1,
-	fcc_greater = 2,
-	fcc_unordered = 3
+	fcc_equal = 0, fcc_less = 1, fcc_greater = 2, fcc_unordered = 3
 };
 
 #ifdef __sparcv9
@@ -60,7 +55,8 @@
 extern enum fcc_type _Q_cmp(const long double *, const long double *);
 
 float
-__nexttowardf(float x, long double y) {
+__nexttowardf(float x, long double y)
+{
 	union {
 		unsigned i;
 		float f;
@@ -69,6 +65,7 @@
 		unsigned i[4];
 		long double q;
 	} yy;
+
 	long double lx;
 	unsigned hx;
 	volatile float dummy;
@@ -86,6 +83,7 @@
 
 	/* check for each of four possible orderings */
 	rel = _Q_cmp(&lx, &y);
+
 	if (rel == fcc_unordered)
 		return (qnan);
 
@@ -95,20 +93,21 @@
 			xx.i = yy.i[0];
 			return (xx.f);
 		}
+
 		return (x);
 	}
 
 	if (rel == fcc_less) {
-		if (hx == 0)	/* x is zero */
+		if (hx == 0)			/* x is zero */
 			xx.i = 0x00000001;
-		else if ((int) xx.i >= 0)	/* x is positive */
+		else if ((int)xx.i >= 0)	/* x is positive */
 			xx.i++;
 		else
 			xx.i--;
 	} else {
-		if (hx == 0)	/* x is zero */
+		if (hx == 0)			/* x is zero */
 			xx.i = 0x80000001;
-		else if ((int) xx.i >= 0)	/* x is positive */
+		else if ((int)xx.i >= 0)	/* x is positive */
 			xx.i--;
 		else
 			xx.i++;
@@ -116,6 +115,7 @@
 
 	/* raise exceptions as needed */
 	hx = xx.i & ~0x80000000;
+
 	if (hx == 0x7f800000) {
 		dummy = huge;
 		dummy *= huge;
@@ -126,15 +126,15 @@
 
 	return (xx.f);
 }
-
 #elif defined(__x86)
-
 float
-__nexttowardf(float x, long double y) {
+__nexttowardf(float x, long double y)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx;
+
 	unsigned hx;
 	long double lx;
 	volatile float dummy;
@@ -144,22 +144,22 @@
 
 	/* check for each of four possible orderings */
 	if (isunordered(lx, y))
-		return ((float) (lx + y));
+		return ((float)(lx + y));
 
 	if (lx == y)
-		return ((float) y);
+		return ((float)y);
 
 	if (lx < y) {
-		if (hx == 0)	/* x is zero */
+		if (hx == 0)			/* x is zero */
 			xx.i = 0x00000001;
-		else if ((int) xx.i >= 0)	/* x is positive */
+		else if ((int)xx.i >= 0)	/* x is positive */
 			xx.i++;
 		else
 			xx.i--;
 	} else {
-		if (hx == 0)	/* x is zero */
+		if (hx == 0)			/* x is zero */
 			xx.i = 0x80000001;
-		else if ((int) xx.i >= 0)	/* x is positive */
+		else if ((int)xx.i >= 0)	/* x is positive */
 			xx.i--;
 		else
 			xx.i++;
@@ -167,6 +167,7 @@
 
 	/* raise exceptions as needed */
 	hx = xx.i & ~0x80000000;
+
 	if (hx == 0x7f800000) {
 		dummy = huge;
 		dummy *= huge;
@@ -177,7 +178,6 @@
 
 	return (xx.f);
 }
-
 #else
 #error Unknown architecture
 #endif
--- old/usr/src/lib/libm/common/m9x/nexttowardl.c	2019-06-06 20:40:32.545618921 +0000
+++ new/usr/src/lib/libm/common/m9x/nexttowardl.c	2019-06-06 20:40:32.565962321 +0000
@@ -58,9 +58,9 @@
 /*
  * if pseudo-denormal, replace by the equivalent normal
  */
-#define	X86PDNRM1(x)	if (XBIASED_EXP(x) == 0 && (((int *) &x)[1] & \
+#define	X86PDNRM1(x)	if (XBIASED_EXP(x) == 0 && (((int *)&x)[1] & \
 				0x80000000) != 0) \
-				((int *) &x)[2] |= 1
+				((int *)&x)[2] |= 1
 #define	INC(px)	{ \
 			if (++px[n2] == 0) \
 				if ((++px[n1] & ~0x80000000) == 0) \
@@ -75,9 +75,10 @@
 #endif
 
 long double
-nexttowardl(long double x, long double y) {
-	int *px = (int *) &x;
-	int *py = (int *) &y;
+nexttowardl(long double x, long double y)
+{
+	int *px = (int *)&x;
+	int *py = (int *)&y;
 
 	if (x == y)
 		return (y);		/* C99 requirement */
--- old/usr/src/lib/libm/common/m9x/remquo.c	2019-06-06 20:40:33.048225148 +0000
+++ new/usr/src/lib/libm/common/m9x/remquo.c	2019-06-06 20:40:33.067299932 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __remquo = remquo
 
-/* INDENT OFF */
+
 /*
  * double remquo(double x, double y, int *quo) return remainder(x,y) and an
  * integer pointer quo such that *quo = N mod {2**31}, where N is the
@@ -37,56 +38,58 @@
  *
  * remquo call internal fmodquo
  */
-/* INDENT ON */
 
 #include "libm.h"
 #include "libm_protos.h"
-#include <math.h>		/* fabs() */
+#include <math.h>			/* fabs() */
 #include <sys/isa_defs.h>
 
 #if defined(_BIG_ENDIAN)
-#define	HIWORD	0
-#define	LOWORD	1
+#define	HIWORD		0
+#define	LOWORD		1
 #else
-#define	HIWORD	1
-#define	LOWORD	0
+#define	HIWORD		1
+#define	LOWORD		0
 #endif
-#define	__HI(x)	((int *) &x)[HIWORD]
-#define	__LO(x)	((int *) &x)[LOWORD]
-
-static const double one = 1.0, Zero[] = {0.0, -0.0};
+#define	__HI(x)		((int *)&x)[HIWORD]
+#define	__LO(x)		((int *)&x)[LOWORD]
 
+static const double one = 1.0, Zero[] = { 0.0, -0.0 };
 static double
-fmodquo(double x, double y, int *quo) {
+fmodquo(double x, double y, int *quo)
+{
 	int n, hx, hy, hz, ix, iy, sx, sq, i, m;
 	unsigned lx, ly, lz;
 
-	hx = __HI(x);		/* high word of x */
-	lx = __LO(x);		/* low  word of x */
-	hy = __HI(y);		/* high word of y */
-	ly = __LO(y);		/* low  word of y */
-	sx = hx & 0x80000000;	/* sign of x */
+	hx = __HI(x);			/* high word of x */
+	lx = __LO(x);			/* low  word of x */
+	hy = __HI(y);			/* high word of y */
+	ly = __LO(y);			/* low  word of y */
+	sx = hx & 0x80000000;		/* sign of x */
 	sq = (hx ^ hy) & 0x80000000;	/* sign of x/y */
-	hx ^= sx;		/* |x| */
-	hy &= 0x7fffffff;	/* |y| */
+	hx ^= sx;			/* |x| */
+	hy &= 0x7fffffff;		/* |y| */
 
 	/* purge off exception values */
 	*quo = 0;
+
 	if ((hy | ly) == 0 || hx >= 0x7ff00000 ||	/* y=0, or x !finite */
 	    (hy | ((ly | -ly) >> 31)) > 0x7ff00000)	/* or y is NaN */
 		return ((x * y) / (x * y));
+
 	if (hx <= hy) {
 		if (hx < hy || lx < ly)
 			return (x);	/* |x|<|y| return x */
+
 		if (lx == ly) {
 			*quo = 1 + (sq >> 30);
 			/* |x|=|y| return x*0 */
-			return (Zero[(unsigned) sx >> 31]);
+			return (Zero[(unsigned)sx >> 31]);
 		}
 	}
 
 	/* determine ix = ilogb(x) */
-	if (hx < 0x00100000) {	/* subnormal x */
+	if (hx < 0x00100000) {		/* subnormal x */
 		if (hx == 0) {
 			for (ix = -1043, i = lx; i > 0; i <<= 1)
 				ix -= 1;
@@ -94,11 +97,12 @@
 			for (ix = -1022, i = (hx << 11); i > 0; i <<= 1)
 				ix -= 1;
 		}
-	} else
+	} else {
 		ix = (hx >> 20) - 1023;
+	}
 
 	/* determine iy = ilogb(y) */
-	if (hy < 0x00100000) {	/* subnormal y */
+	if (hy < 0x00100000) {		/* subnormal y */
 		if (hy == 0) {
 			for (iy = -1043, i = ly; i > 0; i <<= 1)
 				iy -= 1;
@@ -106,14 +110,16 @@
 			for (iy = -1022, i = (hy << 11); i > 0; i <<= 1)
 				iy -= 1;
 		}
-	} else
+	} else {
 		iy = (hy >> 20) - 1023;
+	}
 
 	/* set up {hx,lx}, {hy,ly} and align y to x */
-	if (ix >= -1022)
+	if (ix >= -1022) {
 		hx = 0x00100000 | (0x000fffff & hx);
-	else {			/* subnormal x, shift x to normal */
+	} else {			/* subnormal x, shift x to normal */
 		n = -1022 - ix;
+
 		if (n <= 31) {
 			hx = (hx << n) | (lx >> (32 - n));
 			lx <<= n;
@@ -122,10 +128,12 @@
 			lx = 0;
 		}
 	}
-	if (iy >= -1022)
+
+	if (iy >= -1022) {
 		hy = 0x00100000 | (0x000fffff & hy);
-	else {			/* subnormal y, shift y to normal */
+	} else {			/* subnormal y, shift y to normal */
 		n = -1022 - iy;
+
 		if (n <= 31) {
 			hy = (hy << n) | (ly >> (32 - n));
 			ly <<= n;
@@ -138,59 +146,72 @@
 	/* fix point fmod */
 	n = ix - iy;
 	m = 0;
+
 	while (n--) {
 		hz = hx - hy;
 		lz = lx - ly;
+
 		if (lx < ly)
 			hz -= 1;
+
 		if (hz < 0) {
 			hx = hx + hx + (lx >> 31);
 			lx = lx + lx;
 		} else {
 			m += 1;
+
 			if ((hz | lz) == 0) {	/* return sign(x)*0 */
 				if (n < 31)
 					m <<= 1 + n;
 				else
 					m = 0;
+
 				m &= 0x7fffffff;
 				*quo = sq >= 0 ? m : -m;
-				return (Zero[(unsigned) sx >> 31]);
+				return (Zero[(unsigned)sx >> 31]);
 			}
+
 			hx = hz + hz + (lz >> 31);
 			lx = lz + lz;
 		}
+
 		m += m;
 	}
+
 	hz = hx - hy;
 	lz = lx - ly;
+
 	if (lx < ly)
 		hz -= 1;
+
 	if (hz >= 0) {
 		hx = hz;
 		lx = lz;
 		m += 1;
 	}
+
 	m &= 0x7fffffff;
 	*quo = sq >= 0 ? m : -m;
 
 	/* convert back to floating value and restore the sign */
-	if ((hx | lx) == 0) {	/* return sign(x)*0 */
-		return (Zero[(unsigned) sx >> 31]);
-	}
+	if ((hx | lx) == 0)		/* return sign(x)*0 */
+		return (Zero[(unsigned)sx >> 31]);
+
 	while (hx < 0x00100000) {	/* normalize x */
 		hx = hx + hx + (lx >> 31);
 		lx = lx + lx;
 		iy -= 1;
 	}
-	if (iy >= -1022) {	/* normalize output */
+
+	if (iy >= -1022) {		/* normalize output */
 		hx = (hx - 0x00100000) | ((iy + 1023) << 20);
 		__HI(x) = hx | sx;
 		__LO(x) = lx;
 	} else {			/* subnormal output */
 		n = -1022 - iy;
+
 		if (n <= 20) {
-			lx = (lx >> n) | ((unsigned) hx << (32 - n));
+			lx = (lx >> n) | ((unsigned)hx << (32 - n));
 			hx >>= n;
 		} else if (n <= 31) {
 			lx = (hx << (32 - n)) | (lx >> n);
@@ -199,48 +220,56 @@
 			lx = hx >> (n - 32);
 			hx = sx;
 		}
+
 		__HI(x) = hx | sx;
 		__LO(x) = lx;
-		x *= one;	/* create necessary signal */
+		x *= one;		/* create necessary signal */
 	}
-	return (x);		/* exact output */
+
+	return (x);			/* exact output */
 }
 
 #define	zero	Zero[0]
 
 double
-remquo(double x, double y, int *quo) {
+remquo(double x, double y, int *quo)
+{
 	int hx, hy, sx, sq;
 	double v;
 	unsigned ly;
 
-	hx = __HI(x);		/* high word of x */
-	hy = __HI(y);		/* high word of y */
-	ly = __LO(y);		/* low  word of y */
-	sx = hx & 0x80000000;	/* sign of x */
+	hx = __HI(x);			/* high word of x */
+	hy = __HI(y);			/* high word of y */
+	ly = __LO(y);			/* low  word of y */
+	sx = hx & 0x80000000;		/* sign of x */
 	sq = (hx ^ hy) & 0x80000000;	/* sign of x/y */
-	hx ^= sx;		/* |x| */
-	hy &= 0x7fffffff;	/* |y| */
+	hx ^= sx;			/* |x| */
+	hy &= 0x7fffffff;		/* |y| */
 
 	/* purge off exception values */
 	*quo = 0;
+
 	if ((hy | ly) == 0 || hx >= 0x7ff00000 ||	/* y=0, or x !finite */
 	    (hy | ((ly | -ly) >> 31)) > 0x7ff00000)	/* or y is NaN */
 		return ((x * y) / (x * y));
 
 	y = fabs(y);
 	x = fabs(x);
+
 	if (hy <= 0x7fdfffff) {
 		x = fmodquo(x, y + y, quo);
 		*quo = ((*quo) & 0x3fffffff) << 1;
 	}
+
 	if (hy < 0x00200000) {
 		if (x + x > y) {
 			*quo += 1;
+
 			if (x == y)
 				x = zero;
 			else
 				x -= y;
+
 			if (x + x >= y) {
 				x -= y;
 				*quo += 1;
@@ -248,19 +277,24 @@
 		}
 	} else {
 		v = 0.5 * y;
+
 		if (x > v) {
 			*quo += 1;
+
 			if (x == y)
 				x = zero;
 			else
 				x -= y;
+
 			if (x >= v) {
 				x -= y;
 				*quo += 1;
 			}
 		}
 	}
+
 	if (sq != 0)
 		*quo = -(*quo);
+
 	return (sx == 0 ? x : -x);
 }
--- old/usr/src/lib/libm/common/m9x/remquof.c	2019-06-06 20:40:33.577103192 +0000
+++ new/usr/src/lib/libm/common/m9x/remquof.c	2019-06-06 20:40:33.595078073 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,7 +30,7 @@
 
 #pragma weak __remquof = remquof
 
-/* INDENT OFF */
+
 /*
  * float remquof(float x, float y, int *quo) return remainderf(x,y) and an
  * integer pointer quo such that *quo = N mod (2**31),  where N is the
@@ -41,74 +42,80 @@
 #include "libm.h"
 #include "libm_protos.h"
 #include <math.h>
-extern float fabsf(float);
 
-static const int
-	is = (int) 0x80000000,
+extern float fabsf(float);
+static const int is = (int)0x80000000,
 	im = 0x007fffff,
 	ii = 0x7f800000,
 	iu = 0x00800000;
-
 static const float zero = 0.0F, half = 0.5F;
-/* INDENT ON */
 
 static float
-fmodquof(float x, float y, int *quo) {
+fmodquof(float x, float y, int *quo)
+{
 	float w;
 	int hx, ix, iy, iz, k, ny, nd, m, sq;
 
-	hx = *(int *) &x;
+	hx = *(int *)&x;
 	ix = hx & 0x7fffffff;
-	iy = *(int *) &y;
-	sq = (iy ^ hx) & is;	/* sign of x/y */
+	iy = *(int *)&y;
+	sq = (iy ^ hx) & is;		/* sign of x/y */
 	iy &= 0x7fffffff;
 
 	/* purge off exception values */
 	*quo = 0;
+
 	if (ix >= ii || iy > ii || iy == 0) {
 		w = x * y;
 		w = w / w;
 	} else if (ix <= iy) {
-		if (ix < iy)
-			w = x;	/* return x if |x|<|y| */
-		else {
+		if (ix < iy) {
+			w = x;		/* return x if |x|<|y| */
+		} else {
 			*quo = 1 + (sq >> 30);
 			w = zero * x;	/* return sign(x)*0.0  */
 		}
 	} else {
-		/* INDENT OFF */
+
 		/*
 		 * scale x,y to "normal" with
 		 *	ny = exponent of y
 		 *	nd = exponent of x minus exponent of y
 		 */
-		/* INDENT ON */
 		ny = iy >> 23;
 		k = ix >> 23;
 
 		/* special case for subnormal y or x */
 		if (ny == 0) {
 			ny = 1;
+
 			while (iy < iu) {
 				ny -= 1;
 				iy += iy;
 			}
+
 			nd = k - ny;
+
 			if (k == 0) {
 				nd += 1;
+
 				while (ix < iu) {
 					nd -= 1;
 					ix += ix;
 				}
-			} else
+			} else {
 				ix = iu | (ix & im);
+			}
 		} else {
 			nd = k - ny;
 			ix = iu | (ix & im);
 			iy = iu | (iy & im);
 		}
-		/* INDENT OFF */
-		/* fix point fmod for normalized ix and iy */
+
+		/*
+		 * fix point fmod for normalized ix and iy
+		 */
+
 		/*
 		 * while (nd--) {
 		 *	iz = ix - iy;
@@ -121,109 +128,140 @@
 		 *		ix = iz + iz;
 		 * }
 		 */
-		/* INDENT ON */
-		/* unroll the above loop 4 times to gain performance */
+
+		/*
+		 * unroll the above loop 4 times to gain performance
+		 */
 		m = 0;
 		k = nd >> 2;
 		nd -= (k << 2);
+
 		while (k--) {
 			iz = ix - iy;
+
 			if (iz >= 0) {
 				m += 1;
 				ix = iz + iz;
-			} else
+			} else {
 				ix += ix;
+			}
+
 			m += m;
 			iz = ix - iy;
+
 			if (iz >= 0) {
 				m += 1;
 				ix = iz + iz;
-			} else
+			} else {
 				ix += ix;
+			}
+
 			m += m;
 			iz = ix - iy;
+
 			if (iz >= 0) {
 				m += 1;
 				ix = iz + iz;
-			} else
+			} else {
 				ix += ix;
+			}
+
 			m += m;
 			iz = ix - iy;
+
 			if (iz >= 0) {
 				m += 1;
 				ix = iz + iz;
-			} else
+			} else {
 				ix += ix;
+			}
+
 			m += m;
+
 			if (iz == 0) {
 				iz = (k << 2) + nd;
+
 				if (iz < 32)
 					m <<= iz;
 				else
 					m = 0;
+
 				m &= 0x7fffffff;
 				*quo = sq >= 0 ? m : -m;
-				*(int *) &w = is & hx;
+				*(int *)&w = is & hx;
 				return (w);
 			}
 		}
+
 		while (nd--) {
 			iz = ix - iy;
+
 			if (iz >= 0) {
 				m += 1;
 				ix = iz + iz;
-			} else
+			} else {
 				ix += ix;
+			}
+
 			m += m;
 		}
+
 		/* end of unrolling */
 
 		iz = ix - iy;
+
 		if (iz >= 0) {
 			m += 1;
 			ix = iz;
 		}
+
 		m &= 0x7fffffff;
 		*quo = sq >= 0 ? m : -m;
 
 		/* convert back to floating value and restore the sign */
 		if (ix == 0) {
-			*(int *) &w = is & hx;
+			*(int *)&w = is & hx;
 			return (w);
 		}
+
 		while (ix < iu) {
 			ix += ix;
 			ny -= 1;
 		}
+
 		while (ix > (iu + iu)) {
 			ny += 1;
 			ix >>= 1;
 		}
-		if (ny > 0)
-			*(int *) &w = (is & hx) | (ix & im) | (ny << 23);
-		else {		/* subnormal output */
+
+		if (ny > 0) {
+			*(int *)&w = (is & hx) | (ix & im) | (ny << 23);
+		} else {		/* subnormal output */
 			k = -ny + 1;
 			ix >>= k;
-			*(int *) &w = (is & hx) | ix;
+			*(int *)&w = (is & hx) | ix;
 		}
 	}
+
 	return (w);
 }
 
 float
-remquof(float x, float y, int *quo) {
+remquof(float x, float y, int *quo)
+{
 	int hx, hy, sx, sq;
 	float v;
 
-	hx = *(int *) &x;	/* high word of x */
-	hy = *(int *) &y;	/* high word of y */
-	sx = hx & is;		/* sign of x */
-	sq = (hx ^ hy) & is;	/* sign of x/y */
-	hx ^= sx;		/* |x| */
-	hy &= 0x7fffffff;	/* |y| */
+	hx = *(int *)&x;		/* high word of x */
+	hy = *(int *)&y;		/* high word of y */
+	sx = hx & is;			/* sign of x */
+	sq = (hx ^ hy) & is;		/* sign of x/y */
+	hx ^= sx;			/* |x| */
+	hy &= 0x7fffffff;		/* |y| */
 
 	/* purge off exception values: y is 0 or NaN, x is Inf or NaN */
 	*quo = 0;
+
 	if (hx >= ii || hy > ii || hy == 0) {
 		v = x * y;
 		return (v / v);
@@ -231,17 +269,21 @@
 
 	y = fabsf(y);
 	x = fabsf(x);
+
 	if (hy <= 0x7f7fffff) {
 		x = fmodquof(x, y + y, quo);
 		*quo = ((*quo) & 0x3fffffff) << 1;
 	}
+
 	if (hy < 0x01000000) {
 		if (x + x > y) {
 			*quo += 1;
+
 			if (x == y)
 				x = zero;
 			else
 				x -= y;
+
 			if (x + x >= y) {
 				x -= y;
 				*quo += 1;
@@ -249,19 +291,24 @@
 		}
 	} else {
 		v = half * y;
+
 		if (x > v) {
 			*quo += 1;
+
 			if (x == y)
 				x = zero;
 			else
 				x -= y;
+
 			if (x >= v) {
 				x -= y;
 				*quo += 1;
 			}
 		}
 	}
+
 	if (sq != 0)
 		*quo = -(*quo);
+
 	return (sx == 0 ? x : -x);
 }
--- old/usr/src/lib/libm/common/m9x/remquol.c	2019-06-06 20:40:34.110791324 +0000
+++ new/usr/src/lib/libm/common/m9x/remquol.c	2019-06-06 20:40:34.131359988 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,20 +34,16 @@
 #if defined(__SUNPRO_C)
 #include <sunmath.h>			/* fabsl */
 #endif
-/* INDENT OFF */
-static const int
-	is = -0x7fffffff - 1,
-	im = 0x0000ffff,
-	iu = 0x00010000;
 
+static const int is = -0x7fffffff - 1, im = 0x0000ffff, iu = 0x00010000;
 static const long double zero = 0.0L, one = 1.0L;
-/* INDENT ON */
+
 
 #if defined(__sparc)
-#define	__H0(x)	((int *) &x)[0]
-#define	__H1(x)	((int *) &x)[1]
-#define	__H2(x)	((int *) &x)[2]
-#define	__H3(x)	((int *) &x)[3]
+#define	__H0(x)		((int *)&x)[0]
+#define	__H1(x)		((int *)&x)[1]
+#define	__H2(x)		((int *)&x)[2]
+#define	__H3(x)		((int *)&x)[3]
 #else
 #error Unsupported architecture
 #endif
@@ -55,7 +52,8 @@
  * On entrance: *quo is initialized to 0, x finite and y non-zero & ordered
  */
 static long double
-fmodquol(long double x, long double y, int *quo) {
+fmodquol(long double x, long double y, int *quo)
+{
 	long double a, b;
 	int n, ix, iy, k, sx, sq, m;
 	int hx;
@@ -78,18 +76,21 @@
 
 	a = fabsl(x);
 	b = fabsl(y);
+
 	if (a <= b) {
-		if (a < b)
+		if (a < b) {
 			return (x);
-		else {
+		} else {
 			*quo = 1 + (sq >> 30);
 			return (zero * x);
 		}
 	}
+
 	/* determine ix = ilogbl(x) */
-	if (x0 < iu) {		/* subnormal x */
+	if (x0 < iu) {			/* subnormal x */
 		ix = 0;
 		ix = -16382;
+
 		while (x0 == 0) {
 			ix -= 16;
 			x0 = x1 >> 16;
@@ -97,6 +98,7 @@
 			x2 = (x2 << 16) | (x3 >> 16);
 			x3 = (x3 << 16);
 		}
+
 		while (x0 < iu) {
 			ix -= 1;
 			x0 = (x0 << 1) | (x1 >> 31);
@@ -110,8 +112,9 @@
 	}
 
 	/* determine iy = ilogbl(y) */
-	if (y0 < iu) {		/* subnormal y */
+	if (y0 < iu) {			/* subnormal y */
 		iy = -16382;
+
 		while (y0 == 0) {
 			iy -= 16;
 			y0 = y1 >> 16;
@@ -119,6 +122,7 @@
 			y2 = (y2 << 16) | (y3 >> 16);
 			y3 = (y3 << 16);
 		}
+
 		while (y0 < iu) {
 			iy -= 1;
 			y0 = (y0 << 1) | (y1 >> 31);
@@ -131,10 +135,10 @@
 		y0 = iu | (y0 & im);
 	}
 
-
 	/* fix point fmod */
 	n = ix - iy;
 	m = 0;
+
 	while (n--) {
 		while (x0 == 0 && n >= 16) {
 			m <<= 16;
@@ -144,6 +148,7 @@
 			x2 = (x2 << 16) | (x3 >> 16);
 			x3 = (x3 << 16);
 		}
+
 		while (x0 < iu && n >= 1) {
 			m += m;
 			n -= 1;
@@ -152,9 +157,11 @@
 			x2 = (x2 << 1) | (x3 >> 31);
 			x3 = (x3 << 1);
 		}
+
 		carry = 0;
 		z3 = x3 - y3;
 		carry = z3 > x3;
+
 		if (carry == 0) {
 			z2 = x2 - y2;
 			carry = z2 > x2;
@@ -162,6 +169,7 @@
 			z2 = x2 - y2 - 1;
 			carry = z2 >= x2;
 		}
+
 		if (carry == 0) {
 			z1 = x1 - y1;
 			carry = z1 > x1;
@@ -169,8 +177,10 @@
 			z1 = x1 - y1 - 1;
 			carry = z1 >= x1;
 		}
+
 		z0 = x0 - y0 - carry;
-		if (z0 < 0) {	/* double x */
+
+		if (z0 < 0) {		/* double x */
 			x0 = x0 + x0 + ((x1 & is) != 0);
 			x1 = x1 + x1 + ((x2 & is) != 0);
 			x2 = x2 + x2 + ((x3 & is) != 0);
@@ -178,6 +188,7 @@
 			m += m;
 		} else {
 			m += 1;
+
 			if (z0 == 0) {
 				if ((z1 | z2 | z3) == 0) {
 					/* 0: we are done */
@@ -185,6 +196,7 @@
 						m <<= (1 + n);
 					else
 						m = 0;
+
 					m &= ~0x80000000;
 					*quo = sq >= 0 ? m : -m;
 					__H0(a) = hx & is;
@@ -192,6 +204,7 @@
 					return (a);
 				}
 			}
+
 			/* x = z << 1 */
 			z0 = z0 + z0 + ((z1 & is) != 0);
 			z1 = z1 + z1 + ((z2 & is) != 0);
@@ -204,9 +217,11 @@
 			m += m;
 		}
 	}
+
 	carry = 0;
 	z3 = x3 - y3;
 	carry = z3 > x3;
+
 	if (carry == 0) {
 		z2 = x2 - y2;
 		carry = z2 > x2;
@@ -214,6 +229,7 @@
 		z2 = x2 - y2 - 1;
 		carry = z2 >= x2;
 	}
+
 	if (carry == 0) {
 		z1 = x1 - y1;
 		carry = z1 > x1;
@@ -221,7 +237,9 @@
 		z1 = x1 - y1 - 1;
 		carry = z1 >= x1;
 	}
+
 	z0 = x0 - y0 - carry;
+
 	if (z0 >= 0) {
 		x0 = z0;
 		x1 = z1;
@@ -229,6 +247,7 @@
 		x3 = z3;
 		m += 1;
 	}
+
 	m &= ~0x80000000;
 	*quo = sq >= 0 ? m : -m;
 
@@ -238,6 +257,7 @@
 		__H1(a) = __H2(a) = __H3(a) = 0;
 		return (a);
 	}
+
 	while (x0 < iu) {
 		if (x0 == 0) {
 			iy -= 16;
@@ -260,9 +280,10 @@
 		__H1(a) = x1;
 		__H2(a) = x2;
 		__H3(a) = x3;
-	} else {		/* subnormal output */
+	} else {			/* subnormal output */
 		n = -16382 - iy;
 		k = n & 31;
+
 		if (k <= 16) {
 			x3 = (x2 << (32 - k)) | (x3 >> k);
 			x2 = (x1 << (32 - k)) | (x2 >> k);
@@ -274,6 +295,7 @@
 			x1 = (x0 << (32 - k)) | (x1 >> k);
 			x0 = 0;
 		}
+
 		while (n >= 32) {
 			n -= 32;
 			x3 = x2;
@@ -281,46 +303,54 @@
 			x1 = x0;
 			x0 = 0;
 		}
+
 		__H0(a) = x0 | sx;
 		__H1(a) = x1;
 		__H2(a) = x2;
 		__H3(a) = x3;
 		a *= one;
 	}
+
 	return (a);
 }
 
 long double
-remquol(long double x, long double y, int *quo) {
+remquol(long double x, long double y, int *quo)
+{
 	int hx, hy, sx, sq;
 	long double v;
 
-	hx = __H0(x);		/* high word of x */
-	hy = __H0(y);		/* high word of y */
-	sx = hx & is;		/* sign of x */
-	sq = (hx ^ hy) & is;	/* sign of x/y */
-	hx ^= sx;		/* |x| */
+	hx = __H0(x);			/* high word of x */
+	hy = __H0(y);			/* high word of y */
+	sx = hx & is;			/* sign of x */
+	sq = (hx ^ hy) & is;		/* sign of x/y */
+	hx ^= sx;			/* |x| */
 	hy &= ~0x80000000;
 
 	/* purge off exception values */
 	*quo = 0;
+
 	/* y=0, y is NaN, x is NaN or inf */
 	if (y == 0.0L || y != y || hx >= 0x7fff0000)
 		return ((x * y) / (x * y));
 
 	y = fabsl(y);
 	x = fabsl(x);
+
 	if (hy <= 0x7ffdffff) {
 		x = fmodquol(x, y + y, quo);
 		*quo = ((*quo) & 0x3fffffff) << 1;
 	}
+
 	if (hy < 0x00020000) {
 		if (x + x > y) {
 			*quo += 1;
+
 			if (x == y)
 				x = zero;
 			else
 				x -= y;
+
 			if (x + x >= y) {
 				x -= y;
 				*quo += 1;
@@ -328,19 +358,24 @@
 		}
 	} else {
 		v = 0.5L * y;
+
 		if (x > v) {
 			*quo += 1;
+
 			if (x == y)
 				x = zero;
 			else
 				x -= y;
+
 			if (x >= v) {
 				x -= y;
 				*quo += 1;
 			}
 		}
 	}
+
 	if (sq != 0)
 		*quo = -(*quo);
+
 	return (sx == 0 ? x : -x);
 }
--- old/usr/src/lib/libm/common/m9x/round.c	2019-06-06 20:40:34.664152776 +0000
+++ new/usr/src/lib/libm/common/m9x/round.c	2019-06-06 20:40:34.682816241 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,20 +33,24 @@
 #include "libm.h"
 
 double
-round(double x) {
+round(double x)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 	sx = xx.i[HIWORD] & 0x80000000;
-	if (hx < 0x43300000) {	/* |x| < 2^52 */
+
+	if (hx < 0x43300000) {		/* |x| < 2^52 */
 		if (hx < 0x3ff00000) {	/* |x| < 1 */
 			if (hx >= 0x3fe00000)
 				return (sx ? -1.0 : 1.0);
+
 			return (sx ? -0.0 : 0.0);
 		}
 
@@ -57,18 +62,23 @@
 		} else {
 			i = 1 << (0x432 - (hx >> 20));
 			xx.i[LOWORD] += i;
+
 			if (xx.i[LOWORD] < i)
 				xx.i[HIWORD]++;
+
 			xx.i[LOWORD] &= ~(i | (i - 1));
 		}
+
 		return (xx.d);
-	} else if (hx < 0x7ff00000)
+	} else if (hx < 0x7ff00000) {
 		return (x);
-	else
+	} else {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (hx >= 0x7ff80000 ? x : x + x);
-		/* assumes sparc-like QNaN */
+
+	/* assumes sparc-like QNaN */
 #else
 		return (x + x);
 #endif
+	}
 }
--- old/usr/src/lib/libm/common/m9x/roundf.c	2019-06-06 20:40:35.175022669 +0000
+++ new/usr/src/lib/libm/common/m9x/roundf.c	2019-06-06 20:40:35.192740333 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,20 +33,24 @@
 #include "libm.h"
 
 float
-roundf(float x) {
+roundf(float x)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
 	sx = xx.i & 0x80000000;
+
 	if (hx < 0x4b000000) {		/* |x| < 2^23 */
-		if (hx < 0x3f800000) {		/* |x| < 1 */
+		if (hx < 0x3f800000) {	/* |x| < 1 */
 			if (hx >= 0x3f000000)
 				return (sx ? -1.0F : 1.0F);
+
 			return (sx ? -0.0F : 0.0F);
 		}
 
@@ -53,12 +58,13 @@
 		i = 1 << (0x95 - (hx >> 23));
 		xx.i = (xx.i + i) & ~((i << 1) - 1);
 		return (xx.f);
-	} else if (hx < 0x7f800000)	/* |x| is integral */
+	} else if (hx < 0x7f800000) {	/* |x| is integral */
 		return (x);
-	else
+	} else {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (hx > 0x7f800000 ? x * x : x + x);
 #else
 		return (x + x);
 #endif
+	}
 }
--- old/usr/src/lib/libm/common/m9x/roundl.c	2019-06-06 20:40:35.675900421 +0000
+++ new/usr/src/lib/libm/common/m9x/roundl.c	2019-06-06 20:40:35.693549078 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,11 +34,13 @@
 
 #if defined(__sparc)
 long double
-roundl(long double x) {
+roundl(long double x)
+{
 	union {
 		unsigned i[4];
 		long double q;
 	} xx;
+
 	unsigned hx, sx, v;
 	int j;
 
@@ -46,63 +49,79 @@
 	hx = xx.i[0] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx >= 0x406f0000) /* |x| >= 2^112 + ... or x is nan */
+	if (hx >= 0x406f0000)		/* |x| >= 2^112 + ... or x is nan */
 		return (hx >= 0x7fff0000 ? x + x : x);
 
 	/* handle |x| < 1 */
 	if (hx < 0x3fff0000) {
 		if (hx >= 0x3ffe0000)
 			return (sx ? -1.0L : 1.0L);
+
 		return (sx ? -0.0L : 0.0L);
 	}
 
 	xx.i[0] = hx;
-	j = 0x406f - (hx >> 16);		/* 1 <= j <= 112 */
-	if (j >= 96) {				/* 96 <= j <= 112 */
+	j = 0x406f - (hx >> 16);	/* 1 <= j <= 112 */
+
+	if (j >= 96) {			/* 96 <= j <= 112 */
 		v = (1U << (j - 96)) >> 1;
+
 		if (v) {
 			if (xx.i[0] & v)
 				xx.i[0] += v;
+
 			xx.i[0] &= ~(v - 1);
-		} else if (xx.i[1] & 0x80000000)
-				++xx.i[0];
+		} else if (xx.i[1] & 0x80000000) {
+			++xx.i[0];
+		}
+
 		xx.i[1] = xx.i[2] = xx.i[3] = 0;
-	} else if (j >= 64) {			/* 64 <= j <= 95 */
+	} else if (j >= 64) {		/* 64 <= j <= 95 */
 		v = (1U << (j - 64)) >> 1;
+
 		if (v) {
 			if (xx.i[1] & v) {
 				xx.i[1] += v;
+
 				if (xx.i[1] < v)
 					++xx.i[0];
 			}
+
 			xx.i[1] &= ~(v - 1);
 		} else if (xx.i[2] & 0x80000000) {
-				if (++xx.i[1] == 0)
-					++xx.i[0];
+			if (++xx.i[1] == 0)
+				++xx.i[0];
 		}
+
 		xx.i[2] = xx.i[3] = 0;
-	} else if (j >= 32) {			/* 32 <= j <= 63 */
+	} else if (j >= 32) {		/* 32 <= j <= 63 */
 		v = (1U << (j - 32)) >> 1;
+
 		if (v) {
 			if (xx.i[2] & v) {
 				xx.i[2] += v;
+
 				if (xx.i[2] < v) {
 					if (++xx.i[1] == 0)
 						++xx.i[0];
 				}
 			}
+
 			xx.i[2] &= ~(v - 1);
 		} else if (xx.i[3] & 0x80000000) {
-				if (++xx.i[2] == 0) {
-					if (++xx.i[1] == 0)
-						++xx.i[0];
-				}
+			if (++xx.i[2] == 0) {
+				if (++xx.i[1] == 0)
+					++xx.i[0];
+			}
 		}
+
 		xx.i[3] = 0;
-	} else {				/* 1 <= j <= 31 */
+	} else {			/* 1 <= j <= 31 */
 		v = 1U << (j - 1);
+
 		if (xx.i[3] & v) {
 			xx.i[3] += v;
+
 			if (xx.i[3] < v) {
 				if (++xx.i[2] == 0) {
 					if (++xx.i[1] == 0)
@@ -110,30 +129,36 @@
 				}
 			}
 		}
+
 		xx.i[3] &= ~(v - 1);
 	}
 
 	/* negate result if need be */
 	if (sx)
 		xx.i[0] |= 0x80000000;
+
 	return (xx.q);
 }
 #elif defined(__x86)
 long double
-roundl(long double x) {
+roundl(long double x)
+{
 	union {
 		unsigned i[3];
 		long double e;
 	} xx;
+
 	int ex, sx, i;
 
 	xx.e = x;
 	ex = xx.i[2] & 0x7fff;
 	sx = xx.i[2] & 0x8000;
-	if (ex < 0x403e) {	/* |x| < 2^63 */
+
+	if (ex < 0x403e) {		/* |x| < 2^63 */
 		if (ex < 0x3fff) {	/* |x| < 1 */
 			if (ex >= 0x3ffe)
 				return (sx ? -1.0L : 1.0L);
+
 			return (sx ? -0.0L : 0.0L);
 		}
 
@@ -145,20 +170,25 @@
 		} else {
 			i = 1 << (0x403d - ex);
 			xx.i[0] += i;
+
 			if (xx.i[0] < i)
 				xx.i[1]++;
+
 			xx.i[0] &= ~(i | (i - 1));
 		}
+
 		if (xx.i[1] == 0) {
 			xx.i[2] = sx | ++ex;
 			xx.i[1] = 0x80000000U;
 		}
+
 		return (xx.e);
-	} else if (ex < 0x7fff)	/* x is integral */
+	} else if (ex < 0x7fff) {	/* x is integral */
 		return (x);
-	else			/* inf or nan */
+	} else {			/* inf or nan */
 		return (x + x);
+	}
 }
 #else
 #error Unknown architecture
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
--- old/usr/src/lib/libm/common/m9x/scalbln.c	2019-06-06 20:40:36.186401246 +0000
+++ new/usr/src/lib/libm/common/m9x/scalbln.c	2019-06-06 20:40:36.204055036 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,9 +31,10 @@
 #pragma weak __scalbln = scalbln
 
 #include "libm.h"
-#include <float.h>		/* DBL_MAX, DBL_MIN */
+#include <float.h>			/* DBL_MAX, DBL_MIN */
 
 static const double twom54 = 5.5511151231257827021181583404541015625e-17;
+
 #if defined(__x86)
 static const double two52 = 4503599627370496.0;
 #else
@@ -40,7 +42,8 @@
  * Normalize non-zero subnormal x and return biased exponent of x in [-51,0]
  */
 static int
-ilogb_biased(unsigned *px) {
+ilogb_biased(unsigned *px)
+{
 	int s = 52;
 	unsigned v = px[HIWORD] & ~0x80000000, w = px[LOWORD], t = v;
 
@@ -48,14 +51,19 @@
 		s -= 32;
 	else
 		t = w;
+
 	if (t & 0xffff0000)
 		s -= 16, t >>= 16;
+
 	if (t & 0xff00)
 		s -= 8, t >>= 8;
+
 	if (t & 0xf0)
 		s -= 4, t >>= 4;
+
 	t <<= 1;
 	s -= (0xffffaa50 >> t) & 0x3;
+
 	if (s < 32) {
 		v = (v << s) | w >> (32 - s);
 		w <<= s;
@@ -63,44 +71,55 @@
 		v = w << (s - 32);
 		w = 0;
 	}
+
 	px[HIWORD] = (px[HIWORD] & 0x80000000) | v;
 	px[LOWORD] = w;
 	return (1 - s);
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 double
-scalbln(double x, long n) {
-	int *px = (int *) &x, ix, k;
+scalbln(double x, long n)
+{
+	int *px = (int *)&x, ix, k;
 
 	ix = px[HIWORD] & ~0x80000000;
 	k = ix >> 20;
+
 	if (k == 0x7ff)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return ((px[HIWORD] & 0x80000) != 0 ? x : x + x);
-		/* assumes sparc-like QNaN */
+
+	/* assumes sparc-like QNaN */
 #else
 		return (x + x);
 #endif
+
 	if ((px[LOWORD] | ix) == 0 || n == 0)
 		return (x);
+
 	if (k == 0) {
 #if defined(__x86)
 		x *= two52;
 		k = ((px[HIWORD] & ~0x80000000) >> 20) - 52;
 #else
-		k = ilogb_biased((unsigned *) px);
+		k = ilogb_biased((unsigned *)px);
 #endif
 	}
-	k += (int) n;
+
+	k += (int)n;
+
 	if (n > 5000 || k > 0x7fe)
 		return (DBL_MAX * copysign(DBL_MAX, x));
+
 	if (n < -5000 || k <= -54)
 		return (DBL_MIN * copysign(DBL_MIN, x));
+
 	if (k > 0) {
 		px[HIWORD] = (px[HIWORD] & ~0x7ff00000) | (k << 20);
 		return (x);
 	}
+
 	k += 54;
 	px[HIWORD] = (px[HIWORD] & ~0x7ff00000) | (k << 20);
 	return (x * twom54);
--- old/usr/src/lib/libm/common/m9x/scalblnf.c	2019-06-06 20:40:36.707770183 +0000
+++ new/usr/src/lib/libm/common/m9x/scalblnf.c	2019-06-06 20:40:36.729847865 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,9 +31,10 @@
 #pragma weak __scalblnf = scalblnf
 
 #include "libm.h"
-#include <float.h>		/* FLT_MAX, FLT_MIN */
+#include <float.h>			/* FLT_MAX, FLT_MIN */
 
 static const float twom25f = 2.98023223876953125e-8F;
+
 #if defined(__x86)
 static const float two23f = 8388608.0F;
 #else
@@ -40,34 +42,42 @@
  * v: a non-zero subnormal |x|; returns [-22, 0]
  */
 static int
-ilogbf_biased(unsigned v) {
+ilogbf_biased(unsigned v)
+{
 	int r = -22;
 
 	if (v & 0xffff0000)
 		r += 16, v >>= 16;
+
 	if (v & 0xff00)
 		r += 8, v >>= 8;
+
 	if (v & 0xf0)
 		r += 4, v >>= 4;
+
 	v <<= 1;
 	return (r + ((0xffffaa50 >> v) & 0x3));
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 float
-scalblnf(float x, long n) {
-	int *px = (int *) &x, ix, k;
+scalblnf(float x, long n)
+{
+	int *px = (int *)&x, ix, k;
 
 	ix = *px & ~0x80000000;
 	k = ix >> 23;
+
 	if (k == 0xff)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (ix > 0x7f800000 ? x * x : x);
 #else
 		return (x + x);
 #endif
+
 	if (ix == 0 || n == 0)
 		return (x);
+
 	if (k == 0) {
 #if defined(__x86)
 		x *= two23f;
@@ -77,15 +87,20 @@
 		*px = (*px & 0x80000000) | (ix << (-k + 1));
 #endif
 	}
-	k += (int) n;
+
+	k += (int)n;
+
 	if (n > 5000 || k > 0xfe)
 		return (FLT_MAX * copysignf(FLT_MAX, x));
+
 	if (n < -5000 || k <= -25)
 		return (FLT_MIN * copysignf(FLT_MIN, x));
+
 	if (k > 0) {
 		*px = (*px & ~0x7f800000) | (k << 23);
 		return (x);
 	}
+
 	k += 25;
 	*px = (*px & ~0x7f800000) | (k << 23);
 	return (x * twom25f);
--- old/usr/src/lib/libm/common/m9x/scalblnl.c	2019-06-06 20:40:37.242808196 +0000
+++ new/usr/src/lib/libm/common/m9x/scalblnl.c	2019-06-06 20:40:37.261066999 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,50 +31,61 @@
 #pragma weak __scalblnl = scalblnl
 
 #include "libm.h"
-#include <float.h>		/* LDBL_MAX, LDBL_MIN */
+#include <float.h>			/* LDBL_MAX, LDBL_MIN */
 
 #if defined(__sparc)
-#define	XSET_EXP(k, x)	((int *) &x)[0] = (((int *) &x)[0] & ~0x7fff0000) | \
-				(k << 16)
-#define	ISINFNANL(k, x)	(k == 0x7fff)
-#define	XTWOT_OFFSET	113
-static const long double xtwot = 10384593717069655257060992658440192.0L,
-								/* 2^113 */
+#define	XSET_EXP(k, x)			((int *)&x)[0] = (((int *)&x)[0] & \
+	    ~0x7fff0000) | (k << 16)
+#define	ISINFNANL(k, x)			(k == 0x7fff)
+#define	XTWOT_OFFSET			113
+
+static const long double
+	xtwot = 10384593717069655257060992658440192.0L, /* 2^113 */
 	twomtm1 = 4.814824860968089632639944856462318296E-35L;	/* 2^-114 */
 #elif defined(__x86)
-#define	XSET_EXP(k, x)	((int *) &x)[2] = (((int *) &x)[2] & ~0x7fff) | k
+#define	XSET_EXP(k, x)			((int *)&x)[2] = (((int *)&x)[2] & \
+	    ~0x7fff) | k
 #if defined(HANDLE_UNSUPPORTED)
-#define      ISINFNANL(k, x) (k == 0x7fff || \
-                        (k != 0 && (((int *) &x)[1] & 0x80000000) == 0))
+#define	ISINFNANL(k, x)		(k == 0x7fff || (k != 0 && \
+	(((int *)&x)[1] & 0x80000000) == 0))
 #else
-#define	ISINFNANL(k, x)	(k == 0x7fff)
+#define	ISINFNANL(k, x)			(k == 0x7fff)
 #endif
-#define	XTWOT_OFFSET	64
+#define	XTWOT_OFFSET			64
+
 static const long double xtwot = 18446744073709551616.0L,	/* 2^64 */
 	twomtm1 = 2.7105054312137610850186E-20L;		/* 2^-65 */
 #endif
 
 long double
-scalblnl(long double x, long n) {
+scalblnl(long double x, long n)
+{
 	int k = XBIASED_EXP(x);
 
 	if (ISINFNANL(k, x))
 		return (x + x);
+
 	if (ISZEROL(x) || n == 0)
 		return (x);
+
 	if (k == 0) {
 		x *= xtwot;
 		k = XBIASED_EXP(x) - XTWOT_OFFSET;
 	}
-	k += (int) n;
+
+	k += (int)n;
+
 	if (n > 50000 || k > 0x7ffe)
 		return (LDBL_MAX * copysignl(LDBL_MAX, x));
+
 	if (n < -50000 || k <= -XTWOT_OFFSET - 1)
 		return (LDBL_MIN * copysignl(LDBL_MIN, x));
+
 	if (k > 0) {
 		XSET_EXP(k, x);
 		return (x);
 	}
+
 	k += XTWOT_OFFSET + 1;
 	XSET_EXP(k, x);
 	return (x * twomtm1);
--- old/usr/src/lib/libm/common/m9x/tgamma.c	2019-06-06 20:40:37.732554113 +0000
+++ new/usr/src/lib/libm/common/m9x/tgamma.c	2019-06-06 20:40:37.751336162 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -29,14 +30,14 @@
 
 #pragma weak __tgamma = tgamma
 
-/* INDENT OFF */
+/* BEGIN CSTYLED */
 /*
  * True gamma function
  * double tgamma(double x)
  *
  * Error:
  * ------
- *  	Less that one ulp for both positive and negative arguments.
+ *      Less that one ulp for both positive and negative arguments.
  *
  * Algorithm:
  * ---------
@@ -45,7 +46,7 @@
  *		(2) Underflow Threshold
  *		(3) Reduction to gamma(1+x)
  *	B: For x between 1 and 2
- * 	C: For x between 0 and 1
+ *      C: For x between 0 and 1
  *	D: For x between 2 and 8
  *	E: Overflow thresold {see over.c}
  *	F: For overflow_threshold >= x >= 8
@@ -93,9 +94,9 @@
  *	   (II)  t = 0.5-z   when 0.31830...  <= z < 0.681690...
  *	   (III) t = 1-z     when 0.681690... <= z < 1.00000
  *	and correspondingly
- *	   (I)   kpsin(z) = kpsin(t)  	... 0<= z < 0.3184
- *	   (II)  kpsin(z) = kpcos(t) 	... |t|   < 0.182
- *	   (III) kpsin(z) = kpsin(t) 	... 0<= t < 0.3184
+ *	   (I)   kpsin(z) = kpsin(t)    ... 0<= z < 0.3184
+ *	   (II)  kpsin(z) = kpcos(t)    ... |t|   < 0.182
+ *	   (III) kpsin(z) = kpsin(t)    ... 0<= t < 0.3184
  *
  *	Using a special Remez algorithm, we obtain the following polynomial
  *	approximation for kpsin(t) for 0<=t<0.3184:
@@ -144,7 +145,7 @@
  *
  *	Computation note: in simulating higher precision arithmetic, kcpsin
  *	return head = t and tail = kc[0]*t^3 + (...) to maintain extra bits
- *   	precision.
+ *      precision.
  *
  *	And for kpcos(t) for |t|< 0.183:
  *
@@ -192,19 +193,19 @@
  *	For z in (I)
  *                                    k+1
  *			          (-1)
- * 		gamma(-x) = ------------------- ;
+ *              gamma(-x) = ------------------- ;
  *		            kpsin(z)*gamma(1+x)
  *
  *	otherwise, for z in (II),
  *                                      k+1
  *			            (-1)
- * 		gamma(-x) = ----------------------- ;
+ *              gamma(-x) = ----------------------- ;
  *			    kpcos(0.5-z)*gamma(1+x)
  *
  *	otherwise, for z in (III),
  *                                      k+1
  *			            (-1)
- * 		gamma(-x) = --------------------- .
+ *              gamma(-x) = --------------------- .
  *		            kpsin(1-z)*gamma(1+x)
  *
  *	Thus, the computation of gamma(-x) reduced to the computation of
@@ -212,11 +213,11 @@
  *
  * (B) For x between 1 and 2.  We break [1,2] into three parts:
  *	GT1 = [1.0000, 1.2845]
- * 	GT2 = [1.2844, 1.6374]
- * 	GT3 = [1.6373, 2.0000]
+ *      GT2 = [1.2844, 1.6374]
+ *      GT3 = [1.6373, 2.0000]
  *
  *    For x in GTi, i=1,2,3, let
- * 	z1  =  1.134861805732790769689793935774652917006
+ *      z1  =  1.134861805732790769689793935774652917006
  *	gz1 = gamma(z1)  =   0.9382046279096824494097535615803269576988
  *	tz1 = gamma'(z1) =  -0.3517214357852935791015625000000000000000
  *
@@ -320,7 +321,7 @@
  *       p3[4] =   1.76308239242717268530498313416899188157165183405e-0002
  *
  *    Coefficents: Double precision
- * 	i = 1:
+ *      i = 1:
  *       p1[0]   =   0.70908683619977797008004927192814648151397705078125000
  *       p1[1]   =   1.71987061393048558089579513384356441668351720061e-0001
  *       p1[2]   =  -3.19273345791990970293320316122813960527705450671e-0002
@@ -332,7 +333,7 @@
  *       q1[3]   =  -1.19345944932265559769719470515102012246995255372e-0001
  *       q1[4]   =   1.59913445751425002620935120470781382215050284762e-0002
  *	 q1[5]   =   1.12601136853374984566572691306402321911547550783e-0003
- * 	i = 2:
+ *      i = 2:
  *       p2[0]   =   0.42848681585558601181418225678498856723308563232421875
  *       p2[1]   =   6.53596762668970816023718845105667418483122103629e-0002
  *       p2[2]   =  -6.97280829631212931321050770925128264272768936731e-0003
@@ -344,7 +345,7 @@
  *       q2[4]   =   2.43574726993169566475227642128830141304953840502e-0002
  *       q2[5]   =  -5.20390406466942525358645957564897411258667085501e-0003
  *       q2[6]   =   4.79520251383279837635552431988023256031951133885e-0004
- * 	i = 3:
+ *      i = 3:
  *	 p3[0]   =   0.382409479734567459008331979930517263710498809814453125
  *       p3[1]   =   1.42876048697668161599069814043449301572928034140e-0001
  *       p3[2]   =   3.42157571052250536817923866013561760785748899071e-0003
@@ -361,7 +362,7 @@
  *    special Remez Algorithm.
  *
  *    Coefficents: Quad precision
- * 	i = 1:
+ *      i = 1:
  *       p1[0] =   0.709086836199777919037185741507610124611513720557
  *       p1[1] =   4.45754781206489035827915969367354835667391606951e-0001
  *       p1[2] =   3.21049298735832382311662273882632210062918153852e-0002
@@ -382,7 +383,7 @@
  *       q1[7] =  -3.12653708152290867248931925120380729518332507388e-0004
  *       q1[8] =   2.36672170850409745237358105667757760527014332458e-0005
  *
- * 	i = 2:
+ *      i = 2:
  *       p2[0] =   0.428486815855585429730209907810650616737756697477
  *       p2[1] =   2.63622124067885222919192651151581541943362617352e-0001
  *       p2[2] =   3.85520683670028865731877276741390421744971446855e-0002
@@ -443,7 +444,7 @@
  *	  0 <  --- - gamma(x) <= ---  -  ----------- < 0.578
  *              x                 x      x(1+0.578x)
  *                                     1       1                        -P
- * 	The error is thus bounded by --- ulp(---) + 0.578. Since x <= 2   ,
+ *      The error is thus bounded by --- ulp(---) + 0.578. Since x <= 2   ,
  *                                     2       x
  *       1      P       1           P                                      1
  *	--- >= 2 , ulp(---) >= ulp(2  ) >= 2. Thus 0.578=0.289*2<=0.289ulp(-)
@@ -458,7 +459,7 @@
  *                            n                             1
  *	except only when x = 2 , (n<= -53). In such cases, --- is exact
  *                                                          x
- * 	and therefore the error is bounded by
+ *      and therefore the error is bounded by
  *                         1
  *		0.298*ulp(---) = 0.298*2*ulp(gamma(x)) = 0.578ulp(gamma(x)).
  *                         x
@@ -542,10 +543,10 @@
  *    The range of L1,L2, and L3 are as follows:
  *
  *	------------------------------------------------------------------
- *  	Range(L1) =  (single) [8.09..,88.30..]	 =[2** 3.01..,2**  6.46..]
+ *      Range(L1) =  (single) [8.09..,88.30..]	 =[2** 3.01..,2**  6.46..]
  *                   (double) [8.09..,709.3..]   =[2** 3.01..,2**  9.47..]
  *		     (quad)   [8.09..,11356.10..]=[2** 3.01..,2** 13.47..]
- *  	Range(L2) = 0.41893853.....
+ *      Range(L2) = 0.41893853.....
  *	Range(L3) = [0.0104...., 0.00048....]	 =[2**-6.58..,2**-11.02..]
  *	------------------------------------------------------------------
  *
@@ -612,7 +613,7 @@
  *    For T3, let s = --------; then ----- =  ----- and
  *                     y+z(i)         z(i)     1-s
  *                1+s           2   3    2   5
- *    	T3 = log(-----) = 2s + --- s  + --- s  + ....
+ *      T3 = log(-----) = 2s + --- s  + --- s  + ....
  *                1-s           3        5
  *
  *    Suppose the first term 2s is compute in extra precision. The
@@ -674,7 +675,7 @@
  *	    see "tgammal_log"
  *
  *   The computation of 0.5*(ln(2pi)-1):
- *   	0.5*(ln(2pi)-1) =  0.4189385332046727417803297364056176398614...
+ *      0.5*(ln(2pi)-1) =  0.4189385332046727417803297364056176398614...
  *	split 0.5*(ln(2pi)-1) to hln2pi_h + hln2pi_l, where hln2pi_h is the
  *	leading 21 bits of the constant.
  *	    hln2pi_h= 0.4189383983612060546875
@@ -736,7 +737,7 @@
  *	  = z*(GP0+(z4*(GP2+z4*(GP4+z4*GP6))+z2*(GP1+z4*(GP3+z4*(GP5+z4*GP7)))))
  *
  *   Adding everything up:
- *	t = rr.h*ww.h+hln2pi_h      		... exact
+ *	t = rr.h*ww.h+hln2pi_h                  ... exact
  *	w = (hln2pi_l + ((x-0.5)*ww.l+rr.l*ww.h)) + p
  *
  *   Computing exp(t+w):
@@ -747,11 +748,12 @@
  *	Remez error bound:
  *	|exp(r) - (1+r+Et1*r^2+...+Et5*r^6)| <= 2^(-63).
  */
+/* END CSTYLED */
 
 #include "libm.h"
 
-#define	__HI(x)	((int *) &x)[HIWORD]
-#define	__LO(x)	((unsigned *) &x)[LOWORD]
+#define	__HI(x)		((int *)&x)[HIWORD]
+#define	__LO(x)		((unsigned *)&x)[LOWORD]
 
 struct Double {
 	double h;
@@ -764,10 +766,10 @@
 	+2.0,
 	+0.5,
 	+1.0e-300,
-	+6.66666666666666740682e-01,				/* A1=T3[0] */
-	+3.99999999955626478023093908674902212920e-01,		/* A2=T3[1] */
-	+2.85720221533145659809237398709372330980e-01,		/* A3=T3[2] */
-	+0.0833333333333333287074040640618477,			/* GP[0] */
+	+6.66666666666666740682e-01,	/* A1=T3[0] */
+	+3.99999999955626478023093908674902212920e-01,	/* A2=T3[1] */
+	+2.85720221533145659809237398709372330980e-01,	/* A3=T3[2] */
+	+0.0833333333333333287074040640618477,		/* GP[0] */
 	-2.77777777776649355200565611114627670089130772843e-03,
 	+7.93650787486083724805476194170211775784158551509e-04,
 	-5.95236628558314928757811419580281294593903582971e-04,
@@ -788,32 +790,32 @@
 	+1.38889201930843436040204096950052984793587640227e-03,	/* Et5 */
 };
 
-#define	one	  c[0]
-#define	two	  c[1]
-#define	half	  c[2]
-#define	tiny	  c[3]
-#define	A1	  c[4]
-#define	A2	  c[5]
-#define	A3	  c[6]
-#define	GP0	  c[7]
-#define	GP1	  c[8]
-#define	GP2	  c[9]
-#define	GP3	  c[10]
-#define	GP4	  c[11]
-#define	GP5	  c[12]
-#define	GP6	  c[13]
-#define	GP7	  c[14]
-#define	hln2pi_h  c[15]
-#define	hln2pi_l  c[16]
-#define	hln2pi	  c[17]
-#define	ln2_32hi  c[18]
-#define	ln2_32lo  c[19]
-#define	invln2_32 c[20]
-#define	Et1	  c[21]
-#define	Et2	  c[22]
-#define	Et3	  c[23]
-#define	Et4	  c[24]
-#define	Et5	  c[25]
+#define	one		c[0]
+#define	two		c[1]
+#define	half		c[2]
+#define	tiny		c[3]
+#define	A1		c[4]
+#define	A2		c[5]
+#define	A3		c[6]
+#define	GP0		c[7]
+#define	GP1		c[8]
+#define	GP2		c[9]
+#define	GP3		c[10]
+#define	GP4		c[11]
+#define	GP5		c[12]
+#define	GP6		c[13]
+#define	GP7		c[14]
+#define	hln2pi_h	c[15]
+#define	hln2pi_l	c[16]
+#define	hln2pi		c[17]
+#define	ln2_32hi	c[18]
+#define	ln2_32lo	c[19]
+#define	invln2_32	c[20]
+#define	Et1		c[21]
+#define	Et2		c[22]
+#define	Et3		c[23]
+#define	Et4		c[24]
+#define	Et5		c[25]
 
 /*
  * double precision coefficients for computing log(x)-1 in tgamma.
@@ -990,73 +992,73 @@
 
 /* S[j],S_trail[j] = 2**(j/32.) for the final computation of exp(t+w) */
 static const double S[] = {
-	+1.00000000000000000000e+00,	/* 3FF0000000000000 */
-	+1.02189714865411662714e+00,	/* 3FF059B0D3158574 */
-	+1.04427378242741375480e+00,	/* 3FF0B5586CF9890F */
-	+1.06714040067682369717e+00,	/* 3FF11301D0125B51 */
-	+1.09050773266525768967e+00,	/* 3FF172B83C7D517B */
-	+1.11438674259589243221e+00,	/* 3FF1D4873168B9AA */
-	+1.13878863475669156458e+00,	/* 3FF2387A6E756238 */
-	+1.16372485877757747552e+00,	/* 3FF29E9DF51FDEE1 */
-	+1.18920711500272102690e+00,	/* 3FF306FE0A31B715 */
-	+1.21524735998046895524e+00,	/* 3FF371A7373AA9CB */
-	+1.24185781207348400201e+00,	/* 3FF3DEA64C123422 */
-	+1.26905095719173321989e+00,	/* 3FF44E086061892D */
-	+1.29683955465100964055e+00,	/* 3FF4BFDAD5362A27 */
-	+1.32523664315974132322e+00,	/* 3FF5342B569D4F82 */
-	+1.35425554693689265129e+00,	/* 3FF5AB07DD485429 */
-	+1.38390988196383202258e+00,	/* 3FF6247EB03A5585 */
-	+1.41421356237309514547e+00,	/* 3FF6A09E667F3BCD */
-	+1.44518080697704665027e+00,	/* 3FF71F75E8EC5F74 */
-	+1.47682614593949934623e+00,	/* 3FF7A11473EB0187 */
-	+1.50916442759342284141e+00,	/* 3FF82589994CCE13 */
-	+1.54221082540794074411e+00,	/* 3FF8ACE5422AA0DB */
-	+1.57598084510788649659e+00,	/* 3FF93737B0CDC5E5 */
-	+1.61049033194925428347e+00,	/* 3FF9C49182A3F090 */
-	+1.64575547815396494578e+00,	/* 3FFA5503B23E255D */
-	+1.68179283050742900407e+00,	/* 3FFAE89F995AD3AD */
-	+1.71861929812247793414e+00,	/* 3FFB7F76F2FB5E47 */
-	+1.75625216037329945351e+00,	/* 3FFC199BDD85529C */
-	+1.79470907500310716820e+00,	/* 3FFCB720DCEF9069 */
-	+1.83400808640934243066e+00,	/* 3FFD5818DCFBA487 */
-	+1.87416763411029996256e+00,	/* 3FFDFC97337B9B5F */
-	+1.91520656139714740007e+00,	/* 3FFEA4AFA2A490DA */
-	+1.95714412417540017941e+00,	/* 3FFF50765B6E4540 */
+	+1.00000000000000000000e+00, /* 3FF0000000000000 */
+	+1.02189714865411662714e+00, /* 3FF059B0D3158574 */
+	+1.04427378242741375480e+00, /* 3FF0B5586CF9890F */
+	+1.06714040067682369717e+00, /* 3FF11301D0125B51 */
+	+1.09050773266525768967e+00, /* 3FF172B83C7D517B */
+	+1.11438674259589243221e+00, /* 3FF1D4873168B9AA */
+	+1.13878863475669156458e+00, /* 3FF2387A6E756238 */
+	+1.16372485877757747552e+00, /* 3FF29E9DF51FDEE1 */
+	+1.18920711500272102690e+00, /* 3FF306FE0A31B715 */
+	+1.21524735998046895524e+00, /* 3FF371A7373AA9CB */
+	+1.24185781207348400201e+00, /* 3FF3DEA64C123422 */
+	+1.26905095719173321989e+00, /* 3FF44E086061892D */
+	+1.29683955465100964055e+00, /* 3FF4BFDAD5362A27 */
+	+1.32523664315974132322e+00, /* 3FF5342B569D4F82 */
+	+1.35425554693689265129e+00, /* 3FF5AB07DD485429 */
+	+1.38390988196383202258e+00, /* 3FF6247EB03A5585 */
+	+1.41421356237309514547e+00, /* 3FF6A09E667F3BCD */
+	+1.44518080697704665027e+00, /* 3FF71F75E8EC5F74 */
+	+1.47682614593949934623e+00, /* 3FF7A11473EB0187 */
+	+1.50916442759342284141e+00, /* 3FF82589994CCE13 */
+	+1.54221082540794074411e+00, /* 3FF8ACE5422AA0DB */
+	+1.57598084510788649659e+00, /* 3FF93737B0CDC5E5 */
+	+1.61049033194925428347e+00, /* 3FF9C49182A3F090 */
+	+1.64575547815396494578e+00, /* 3FFA5503B23E255D */
+	+1.68179283050742900407e+00, /* 3FFAE89F995AD3AD */
+	+1.71861929812247793414e+00, /* 3FFB7F76F2FB5E47 */
+	+1.75625216037329945351e+00, /* 3FFC199BDD85529C */
+	+1.79470907500310716820e+00, /* 3FFCB720DCEF9069 */
+	+1.83400808640934243066e+00, /* 3FFD5818DCFBA487 */
+	+1.87416763411029996256e+00, /* 3FFDFC97337B9B5F */
+	+1.91520656139714740007e+00, /* 3FFEA4AFA2A490DA */
+	+1.95714412417540017941e+00, /* 3FFF50765B6E4540 */
 };
 
 static const double S_trail[] = {
 	+0.00000000000000000000e+00,
-	+5.10922502897344389359e-17,	/* 3C8D73E2A475B465 */
-	+8.55188970553796365958e-17,	/* 3C98A62E4ADC610A */
-	-7.89985396684158212226e-17,	/* BC96C51039449B3A */
-	-3.04678207981247114697e-17,	/* BC819041B9D78A76 */
-	+1.04102784568455709549e-16,	/* 3C9E016E00A2643C */
-	+8.91281267602540777782e-17,	/* 3C99B07EB6C70573 */
-	+3.82920483692409349872e-17,	/* 3C8612E8AFAD1255 */
-	+3.98201523146564611098e-17,	/* 3C86F46AD23182E4 */
-	-7.71263069268148813091e-17,	/* BC963AEABF42EAE2 */
-	+4.65802759183693679123e-17,	/* 3C8ADA0911F09EBC */
-	+2.66793213134218609523e-18,	/* 3C489B7A04EF80D0 */
-	+2.53825027948883149593e-17,	/* 3C7D4397AFEC42E2 */
-	-2.85873121003886075697e-17,	/* BC807ABE1DB13CAC */
-	+7.70094837980298946162e-17,	/* 3C96324C054647AD */
-	-6.77051165879478628716e-17,	/* BC9383C17E40B497 */
-	-9.66729331345291345105e-17,	/* BC9BDD3413B26456 */
-	-3.02375813499398731940e-17,	/* BC816E4786887A99 */
-	-3.48399455689279579579e-17,	/* BC841577EE04992F */
-	-1.01645532775429503911e-16,	/* BC9D4C1DD41532D8 */
-	+7.94983480969762085616e-17,	/* 3C96E9F156864B27 */
-	-1.01369164712783039808e-17,	/* BC675FC781B57EBC */
-	+2.47071925697978878522e-17,	/* 3C7C7C46B071F2BE */
-	-1.01256799136747726038e-16,	/* BC9D2F6EDB8D41E1 */
-	+8.19901002058149652013e-17,	/* 3C97A1CD345DCC81 */
-	-1.85138041826311098821e-17,	/* BC75584F7E54AC3B */
-	+2.96014069544887330703e-17,	/* 3C811065895048DD */
-	+1.82274584279120867698e-17,	/* 3C7503CBD1E949DB */
-	+3.28310722424562658722e-17,	/* 3C82ED02D75B3706 */
-	-6.12276341300414256164e-17,	/* BC91A5CD4F184B5C */
-	-1.06199460561959626376e-16,	/* BC9E9C23179C2893 */
-	+8.96076779103666776760e-17,	/* 3C99D3E12DD8A18B */
+	+5.10922502897344389359e-17, /* 3C8D73E2A475B465 */
+	+8.55188970553796365958e-17, /* 3C98A62E4ADC610A */
+	-7.89985396684158212226e-17, /* BC96C51039449B3A */
+	-3.04678207981247114697e-17, /* BC819041B9D78A76 */
+	+1.04102784568455709549e-16, /* 3C9E016E00A2643C */
+	+8.91281267602540777782e-17, /* 3C99B07EB6C70573 */
+	+3.82920483692409349872e-17, /* 3C8612E8AFAD1255 */
+	+3.98201523146564611098e-17, /* 3C86F46AD23182E4 */
+	-7.71263069268148813091e-17, /* BC963AEABF42EAE2 */
+	+4.65802759183693679123e-17, /* 3C8ADA0911F09EBC */
+	+2.66793213134218609523e-18, /* 3C489B7A04EF80D0 */
+	+2.53825027948883149593e-17, /* 3C7D4397AFEC42E2 */
+	-2.85873121003886075697e-17, /* BC807ABE1DB13CAC */
+	+7.70094837980298946162e-17, /* 3C96324C054647AD */
+	-6.77051165879478628716e-17, /* BC9383C17E40B497 */
+	-9.66729331345291345105e-17, /* BC9BDD3413B26456 */
+	-3.02375813499398731940e-17, /* BC816E4786887A99 */
+	-3.48399455689279579579e-17, /* BC841577EE04992F */
+	-1.01645532775429503911e-16, /* BC9D4C1DD41532D8 */
+	+7.94983480969762085616e-17, /* 3C96E9F156864B27 */
+	-1.01369164712783039808e-17, /* BC675FC781B57EBC */
+	+2.47071925697978878522e-17, /* 3C7C7C46B071F2BE */
+	-1.01256799136747726038e-16, /* BC9D2F6EDB8D41E1 */
+	+8.19901002058149652013e-17, /* 3C97A1CD345DCC81 */
+	-1.85138041826311098821e-17, /* BC75584F7E54AC3B */
+	+2.96014069544887330703e-17, /* 3C811065895048DD */
+	+1.82274584279120867698e-17, /* 3C7503CBD1E949DB */
+	+3.28310722424562658722e-17, /* 3C82ED02D75B3706 */
+	-6.12276341300414256164e-17, /* BC91A5CD4F184B5C */
+	-1.06199460561959626376e-16, /* BC9E9C23179C2893 */
+	+8.96076779103666776760e-17, /* 3C99D3E12DD8A18B */
 };
 
 /* Primary interval GTi() */
@@ -1099,42 +1101,41 @@
 	-2.12950201683609187927899416700094630764182477464e-0003,
 };
 
-#define	P10   cr[0]
-#define	P11   cr[1]
-#define	P12   cr[2]
-#define	P13   cr[3]
-#define	P14   cr[4]
-#define	Q10   cr[5]
-#define	Q11   cr[6]
-#define	Q12   cr[7]
-#define	Q13   cr[8]
-#define	Q14   cr[9]
-#define	Q15   cr[10]
-#define	P20   cr[11]
-#define	P21   cr[12]
-#define	P22   cr[13]
-#define	P23   cr[14]
-#define	Q20   cr[15]
-#define	Q21   cr[16]
-#define	Q22   cr[17]
-#define	Q23   cr[18]
-#define	Q24   cr[19]
-#define	Q25   cr[20]
-#define	Q26   cr[21]
-#define	P30   cr[22]
-#define	P31   cr[23]
-#define	P32   cr[24]
-#define	P33   cr[25]
-#define	P34   cr[26]
-#define	Q30   cr[27]
-#define	Q31   cr[28]
-#define	Q32   cr[29]
-#define	Q33   cr[30]
-#define	Q34   cr[31]
-#define	Q35   cr[32]
+#define	P10		cr[0]
+#define	P11		cr[1]
+#define	P12		cr[2]
+#define	P13		cr[3]
+#define	P14		cr[4]
+#define	Q10		cr[5]
+#define	Q11		cr[6]
+#define	Q12		cr[7]
+#define	Q13		cr[8]
+#define	Q14		cr[9]
+#define	Q15		cr[10]
+#define	P20		cr[11]
+#define	P21		cr[12]
+#define	P22		cr[13]
+#define	P23		cr[14]
+#define	Q20		cr[15]
+#define	Q21		cr[16]
+#define	Q22		cr[17]
+#define	Q23		cr[18]
+#define	Q24		cr[19]
+#define	Q25		cr[20]
+#define	Q26		cr[21]
+#define	P30		cr[22]
+#define	P31		cr[23]
+#define	P32		cr[24]
+#define	P33		cr[25]
+#define	P34		cr[26]
+#define	Q30		cr[27]
+#define	Q31		cr[28]
+#define	Q32		cr[29]
+#define	Q33		cr[30]
+#define	Q34		cr[31]
+#define	Q35		cr[32]
 
-static const double
-	GZ1_h = +0.938204627909682398190,
+static const double GZ1_h = +0.938204627909682398190,
 	GZ1_l = +5.121952600248205157935e-17,
 	GZ2_h = +0.885603194410888749921,
 	GZ2_l = -4.964236872556339810692e-17,
@@ -1142,80 +1143,88 @@
 	GZ3_l = -2.541923110834479415023e-17,
 	TZ1 = -0.3517214357852935791015625,
 	TZ3 = +0.280530631542205810546875;
-/* INDENT ON */
 
-/* compute gamma(y=yh+yl) for y in GT1 = [1.0000, 1.2845] */
-/* assume yh got 20 significant bits */
+/*
+ * compute gamma(y=yh+yl) for y in GT1 = [1.0000, 1.2845]
+ * assume yh got 20 significant bits
+ */
 static struct Double
-GT1(double yh, double yl) {
+GT1(double yh, double yl)
+{
 	double t3, t4, y, z;
 	struct Double r;
 
 	y = yh + yl;
 	z = y * y;
-	t3 = (z * (P10 + y * ((P11 + y * P12) + z * (P13 + y * P14)))) /
-		(Q10 + y * ((Q11 + y * Q12) + z * ((Q13 + Q14 * y) + z * Q15)));
+	t3 = (z * (P10 + y * ((P11 + y * P12) + z * (P13 + y * P14)))) / (Q10 +
+	    y * ((Q11 + y * Q12) + z * ((Q13 + Q14 * y) + z * Q15)));
 	t3 += (TZ1 * yl + GZ1_l);
 	t4 = TZ1 * yh;
-	r.h = (double) ((float) (t4 + GZ1_h + t3));
+	r.h = (double)((float)(t4 + GZ1_h + t3));
 	t3 += (t4 - (r.h - GZ1_h));
 	r.l = t3;
 	return (r);
 }
 
-/* compute gamma(y=yh+yl) for y in GT2 = [1.2844, 1.6374] */
-/* assume yh got 20 significant bits */
+/*
+ * compute gamma(y=yh+yl) for y in GT2 = [1.2844, 1.6374]
+ * assume yh got 20 significant bits
+ */
 static struct Double
-GT2(double yh, double yl) {
+GT2(double yh, double yl)
+{
 	double t3, y, z;
 	struct Double r;
 
 	y = yh + yl;
 	z = y * y;
-	t3 = (z * (P20 + y * P21 + z * (P22 + y * P23))) /
-		(Q20 + (y * ((Q21 + Q22 * y) + z * Q23) +
-		(z * z) * ((Q24 + Q25 * y) + z * Q26))) + GZ2_l;
-	r.h = (double) ((float) (GZ2_h + t3));
+	t3 = (z * (P20 + y * P21 + z * (P22 + y * P23))) / (Q20 + (y * ((Q21 +
+	    Q22 * y) + z * Q23) + (z * z) * ((Q24 + Q25 * y) + z * Q26))) +
+	    GZ2_l;
+	r.h = (double)((float)(GZ2_h + t3));
 	r.l = t3 - (r.h - GZ2_h);
 	return (r);
 }
 
-/* compute gamma(y=yh+yl) for y in GT3 = [1.6373, 2.0000] */
-/* assume yh got 20 significant bits */
+/*
+ * compute gamma(y=yh+yl) for y in GT3 = [1.6373, 2.0000]
+ * assume yh got 20 significant bits
+ */
 static struct Double
-GT3(double yh, double yl) {
+GT3(double yh, double yl)
+{
 	double t3, t4, y, z;
 	struct Double r;
 
 	y = yh + yl;
 	z = y * y;
-	t3 = (z * (P30 + y * ((P31 + y * P32) + z * (P33 + y * P34)))) /
-		(Q30 + y * ((Q31 + y * Q32) + z * ((Q33 + Q34 * y) + z * Q35)));
+	t3 = (z * (P30 + y * ((P31 + y * P32) + z * (P33 + y * P34)))) / (Q30 +
+	    y * ((Q31 + y * Q32) + z * ((Q33 + Q34 * y) + z * Q35)));
 	t3 += (TZ3 * yl + GZ3_l);
 	t4 = TZ3 * yh;
-	r.h = (double) ((float) (t4 + GZ3_h + t3));
+	r.h = (double)((float)(t4 + GZ3_h + t3));
 	t3 += (t4 - (r.h - GZ3_h));
 	r.l = t3;
 	return (r);
 }
 
-/* INDENT OFF */
+
 /*
  * return tgamma(x) scaled by 2**-m for 8<x<=171.62... using Stirling's formula
  *     log(G(x)) ~= (x-.5)*(log(x)-1) + .5(log(2*pi)-1) + (1/x)*P(1/(x*x))
  *                = L1 + L2 + L3,
  */
-/* INDENT ON */
 static struct Double
-large_gam(double x, int *m) {
-	double z, t1, t2, t3, z2, t5, w, y, u, r, z4, v, t24 = 16777216.0,
-		p24 = 1.0 / 16777216.0;
+large_gam(double x, int *m)
+{
+	double z, t1, t2, t3, z2, t5, w, y, u, r, z4, v, t24 = 16777216.0, p24 =
+	    1.0 / 16777216.0;
 	int n2, j2, k, ix, j;
 	unsigned lx;
 	struct Double zz;
 	double u2, ss_h, ss_l, r_h, w_h, w_l, t4;
 
-/* INDENT OFF */
+
 /*
  * compute ss = ss.h+ss.l = log(x)-1 (see tgamma_log.h for details)
  *
@@ -1239,36 +1248,37 @@
  *                       -------------------------------------------
  *                          [leading] + [Trailing]
  */
-/* INDENT ON */
 	ix = __HI(x);
 	lx = __LO(x);
-	n2 = (ix >> 20) - 0x3ff;	/* exponent of x, range:3-7 */
-	n2 += n2;			/* 2n */
+	n2 = (ix >> 20) - 0x3ff;		/* exponent of x, range:3-7 */
+	n2 += n2;				/* 2n */
 	ix = (ix & 0x000fffff) | 0x3ff00000;	/* y = scale x to [1,2] */
 	__HI(y) = ix;
 	__LO(y) = lx;
 	__HI(z) = (ix & 0xffffc000) | 0x2000;	/* z[j]=1+j/64+1/128 */
 	__LO(z) = 0;
-	j2 = (ix >> 13) & 0x7e;	/* 2j */
+	j2 = (ix >> 13) & 0x7e;			/* 2j */
 	t1 = y + z;
 	t2 = y - z;
 	r = one / t1;
-	t1 = (double) ((float) t1);
-	u = r * t2;		/* u = (y-z)/(y+z) */
+	t1 = (double)((float)t1);
+	u = r * t2;			/* u = (y-z)/(y+z) */
 	t4 = T2[j2 + 1] + T1[n2 + 1];
 	z2 = u * u;
 	k = __HI(u) & 0x7fffffff;
 	t3 = T2[j2] + T1[n2];
+
 	if ((k >> 20) < 0x3ec) {	/* |u|<2**-19 */
 		t2 = t4 + u * ((two + z2 * A1) + (z2 * z2) * (A2 + z2 * A3));
 	} else {
 		t5 = t4 + u * (z2 * A1 + (z2 * z2) * (A2 + z2 * A3));
 		u2 = u + u;
-		v = (double) ((int) (u2 * t24)) * p24;
+		v = (double)((int)(u2 * t24)) * p24;
 		t2 = t5 + r * ((two * t2 - v * t1) - v * (y - (t1 - z)));
 		t3 += v;
 	}
-	ss_h = (double) ((float) (t2 + t3));
+
+	ss_h = (double)((float)(t2 + t3));
 	ss_l = t2 - (ss_h - t3);
 
 	/*
@@ -1277,7 +1287,7 @@
 	 */
 	z = one / x;
 	r = x - half;
-	r_h = (double) ((float) r);
+	r_h = (double)((float)r);
 	w_h = r_h * ss_h + hln2pi_h;
 	z2 = z * z;
 	w = (r - r_h) * ss_h + r * ss_l;
@@ -1287,12 +1297,12 @@
 	t1 += t2;
 	w += hln2pi_l;
 	w_l = z * (GP0 + t1) + w;
-	k = (int) ((w_h + w_l) * invln2_32 + half);
+	k = (int)((w_h + w_l) * invln2_32 + half);
 
 	/* compute the exponential of w_h+w_l */
 	j = k & 0x1f;
 	*m = (k >> 5);
-	t3 = (double) k;
+	t3 = (double)k;
 
 	/* perform w - k*ln2_32 (represent as w_h - w_l) */
 	t1 = w_h - t3 * ln2_32hi;
@@ -1312,7 +1322,7 @@
 	return (zz);
 }
 
-/* INDENT OFF */
+
 /*
  * kpsin(x)= sin(pi*x)/pi
  *                 3        5        7        9        11        13        15
@@ -1327,11 +1337,11 @@
 	+1.48413292290051695897242899977121846763824221705e-0004,
 	-6.87730769637543488108688726777687262485357072242e-0006,
 };
-/* INDENT ON */
 
 /* assume x is not tiny and positive */
 static struct Double
-kpsin(double x) {
+kpsin(double x)
+{
 	double z, t1, t2, t3, t4;
 	struct Double xx;
 
@@ -1340,13 +1350,13 @@
 	t1 = z * x;
 	t2 = z * z;
 	t4 = t1 * ks[0];
-	t3 = (t1 * z) * ((ks[1] + z * ks[2] + t2 * ks[3]) + (z * t2) *
-		(ks[4] + z * ks[5] + t2 * ks[6]));
+	t3 = (t1 * z) * ((ks[1] + z * ks[2] + t2 * ks[3]) + (z * t2) * (ks[4] +
+	    z * ks[5] + t2 * ks[6]));
 	xx.l = t4 + t3;
 	return (xx);
 }
 
-/* INDENT OFF */
+
 /*
  * kpcos(x)= cos(pi*x)/pi
  *                     2        4        6        8        10        12
@@ -1354,9 +1364,9 @@
  */
 
 static const double one_pi_h = 0.318309886183790635705292970,
-		one_pi_l = 3.583247455607534006714276420e-17;
+	one_pi_l = 3.583247455607534006714276420e-17;
 static const double npi_2_h = -1.5625,
-		npi_2_l = -0.00829632679489661923132169163975055099555883223;
+	npi_2_l = -0.00829632679489661923132169163975055099555883223;
 static const double kc[] = {
 	-1.57079632679489661923132169163975055099555883223e+0000,
 	+1.29192819501230224953283586722575766189551966008e+0000,
@@ -1365,99 +1375,101 @@
 	-8.21442040906099210866977352284054849051348692715e-0003,
 	+6.10411356829515414575566564733632532333904115968e-0004,
 };
-/* INDENT ON */
 
 /* assume x is not tiny and positive */
 static struct Double
-kpcos(double x) {
+kpcos(double x)
+{
 	double z, t1, t2, t3, t4, x4, x8;
 	struct Double xx;
 
 	z = x * x;
 	xx.h = one_pi_h;
-	t1 = (double) ((float) x);
+	t1 = (double)((float)x);
 	x4 = z * z;
 	t2 = npi_2_l * z + npi_2_h * (x + t1) * (x - t1);
-	t3 = one_pi_l + x4 * ((kc[1] + z * kc[2]) + x4 * (kc[3] + z *
-		kc[4] + x4 * kc[5]));
-	t4 = t1 * t1;	/* 48 bits mantissa */
+	t3 = one_pi_l + x4 * ((kc[1] + z * kc[2]) + x4 * (kc[3] + z * kc[4] +
+	    x4 * kc[5]));
+	t4 = t1 * t1;		/* 48 bits mantissa */
 	x8 = t2 + t3;
-	t4 *= npi_2_h;	/* npi_2_h is 5 bits const. The product is exact */
-	xx.l = x8 + t4;	/* that will minimized the rounding error in xx.l */
+	t4 *= npi_2_h;	  /* npi_2_h is 5 bits const. The product is exact */
+	xx.l = x8 + t4;	  /* that will minimized the rounding error in xx.l */
 	return (xx);
 }
 
-/* INDENT OFF */
 static const double
-	/* 0.134861805732790769689793935774652917006 */
-	t0z1   =  0.1348618057327907737708,
+/* 0.134861805732790769689793935774652917006 */
+	t0z1 = 0.1348618057327907737708,
 	t0z1_l = -4.0810077708578299022531e-18,
-	/* 0.461632144968362341262659542325721328468 */
-	t0z2   =  0.4616321449683623567850,
+/* 0.461632144968362341262659542325721328468 */
+	t0z2 = 0.4616321449683623567850,
 	t0z2_l = -1.5522348162858676890521e-17,
-	/* 0.819773101100500601787868704921606996312 */
-	t0z3   =  0.8197731011005006118708,
+/* 0.819773101100500601787868704921606996312 */
+	t0z3 = 0.8197731011005006118708,
 	t0z3_l = -1.0082945122487103498325e-17;
-	/* 1.134861805732790769689793935774652917006 */
-/* INDENT ON */
+
+/*
+ * 1.134861805732790769689793935774652917006
+ */
 
 /* gamma(x+i) for 0 <= x < 1  */
 static struct Double
-gam_n(int i, double x) {
-	struct Double rr = {0.0L, 0.0L}, yy;
+gam_n(int i, double x)
+{
+	struct Double rr = { 0.0L, 0.0L }, yy;
 	double r1, r2, t2, z, xh, xl, yh, yl, zh, z1, z2, zl, x5, wh, wl;
 
 	/* compute yy = gamma(x+1) */
 	if (x > 0.2845) {
 		if (x > 0.6374) {
 			r1 = x - t0z3;
-			r2 = (double) ((float) (r1 - t0z3_l));
+			r2 = (double)((float)(r1 - t0z3_l));
 			t2 = r1 - r2;
 			yy = GT3(r2, t2 - t0z3_l);
 		} else {
 			r1 = x - t0z2;
-			r2 = (double) ((float) (r1 - t0z2_l));
+			r2 = (double)((float)(r1 - t0z2_l));
 			t2 = r1 - r2;
 			yy = GT2(r2, t2 - t0z2_l);
 		}
 	} else {
 		r1 = x - t0z1;
-		r2 = (double) ((float) (r1 - t0z1_l));
+		r2 = (double)((float)(r1 - t0z1_l));
 		t2 = r1 - r2;
 		yy = GT1(r2, t2 - t0z1_l);
 	}
 
 	/* compute gamma(x+i) = (x+i-1)*...*(x+1)*yy, 0<i<8 */
 	switch (i) {
-	case 0:		/* yy/x */
+	case 0:					/* yy/x */
 		r1 = one / x;
-		xh = (double) ((float) x);	/* x is not tiny */
-		rr.h = (double) ((float) ((yy.h + yy.l) * r1));
-		rr.l = r1 * (yy.h - rr.h * xh) -
-			((r1 * rr.h) * (x - xh) - r1 * yy.l);
+		xh = (double)((float)x);	/* x is not tiny */
+		rr.h = (double)((float)((yy.h + yy.l) * r1));
+		rr.l = r1 * (yy.h - rr.h * xh) - ((r1 * rr.h) * (x - xh) - r1 *
+		    yy.l);
 		break;
-	case 1:		/* yy */
+	case 1:				/* yy */
 		rr.h = yy.h;
 		rr.l = yy.l;
 		break;
-	case 2:		/* (x+1)*yy */
-		z = x + one;	/* may not be exact */
-		zh = (double) ((float) z);
+	case 2:				/* (x+1)*yy */
+		z = x + one;		/* may not be exact */
+		zh = (double)((float)z);
 		rr.h = zh * yy.h;
 		rr.l = z * yy.l + (x - (zh - one)) * yy.h;
 		break;
-	case 3:		/* (x+2)*(x+1)*yy */
+	case 3:				/* (x+2)*(x+1)*yy */
 		z1 = x + one;
 		z2 = x + 2.0;
 		z = z1 * z2;
-		xh = (double) ((float) z);
-		zh = (double) ((float) z1);
+		xh = (double)((float)z);
+		zh = (double)((float)z1);
 		xl = (x - (zh - one)) * (z2 + zh) - (xh - zh * (zh + one));
 		rr.h = xh * yy.h;
 		rr.l = z * yy.l + xl * yy.h;
 		break;
 
-	case 4:		/* (x+1)*(x+3)*(x+2)*yy */
+	case 4:				/* (x+1)*(x+3)*(x+2)*yy */
 		z1 = x + 2.0;
 		z2 = (x + one) * (x + 3.0);
 		zh = z1;
@@ -1465,71 +1477,79 @@
 		__HI(zh) &= 0xfffffff8;	/* zh 18 bits mantissa */
 		zl = x - (zh - 2.0);
 		z = z1 * z2;
-		xh = (double) ((float) z);
+		xh = (double)((float)z);
 		xl = zl * (z2 + zh * (z1 + zh)) - (xh - zh * (zh * zh - one));
 		rr.h = xh * yy.h;
 		rr.l = z * yy.l + xl * yy.h;
 		break;
-	case 5:		/* ((x+1)*(x+4)*(x+2)*(x+3))*yy */
+	case 5:				/* ((x+1)*(x+4)*(x+2)*(x+3))*yy */
 		z1 = x + 2.0;
 		z2 = x + 3.0;
 		z = z1 * z2;
-		zh = (double) ((float) z1);
-		yh = (double) ((float) z);
+		zh = (double)((float)z1);
+		yh = (double)((float)z);
 		yl = (x - (zh - 2.0)) * (z2 + zh) - (yh - zh * (zh + one));
 		z2 = z - 2.0;
 		z *= z2;
-		xh = (double) ((float) z);
+		xh = (double)((float)z);
 		xl = yl * (z2 + yh) - (xh - yh * (yh - 2.0));
 		rr.h = xh * yy.h;
 		rr.l = z * yy.l + xl * yy.h;
 		break;
-	case 6:		/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5))*yy */
+	case 6:				/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5))*yy */
 		z1 = x + 2.0;
 		z2 = x + 3.0;
 		z = z1 * z2;
-		zh = (double) ((float) z1);
-		yh = (double) ((float) z);
+		zh = (double)((float)z1);
+		yh = (double)((float)z);
 		z1 = x - (zh - 2.0);
 		yl = z1 * (z2 + zh) - (yh - zh * (zh + one));
 		z2 = z - 2.0;
 		x5 = x + 5.0;
 		z *= z2;
-		xh = (double) ((float) z);
+		xh = (double)((float)z);
 		zh += 3.0;
 		xl = yl * (z2 + yh) - (xh - yh * (yh - 2.0));
-						/* xh+xl=(x+1)*...*(x+4) */
-		/* wh+wl=(x+5)*yy */
-		wh = (double) ((float) (x5 * (yy.h + yy.l)));
+
+		/*
+		 * xh+xl=(x+1)*...*(x+4)
+		 * wh+wl=(x+5)*yy
+		 */
+		wh = (double)((float)(x5 * (yy.h + yy.l)));
 		wl = (z1 * yy.h + x5 * yy.l) - (wh - zh * yy.h);
 		rr.h = wh * xh;
 		rr.l = z * wl + xl * wh;
 		break;
-	case 7:		/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5)*(x+6))*yy */
+	case 7:			/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5)*(x+6))*yy */
 		z1 = x + 3.0;
 		z2 = x + 4.0;
 		z = z2 * z1;
-		zh = (double) ((float) z1);
-		yh = (double) ((float) z);	/* yh+yl = (x+3)(x+4) */
+		zh = (double)((float)z1);
+		yh = (double)((float)z);	/* yh+yl = (x+3)(x+4) */
 		yl = (x - (zh - 3.0)) * (z2 + zh) - (yh - (zh * (zh + one)));
 		z1 = x + 6.0;
-		z2 = z - 2.0;	/* z2 = (x+2)*(x+5) */
+		z2 = z - 2.0;			/* z2 = (x+2)*(x+5) */
 		z *= z2;
-		xh = (double) ((float) z);
+		xh = (double)((float)z);
 		xl = yl * (z2 + yh) - (xh - yh * (yh - 2.0));
-						/* xh+xl=(x+2)*...*(x+5) */
-		/* wh+wl=(x+1)(x+6)*yy */
-		z2 -= 4.0;	/* z2 = (x+1)(x+6) */
-		wh = (double) ((float) (z2 * (yy.h + yy.l)));
+
+		/*
+		 * xh+xl=(x+2)*...*(x+5)
+		 * wh+wl=(x+1)(x+6)*yy
+		 */
+		z2 -= 4.0;		/* z2 = (x+1)(x+6) */
+		wh = (double)((float)(z2 * (yy.h + yy.l)));
 		wl = (z2 * yy.l + yl * yy.h) - (wh - (yh - 6.0) * yy.h);
 		rr.h = wh * xh;
 		rr.l = z * wl + xl * wh;
 	}
+
 	return (rr);
 }
 
 double
-tgamma(double x) {
+tgamma(double x)
+{
 	struct Double ss, ww;
 	double t, t1, t2, t3, t4, t5, w, y, z, z1, z2, z3, z5;
 	int i, j, k, m, ix, hx, xk;
@@ -1542,28 +1562,34 @@
 
 	if (ix < 0x3ca00000)
 		return (one / x);	/* |x| < 2**-53 */
+
 	if (ix >= 0x7ff00000)
-			/* +Inf -> +Inf, -Inf or NaN -> NaN */
-		return (x * ((hx < 0)? 0.0 : x));
-	if (hx > 0x406573fa ||	/* x > 171.62... overflow to +inf */
+		/* +Inf -> +Inf, -Inf or NaN -> NaN */
+		return (x * ((hx < 0) ? 0.0 : x));
+
+	if (hx > 0x406573fa ||		/* x > 171.62... overflow to +inf */
 	    (hx == 0x406573fa && lx > 0xE561F647)) {
 		z = x / tiny;
 		return (z * z);
 	}
-	if (hx >= 0x40200000) {	/* x >= 8 */
+
+	if (hx >= 0x40200000) {		/* x >= 8 */
 		ww = large_gam(x, &m);
 		w = ww.h + ww.l;
 		__HI(w) += m << 20;
 		return (w);
 	}
-	if (hx > 0) {		/* 0 < x < 8 */
-		i = (int) x;
-		ww = gam_n(i, x - (double) i);
+
+	if (hx > 0) {			/* 0 < x < 8 */
+		i = (int)x;
+		ww = gam_n(i, x - (double)i);
 		return (ww.h + ww.l);
 	}
 
-	/* negative x */
-	/* INDENT OFF */
+	/*
+	 * negative x
+	 */
+
 	/*
 	 * compute: xk =
 	 *	-2 ... x is an even int (-inf is even)
@@ -1571,8 +1597,8 @@
 	 *	+0 ... x is not an int but chopped to an even int
 	 *	+1 ... x is not an int but chopped to an odd int
 	 */
-	/* INDENT ON */
 	xk = 0;
+
 	if (ix >= 0x43300000) {
 		if (ix >= 0x43400000)
 			xk = -2;
@@ -1580,31 +1606,36 @@
 			xk = -2 + (lx & 1);
 	} else if (ix >= 0x3ff00000) {
 		k = (ix >> 20) - 0x3ff;
+
 		if (k > 20) {
 			j = lx >> (52 - k);
+
 			if ((j << (52 - k)) == lx)
 				xk = -2 + (j & 1);
 			else
 				xk = j & 1;
 		} else {
 			j = ix >> (20 - k);
+
 			if ((j << (20 - k)) == ix && lx == 0)
 				xk = -2 + (j & 1);
 			else
 				xk = j & 1;
 		}
 	}
+
 	if (xk < 0)
 		/* ideally gamma(-n)= (-1)**(n+1) * inf, but c99 expect NaN */
-		return ((x - x) / (x - x));		/* 0/0 = NaN */
-
+		return ((x - x) / (x - x));	/* 0/0 = NaN */
 
 	/* negative underflow thresold */
 	if (ix > 0x4066e000 || (ix == 0x4066e000 && lx > 11)) {
 		/* x < -183.0 - 11ulp */
 		z = tiny / x;
+
 		if (xk == 1)
 			z = -z;
+
 		return (z * tiny);
 	}
 
@@ -1615,15 +1646,18 @@
 	 * gamma(x) = 1/(ss*gamma(1+y))
 	 */
 	y = -x;
-	j = (int) y;
-	z = y - (double) j;
-	if (z > 0.3183098861837906715377675)
+	j = (int)y;
+	z = y - (double)j;
+
+	if (z > 0.3183098861837906715377675) {
 		if (z > 0.6816901138162093284622325)
 			ss = kpsin(one - z);
 		else
 			ss = kpcos(0.5 - z);
-	else
+	} else {
 		ss = kpsin(z);
+	}
+
 	if (xk == 0) {
 		ss.h = -ss.h;
 		ss.l = -ss.l;
@@ -1631,14 +1665,17 @@
 
 	/* Then compute ww = gamma(1+y), note that result scale to 2**m */
 	m = 0;
+
 	if (j < 7) {
 		ww = gam_n(j + 1, z);
 	} else {
 		w = y + one;
+
 		if ((lx & 1) == 0) {	/* y+1 exact (note that y<184) */
 			ww = large_gam(w, &m);
 		} else {
 			t = w - one;
+
 			if (t == y) {	/* y+one exact */
 				ww = large_gam(w, &m);
 			} else {	/* use y*gamma(y) */
@@ -1646,10 +1683,11 @@
 					ww = gam_n(j, z);
 				else
 					ww = large_gam(y, &m);
+
 				t4 = ww.h + ww.l;
-				t1 = (double) ((float) y);
-				t2 = (double) ((float) t4);
-						/* t4 will not be too large */
+				t1 = (double)((float)y);
+				t2 = (double)((float)t4);
+				/* t4 will not be too large */
 				ww.l = y * (ww.l - (t2 - ww.h)) + (y - t1) * t2;
 				ww.h = t1 * t2;
 			}
@@ -1659,17 +1697,17 @@
 	/* compute 1/(ss*ww) */
 	t3 = ss.h + ss.l;
 	t4 = ww.h + ww.l;
-	t1 = (double) ((float) t3);
-	t2 = (double) ((float) t4);
+	t1 = (double)((float)t3);
+	t2 = (double)((float)t4);
 	z1 = ss.l - (t1 - ss.h);	/* (t1,z1) = ss */
 	z2 = ww.l - (t2 - ww.h);	/* (t2,z2) = ww */
 	t3 = t3 * t4;			/* t3 = ss*ww */
 	z3 = one / t3;			/* z3 = 1/(ss*ww) */
 	t5 = t1 * t2;
 	z5 = z1 * t4 + t1 * z2;		/* (t5,z5) = ss*ww */
-	t1 = (double) ((float) t3);	/* (t1,z1) = ss*ww */
+	t1 = (double)((float)t3);	/* (t1,z1) = ss*ww */
 	z1 = z5 - (t1 - t5);
-	t2 = (double) ((float) z3);	/* leading 1/(ss*ww) */
+	t2 = (double)((float)z3);	/* leading 1/(ss*ww) */
 	z2 = z3 * (t2 * z1 - (one - t2 * t1));
 	z = t2 - z2;
 
@@ -1679,6 +1717,7 @@
 		i = hx & 0x80000000;
 		ix = hx ^ i;
 		j = ix >> 20;
+
 		if (j > m) {
 			ix -= m << 20;
 			__HI(z) = ix ^ i;
@@ -1698,5 +1737,6 @@
 			z *= t;
 		}
 	}
+
 	return (z);
 }
--- old/usr/src/lib/libm/common/m9x/tgammaf.c	2019-06-06 20:40:38.402404877 +0000
+++ new/usr/src/lib/libm/common/m9x/tgammaf.c	2019-06-06 20:40:38.420268533 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -47,14 +48,14 @@
 #include <sys/isa_defs.h>
 
 #if defined(_BIG_ENDIAN)
-#define	HIWORD	0
-#define	LOWORD	1
+#define	HIWORD		0
+#define	LOWORD		1
 #else
-#define	HIWORD	1
-#define	LOWORD	0
+#define	HIWORD		1
+#define	LOWORD		0
 #endif
-#define	__HI(x)	((int *) &x)[HIWORD]
-#define	__LO(x)	((unsigned *) &x)[LOWORD]
+#define	__HI(x)		((int *)&x)[HIWORD]
+#define	__LO(x)		((unsigned *)&x)[LOWORD]
 
 /* Coefficients for primary intervals GTi() */
 static const double cr[] = {
@@ -65,7 +66,6 @@
 	-4.54586308717075010784041566069480411732634814899e-0001,
 	+4.20596490915239085459964590559256913498190955233e-0001,
 	-3.57307589712377520978332185838241458642142185789e-0001,
-
 	/* p2 */
 	+4.28486983980295198166056119223984284434264344578e-0001,
 	-1.30704539487709138528680121627899735386650103914e-0001,
@@ -73,92 +73,92 @@
 	-9.22285161346010583774458802067371182158937943507e-0002,
 	+7.19240511767225260740890292605070595560626179357e-0002,
 	-4.88158265593355093703112238534484636193260459574e-0002,
-
 	/* p3 */
 	+3.82409531118807759081121479786092134814808872880e-0001,
 	+2.65309888180188647956400403013495759365167853426e-0002,
 	+8.06815109775079171923561169415370309376296739835e-0002,
 	-1.54821591666137613928840890835174351674007764799e-0002,
 	+1.76308239242717268530498313416899188157165183405e-0002,
-
 	/* GZi and TZi */
 	+0.9382046279096824494097535615803269576988,	/* GZ1 */
 	+0.8856031944108887002788159005825887332080,	/* GZ2 */
 	+0.9367814114636523216188468970808378497426,	/* GZ3 */
-	-0.3517214357852935791015625,	/* TZ1 */
-	+0.280530631542205810546875,	/* TZ3 */
+	-0.3517214357852935791015625,			/* TZ1 */
+	+0.280530631542205810546875,			/* TZ3 */
 };
 
-#define	P10	cr[0]
-#define	P11	cr[1]
-#define	P12	cr[2]
-#define	P13	cr[3]
-#define	P14	cr[4]
-#define	P15	cr[5]
-#define	P20	cr[6]
-#define	P21	cr[7]
-#define	P22	cr[8]
-#define	P23	cr[9]
-#define	P24	cr[10]
-#define	P25	cr[11]
-#define	P30	cr[12]
-#define	P31	cr[13]
-#define	P32	cr[14]
-#define	P33	cr[15]
-#define	P34	cr[16]
-#define	GZ1	cr[17]
-#define	GZ2	cr[18]
-#define	GZ3	cr[19]
-#define	TZ1	cr[20]
-#define	TZ3	cr[21]
+#define	P10		cr[0]
+#define	P11		cr[1]
+#define	P12		cr[2]
+#define	P13		cr[3]
+#define	P14		cr[4]
+#define	P15		cr[5]
+#define	P20		cr[6]
+#define	P21		cr[7]
+#define	P22		cr[8]
+#define	P23		cr[9]
+#define	P24		cr[10]
+#define	P25		cr[11]
+#define	P30		cr[12]
+#define	P31		cr[13]
+#define	P32		cr[14]
+#define	P33		cr[15]
+#define	P34		cr[16]
+#define	GZ1		cr[17]
+#define	GZ2		cr[18]
+#define	GZ3		cr[19]
+#define	TZ1		cr[20]
+#define	TZ3		cr[21]
 
 /* compute gamma(y) for y in GT1 = [1.0000, 1.2845] */
 static double
-GT1(double y) {
+GT1(double y)
+{
 	double z, r;
 
 	z = y * y;
 	r = TZ1 * y + z * ((P10 + y * P11 + z * P12) + (z * y) * (P13 + y *
-		P14 + z * P15));
+	    P14 + z * P15));
 	return (GZ1 + r);
 }
 
 /* compute gamma(y) for y in GT2 = [1.2844, 1.6374] */
 static double
-GT2(double y) {
+GT2(double y)
+{
 	double z;
 
 	z = y * y;
 	return (GZ2 + z * ((P20 + y * P21 + z * P22) + (z * y) * (P23 + y *
-		P24 + z * P25)));
+	    P24 + z * P25)));
 }
 
 /* compute gamma(y) for y in GT3 = [1.6373, 2.0000] */
 static double
-GT3(double y) {
-double z, r;
+GT3(double y)
+{
+	double z, r;
 
 	z = y * y;
 	r = TZ3 * y + z * ((P30 + y * P31 + z * P32) + (z * y) * (P33 + y *
-		P34));
+	    P34));
 	return (GZ3 + r);
 }
 
-/* INDENT OFF */
 static const double c[] = {
-+1.0,
-+2.0,
-+0.5,
-+1.0e-300,
-+6.666717231848518054693623697539230e-0001,			/* A1=T3[0] */
-+8.33333330959694065245736888749042811909994573178e-0002,	/* GP[0] */
--2.77765545601667179767706600890361535225507762168e-0003,	/* GP[1] */
-+7.77830853479775281781085278324621033523037489883e-0004,	/* GP[2] */
-+4.18938533204672741744150788368695779923320328369e-0001,	/* hln2pi   */
-+2.16608493924982901946e-02,					/* ln2_32 */
-+4.61662413084468283841e+01,					/* invln2_32 */
-+5.00004103388988968841156421415669985414073453720e-0001,	/* Et1 */
-+1.66667656752800761782778277828110208108687545908e-0001,	/* Et2 */
+	+1.0,
+	+2.0,
+	+0.5,
+	+1.0e-300,
+	+6.666717231848518054693623697539230e-0001,	/* A1=T3[0] */
+	+8.33333330959694065245736888749042811909994573178e-0002, /* GP[0] */
+	-2.77765545601667179767706600890361535225507762168e-0003, /* GP[1] */
+	+7.77830853479775281781085278324621033523037489883e-0004, /* GP[2] */
+	+4.18938533204672741744150788368695779923320328369e-0001, /* hln2pi   */
+	+2.16608493924982901946e-02, /* ln2_32 */
+	+4.61662413084468283841e+01, /* invln2_32 */
+	+5.00004103388988968841156421415669985414073453720e-0001, /* Et1 */
+	+1.66667656752800761782778277828110208108687545908e-0001, /* Et2 */
 };
 
 #define	one		c[0]
@@ -177,46 +177,46 @@
 
 /* S[j] = 2**(j/32.) for the final computation of exp(w) */
 static const double S[] = {
-+1.00000000000000000000e+00,	/* 3FF0000000000000 */
-+1.02189714865411662714e+00,	/* 3FF059B0D3158574 */
-+1.04427378242741375480e+00,	/* 3FF0B5586CF9890F */
-+1.06714040067682369717e+00,	/* 3FF11301D0125B51 */
-+1.09050773266525768967e+00,	/* 3FF172B83C7D517B */
-+1.11438674259589243221e+00,	/* 3FF1D4873168B9AA */
-+1.13878863475669156458e+00,	/* 3FF2387A6E756238 */
-+1.16372485877757747552e+00,	/* 3FF29E9DF51FDEE1 */
-+1.18920711500272102690e+00,	/* 3FF306FE0A31B715 */
-+1.21524735998046895524e+00,	/* 3FF371A7373AA9CB */
-+1.24185781207348400201e+00,	/* 3FF3DEA64C123422 */
-+1.26905095719173321989e+00,	/* 3FF44E086061892D */
-+1.29683955465100964055e+00,	/* 3FF4BFDAD5362A27 */
-+1.32523664315974132322e+00,	/* 3FF5342B569D4F82 */
-+1.35425554693689265129e+00,	/* 3FF5AB07DD485429 */
-+1.38390988196383202258e+00,	/* 3FF6247EB03A5585 */
-+1.41421356237309514547e+00,	/* 3FF6A09E667F3BCD */
-+1.44518080697704665027e+00,	/* 3FF71F75E8EC5F74 */
-+1.47682614593949934623e+00,	/* 3FF7A11473EB0187 */
-+1.50916442759342284141e+00,	/* 3FF82589994CCE13 */
-+1.54221082540794074411e+00,	/* 3FF8ACE5422AA0DB */
-+1.57598084510788649659e+00,	/* 3FF93737B0CDC5E5 */
-+1.61049033194925428347e+00,	/* 3FF9C49182A3F090 */
-+1.64575547815396494578e+00,	/* 3FFA5503B23E255D */
-+1.68179283050742900407e+00,	/* 3FFAE89F995AD3AD */
-+1.71861929812247793414e+00,	/* 3FFB7F76F2FB5E47 */
-+1.75625216037329945351e+00,	/* 3FFC199BDD85529C */
-+1.79470907500310716820e+00,	/* 3FFCB720DCEF9069 */
-+1.83400808640934243066e+00,	/* 3FFD5818DCFBA487 */
-+1.87416763411029996256e+00,	/* 3FFDFC97337B9B5F */
-+1.91520656139714740007e+00,	/* 3FFEA4AFA2A490DA */
-+1.95714412417540017941e+00,	/* 3FFF50765B6E4540 */
+	+1.00000000000000000000e+00,	/* 3FF0000000000000 */
+	+1.02189714865411662714e+00,	/* 3FF059B0D3158574 */
+	+1.04427378242741375480e+00,	/* 3FF0B5586CF9890F */
+	+1.06714040067682369717e+00,	/* 3FF11301D0125B51 */
+	+1.09050773266525768967e+00,	/* 3FF172B83C7D517B */
+	+1.11438674259589243221e+00,	/* 3FF1D4873168B9AA */
+	+1.13878863475669156458e+00,	/* 3FF2387A6E756238 */
+	+1.16372485877757747552e+00,	/* 3FF29E9DF51FDEE1 */
+	+1.18920711500272102690e+00,	/* 3FF306FE0A31B715 */
+	+1.21524735998046895524e+00,	/* 3FF371A7373AA9CB */
+	+1.24185781207348400201e+00,	/* 3FF3DEA64C123422 */
+	+1.26905095719173321989e+00,	/* 3FF44E086061892D */
+	+1.29683955465100964055e+00,	/* 3FF4BFDAD5362A27 */
+	+1.32523664315974132322e+00,	/* 3FF5342B569D4F82 */
+	+1.35425554693689265129e+00,	/* 3FF5AB07DD485429 */
+	+1.38390988196383202258e+00,	/* 3FF6247EB03A5585 */
+	+1.41421356237309514547e+00,	/* 3FF6A09E667F3BCD */
+	+1.44518080697704665027e+00,	/* 3FF71F75E8EC5F74 */
+	+1.47682614593949934623e+00,	/* 3FF7A11473EB0187 */
+	+1.50916442759342284141e+00,	/* 3FF82589994CCE13 */
+	+1.54221082540794074411e+00,	/* 3FF8ACE5422AA0DB */
+	+1.57598084510788649659e+00,	/* 3FF93737B0CDC5E5 */
+	+1.61049033194925428347e+00,	/* 3FF9C49182A3F090 */
+	+1.64575547815396494578e+00,	/* 3FFA5503B23E255D */
+	+1.68179283050742900407e+00,	/* 3FFAE89F995AD3AD */
+	+1.71861929812247793414e+00,	/* 3FFB7F76F2FB5E47 */
+	+1.75625216037329945351e+00,	/* 3FFC199BDD85529C */
+	+1.79470907500310716820e+00,	/* 3FFCB720DCEF9069 */
+	+1.83400808640934243066e+00,	/* 3FFD5818DCFBA487 */
+	+1.87416763411029996256e+00,	/* 3FFDFC97337B9B5F */
+	+1.91520656139714740007e+00,	/* 3FFEA4AFA2A490DA */
+	+1.95714412417540017941e+00,	/* 3FFF50765B6E4540 */
 };
-/* INDENT ON */
 
-/* INDENT OFF */
+
 /*
  * return tgammaf(x) in double for 8<x<=35.040096283... using Stirling's formula
  *     log(G(x)) ~= (x-.5)*(log(x)-1) + .5(log(2*pi)-1) + (1/x)*P(1/(x*x))
  */
+
 /*
  * compute ss = log(x)-1
  *
@@ -229,83 +229,82 @@
  *  (1) Remez error for T3(s) is bounded by 2**(-35.8)
  *	(see mpremez/work/Log/tgamma_log_2_outr1)
  */
-
-static const double T1[] = { /* T1[j]=(j+3)*log(2)-1 */
-+1.079441541679835928251696364375e+00,
-+1.772588722239781237668928485833e+00,
-+2.465735902799726547086160607291e+00,
+static const double T1[] = {		/* T1[j]=(j+3)*log(2)-1 */
+	+1.079441541679835928251696364375e+00,
+	+1.772588722239781237668928485833e+00,
+	+2.465735902799726547086160607291e+00,
 };
 
-static const double T2[] = {   /* T2[j]=log(1+j/64+1/128) */
-+7.782140442054948947462900061137e-03,
-+2.316705928153437822879916096229e-02,
-+3.831886430213659919375532512380e-02,
-+5.324451451881228286587019378653e-02,
-+6.795066190850774939456527777263e-02,
-+8.244366921107459126816006866831e-02,
-+9.672962645855111229557105648746e-02,
-+1.108143663402901141948061693232e-01,
-+1.247034785009572358634065153809e-01,
-+1.384023228591191356853258736016e-01,
-+1.519160420258419750718034248969e-01,
-+1.652495728953071628756114492772e-01,
-+1.784076574728182971194002415109e-01,
-+1.913948529996294546092988075613e-01,
-+2.042155414286908915038203861962e-01,
-+2.168739383006143596190895257443e-01,
-+2.293741010648458299914807250461e-01,
-+2.417199368871451681443075159135e-01,
-+2.539152099809634441373232979066e-01,
-+2.659635484971379413391259265375e-01,
-+2.778684510034563061863500329234e-01,
-+2.896332925830426768788930555257e-01,
-+3.012613305781617810128755382338e-01,
-+3.127557100038968883862465596883e-01,
-+3.241194686542119760906707604350e-01,
-+3.353555419211378302571795798142e-01,
-+3.464667673462085809184621884258e-01,
-+3.574558889218037742260094901409e-01,
-+3.683255611587076530482301540504e-01,
-+3.790783529349694583908533456310e-01,
-+3.897167511400252133704636040035e-01,
-+4.002431641270127069293251019951e-01,
-+4.106599249852683859343062031758e-01,
-+4.209692946441296361288671615068e-01,
-+4.311734648183713408591724789556e-01,
-+4.412745608048752294894964416613e-01,
-+4.512746441394585851446923830790e-01,
-+4.611757151221701663679999255979e-01,
-+4.709797152187910125468978560564e-01,
-+4.806885293457519076766184554480e-01,
-+4.903039880451938381503461596457e-01,
-+4.998278695564493298213314152470e-01,
-+5.092619017898079468040749192283e-01,
-+5.186077642080456321529769963648e-01,
-+5.278670896208423851138922177783e-01,
-+5.370414658968836545667292441538e-01,
-+5.461324375981356503823972092312e-01,
-+5.551415075405015927154803595159e-01,
-+5.640701382848029660713842900902e-01,
-+5.729197535617855090927567266263e-01,
-+5.816917396346224825206107537254e-01,
-+5.903874466021763746419167081236e-01,
-+5.990081896460833993816000244617e-01,
-+6.075552502245417955010851527911e-01,
-+6.160298772155140196475659281967e-01,
-+6.244332880118935010425387440547e-01,
-+6.327666695710378295457864685036e-01,
-+6.410311794209312910556013344054e-01,
-+6.492279466251098188908399699053e-01,
-+6.573580727083600301418900232459e-01,
-+6.654226325450904489500926100067e-01,
-+6.734226752121667202979603888010e-01,
-+6.813592248079030689480715595681e-01,
-+6.892332812388089803249143378146e-01,
+static const double T2[] = {		/* T2[j]=log(1+j/64+1/128) */
+	+7.782140442054948947462900061137e-03,
+	+2.316705928153437822879916096229e-02,
+	+3.831886430213659919375532512380e-02,
+	+5.324451451881228286587019378653e-02,
+	+6.795066190850774939456527777263e-02,
+	+8.244366921107459126816006866831e-02,
+	+9.672962645855111229557105648746e-02,
+	+1.108143663402901141948061693232e-01,
+	+1.247034785009572358634065153809e-01,
+	+1.384023228591191356853258736016e-01,
+	+1.519160420258419750718034248969e-01,
+	+1.652495728953071628756114492772e-01,
+	+1.784076574728182971194002415109e-01,
+	+1.913948529996294546092988075613e-01,
+	+2.042155414286908915038203861962e-01,
+	+2.168739383006143596190895257443e-01,
+	+2.293741010648458299914807250461e-01,
+	+2.417199368871451681443075159135e-01,
+	+2.539152099809634441373232979066e-01,
+	+2.659635484971379413391259265375e-01,
+	+2.778684510034563061863500329234e-01,
+	+2.896332925830426768788930555257e-01,
+	+3.012613305781617810128755382338e-01,
+	+3.127557100038968883862465596883e-01,
+	+3.241194686542119760906707604350e-01,
+	+3.353555419211378302571795798142e-01,
+	+3.464667673462085809184621884258e-01,
+	+3.574558889218037742260094901409e-01,
+	+3.683255611587076530482301540504e-01,
+	+3.790783529349694583908533456310e-01,
+	+3.897167511400252133704636040035e-01,
+	+4.002431641270127069293251019951e-01,
+	+4.106599249852683859343062031758e-01,
+	+4.209692946441296361288671615068e-01,
+	+4.311734648183713408591724789556e-01,
+	+4.412745608048752294894964416613e-01,
+	+4.512746441394585851446923830790e-01,
+	+4.611757151221701663679999255979e-01,
+	+4.709797152187910125468978560564e-01,
+	+4.806885293457519076766184554480e-01,
+	+4.903039880451938381503461596457e-01,
+	+4.998278695564493298213314152470e-01,
+	+5.092619017898079468040749192283e-01,
+	+5.186077642080456321529769963648e-01,
+	+5.278670896208423851138922177783e-01,
+	+5.370414658968836545667292441538e-01,
+	+5.461324375981356503823972092312e-01,
+	+5.551415075405015927154803595159e-01,
+	+5.640701382848029660713842900902e-01,
+	+5.729197535617855090927567266263e-01,
+	+5.816917396346224825206107537254e-01,
+	+5.903874466021763746419167081236e-01,
+	+5.990081896460833993816000244617e-01,
+	+6.075552502245417955010851527911e-01,
+	+6.160298772155140196475659281967e-01,
+	+6.244332880118935010425387440547e-01,
+	+6.327666695710378295457864685036e-01,
+	+6.410311794209312910556013344054e-01,
+	+6.492279466251098188908399699053e-01,
+	+6.573580727083600301418900232459e-01,
+	+6.654226325450904489500926100067e-01,
+	+6.734226752121667202979603888010e-01,
+	+6.813592248079030689480715595681e-01,
+	+6.892332812388089803249143378146e-01,
 };
-/* INDENT ON */
 
 static double
-large_gam(double x) {
+large_gam(double x)
+{
 	double ss, zz, z, t1, t2, w, y, u;
 	unsigned lx;
 	int k, ix, j, m;
@@ -323,7 +322,8 @@
 	t2 = y - z;
 	u = t2 / t1;
 	ss = T1[m - 3] + T2[j] + u * (two + A1 * (u * u));
-							/* ss = log(x)-1 */
+	/* ss = log(x)-1 */
+
 	/*
 	 * compute ww = (x-.5)*(log(x)-1) + .5*(log(2pi)-1) + 1/x*(P(1/x^2)))
 	 * where ss = log(x) - 1
@@ -331,74 +331,76 @@
 	z = one / x;
 	zz = z * z;
 	w = ((x - half) * ss + hln2pi) + z * (GP0 + zz * GP1 + (zz * zz) * GP2);
-	k = (int) (w * invln2_32 + half);
+	k = (int)(w * invln2_32 + half);
 
 	/* compute the exponential of w */
 	j = k & 0x1f;
 	m = k >> 5;
-	z = w - (double) k *ln2_32;
+	z = w - (double)k * ln2_32;
 	zz = S[j] * (one + z + (z * z) * (Et1 + z * Et2));
 	__HI(zz) += m << 20;
 	return (zz);
 }
-/* INDENT OFF */
+
+
 /*
  * kpsin(x)= sin(pi*x)/pi
  *                 3        5        7        9
  *	= x+ks[0]*x +ks[1]*x +ks[2]*x +ks[3]*x
  */
 static const double ks[] = {
--1.64493404985645811354476665052005342839447790544e+0000,
-+8.11740794458351064092797249069438269367389272270e-0001,
--1.90703144603551216933075809162889536878854055202e-0001,
-+2.55742333994264563281155312271481108635575331201e-0002,
+	-1.64493404985645811354476665052005342839447790544e+0000,
+	+8.11740794458351064092797249069438269367389272270e-0001,
+	-1.90703144603551216933075809162889536878854055202e-0001,
+	+2.55742333994264563281155312271481108635575331201e-0002,
 };
-/* INDENT ON */
 
 static double
-kpsin(double x) {
+kpsin(double x)
+{
 	double z;
 
 	z = x * x;
 	return (x + (x * z) * ((ks[0] + z * ks[1]) + (z * z) * (ks[2] + z *
-		ks[3])));
+	    ks[3])));
 }
 
-/* INDENT OFF */
+
 /*
  * kpcos(x)= cos(pi*x)/pi
  *                     2        4        6
  *	= kc[0]+kc[1]*x +kc[2]*x +kc[3]*x
  */
 static const double kc[] = {
-+3.18309886183790671537767526745028724068919291480e-0001,
--1.57079581447762568199467875065854538626594937791e+0000,
-+1.29183528092558692844073004029568674027807393862e+0000,
--4.20232949771307685981015914425195471602739075537e-0001,
+	+3.18309886183790671537767526745028724068919291480e-0001,
+	-1.57079581447762568199467875065854538626594937791e+0000,
+	+1.29183528092558692844073004029568674027807393862e+0000,
+	-4.20232949771307685981015914425195471602739075537e-0001,
 };
-/* INDENT ON */
 
 static double
-kpcos(double x) {
+kpcos(double x)
+{
 	double z;
 
 	z = x * x;
 	return (kc[0] + z * (kc[1] + z * kc[2] + (z * z) * kc[3]));
 }
 
-/* INDENT OFF */
-static const double
-t0z1 = 0.134861805732790769689793935774652917006,
-t0z2 = 0.461632144968362341262659542325721328468,
-t0z3 = 0.819773101100500601787868704921606996312;
-	/* 1.134861805732790769689793935774652917006 */
-/* INDENT ON */
+static const double t0z1 = 0.134861805732790769689793935774652917006,
+	t0z2 = 0.461632144968362341262659542325721328468,
+	t0z3 = 0.819773101100500601787868704921606996312;
+
+/*
+ * 1.134861805732790769689793935774652917006
+ */
 
 /*
  * gamma(x+i) for 0 <= x < 1
  */
 static double
-gam_n(int i, double x) {
+gam_n(int i, double x)
+{
 	double rr = 0.0L, yy;
 	double z1, z2;
 
@@ -408,76 +410,82 @@
 			yy = GT3(x - t0z3);
 		else
 			yy = GT2(x - t0z2);
-	} else
+	} else {
 		yy = GT1(x - t0z1);
+	}
 
 	/* compute gamma(x+i) = (x+i-1)*...*(x+1)*yy, 0<i<8 */
 	switch (i) {
-	case 0:		/* yy/x */
+	case 0:				/* yy/x */
 		rr = yy / x;
 		break;
-	case 1:		/* yy */
+	case 1:				/* yy */
 		rr = yy;
 		break;
-	case 2:		/* (x+1)*yy */
+	case 2:				/* (x+1)*yy */
 		rr = (x + one) * yy;
 		break;
-	case 3:		/* (x+2)*(x+1)*yy */
+	case 3:				/* (x+2)*(x+1)*yy */
 		rr = (x + one) * (x + two) * yy;
 		break;
 
-	case 4:		/* (x+1)*(x+3)*(x+2)*yy */
+	case 4:				/* (x+1)*(x+3)*(x+2)*yy */
 		rr = (x + one) * (x + two) * ((x + 3.0) * yy);
 		break;
-	case 5:		/* ((x+1)*(x+4)*(x+2)*(x+3))*yy */
+	case 5:				/* ((x+1)*(x+4)*(x+2)*(x+3))*yy */
 		z1 = (x + two) * (x + 3.0) * yy;
 		z2 = (x + one) * (x + 4.0);
 		rr = z1 * z2;
 		break;
-	case 6:		/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5))*yy */
+	case 6:				/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5))*yy */
 		z1 = (x + two) * (x + 3.0);
 		z2 = (x + 5.0) * yy;
 		rr = z1 * (z1 - two) * z2;
 		break;
-	case 7:		/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5)*(x+6))*yy */
+	case 7:			/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5)*(x+6))*yy */
 		z1 = (x + two) * (x + 3.0);
 		z2 = (x + 5.0) * (x + 6.0) * yy;
 		rr = z1 * (z1 - two) * z2;
 		break;
 	}
+
 	return (rr);
 }
 
 float
-tgammaf(float xf) {
+tgammaf(float xf)
+{
 	float zf;
 	double ss, ww;
 	double x, y, z;
 	int i, j, k, ix, hx, xk;
 
-	hx = *(int *) &xf;
+	hx = *(int *)&xf;
 	ix = hx & 0x7fffffff;
 
-	x = (double) xf;
+	x = (double)xf;
+
 	if (ix < 0x33800000)
-		return (1.0F / xf);	/* |x| < 2**-24 */
+		return (1.0F / xf);			/* |x| < 2**-24 */
 
 	if (ix >= 0x7f800000)
-		return (xf * ((hx < 0)? 0.0F : xf)); /* +-Inf or NaN */
+		return (xf * ((hx < 0) ? 0.0F : xf));	/* +-Inf or NaN */
 
-	if (hx > 0x420C290F) 	/* x > 35.040096283... overflow */
-		return (float)(x / tiny);
+	if (hx > 0x420C290F)	/* x > 35.040096283... overflow */
+		return ((float)(x / tiny));
 
-	if (hx >= 0x41000000)	/* x >= 8 */
-		return ((float) large_gam(x));
+	if (hx >= 0x41000000)				/* x >= 8 */
+		return ((float)large_gam(x));
 
-	if (hx > 0) {		/* 0 < x < 8 */
-		i = (int) xf;
-		return ((float) gam_n(i, x - (double) i));
+	if (hx > 0) {					/* 0 < x < 8 */
+		i = (int)xf;
+		return ((float)gam_n(i, x - (double)i));
 	}
 
-	/* negative x */
-	/* INDENT OFF */
+	/*
+	 * negative x
+	 */
+
 	/*
 	 * compute xk =
 	 *	-2 ... x is an even int (-inf is considered even)
@@ -485,8 +493,8 @@
 	 *	+0 ... x is not an int but chopped to an even int
 	 *	+1 ... x is not an int but chopped to an odd int
 	 */
-	/* INDENT ON */
 	xk = 0;
+
 	if (ix >= 0x4b000000) {
 		if (ix > 0x4b000000)
 			xk = -2;
@@ -495,11 +503,13 @@
 	} else if (ix >= 0x3f800000) {
 		k = (ix >> 23) - 0x7f;
 		j = ix >> (23 - k);
+
 		if ((j << (23 - k)) == ix)
 			xk = -2 + (j & 1);
 		else
 			xk = j & 1;
 	}
+
 	if (xk < 0) {
 		/* 0/0 invalid NaN, ideally gamma(-n)= (-1)**(n+1) * inf */
 		zf = xf - xf;
@@ -507,31 +517,36 @@
 	}
 
 	/* negative underflow thresold */
-	if (ix > 0x4224000B) {	/* x < -(41+11ulp) */
+	if (ix > 0x4224000B) {		/* x < -(41+11ulp) */
 		if (xk == 0)
 			z = -tiny;
 		else
 			z = tiny;
+
 		return ((float)z);
 	}
 
-	/* INDENT OFF */
-	/* now compute gamma(x) by  -1/((sin(pi*y)/pi)*gamma(1+y)), y = -x */
+	/*
+	 * now compute gamma(x) by  -1/((sin(pi*y)/pi)*gamma(1+y)), y = -x
+	 */
+
 	/*
 	 * First compute ss = -sin(pi*y)/pi , so that
 	 * gamma(x) = 1/(ss*gamma(1+y))
 	 */
-	/* INDENT ON */
 	y = -x;
-	j = (int) y;
-	z = y - (double) j;
-	if (z > 0.3183098861837906715377675)
+	j = (int)y;
+	z = y - (double)j;
+
+	if (z > 0.3183098861837906715377675) {
 		if (z > 0.6816901138162093284622325)
 			ss = kpsin(one - z);
 		else
 			ss = kpcos(0.5 - z);
-	else
+	} else {
 		ss = kpsin(z);
+	}
+
 	if (xk == 0)
 		ss = -ss;
 
@@ -542,5 +557,5 @@
 		ww = large_gam(y + one);
 
 	/* return 1/(ss*ww) */
-	return ((float) (one / (ww * ss)));
+	return ((float)(one / (ww * ss)));
 }
--- old/usr/src/lib/libm/common/m9x/tgammal.c	2019-06-06 20:40:38.931527296 +0000
+++ new/usr/src/lib/libm/common/m9x/tgammal.c	2019-06-06 20:40:38.950016610 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,22 +34,23 @@
 #include <sys/isa_defs.h>
 
 #if defined(_BIG_ENDIAN)
-#define	H0_WORD(x)	((unsigned *) &x)[0]
-#define	H3_WORD(x)	((unsigned *) &x)[3]
-#define	CHOPPED(x)	(long double) ((double) (x))
+#define	H0_WORD(x)		((unsigned *)&x)[0]
+#define	H3_WORD(x)		((unsigned *)&x)[3]
+#define	CHOPPED(x)		(long double)((double)(x))
 #else
-#define	H0_WORD(x)	((((int *) &x)[2] << 16) | \
-			(0x0000ffff & (((unsigned *) &x)[1] >> 15)))
-#define	H3_WORD(x)	((unsigned *) &x)[0]
-#define	CHOPPED(x)	(long double) ((float) (x))
+#define	H0_WORD(x)		((((int *)&x)[2] << 16) | (0x0000ffff & \
+	(((unsigned *)&x)[1] >> 15)))
+#define	H3_WORD(x)		((unsigned *)&x)[0]
+#define	CHOPPED(x)		(long double)((float)(x))
 #endif
 
 struct LDouble {
 	long double h, l;
 };
 
-/* INDENT OFF */
-/* Primary interval GTi() */
+/*
+ * Primary interval GTi()
+ */
 static const long double P1[] = {
 	+0.709086836199777919037185741507610124611513720557L,
 	+4.45754781206489035827915969367354835667391606951e-0001L,
@@ -61,8 +63,9 @@
 	+5.68521076168495673844711465407432189190681541547e-0007L,
 	+3.30749673519634895220582062520286565610418952979e-0008L,
 };
+
 static const long double Q1[] = {
-	+1.0+0000L,
+	+1.0 + 0000L,
 	+1.35806511721671070408570853537257079579490650668e+0000L,
 	+2.97567810153429553405327140096063086994072952961e-0001L,
 	-1.52956835982588571502954372821681851681118097870e-0001L,
@@ -72,6 +75,7 @@
 	-3.12653708152290867248931925120380729518332507388e-0004L,
 	+2.36672170850409745237358105667757760527014332458e-0005L,
 };
+
 static const long double P2[] = {
 	+0.428486815855585429730209907810650135255270600668084114L,
 	+2.62768479103809762805691743305424077975230551176e-0001L,
@@ -84,6 +88,7 @@
 	+2.13734755837595695602045100675540011352948958453e-0007L,
 	+9.74123440547918230781670266967882492234877125358e-0009L,
 };
+
 static const long double Q2[] = {
 	+1.0L,
 	+9.18284118632506842664645516830761489700556179701e-0001L,
@@ -96,6 +101,7 @@
 	+3.10019017590151598732360097849672925448587547746e-0005L,
 	-1.77260223349332617658921874288026777465782364070e-0006L,
 };
+
 static const long double P3[] = {
 	+0.3824094797345675048502747661075355640070439388902L,
 	+3.42198093076618495415854906335908427159833377774e-0001L,
@@ -108,9 +114,9 @@
 	+9.66243228508380420159234853278906717065629721016e-0007L,
 	+2.31858885579177250541163820671121664974334728142e-0008L,
 };
+
 static const long double Q3[] = {
-	+1.0L,
-	+8.25479821168813634632437430090376252512793067339e-0001L,
+	+1.0L, +8.25479821168813634632437430090376252512793067339e-0001L,
 	-1.62251363073937769739639623669295110346015576320e-0002L,
 	-1.10621286905916732758745130629426559691187579852e-0001L,
 	+3.48309693970985612644446415789230015515365291459e-0003L,
@@ -123,41 +129,42 @@
 
 static const long double
 #if defined(__x86)
-GZ1_h 	=  0.938204627909682449364570100414084663498215377L,
-GZ1_l   =  4.518346116624229420055327632718530617227944106e-20L,
-GZ2_h 	=  0.885603194410888700264725126309883762587560340L,
-GZ2_l   =  1.409077427270497062039119290776508217077297169e-20L,
-GZ3_h 	=  0.936781411463652321613537060640553022494714241L,
-GZ3_l   =  5.309836440284827247897772963887219035221996813e-21L,
+	GZ1_h = 0.938204627909682449364570100414084663498215377L,
+	GZ1_l = 4.518346116624229420055327632718530617227944106e-20L,
+	GZ2_h = 0.885603194410888700264725126309883762587560340L,
+	GZ2_l = 1.409077427270497062039119290776508217077297169e-20L,
+	GZ3_h = 0.936781411463652321613537060640553022494714241L,
+	GZ3_l = 5.309836440284827247897772963887219035221996813e-21L,
 #else
-GZ1_h 	=  0.938204627909682449409753561580326910854647031L,
-GZ1_l   =  4.684412162199460089642452580902345976446297037e-35L,
-GZ2_h 	=  0.885603194410888700278815900582588658192658794L,
-GZ2_l   =  7.501529273890253789219935569758713534641074860e-35L,
-GZ3_h 	=  0.936781411463652321618846897080837818855399840L,
-GZ3_l   =  3.088721217404784363585591914529361687403776917e-35L,
+	GZ1_h = 0.938204627909682449409753561580326910854647031L,
+	GZ1_l = 4.684412162199460089642452580902345976446297037e-35L,
+	GZ2_h = 0.885603194410888700278815900582588658192658794L,
+	GZ2_l = 7.501529273890253789219935569758713534641074860e-35L,
+	GZ3_h = 0.936781411463652321618846897080837818855399840L,
+	GZ3_l = 3.088721217404784363585591914529361687403776917e-35L,
 #endif
-TZ1	= -0.3517214357852935791015625L,
-TZ3	=  0.280530631542205810546875L;
-/* INDENT ON */
+	TZ1 = -0.3517214357852935791015625L,
+	TZ3 = 0.280530631542205810546875L;
+
 
-/* INDENT OFF */
 /*
  * compute gamma(y=yh+yl) for y in GT1 = [1.0000, 1.2845]
  * ...assume yh got 53 or 24(i386) significant bits
  */
-/* INDENT ON */
 static struct LDouble
-GT1(long double yh, long double yl) {
+GT1(long double yh, long double yl)
+{
 	long double t3, t4, y;
 	int i;
 	struct LDouble r;
 
 	y = yh + yl;
+
 	for (t4 = Q1[8], t3 = P1[8] + y * P1[9], i = 7; i >= 0; i--) {
 		t4 = t4 * y + Q1[i];
 		t3 = t3 * y + P1[i];
 	}
+
 	t3 = (y * y) * t3 / t4;
 	t3 += (TZ1 * yl + GZ1_l);
 	t4 = TZ1 * yh;
@@ -167,46 +174,50 @@
 	return (r);
 }
 
-/* INDENT OFF */
+
 /*
  * compute gamma(y=yh+yl) for y in GT2 = [1.2844, 1.6374]
  * ...assume yh got 53 significant bits
  */
-/* INDENT ON */
 static struct LDouble
-GT2(long double yh, long double yl) {
+GT2(long double yh, long double yl)
+{
 	long double t3, t4, y;
 	int i;
 	struct LDouble r;
 
 	y = yh + yl;
+
 	for (t4 = Q2[9], t3 = P2[9], i = 8; i >= 0; i--) {
 		t4 = t4 * y + Q2[i];
 		t3 = t3 * y + P2[i];
 	}
+
 	t3 = GZ2_l + (y * y) * t3 / t4;
 	r.h = CHOPPED((GZ2_h + t3));
 	r.l = t3 - (r.h - GZ2_h);
 	return (r);
 }
 
-/* INDENT OFF */
+
 /*
  * compute gamma(y=yh+yl) for y in GT3 = [1.6373, 2.0000]
  * ...assume yh got 53 significant bits
  */
-/* INDENT ON */
 static struct LDouble
-GT3(long double yh, long double yl) {
+GT3(long double yh, long double yl)
+{
 	long double t3, t4, y;
 	int i;
 	struct LDouble r;
 
 	y = yh + yl;
+
 	for (t4 = Q3[9], t3 = P3[9], i = 8; i >= 0; i--) {
 		t4 = t4 * y + Q3[i];
 		t3 = t3 * y + P3[i];
 	}
+
 	t3 = (y * y) * t3 / t4;
 	t3 += (TZ3 * yl + GZ3_l);
 	t4 = TZ3 * yh;
@@ -216,8 +227,9 @@
 	return (r);
 }
 
-/* INDENT OFF */
-/* Hex value of GP[0] shoule be 3FB55555 55555555 */
+/*
+ * Hex value of GP[0] shoule be 3FB55555 55555555
+ */
 static const long double GP[] = {
 	+0.083333333333333333333333333333333172839171301L,
 	-2.77777777777777777777777777492501211999399424104e-0003L,
@@ -238,50 +250,51 @@
 	+2.09263249637351298563934942349749718491071093210e+0008L,
 	-2.96247483183169219343745316433899599834685703457e+0009L,
 	+2.88984933605896033154727626086506756972327292981e+0010L,
-	-1.40960434146030007732838382416230610302678063984e+0011L,	/* 19 */
+	-1.40960434146030007732838382416230610302678063984e+0011L, /* 19 */
 };
 
 static const long double T3[] = {
-	+0.666666666666666666666666666666666634567834260213L,	/* T3[0] */
-	+0.400000000000000000000000000040853636176634934140L,	/* T3[1] */
-	+0.285714285714285714285696975252753987869020263448L,	/* T3[2] */
-	+0.222222222222222225593221101192317258554772129875L,	/* T3[3] */
-	+0.181818181817850192105847183461778186703779262916L,	/* T3[4] */
-	+0.153846169861348633757101285952333369222567014596L,	/* T3[5] */
-	+0.133033462889260193922261296772841229985047571265L,	/* T3[6] */
+	+0.666666666666666666666666666666666634567834260213L, /* T3[0] */
+	+0.400000000000000000000000000040853636176634934140L, /* T3[1] */
+	+0.285714285714285714285696975252753987869020263448L, /* T3[2] */
+	+0.222222222222222225593221101192317258554772129875L, /* T3[3] */
+	+0.181818181817850192105847183461778186703779262916L, /* T3[4] */
+	+0.153846169861348633757101285952333369222567014596L, /* T3[5] */
+	+0.133033462889260193922261296772841229985047571265L, /* T3[6] */
 };
-
+/* BEGIN CSTYLED */
 static const long double c[] = {
-0.0L,
-1.0L,
-2.0L,
-0.5L,
-1.0e-4930L,							/* tiny */
-4.18937683105468750000e-01L,					/* hln2pim1_h */
-8.50099203991780329736405617639861397473637783412817152e-07L,	/* hln2pim1_l */
-0.418938533204672741780329736405617639861397473637783412817152L, /* hln2pim1 */
-2.16608493865351192653179168701171875e-02L,			/* ln2_32hi */
-5.96317165397058692545083025235937919875797669127130e-12L,	/* ln2_32lo */
-46.16624130844682903551758979206054839765267053289554989233L,	/* invln2_32 */
+	0.0L,
+	1.0L,
+	2.0L,
+	0.5L,
+	1.0e-4930L,		     /* tiny */
+	4.18937683105468750000e-01L, /* hln2pim1_h */
+	8.50099203991780329736405617639861397473637783412817152e-07L, /* hln2pim1_l */
+	0.418938533204672741780329736405617639861397473637783412817152L, /* hln2pim1 */
+	2.16608493865351192653179168701171875e-02L, /* ln2_32hi */
+	5.96317165397058692545083025235937919875797669127130e-12L, /* ln2_32lo */
+	46.16624130844682903551758979206054839765267053289554989233L, /* invln2_32 */
 #if defined(__x86)
-1.7555483429044629170023839037639845628291e+03L,		/* overflow */
+	1.7555483429044629170023839037639845628291e+03L, /* overflow */
 #else
-1.7555483429044629170038892160702032034177e+03L,		/* overflow */
+	1.7555483429044629170038892160702032034177e+03L, /* overflow */
 #endif
 };
+/* END CSTYLED */
 
-#define	zero		c[0]
-#define	one		c[1]
-#define	two		c[2]
-#define	half		c[3]
-#define	tiny		c[4]
-#define	hln2pim1_h	c[5]
-#define	hln2pim1_l	c[6]
-#define	hln2pim1	c[7]
-#define	ln2_32hi	c[8]
-#define	ln2_32lo	c[9]
-#define	invln2_32	c[10]
-#define	overflow	c[11]
+#define	zero			c[0]
+#define	one			c[1]
+#define	two			c[2]
+#define	half			c[3]
+#define	tiny			c[4]
+#define	hln2pim1_h		c[5]
+#define	hln2pim1_l		c[6]
+#define	hln2pim1		c[7]
+#define	ln2_32hi		c[8]
+#define	ln2_32lo		c[9]
+#define	invln2_32		c[10]
+#define	overflow		c[11]
 
 /*
  * |exp(r) - (1+r+Et0*r^2+...+Et10*r^12)| <= 2^(-128.88) for |r|<=ln2/64
@@ -314,10 +327,10 @@
  *  (2) Remez error for T3(s) is bounded by 2**(-136.54)
  */
 static const long double T1[] = {
--1.000000000000000000000000000000000000000000e+00L,
+	-1.000000000000000000000000000000000000000000e+00L,
 	+0.000000000000000000000000000000000000000000e+00L,
--3.068528175354003906250000000000000000000000e-01L,
--1.904654299957767878541823431924500011926579e-09L,
+	-3.068528175354003906250000000000000000000000e-01L,
+	-1.904654299957767878541823431924500011926579e-09L,
 	+3.862943053245544433593750000000000000000000e-01L,
 	+5.579533617547508924291635313615100141107647e-08L,
 	+1.079441487789154052734375000000000000000000e+00L,
@@ -544,6 +557,7 @@
 	+1.95714412417540026901832225162687149e+00L,
 #endif
 };
+
 static const long double S_trail[] = {
 #if defined(__x86)
 	+0.0000000000000000000000000e+00L,
@@ -581,56 +595,55 @@
 #else
 	+0.00000000000000000000000000000000000e+00L,
 	+1.80506787420330954745573333054573786e-35L,
--9.37452029228042742195756741973083214e-35L,
--1.59696844729275877071290963023149997e-35L,
+	-9.37452029228042742195756741973083214e-35L,
+	-1.59696844729275877071290963023149997e-35L,
 	+9.11249341012502297851168610167248666e-35L,
--6.50422820697854828723037477525938871e-35L,
--8.14846884452585113732569176748815532e-35L,
--5.06621457672180031337233074514290335e-35L,
--1.35983097468881697374987563824591912e-35L,
+	-6.50422820697854828723037477525938871e-35L,
+	-8.14846884452585113732569176748815532e-35L,
+	-5.06621457672180031337233074514290335e-35L,
+	-1.35983097468881697374987563824591912e-35L,
 	+9.49742763556319647030771056643324660e-35L,
--3.28317052317699860161506596533391526e-36L,
--5.01723570938719041029018653045842895e-35L,
--2.39147479768910917162283430160264014e-35L,
--8.35057135763390881529889073794408385e-36L,
+	-3.28317052317699860161506596533391526e-36L,
+	-5.01723570938719041029018653045842895e-35L,
+	-2.39147479768910917162283430160264014e-35L,
+	-8.35057135763390881529889073794408385e-36L,
 	+7.03675688907326504242173719067187644e-35L,
--5.18248485306464645753689301856695619e-35L,
+	-5.18248485306464645753689301856695619e-35L,
 	+9.42224254862183206569211673639406488e-35L,
--3.96750082539886230916730613021641828e-35L,
+	-3.96750082539886230916730613021641828e-35L,
 	+7.14352899156330061452327361509276724e-35L,
 	+1.15987125286798512424651783410044433e-35L,
 	+4.69693347835811549530973921320187447e-35L,
--3.38651317599500471079924198499981917e-35L,
--8.58731877429824706886865593510387445e-35L,
--9.60595154874935050318549936224606909e-35L,
+	-3.38651317599500471079924198499981917e-35L,
+	-8.58731877429824706886865593510387445e-35L,
+	-9.60595154874935050318549936224606909e-35L,
 	+9.60973393212801278450755869714178581e-35L,
 	+6.37839792144002843924476144978084855e-35L,
 	+7.79243078569586424945646112516927770e-35L,
 	+7.36133776758845652413193083663393220e-35L,
--6.47299514791334723003521457561217053e-35L,
+	-6.47299514791334723003521457561217053e-35L,
 	+8.58747441795369869427879806229522962e-35L,
 	+2.37181542282517483569165122830269098e-35L,
--3.02689168209611877300459737342190031e-37L,
+	-3.02689168209611877300459737342190031e-37L,
 #endif
 };
-/* INDENT ON */
 
-/* INDENT OFF */
+
 /*
  * return tgamma(x) scaled by 2**-m for 8<x<=171.62... using Stirling's formula
  *     log(G(x)) ~= (x-.5)*(log(x)-1) + .5(log(2*pi)-1) + (1/x)*P(1/(x*x))
  *                = L1 + L2 + L3,
  */
-/* INDENT ON */
 static struct LDouble
-large_gam(long double x, int *m) {
+large_gam(long double x, int *m)
+{
 	long double z, t1, t2, t3, z2, t5, w, y, u, r, v;
 	long double t24 = 16777216.0L, p24 = 1.0L / 16777216.0L;
 	int n2, j2, k, ix, j, i;
 	struct LDouble zz;
 	long double u2, ss_h, ss_l, r_h, w_h, w_l, t4;
 
-/* INDENT OFF */
+/* BEGIN CSTYLED */
 /*
  * compute ss = ss.h+ss.l = log(x)-1 (see tgamma_log.h for details)
  *
@@ -654,42 +667,44 @@
  *                       -------------------------------------------
  *                          [leading] + [Trailing]
  */
-	/* INDENT ON */
+	/* END CSTYLED */
 	ix = H0_WORD(x);
-	n2 = (ix >> 16) - 0x3fff;	/* exponent of x, range:3-10 */
-	y = scalbnl(x, -n2);	/* y = scale x to [1,2] */
-	n2 += n2;		/* 2n */
-	j = (ix >> 10) & 0x3f;	/* j */
-	z = 1.0078125L + (long double) j * 0.015625L;	/* z[j]=1+j/64+1/128 */
+	n2 = (ix >> 16) - 0x3fff; /* exponent of x, range:3-10 */
+	y = scalbnl(x, -n2);	  /* y = scale x to [1,2] */
+	n2 += n2;		  /* 2n */
+	j = (ix >> 10) & 0x3f;	  /* j */
+	z = 1.0078125L + (long double)j * 0.015625L;	/* z[j]=1+j/64+1/128 */
 	j2 = j + j;
 	t1 = y + z;
 	t2 = y - z;
 	r = one / t1;
-	u = r * t2;		/* u = (y-z)/(y+z) */
+	u = r * t2;			/* u = (y-z)/(y+z) */
 	t1 = CHOPPED(t1);
 	t4 = T2[j2 + 1] + T1[n2 + 1];
 	z2 = u * u;
 	k = H0_WORD(u) & 0x7fffffff;
 	t3 = T2[j2] + T1[n2];
+
 	for (t5 = T3[6], i = 5; i >= 0; i--)
 		t5 = z2 * t5 + T3[i];
+
 	if ((k >> 16) < 0x3fec) {	/* |u|<2**-19 */
 		t2 = t4 + u * (two + z2 * t5);
 	} else {
 		t5 = t4 + (u * z2) * t5;
 		u2 = u + u;
-		v = (long double) ((int) (u2 * t24)) * p24;
+		v = (long double)((int)(u2 * t24)) * p24;
 		t2 = t5 + r * ((two * t2 - v * t1) - v * (y - (t1 - z)));
 		t3 += v;
 	}
+
 	ss_h = CHOPPED((t2 + t3));
 	ss_l = t2 - (ss_h - t3);
-/* INDENT OFF */
+
 /*
  * compute ww = (x-.5)*(log(x)-1) + .5*(log(2pi)-1) + 1/x*(P(1/x^2)))
  * where ss = log(x) - 1 in already in extra precision
  */
-	/* INDENT ON */
 	z = one / x;
 	r = x - half;
 	r_h = CHOPPED((r));
@@ -697,17 +712,19 @@
 	z2 = z * z;
 	w = (r - r_h) * ss_h + r * ss_l;
 	t1 = GP[19];
+
 	for (i = 18; i > 0; i--)
 		t1 = z2 * t1 + GP[i];
+
 	w += hln2pim1_l;
 	w_l = z * (GP[0] + z2 * t1) + w;
-	k = (int) ((w_h + w_l) * invln2_32 + half);
+	k = (int)((w_h + w_l) * invln2_32 + half);
 
 	/* compute the exponential of w_h+w_l */
 
 	j = k & 0x1f;
 	*m = k >> 5;
-	t3 = (long double) k;
+	t3 = (long double)k;
 
 	/* perform w - k*ln2_32 (represent as w_h - w_l) */
 	t1 = w_h - t3 * ln2_32hi;
@@ -718,15 +735,17 @@
 
 	/* compute exp(w_h-w_l) */
 	z = w_h - w_l;
+
 	for (t1 = Et[10], i = 9; i >= 0; i--)
 		t1 = z * t1 + Et[i];
+
 	t3 = w_h - (w_l - (z * z) * t1);	/* t3 = expm1(z) */
 	zz.l = S_trail[j] * (one + t3) + S[j] * t3;
 	zz.h = S[j];
 	return (zz);
 }
 
-/* INDENT OFF */
+
 /*
  * kpsin(x)= sin(pi*x)/pi
  *	           3        5        7        9        11                27
@@ -747,28 +766,30 @@
 	+5.50724992262622033449487808306969135431411753047e-0014L,
 	-7.67678132753577998601234393215802221104236979928e-0016L,
 };
-/* INDENT ON */
 
 /*
  * assume x is not tiny and positive
  */
 static struct LDouble
-kpsin(long double x) {
+kpsin(long double x)
+{
 	long double z, t1, t2;
 	struct LDouble xx;
 	int i;
 
 	z = x * x;
 	xx.h = x;
+
 	for (t2 = ks[12], i = 11; i > 0; i--)
 		t2 = z * t2 + ks[i];
+
 	t1 = z * x;
 	t2 *= z * t1;
 	xx.l = t1 * ks[0] + t2;
 	return (xx);
 }
 
-/* INDENT OFF */
+
 /*
  * kpcos(x)= cos(pi*x)/pi
  *                     2        4        6        8        10        12
@@ -799,15 +820,14 @@
 
 static const long double
 #if defined(__x86)
-one_pi_h = 0.3183098861481994390487670898437500L,	/* 31 bits */
-one_pi_l = 3.559123248900043690127872406891929148e-11L,
+	one_pi_h = 0.3183098861481994390487670898437500L,	/* 31 bits */
+	one_pi_l = 3.559123248900043690127872406891929148e-11L,
 #else
-one_pi_h = 0.31830988618379052468299050815403461456298828125L,
-one_pi_l = 1.46854777018590994109505931010230912897495334688117e-16L,
+	one_pi_h = 0.31830988618379052468299050815403461456298828125L,
+	one_pi_l = 1.46854777018590994109505931010230912897495334688117e-16L,
 #endif
-npi_2_h = -1.570796310901641845703125000000000L,
-npi_2_l = -1.5893254773528196691639751442098584699687552910e-8L;
-
+	npi_2_h = -1.570796310901641845703125000000000L,
+	npi_2_l = -1.5893254773528196691639751442098584699687552910e-8L;
 static const long double kc[] = {
 	+1.29192819501249250731151312779548918765320728489e+0000L,
 	-4.25027339979557573976029596929319207009444090366e-0001L,
@@ -820,24 +840,26 @@
 	+1.14741409212381858820016567664488123478660705759e-0009L,
 	-2.44261236114707374558437500654381006300502749632e-0011L,
 };
-/* INDENT ON */
 
 /*
  * assume x is not tiny and positive
  */
 static struct LDouble
-kpcos(long double x) {
+kpcos(long double x)
+{
 	long double z, t1, t2, t3, t4, x4, x8;
 	int i;
 	struct LDouble xx;
 
 	z = x * x;
 	xx.h = one_pi_h;
-	t1 = (long double) ((float) x);
+	t1 = (long double)((float)x);
 	x4 = z * z;
 	t2 = npi_2_l * z + npi_2_h * (x + t1) * (x - t1);
+
 	for (i = 8, t3 = kc[9]; i >= 0; i--)
 		t3 = z * t3 + kc[i];
+
 	t3 = one_pi_l + x4 * t3;
 	t4 = t1 * t1 * npi_2_h;
 	x8 = t2 + t3;
@@ -845,41 +867,40 @@
 	return (xx);
 }
 
-/* INDENT OFF */
 static const long double
-	/* 0.13486180573279076968979393577465291700642511139552429398233 */
+/* 0.13486180573279076968979393577465291700642511139552429398233 */
 #if defined(__x86)
-t0z1   =  0.1348618057327907696779385054997035808810L,
-t0z1_l =  1.1855430274949336125392717150257379614654e-20L,
+	t0z1 = 0.1348618057327907696779385054997035808810L,
+	t0z1_l = 1.1855430274949336125392717150257379614654e-20L,
 #else
-t0z1   =  0.1348618057327907696897939357746529168654L,
-t0z1_l =  1.4102088588676879418739164486159514674310e-37L,
+	t0z1 = 0.1348618057327907696897939357746529168654L,
+	t0z1_l = 1.4102088588676879418739164486159514674310e-37L,
 #endif
-	/* 0.46163214496836234126265954232572132846819620400644635129599 */
+/* 0.46163214496836234126265954232572132846819620400644635129599 */
 #if defined(__x86)
-t0z2   =  0.4616321449683623412538115843295472018326L,
-t0z2_l =  8.84795799617412663558532305039261747030640e-21L,
+	t0z2 = 0.4616321449683623412538115843295472018326L,
+	t0z2_l = 8.84795799617412663558532305039261747030640e-21L,
 #else
-t0z2   =  0.46163214496836234126265954232572132343318L,
-t0z2_l =  5.03501162329616380465302666480916271611101e-36L,
+	t0z2 = 0.46163214496836234126265954232572132343318L,
+	t0z2_l = 5.03501162329616380465302666480916271611101e-36L,
 #endif
-	/* 0.81977310110050060178786870492160699631174407846245179119586 */
+/* 0.81977310110050060178786870492160699631174407846245179119586 */
 #if defined(__x86)
-t0z3   =  0.81977310110050060178773362329351925836817L,
-t0z3_l =  1.350816280877379435658077052534574556256230e-22L
+	t0z3 = 0.81977310110050060178773362329351925836817L,
+	t0z3_l = 1.350816280877379435658077052534574556256230e-22L
 #else
-t0z3   =  0.8197731011005006017878687049216069516957449L,
-t0z3_l =  4.461599916947014419045492615933551648857380e-35L
+	t0z3 = 0.8197731011005006017878687049216069516957449L,
+	t0z3_l = 4.461599916947014419045492615933551648857380e-35L
 #endif
 ;
-/* INDENT ON */
 
 /*
  * gamma(x+i) for 0 <= x < 1
  */
 static struct LDouble
-gam_n(int i, long double x) {
-	struct LDouble rr = {0.0L, 0.0L}, yy;
+gam_n(int i, long double x)
+{
+	struct LDouble rr = { 0.0L, 0.0L }, yy;
 	long double r1, r2, t2, z, xh, xl, yh, yl, zh, z1, z2, zl, x5, wh, wl;
 
 	/* compute yy = gamma(x+1) */
@@ -901,26 +922,27 @@
 		t2 = r1 - r2;
 		yy = GT1(r2, t2 - t0z1_l);
 	}
+
 	/* compute gamma(x+i) = (x+i-1)*...*(x+1)*yy, 0<i<8 */
 	switch (i) {
-	case 0:		/* yy/x */
+	case 0:				/* yy/x */
 		r1 = one / x;
 		xh = CHOPPED((x));	/* x is not tiny */
 		rr.h = CHOPPED(((yy.h + yy.l) * r1));
-		rr.l = r1 * (yy.h - rr.h * xh) - ((r1 * rr.h) * (x - xh) -
-			r1 * yy.l);
+		rr.l = r1 * (yy.h - rr.h * xh) - ((r1 * rr.h) * (x - xh) - r1 *
+		    yy.l);
 		break;
-	case 1:		/* yy */
+	case 1:				/* yy */
 		rr.h = yy.h;
 		rr.l = yy.l;
 		break;
-	case 2:		/* (x+1)*yy */
-		z = x + one;	/* may not be exact */
+	case 2:				/* (x+1)*yy */
+		z = x + one;		/* may not be exact */
 		zh = CHOPPED((z));
 		rr.h = zh * yy.h;
 		rr.l = z * yy.l + (x - (zh - one)) * yy.h;
 		break;
-	case 3:		/* (x+2)*(x+1)*yy */
+	case 3:				/* (x+2)*(x+1)*yy */
 		z1 = x + one;
 		z2 = x + 2.0L;
 		z = z1 * z2;
@@ -932,7 +954,7 @@
 		rr.l = z * yy.l + xl * yy.h;
 		break;
 
-	case 4:		/* (x+1)*(x+3)*(x+2)*yy */
+	case 4:				/* (x+1)*(x+3)*(x+2)*yy */
 		z1 = x + 2.0L;
 		z2 = (x + one) * (x + 3.0L);
 		zh = CHOPPED(z1);
@@ -948,7 +970,7 @@
 		rr.l = z2 * wl + xl * wh;
 
 		break;
-	case 5:		/* ((x+1)*(x+4)*(x+2)*(x+3))*yy */
+	case 5:				/* ((x+1)*(x+4)*(x+2)*(x+3))*yy */
 		z1 = x + 2.0L;
 		z2 = x + 3.0L;
 		z = z1 * z2;
@@ -962,7 +984,7 @@
 		rr.h = xh * yy.h;
 		rr.l = z * yy.l + xl * yy.h;
 		break;
-	case 6:		/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5))*yy */
+	case 6:				/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5))*yy */
 		z1 = x + 2.0L;
 		z2 = x + 3.0L;
 		z = z1 * z2;
@@ -976,14 +998,17 @@
 		xh = CHOPPED(z);
 		zh += 3.0;
 		xl = yl * (z2 + yh) - (xh - yh * (yh - 2.0L));
-						/* xh+xl=(x+1)*...*(x+4) */
-		/* wh+wl=(x+5)*yy */
+
+		/*
+		 * xh+xl=(x+1)*...*(x+4)
+		 * wh+wl=(x+5)*yy
+		 */
 		wh = CHOPPED((x5 * (yy.h + yy.l)));
 		wl = (z1 * yy.h + x5 * yy.l) - (wh - zh * yy.h);
 		rr.h = wh * xh;
 		rr.l = z * wl + xl * wh;
 		break;
-	case 7:		/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5)*(x+6))*yy */
+	case 7:			/* ((x+1)*(x+2)*(x+3)*(x+4)*(x+5)*(x+6))*yy */
 		z1 = x + 3.0L;
 		z2 = x + 4.0L;
 		z = z2 * z1;
@@ -991,23 +1016,28 @@
 		yh = CHOPPED((z));	/* yh+yl = (x+3)(x+4) */
 		yl = (x - (zh - 3.0L)) * (z2 + zh) - (yh - (zh * (zh + one)));
 		z1 = x + 6.0L;
-		z2 = z - 2.0L;	/* z2 = (x+2)*(x+5) */
+		z2 = z - 2.0L;		/* z2 = (x+2)*(x+5) */
 		z *= z2;
 		xh = CHOPPED((z));
 		xl = yl * (z2 + yh) - (xh - yh * (yh - 2.0L));
-						/* xh+xl=(x+2)*...*(x+5) */
-		/* wh+wl=(x+1)(x+6)*yy */
-		z2 -= 4.0L;	/* z2 = (x+1)(x+6) */
+
+		/*
+		 * xh+xl=(x+2)*...*(x+5)
+		 * wh+wl=(x+1)(x+6)*yy
+		 */
+		z2 -= 4.0L;		/* z2 = (x+1)(x+6) */
 		wh = CHOPPED((z2 * (yy.h + yy.l)));
 		wl = (z2 * yy.l + yl * yy.h) - (wh - (yh - 6.0L) * yy.h);
 		rr.h = wh * xh;
 		rr.l = z * wl + xl * wh;
 	}
+
 	return (rr);
 }
 
 long double
-tgammal(long double x) {
+tgammal(long double x)
+{
 	struct LDouble ss, ww;
 	long double t, t1, t2, t3, t4, t5, w, y, z, z1, z2, z3, z5;
 	int i, j, m, ix, hx, xk;
@@ -1017,26 +1047,32 @@
 	lx = H3_WORD(x);
 	ix = hx & 0x7fffffff;
 	y = x;
-	if (ix < 0x3f8e0000) {	/* x < 2**-113 */
+
+	if (ix < 0x3f8e0000)		/* x < 2**-113 */
 		return (one / x);
-	}
+
 	if (ix >= 0x7fff0000)
-		return (x * ((hx < 0)? zero : x));	/* Inf or NaN */
-	if (x > overflow)	/* overflow threshold */
+		return (x * ((hx < 0) ? zero : x));	/* Inf or NaN */
+
+	if (x > overflow)				/* overflow threshold */
 		return (x * 1.0e4932L);
-	if (hx >= 0x40020000) {	/* x >= 8 */
+
+	if (hx >= 0x40020000) {				/* x >= 8 */
 		ww = large_gam(x, &m);
 		w = ww.h + ww.l;
 		return (scalbnl(w, m));
 	}
 
-	if (hx > 0) {		/* 0 < x < 8 */
-		i = (int) x;
-		ww = gam_n(i, x - (long double) i);
+	if (hx > 0) {			/* 0 < x < 8 */
+		i = (int)x;
+		ww = gam_n(i, x - (long double)i);
 		return (ww.h + ww.l);
 	}
-	/* INDENT OFF */
-	/* negative x */
+
+	/*
+	 * negative x
+	 */
+
 	/*
 	 * compute xk =
 	 *	-2 ... x is an even int (-inf is considered an even #)
@@ -1044,16 +1080,15 @@
 	 *	+0 ... x is not an int but chopped to an even int
 	 *	+1 ... x is not an int but chopped to an odd int
 	 */
-	/* INDENT ON */
 	xk = 0;
 #if defined(__x86)
-	if (ix >= 0x403e0000) {	/* x >= 2**63 } */
+	if (ix >= 0x403e0000) {		/* x >= 2**63 } */
 		if (ix >= 0x403f0000)
 			xk = -2;
 		else
 			xk = -2 + (lx & 1);
 #else
-	if (ix >= 0x406f0000) {	/* x >= 2**112 */
+	if (ix >= 0x406f0000) {		/* x >= 2**112 */
 		if (ix >= 0x40700000)
 			xk = -2;
 		else
@@ -1064,6 +1099,7 @@
 		t1 = floorl(w);
 		t2 = t1 * half;
 		t3 = floorl(t2);
+
 		if (t1 == w) {
 			if (t2 == t3)
 				xk = -2;
@@ -1079,7 +1115,7 @@
 
 	if (xk < 0) {
 		/* return NaN. Ideally gamma(-n)= (-1)**(n+1) * inf */
-		return (x - x) / (x - x);
+		return ((x - x) / (x - x));
 	}
 
 	/*
@@ -1087,30 +1123,35 @@
 	 */
 	if (x < -1774.0000000000000000000000000000017749370L) {
 		z = tiny / x;
+
 		if (xk == 1)
 			z = -z;
+
 		return (z * tiny);
 	}
 
-	/* INDENT OFF */
+
 	/*
 	 * now compute gamma(x) by  -1/((sin(pi*y)/pi)*gamma(1+y)), y = -x
 	 */
+
 	/*
 	 * First compute ss = -sin(pi*y)/pi so that
 	 * gamma(x) = 1/(ss*gamma(1+y))
 	 */
-	/* INDENT ON */
 	y = -x;
-	j = (int) y;
-	z = y - (long double) j;
-	if (z > 0.3183098861837906715377675L)
+	j = (int)y;
+	z = y - (long double)j;
+
+	if (z > 0.3183098861837906715377675L) {
 		if (z > 0.6816901138162093284622325L)
 			ss = kpsin(one - z);
 		else
 			ss = kpcos(0.5L - z);
-	else
+	} else {
 		ss = kpsin(z);
+	}
+
 	if (xk == 0) {
 		ss.h = -ss.h;
 		ss.l = -ss.l;
@@ -1118,14 +1159,17 @@
 
 	/* Then compute ww = gamma(1+y), note that result scale to 2**m */
 	m = 0;
+
 	if (j < 7) {
 		ww = gam_n(j + 1, z);
 	} else {
 		w = y + one;
+
 		if ((lx & 1) == 0) {	/* y+1 exact (note that y<184) */
 			ww = large_gam(w, &m);
 		} else {
 			t = w - one;
+
 			if (t == y) {	/* y+one exact */
 				ww = large_gam(w, &m);
 			} else {	/* use y*gamma(y) */
@@ -1133,10 +1177,11 @@
 					ww = gam_n(j, z);
 				else
 					ww = large_gam(y, &m);
+
 				t4 = ww.h + ww.l;
 				t1 = CHOPPED((y));
 				t2 = CHOPPED((t4));
-						/* t4 will not be too large */
+				/* t4 will not be too large */
 				ww.l = y * (ww.l - (t2 - ww.h)) + (y - t1) * t2;
 				ww.h = t1 * t2;
 			}
--- old/usr/src/lib/libm/common/m9x/trunc.c	2019-06-06 20:40:39.583604855 +0000
+++ new/usr/src/lib/libm/common/m9x/trunc.c	2019-06-06 20:40:39.602644093 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,17 +33,20 @@
 #include "libm.h"
 
 double
-trunc(double x) {
+trunc(double x)
+{
 	union {
 		unsigned i[2];
 		double d;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.d = x;
 	hx = xx.i[HIWORD] & ~0x80000000;
 	sx = xx.i[HIWORD] & 0x80000000;
-	if (hx < 0x43300000) {	/* |x| < 2^52 */
+
+	if (hx < 0x43300000) {		/* |x| < 2^52 */
 		if (hx < 0x3ff00000)	/* |x| < 1 */
 			return (sx ? -0.0 : 0.0);
 
@@ -55,14 +59,17 @@
 			i = 1 << (0x432 - (hx >> 20));
 			xx.i[LOWORD] &= ~(i | (i - 1));
 		}
+
 		return (xx.d);
-	} else if (hx < 0x7ff00000)
+	} else if (hx < 0x7ff00000) {
 		return (x);
-	else
+	} else {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (hx >= 0x7ff80000 ? x : x + x);
-		/* assumes sparc-like QNaN */
+
+	/* assumes sparc-like QNaN */
 #else
 		return (x + x);
 #endif
+	}
 }
--- old/usr/src/lib/libm/common/m9x/truncf.c	2019-06-06 20:40:40.095564605 +0000
+++ new/usr/src/lib/libm/common/m9x/truncf.c	2019-06-06 20:40:40.115430366 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -32,30 +33,34 @@
 #include "libm.h"
 
 float
-truncf(float x) {
+truncf(float x)
+{
 	union {
 		unsigned i;
 		float f;
 	} xx;
+
 	unsigned hx, sx, i;
 
 	xx.f = x;
 	hx = xx.i & ~0x80000000;
 	sx = xx.i & 0x80000000;
+
 	if (hx < 0x4b000000) {		/* |x| < 2^23 */
-		if (hx < 0x3f800000)		/* |x| < 1 */
+		if (hx < 0x3f800000)	/* |x| < 1 */
 			return (sx ? -0.0F : 0.0F);
 
 		/* chop x at the integer bit */
 		i = 1 << (0x95 - (hx >> 23));
 		xx.i &= ~((i << 1) - 1);
 		return (xx.f);
-	} else if (hx < 0x7f800000)	/* |x| is integral */
+	} else if (hx < 0x7f800000) {	/* |x| is integral */
 		return (x);
-	else
+	} else {
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (hx > 0x7f800000 ? x * x : x + x);
 #else
 		return (x + x);
 #endif
+	}
 }
--- old/usr/src/lib/libm/common/m9x/truncl.c	2019-06-06 20:40:40.621781576 +0000
+++ new/usr/src/lib/libm/common/m9x/truncl.c	2019-06-06 20:40:40.639426719 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -33,11 +34,13 @@
 
 #if defined(__sparc)
 long double
-truncl(long double x) {
+truncl(long double x)
+{
 	union {
 		unsigned i[4];
 		long double q;
 	} xx;
+
 	unsigned hx, sx;
 	int j;
 
@@ -46,45 +49,51 @@
 	hx = xx.i[0] & ~0x80000000;
 
 	/* handle trivial cases */
-	if (hx >= 0x406f0000) /* |x| >= 2^112 + ... or x is nan */
+	if (hx >= 0x406f0000)		/* |x| >= 2^112 + ... or x is nan */
 		return (hx >= 0x7fff0000 ? x + x : x);
 
 	/* handle |x| < 1 */
 	if (hx < 0x3fff0000)
 		return (sx ? -0.0L : 0.0L);
 
-	j = 0x406f - (hx >> 16);		/* 1 <= j <= 112 */
+	j = 0x406f - (hx >> 16);	/* 1 <= j <= 112 */
 	xx.i[0] = hx;
-	if (j >= 96) {				/* 96 <= j <= 112 */
+
+	if (j >= 96) {			/* 96 <= j <= 112 */
 		xx.i[0] &= ~((1 << (j - 96)) - 1);
 		xx.i[1] = xx.i[2] = xx.i[3] = 0;
-	} else if (j >= 64) {			/* 64 <= j <= 95 */
+	} else if (j >= 64) {		/* 64 <= j <= 95 */
 		xx.i[1] &= ~((1 << (j - 64)) - 1);
 		xx.i[2] = xx.i[3] = 0;
-	} else if (j >= 32) {			/* 32 <= j <= 63 */
+	} else if (j >= 32) {		/* 32 <= j <= 63 */
 		xx.i[2] &= ~((1 << (j - 32)) - 1);
 		xx.i[3] = 0;
-	} else					/* 1 <= j <= 31 */
+	} else {			/* 1 <= j <= 31 */
 		xx.i[3] &= ~((1 << j) - 1);
+	}
 
 	/* negate result if need be */
 	if (sx)
 		xx.i[0] |= 0x80000000;
+
 	return (xx.q);
 }
 #elif defined(__x86)
 long double
-truncl(long double x) {
+truncl(long double x)
+{
 	union {
 		unsigned i[3];
 		long double e;
 	} xx;
+
 	int ex, sx, i;
 
 	xx.e = x;
 	ex = xx.i[2] & 0x7fff;
 	sx = xx.i[2] & 0x8000;
-	if (ex < 0x403e) {	/* |x| < 2^63 */
+
+	if (ex < 0x403e) {		/* |x| < 2^63 */
 		if (ex < 0x3fff)	/* |x| < 1 */
 			return (sx ? -0.0L : 0.0L);
 
@@ -97,12 +106,14 @@
 			i = 1 << (0x403d - ex);
 			xx.i[0] &= ~(i | (i - 1));
 		}
+
 		return (xx.e);
-	} else if (ex < 0x7fff)	/* x is integral */
+	} else if (ex < 0x7fff) {	/* x is integral */
 		return (x);
-	else			/* inf or nan */
+	} else {			/* inf or nan */
 		return (x + x);
+	}
 }
 #else
 #error Unknown architecture
-#endif	/* defined(__sparc) || defined(__x86) */
+#endif /* defined(__sparc) || defined(__x86) */
--- old/usr/src/lib/libm/i386/src/libm_inlines.h	2019-06-06 20:40:41.126566887 +0000
+++ new/usr/src/lib/libm/i386/src/libm_inlines.h	2019-06-06 20:40:41.143859692 +0000
@@ -34,7 +34,6 @@
 #define	_LIBM_INLINES_H
 
 #ifdef __GNUC__
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -261,8 +260,9 @@
 }
 
 extern __GNU_INLINE double
-rint(double a) {
-    return (__inline_rint(a));
+rint(double a)
+{
+	return (__inline_rint(a));
 }
 
 extern __GNU_INLINE double
@@ -345,7 +345,5 @@
 #ifdef __cplusplus
 }
 #endif
-
 #endif  /* __GNUC__ */
-
 #endif /* _LIBM_INLINES_H */
--- old/usr/src/lib/libm/sparc/src/libm_inlines.h	2019-06-06 20:40:41.627526984 +0000
+++ new/usr/src/lib/libm/sparc/src/libm_inlines.h	2019-06-06 20:40:41.645407942 +0000
@@ -34,7 +34,6 @@
 #define	_LIBM_INLINES_H
 
 #ifdef __GNUC__
-
 #include <sys/types.h>
 #include <sys/ieeefp.h>
 
@@ -120,47 +119,47 @@
 	uint32_t tmp;
 
 	__asm__ __volatile__(
-	    "sethi %%hi(0x80000000),%1\n\t"	/* %1 gets 80000000 */
-	    "andn  %2,%1,%0\n\t"		/* %2-%0 gets abs(x) */
-	    "orcc  %0,%3,%%g0\n\t"		/* set cc as x is zero/nonzero */
-	    "bne   1f\n\t"			/* branch if x is nonzero */
+	    "sethi %%hi(0x80000000),%1\n\t" /* %1 gets 80000000 */
+	    "andn  %2,%1,%0\n\t"	    /* %2-%0 gets abs(x) */
+	    "orcc  %0,%3,%%g0\n\t"	    /* set cc as x is zero/nonzero */
+	    "bne   1f\n\t"		    /* branch if x is nonzero */
 	    "nop\n\t"
 	    "mov   0,%0\n\t"
-	    "ba	   2f\n\t"			/* x is 0 */
+	    "ba	   2f\n\t"	/* x is 0 */
 	    "nop\n\t"
 	    "1:\n\t"
-	    "sethi %%hi(0x7ff00000),%1\n\t"	/* %1 gets 7ff00000 */
-	    "andcc %0,%1,%%g0\n\t"		/* cc set by __exp field of x */
-	    "bne   1f\n\t"			/* branch if normal or max __exp */
+	    "sethi %%hi(0x7ff00000),%1\n\t" /* %1 gets 7ff00000 */
+	    "andcc %0,%1,%%g0\n\t"	    /* cc set by __exp field of x */
+	    "bne   1f\n\t"	/* branch if normal or max __exp */
 	    "nop\n\t"
 	    "mov   1,%0\n\t"
-	    "ba	   2f\n\t"			/* x is subnormal */
+	    "ba	   2f\n\t"	/* x is subnormal */
 	    "nop\n\t"
 	    "1:\n\t"
 	    "cmp   %0,%1\n\t"
-	    "bge   1f\n\t"			/* branch if x is max __exp */
+	    "bge   1f\n\t"	/* branch if x is max __exp */
 	    "nop\n\t"
 	    "mov   2,%0\n\t"
-	    "ba	   2f\n\t"			/* x is normal */
+	    "ba	   2f\n\t"	/* x is normal */
 	    "nop\n\t"
 	    "1:\n\t"
-	    "andn  %0,%1,%0\n\t"		/* o0 gets msw __significand field */
-	    "orcc  %0,%3,%%g0\n\t"		/* set cc by OR __significand */
-	    "bne   1f\n\t"			/* Branch if __nan */
+	    "andn  %0,%1,%0\n\t"   /* o0 gets msw __significand field */
+	    "orcc  %0,%3,%%g0\n\t" /* set cc by OR __significand */
+	    "bne   1f\n\t"	   /* Branch if __nan */
 	    "nop\n\t"
 	    "mov   3,%0\n\t"
-	    "ba	   2f\n\t"			/* x is __infinity */
+	    "ba	   2f\n\t"	/* x is __infinity */
 	    "nop\n\t"
 	    "1:\n\t"
 	    "sethi %%hi(0x00080000),%1\n\t"
-	    "andcc %0,%1,%%g0\n\t"		/* set cc by quiet/sig bit */
-	    "be	   1f\n\t"			/* Branch if signaling */
+	    "andcc %0,%1,%%g0\n\t" /* set cc by quiet/sig bit */
+	    "be	   1f\n\t"	   /* Branch if signaling */
 	    "nop\n\t"
-	    "mov   4,%0\n\t"			/* x is quiet NaN */
+	    "mov   4,%0\n\t"	/* x is quiet NaN */
 	    "ba	   2f\n\t"
 	    "nop\n\t"
 	    "1:\n\t"
-	    "mov   5,%0\n\t"			/* x is signaling NaN */
+	    "mov   5,%0\n\t"	/* x is signaling NaN */
 	    "2:\n\t"
 	    : "=&r" (ret), "=&r" (tmp)
 	    : "r" (_HI_WORD(d)), "r" (_LO_WORD(d))
@@ -246,8 +245,8 @@
 	    "sll  %0,23,%2\n\t"		/* shift input to TEM bit location */
 	    ".volatile\n\t"
 	    "st   %%fsr,%1\n\t"
-	    "ld	  %1,%0\n\t"		/* %0 = fsr */
-	    "set  0x0f800000,%3\n\t"	/* mask of TEM (Trap Enable Mode bits) */
+	    "ld	  %1,%0\n\t"	/* %0 = fsr */
+	    "set  0x0f800000,%3\n\t" /* mask of TEM (Trap Enable Mode bits) */
 	    "andn %0,%3,%3\n\t"
 	    "or   %2,%3,%2\n\t"		/* %2 = new fsr */
 	    "st	  %2,%1\n\t"
@@ -295,7 +294,5 @@
 #ifdef __cplusplus
 }
 #endif
-
 #endif	/* __GNUC */
-
 #endif /* _LIBM_INLINES_H */
--- old/usr/src/lib/libm/sparcv9/src/libm_inlines.h	2019-06-06 20:40:42.163496906 +0000
+++ new/usr/src/lib/libm/sparcv9/src/libm_inlines.h	2019-06-06 20:40:42.181807453 +0000
@@ -34,7 +34,6 @@
 #define	_LIBM_INLINES_H
 
 #ifdef __GNUC__
-
 #include <sys/types.h>
 #include <sys/ieeefp.h>
 
@@ -292,7 +291,5 @@
 #ifdef __cplusplus
 }
 #endif
-
 #endif  /* __GNUC__ */
-
 #endif /* _LIBM_INLINES_H */
